(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 9.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       157,          7]
NotebookDataLength[   2948079,      52127]
NotebookOptionsPosition[   2947285,      52097]
NotebookOutlinePosition[   2947641,      52113]
CellTagsIndexPosition[   2947598,      52110]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{
    RowBox[{
     RowBox[{
     "analyze", " ", "the", " ", "evolution", " ", "fo", " ", "the", " ", 
      "different", " ", "types", " ", "of", " ", "crime", " ", "in", " ", 
      "the", " ", "city", " ", "of", " ", "Chicago", " ", "and", " ", "how", 
      " ", "they", " ", "are", " ", "related", " ", "to", " ", "each", " ", 
      "other"}], " ", "-", " ", 
     RowBox[{
     "take", " ", "an", " ", "approach", " ", "similar", " ", "to", " ", 
      "the", " ", "BBVA", " ", "app", " ", "where", " ", "each", " ", "block",
       " ", "can", " ", "vote", " ", "on", " ", "how", " ", "crimes", " ", 
      "are", " ", "related", " ", "of", " ", "not"}]}], ",", " ", 
    RowBox[{
    "then", " ", "look", " ", "that", " ", "the", " ", "structure", " ", "of",
      " ", "the", " ", "emerging", " ", 
     RowBox[{"network", ".", "\[IndentingNewLine]", 
      RowBox[{"author", ":", " ", 
       RowBox[{"Jorge", " ", "Finke", " ", 
        RowBox[{"(", 
         RowBox[{
          RowBox[{"finke", "@", "ieee"}], ".", "org"}], ")"}]}]}]}]}]}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"Table", " ", 
    RowBox[{"headers", ":", "\[IndentingNewLine]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"1", ":", "\"\<IncidntNum\>\""}], ",", 
       RowBox[{"2", ":", "\"\<Category\>\""}], ",", 
       RowBox[{"3", ":", "\"\<Descript\>\""}], ",", 
       RowBox[{"4", ":", "\"\<DayOfWeek\>\""}], ",", 
       RowBox[{"5", ":", "\"\<Date\>\""}], ",", 
       RowBox[{"6", ":", "\"\<Time\>\""}], ",", 
       RowBox[{"7", ":", "\"\<PdDistrict\>\""}], ",", 
       RowBox[{"8", ":", "\"\<Resolution\>\""}], ",", 
       RowBox[{"9", ":", "\"\<Address\>\""}], ",", 
       RowBox[{"10", ":", "\"\<X\>\""}], ",", 
       RowBox[{"11", ":", "\"\<Y\>\""}], ",", 
       RowBox[{"12", ":", "\"\<Location\>\""}]}], "}"}]}]}], 
   "\[IndentingNewLine]", "*)"}], " ", "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"ClearAll", "[", "\"\<Global`*\>\"", "]"}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"SetDirectory", "@", 
     RowBox[{"NotebookDirectory", "[", "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"Import", "[", 
      RowBox[{
      "\"\<SFPD_Incidents_-_Previous_Three_Months.csv\>\"", ",", 
       "\"\<Data\>\""}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"categories", "=", 
     RowBox[{"DeleteDuplicates", "[", 
      RowBox[{"data", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"2", ";;", "All"}], ",", "2"}], "\[RightDoubleBracket]"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"dates", "=", 
     RowBox[{"DeleteDuplicates", "[", 
      RowBox[{"data", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"2", ";;", "All"}], ",", "5"}], "\[RightDoubleBracket]"}], 
      "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"data", "=", 
     RowBox[{"Drop", "[", 
      RowBox[{"data", ",", "None", ",", 
       RowBox[{"{", 
        RowBox[{"10", ",", "11"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"data", "\[LeftDoubleBracket]", 
      RowBox[{
       RowBox[{"2", ";;", "All"}], ",", 
       RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}], "=", 
     RowBox[{
      RowBox[{
       RowBox[{"ToExpression", "[", 
        RowBox[{"StringSplit", "[", 
         RowBox[{"StringReplace", "[", 
          RowBox[{"#", ",", 
           RowBox[{
            RowBox[{"{", 
             RowBox[{"\"\<(\>\"", ",", "\"\<)\>\"", ",", "\"\<,\>\""}], "}"}],
             "\[Rule]", "\"\<\>\""}]}], "]"}], "]"}], "]"}], " ", "&"}], "/@", 
      RowBox[{"data", "\[LeftDoubleBracket]", 
       RowBox[{
        RowBox[{"2", ";;", "All"}], ",", 
        RowBox[{"-", "1"}]}], "\[RightDoubleBracket]"}]}]}], " ", ";", 
    RowBox[{"(*", 
     RowBox[{
     "eliminate", " ", "separate", " ", "x", " ", "and", " ", "y", " ", 
      "coordinates", " ", "and", " ", "convert", " ", "location", " ", "to", 
      " ", "an", " ", "expression"}], "*)"}], "\n", 
    RowBox[{"data", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Select", "[", 
        RowBox[{"data", ",", " ", 
         RowBox[{
          RowBox[{
           RowBox[{
           "#", "\[LeftDoubleBracket]", "5", "\[RightDoubleBracket]"}], "==", 
           
           RowBox[{
           "dates", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}]}], 
          "&"}]}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", 
         RowBox[{"Length", "[", "dates", "]"}], ",", "1", ",", 
         RowBox[{"-", "1"}]}], "}"}]}], "]"}]}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{"chage", " ", "dimensions"}], " ", "-", " ", 
      RowBox[{
      "the", " ", "first", " ", "level", " ", "represents", " ", "the", " ", 
       "most", " ", "recent", " ", "day"}]}], "*)"}], "\n", 
    RowBox[{"(*", "variables", "*)"}], "\[IndentingNewLine]", 
    RowBox[{"w", "=", "2"}], ";", " ", 
    RowBox[{"(*", 
     RowBox[{
     "time", " ", "window", " ", "within", " ", "which", " ", "two", " ", 
      "events", " ", "are", " ", "considered", " ", "concurrent"}], "*)"}], 
    "\[IndentingNewLine]", 
    RowBox[{"r", "=", "0.04"}], " ", ";", 
    RowBox[{"(*", 
     RowBox[{
      RowBox[{
      "geographical", " ", "radius", " ", "within", " ", "which", " ", "two", 
       " ", "events", " ", "are", " ", "considered", " ", "in", " ", "close", 
       " ", "vecinity"}], " ", "-", " ", 
      RowBox[{
      "0.4", " ", "is", " ", "the", " ", "averga", " ", "distance", " ", 
       "between", " ", "incidents"}]}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"T", "=", 
     RowBox[{"12", "-", "w"}]}], ";", 
    RowBox[{"(*", 
     RowBox[{
     "total", " ", "number", " ", "of", " ", "days", " ", "to", " ", 
      "visualize"}], "*)"}], "\n", 
    RowBox[{"(*", 
     RowBox[{
     "computes", " ", "distances", " ", "to", " ", "event", " ", "occuring", 
      " ", "during", " ", "the", " ", "same", " ", "day", " ", "and", " ", 
      "during", " ", "past", " ", "days", " ", "within", " ", "the", " ", 
      "time", " ", "window"}], "*)"}], "\[IndentingNewLine]", 
    RowBox[{"distances", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"Norm", "[", 
          RowBox[{
           RowBox[{"data", "\[LeftDoubleBracket]", 
            RowBox[{"k", ",", "i", ",", "10"}], "\[RightDoubleBracket]"}], 
           "-", "#"}], "]"}], "&"}], "/@", 
        RowBox[{"data", "\[LeftDoubleBracket]", 
         RowBox[{
          RowBox[{"k", "+", "t"}], ",", "All", ",", "10"}], 
         "\[RightDoubleBracket]"}]}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "w"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{
          "data", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
          "]"}]}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{
    "includes", " ", "related", " ", "intances", " ", "for", " ", "diffent", 
     " ", "time", " ", "windows"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"relatedInstances", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"data", "\[LeftDoubleBracket]", 
        RowBox[{
         RowBox[{"k", "+", "t"}], ",", 
         RowBox[{"Flatten", "[", 
          RowBox[{"Position", "[", 
           RowBox[{
            RowBox[{"distances", "\[LeftDoubleBracket]", 
             RowBox[{
              RowBox[{"1", "+", "t"}], ",", "k", ",", "i"}], 
             "\[RightDoubleBracket]"}], ",", 
            RowBox[{"_", "?", 
             RowBox[{"(", 
              RowBox[{
               RowBox[{"#", "<", 
                RowBox[{"r", "/", "10"}]}], "&"}], ")"}]}]}], "]"}], "]"}], 
         ",", "1"}], "\[RightDoubleBracket]"}], ",", 
       RowBox[{"{", 
        RowBox[{"t", ",", "0", ",", "w"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{
          "data", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
          "]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"crimeRelations", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Count", "[", 
        RowBox[{
         RowBox[{"Flatten", "[", 
          RowBox[{
           RowBox[{
            RowBox[{"Cases", "[", 
             RowBox[{
              RowBox[{"Flatten", "[", 
               RowBox[{
                RowBox[{"data", "\[LeftDoubleBracket]", 
                 RowBox[{
                  RowBox[{"k", ";;", 
                   RowBox[{"k", "+", "w"}]}], ",", "All", ",", 
                  RowBox[{"{", 
                   RowBox[{"1", ",", "2"}], "}"}]}], 
                 "\[RightDoubleBracket]"}], ",", "1"}], "]"}], ",", 
              RowBox[{
               RowBox[{"{", 
                RowBox[{"#", ",", "a_"}], "}"}], "\[Rule]", "a"}]}], "]"}], 
            "&"}], "/@", 
           RowBox[{"DeleteDuplicates", "[", 
            RowBox[{"Flatten", "[", 
             RowBox[{"Union", "[", 
              RowBox[{"relatedInstances", "\[LeftDoubleBracket]", 
               RowBox[{"All", ",", "k", ",", "i"}], "\[RightDoubleBracket]"}],
               "]"}], "]"}], "]"}]}], "]"}], ",", "type"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"type", ",", "categories"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"i", ",", "1", ",", 
         RowBox[{"Length", "[", 
          RowBox[{
          "data", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
          "]"}]}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"temp", "=", 
     RowBox[{"Total", "[", 
      RowBox[{"crimeRelations", ",", 
       RowBox[{"{", "3", "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"ListPlot", "[", 
    RowBox[{
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"T", "-", "k", "+", "1"}], ",", 
         RowBox[{"temp", "\[LeftDoubleBracket]", 
          RowBox[{"k", ",", "p"}], "\[RightDoubleBracket]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "1", ",", "34"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}], ",", 
     RowBox[{"PlotRange", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"1", ",", "T"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"0", ",", "2700"}], "}"}]}], "}"}]}], ",", 
     RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]}]}]], "Input",
 CellChangeTimes->{
  3.607874742258964*^9, {3.6078768406393147`*^9, 3.607876903993575*^9}, 
   3.6078783443008823`*^9, 3.607878390783256*^9, {3.607878429164352*^9, 
   3.6078784297930517`*^9}, {3.607878739662868*^9, 3.60787885355783*^9}, {
   3.6079460313685226`*^9, 3.607946032157111*^9}, {3.6079478900452127`*^9, 
   3.607947892326209*^9}, {3.607948731849019*^9, 3.6079487479495983`*^9}, {
   3.608053168543264*^9, 3.6080531838325977`*^9}, 3.608057436196753*^9, {
   3.6081225973803663`*^9, 3.608122599206275*^9}, {3.608160102077379*^9, 
   3.608160102150406*^9}, 3.6081601574014387`*^9, {3.6082021918337507`*^9, 
   3.6082021922069397`*^9}, {3.608202229311802*^9, 3.608202289212776*^9}, 
   3.608240276129787*^9, {3.6082436484239397`*^9, 3.6082436567987432`*^9}, {
   3.60824408564684*^9, 3.6082440862526197`*^9}, {3.60825796075049*^9, 
   3.608257960840159*^9}, {3.608258122009047*^9, 3.60825812272943*^9}, {
   3.608283587668364*^9, 3.608283587773842*^9}, {3.608305071310783*^9, 
   3.60830507853067*^9}, {3.608414353760503*^9, 3.608414380523444*^9}}],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.24720000000000014`, 0.24, 0.6], 
     LineBox[{{10., 1861.}, {9., 1602.}, {8., 1933.}, {7., 1670.}, {6., 
      1222.}, {5., 1630.}, {4., 1247.}, {3., 1759.}, {2., 1707.}, {1., 
      2523.}}]}, 
    {RGBColor[0.6, 0.24, 0.4428931686004542], 
     LineBox[{{10., 202.}, {9., 205.}, {8., 231.}, {7., 168.}, {6., 157.}, {
      5., 165.}, {4., 154.}, {3., 205.}, {2., 167.}, {1., 190.}}]}, 
    {RGBColor[0.6, 0.5470136627990908, 0.24], 
     LineBox[{{10., 384.}, {9., 311.}, {8., 349.}, {7., 301.}, {6., 179.}, {
      5., 267.}, {4., 193.}, {3., 304.}, {2., 258.}, {1., 330.}}]}, 
    {RGBColor[0.24, 0.6, 0.33692049419863584`], 
     LineBox[{{10., 223.}, {9., 188.}, {8., 320.}, {7., 52.}, {6., 82.}, {5., 
      175.}, {4., 90.}, {3., 94.}, {2., 30.}, {1., 100.}}]}, 
    {RGBColor[0.24, 0.3531726744018182, 0.6], 
     LineBox[{{10., 466.}, {9., 293.}, {8., 306.}, {7., 194.}, {6., 134.}, {
      5., 223.}, {4., 179.}, {3., 334.}, {2., 265.}, {1., 265.}}]}, 
    {RGBColor[0.6, 0.24, 0.5632658430022722], 
     LineBox[{{10., 136.}, {9., 149.}, {8., 175.}, {7., 178.}, {6., 177.}, {
      5., 206.}, {4., 144.}, {3., 186.}, {2., 133.}, {1., 111.}}]}, 
    {RGBColor[0.6, 0.42664098839727194`, 0.24], 
     LineBox[{{10., 25.}, {9., 24.}, {8., 44.}, {7., 110.}, {6., 96.}, {5., 
      153.}, {4., 74.}, {3., 101.}, {2., 75.}, {1., 156.}}]}, 
    {RGBColor[0.2634521802031821, 0.6, 0.24], 
     LineBox[{{10., 1165.}, {9., 814.}, {8., 909.}, {7., 719.}, {6., 691.}, {
      5., 786.}, {4., 637.}, {3., 840.}, {2., 839.}, {1., 1094.}}]}, 
    {RGBColor[0.24, 0.47354534880363613`, 0.6], 
     LineBox[{{10., 576.}, {9., 440.}, {8., 703.}, {7., 655.}, {6., 499.}, {
      5., 659.}, {4., 528.}, {3., 618.}, {2., 588.}, {1., 642.}}]}, 
    {RGBColor[0.5163614825959097, 0.24, 0.6], 
     LineBox[{{10., 133.}, {9., 137.}, {8., 152.}, {7., 116.}, {6., 75.}, {5.,
       120.}, {4., 106.}, {3., 98.}, {2., 52.}, {1., 76.}}]}, 
    {RGBColor[0.6, 0.3062683139954558, 0.24], 
     LineBox[{{10., 161.}, {9., 186.}, {8., 249.}, {7., 178.}, {6., 82.}, {5.,
       157.}, {4., 105.}, {3., 131.}, {2., 135.}, {1., 266.}}]}, 
    {RGBColor[0.3838248546049982, 0.6, 0.24], 
     LineBox[{{10., 1377.}, {9., 1086.}, {8., 1211.}, {7., 652.}, {6., 
      556.}, {5., 845.}, {4., 712.}, {3., 1070.}, {2., 1127.}, {1., 1561.}}]}, 
    {RGBColor[0.24, 0.5939180232054561, 0.6], 
     LineBox[{{10., 19.}, {9., 24.}, {8., 17.}, {7., 21.}, {6., 13.}, {5., 
      26.}, {4., 26.}, {3., 22.}, {2., 2.}, {1., 23.}}]}, 
    {RGBColor[0.39598880819409377`, 0.24, 0.6], 
     LineBox[{{10., 168.}, {9., 97.}, {8., 93.}, {7., 52.}, {6., 31.}, {5., 
      34.}, {4., 23.}, {3., 15.}, {2., 25.}, {1., 53.}}]}, 
    {RGBColor[0.6, 0.24, 0.2941043604063603], 
     LineBox[{{10., 770.}, {9., 780.}, {8., 928.}, {7., 577.}, {6., 365.}, {
      5., 903.}, {4., 637.}, {3., 921.}, {2., 874.}, {1., 1028.}}]}, 
    {RGBColor[0.5041975290068142, 0.6, 0.24], 
     LineBox[{{10., 543.}, {9., 455.}, {8., 677.}, {7., 537.}, {6., 368.}, {
      5., 511.}, {4., 386.}, {3., 527.}, {2., 629.}, {1., 900.}}]}, 
    {RGBColor[0.24, 0.6, 0.48570930239273163`], 
     LineBox[{{10., 33.}, {9., 64.}, {8., 24.}, {7., 53.}, {6., 106.}, {5., 
      161.}, {4., 116.}, {3., 65.}, {2., 69.}, {1., 74.}}]}, 
    {RGBColor[0.2756161337922776, 0.24, 0.6], 
     LineBox[{{10., 35.}, {9., 37.}, {8., 59.}, {7., 45.}, {6., 22.}, {5., 
      2.}, {4., 2.}, {3., 2.}, {2., 2.}, {1., 11.}}]}, 
    {RGBColor[0.6, 0.24, 0.4144770348081764], 
     LineBox[{{10., 88.}, {9., 72.}, {8., 98.}, {7., 99.}, {6., 79.}, {5., 
      121.}, {4., 168.}, {3., 153.}, {2., 222.}, {1., 217.}}]}, 
    {RGBColor[0.6, 0.5754297965913696, 0.24], 
     LineBox[{{10., 17.}, {9., 5.}, {8., 0.}, {7., 1.}, {6., 2.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 3.}}]}, 
    {RGBColor[0.24, 0.6, 0.36533662799091565`], 
     LineBox[{{10., 2.}, {9., 8.}, {8., 7.}, {7., 0.}, {6., 0.}, {5., 1.}, {
      4., 2.}, {3., 0.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.24, 0.32475654060953846`, 0.6], 
     LineBox[{{10., 3.}, {9., 5.}, {8., 15.}, {7., 11.}, {6., 2.}, {5., 0.}, {
      4., 1.}, {3., 1.}, {2., 24.}, {1., 57.}}]}, 
    {RGBColor[0.6, 0.24, 0.5348497092099924], 
     LineBox[{{10., 3.}, {9., 0.}, {8., 0.}, {7., 25.}, {6., 20.}, {5., 
      26.}, {4., 3.}, {3., 3.}, {2., 1.}, {1., 0.}}]}, 
    {RGBColor[0.6, 0.45505712218955346`, 0.24], 
     LineBox[{{10., 40.}, {9., 36.}, {8., 55.}, {7., 0.}, {6., 0.}, {5., 
      31.}, {4., 15.}, {3., 34.}, {2., 10.}, {1., 19.}}]}, 
    {RGBColor[0.24, 0.6, 0.24496395358909184`], 
     LineBox[{{10., 27.}, {9., 39.}, {8., 44.}, {7., 56.}, {6., 17.}, {5., 
      21.}, {4., 28.}, {3., 20.}, {2., 30.}, {1., 18.}}]}, 
    {RGBColor[0.24, 0.4451292150113622, 0.6], 
     LineBox[{{10., 25.}, {9., 33.}, {8., 29.}, {7., 39.}, {6., 12.}, {5., 
      2.}, {4., 3.}, {3., 7.}, {2., 12.}, {1., 21.}}]}, 
    {RGBColor[0.5447776163881838, 0.24, 0.6], 
     LineBox[{{10., 9.}, {9., 12.}, {8., 2.}, {7., 0.}, {6., 2.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 2.}}]}, 
    {RGBColor[0.6, 0.3346844477877375, 0.24], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.35540872081272423`, 0.6, 0.24], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.24, 0.5655018894131706, 0.6], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.42440494198636775`, 0.24, 0.6], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.6, 0.24, 0.26568822661407865`], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 13.}, {
      4., 8.}, {3., 6.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.4757813952145403, 0.6, 0.24], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 0.}}]}, 
    {RGBColor[0.24, 0.6, 0.514125436184998], 
     LineBox[{{10., 0.}, {9., 0.}, {8., 0.}, {7., 0.}, {6., 0.}, {5., 0.}, {
      4., 0.}, {3., 0.}, {2., 0.}, {1., 46.}}]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->True,
  AxesLabel->{None, None},
  AxesOrigin->{2., 0},
  Method->{},
  PlotRange->{{1, 10}, {0, 2700}},
  PlotRangeClipping->True,
  PlotRangePadding->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.60828047115783*^9, 3.608289381533784*^9, 
  3.608325927816781*^9, 3.608405591543599*^9}]
}, Open  ]],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{"nodes", " ", "=", 
    RowBox[{"ToLowerCase", "[", "categories", "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"adjacencyMatrix", "=", 
   RowBox[{"Table", "[", 
    RowBox[{"0", ",", 
     RowBox[{"{", "T", "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "nodes", "]"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"Length", "[", "nodes", "]"}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"Do", "[", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     RowBox[{"adjacencyMatrix", "\[LeftDoubleBracket]", 
      RowBox[{"k", ",", 
       RowBox[{"Min", "[", 
        RowBox[{"Ordering", "[", 
         RowBox[{
          RowBox[{"crimeRelations", "\[LeftDoubleBracket]", 
           RowBox[{"k", ",", "All", ",", "i"}], "\[RightDoubleBracket]"}], 
          ",", 
          RowBox[{"-", "2"}]}], "]"}], "]"}], ",", 
       RowBox[{"Max", "[", 
        RowBox[{"Ordering", "[", 
         RowBox[{
          RowBox[{"crimeRelations", "\[LeftDoubleBracket]", 
           RowBox[{"k", ",", "All", ",", "i"}], "\[RightDoubleBracket]"}], 
          ",", 
          RowBox[{"-", "2"}]}], "]"}], "]"}]}], "\[RightDoubleBracket]"}], "+=",
      "1"}], ",", "\[IndentingNewLine]", 
    RowBox[{"{", 
     RowBox[{"k", ",", "1", ",", "T"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"i", ",", " ", "1", ",", " ", 
      RowBox[{"Length", "[", 
       RowBox[{"data", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}],
        "]"}]}], "}"}]}], "]"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"links", "=", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"EdgeList", "[", 
       RowBox[{"AdjacencyGraph", "[", 
        RowBox[{"nodes", ",", 
         RowBox[{
         "adjacencyMatrix", "\[LeftDoubleBracket]", "k", 
          "\[RightDoubleBracket]"}], ",", 
         RowBox[{"DirectedEdges", "\[Rule]", "False"}]}], "]"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], ";"}], 
  "\[IndentingNewLine]"}], "\[IndentingNewLine]"}], "Input",
 CellChangeTimes->{{3.607977812218433*^9, 3.6079778180097523`*^9}, {
   3.607977881870563*^9, 3.607977928451105*^9}, {3.6079780603876963`*^9, 
   3.607978107472754*^9}, {3.607978370990415*^9, 3.607978373530891*^9}, {
   3.607979985723448*^9, 3.607980003097787*^9}, {3.6079800855125923`*^9, 
   3.607980085611064*^9}, {3.607982568209482*^9, 3.607982568525558*^9}, {
   3.6079826055365267`*^9, 3.607982770304151*^9}, {3.607982880078272*^9, 
   3.6079829751109962`*^9}, {3.607983029690597*^9, 3.607983047576097*^9}, {
   3.607983194775172*^9, 3.60798321234365*^9}, {3.6079832770050077`*^9, 
   3.607983277091017*^9}, {3.6080528415968513`*^9, 3.60805285743474*^9}, {
   3.608202096210834*^9, 3.6082020965813017`*^9}, {3.608202317719425*^9, 
   3.608202333387636*^9}, {3.6082023979384117`*^9, 3.6082024304780188`*^9}, {
   3.608203895837241*^9, 3.6082038985811453`*^9}, 3.608203938249309*^9, {
   3.6082040726627283`*^9, 3.608204105181567*^9}, {3.608204270733623*^9, 
   3.608204271045889*^9}, {3.608204339139464*^9, 3.60820434857803*^9}, {
   3.608205385914493*^9, 3.608205515445133*^9}, {3.608205574281711*^9, 
   3.608205639053937*^9}, {3.608205679856152*^9, 3.608205695270637*^9}, 
   3.608205978930296*^9, {3.608206083869872*^9, 3.608206140533264*^9}, {
   3.608206170603908*^9, 3.608206552954369*^9}, {3.6082065881293497`*^9, 
   3.608206601940482*^9}, 3.608206805709762*^9, 3.6082068715301323`*^9, 
   3.608207261813567*^9, {3.608207337710417*^9, 3.608207344431747*^9}, 
   3.608207432319302*^9, 3.608207534266992*^9, 3.6082081874820623`*^9, 
   3.6082082528438253`*^9, {3.608208336778491*^9, 3.60820835202892*^9}, {
   3.608208402912332*^9, 3.608208436741755*^9}, {3.6082084900973186`*^9, 
   3.608208535683329*^9}, 3.6082085860712748`*^9, {3.608208639369505*^9, 
   3.608208655170319*^9}, {3.608208701304961*^9, 3.60820871057127*^9}, 
   3.6082088616994*^9, {3.6082088960336943`*^9, 3.608208897924715*^9}, 
   3.6082091011849957`*^9, {3.608209292849011*^9, 3.6082092931994123`*^9}, {
   3.6082095710924997`*^9, 3.6082096222186213`*^9}, 3.608209971303936*^9, 
   3.608210666779703*^9, 3.608211701686781*^9, 3.608211821696969*^9, {
   3.6082215526364183`*^9, 3.608221553328703*^9}, {3.6082217196294193`*^9, 
   3.608221720256304*^9}, 3.608222081638592*^9, {3.6082222524551983`*^9, 
   3.608222253096155*^9}, {3.6082238346949263`*^9, 3.6082238352776823`*^9}, 
   3.608224345136756*^9, 3.608224984266374*^9, {3.608225143578019*^9, 
   3.6082251523204727`*^9}, 3.608226090463711*^9, 3.608226284069804*^9, {
   3.608226407564336*^9, 3.6082264115868597`*^9}, 3.608226500134172*^9, 
   3.60822672597677*^9, {3.6082270672592287`*^9, 3.608227076964695*^9}, {
   3.608227155033907*^9, 3.608227155200012*^9}, 3.60822721915977*^9, {
   3.608227377449988*^9, 3.6082274030250683`*^9}, 3.6082276284545183`*^9, 
   3.608227739143659*^9, {3.608227814544631*^9, 3.6082278174160233`*^9}, {
   3.6082278985654*^9, 3.608227908929591*^9}, {3.6082291429095297`*^9, 
   3.608229175134089*^9}, 3.60823006054576*^9, 3.6082303637567596`*^9, 
   3.608230573308906*^9, {3.6082423616414948`*^9, 3.60824236633585*^9}, {
   3.608243036666108*^9, 3.608243064760461*^9}, {3.6082580130299664`*^9, 
   3.6082580400754137`*^9}, 3.60828947447596*^9, {3.608289515679942*^9, 
   3.6082895268375463`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"(*", 
    RowBox[{"hypothetical", " ", "network"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"links", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"EdgeList", "[", 
        RowBox[{"RandomGraph", "[", 
         RowBox[{"BarabasiAlbertGraphDistribution", "[", 
          RowBox[{
           RowBox[{"Length", "[", "nodes", "]"}], ",", "1"}], "]"}], "]"}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], ";", " ", 
    "\[IndentingNewLine]", 
    RowBox[{"For", " ", "[", 
     RowBox[{
      RowBox[{"k", "=", "1"}], ",", 
      RowBox[{"k", "\[LessEqual]", " ", "T"}], ",", 
      RowBox[{"k", "++"}], ",", "\[IndentingNewLine]", 
      RowBox[{
       RowBox[{
        RowBox[{"vertex", "\[LeftDoubleBracket]", 
         RowBox[{"k", ",", "All", ",", "1"}], "\[RightDoubleBracket]"}], "=", 
        
        RowBox[{"nodes", "\[LeftDoubleBracket]", 
         RowBox[{"vertex", "\[LeftDoubleBracket]", 
          RowBox[{"k", ",", "All", ",", "1"}], "\[RightDoubleBracket]"}], 
         "\[RightDoubleBracket]"}]}], ";", "\[IndentingNewLine]", 
       RowBox[{
        RowBox[{"vertex", "\[LeftDoubleBracket]", 
         RowBox[{"k", ",", "All", ",", "2"}], "\[RightDoubleBracket]"}], "=", 
        
        RowBox[{"nodes", "\[LeftDoubleBracket]", 
         RowBox[{"vertex", "\[LeftDoubleBracket]", 
          RowBox[{"k", ",", "All", ",", "2"}], "\[RightDoubleBracket]"}], 
         "\[RightDoubleBracket]"}]}], ";"}]}], "\[IndentingNewLine]", "]"}]}],
    "\[IndentingNewLine]", "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"vf", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"xc_", ",", "yc_"}], "}"}], ",", "name_", ",", 
      RowBox[{"{", 
       RowBox[{"w_", ",", "h_"}], "}"}]}], "]"}], ":=", 
    RowBox[{"Rectangle", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xc", "-", 
         RowBox[{
          RowBox[{"StringLength", "[", "name", "]"}], "/", "65"}]}], ",", 
        RowBox[{"yc", "-", "h"}]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"xc", "+", "w"}], ",", 
        RowBox[{"yc", "+", "h"}]}], "}"}]}], "]"}]}], " ", 
   RowBox[{"(*", 
    RowBox[{
     RowBox[{"use", " ", "VertexShapeFunction"}], "\[Rule]", " ", "vf"}], 
    "*)"}], "*)"}], "\n", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"coord", "=", 
     RowBox[{
      RowBox[{
       RowBox[{"PropertyValue", "[", 
        RowBox[{
         RowBox[{"{", 
          RowBox[{
           RowBox[{"g", "[", "1", "]"}], ",", "#"}], "}"}], ",", 
         "VertexCoordinates"}], "]"}], "&"}], "/@", 
      RowBox[{"VertexList", "[", 
       RowBox[{"g", "[", "1", "]"}], "]"}]}]}], ";", "\[IndentingNewLine]", 
    RowBox[{"Export", "[", 
     RowBox[{"\"\<coordinates.csv\>\"", ",", "coord"}], "]"}], ";"}], "*)"}], 
  "\[IndentingNewLine]", "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"Export", "[", 
     RowBox[{"\"\<graphs10.graphml\>\"", ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"g", "[", 
         RowBox[{"T", "-", "k", "+", "1"}], "]"}], ",", 
        RowBox[{"{", 
         RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], "]"}], ";"}], 
   "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{
    RowBox[{"grafo", "=", 
     RowBox[{"Import", "[", "\"\<graphs10.graphml\>\"", "]"}]}], ";"}], 
   "*)"}], "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.607977812218433*^9, 3.6079778180097523`*^9}, {
   3.607977881870563*^9, 3.607977928451105*^9}, {3.6079780603876963`*^9, 
   3.607978107472754*^9}, {3.607978370990415*^9, 3.607978373530891*^9}, {
   3.607979985723448*^9, 3.607980003097787*^9}, {3.6079800855125923`*^9, 
   3.607980085611064*^9}, {3.607982568209482*^9, 3.607982568525558*^9}, {
   3.6079826055365267`*^9, 3.607982770304151*^9}, {3.607982880078272*^9, 
   3.6079829751109962`*^9}, {3.607983029690597*^9, 3.607983047576097*^9}, {
   3.607983194775172*^9, 3.60798321234365*^9}, {3.6079832770050077`*^9, 
   3.607983277091017*^9}, {3.6080528415968513`*^9, 3.60805285743474*^9}, {
   3.608202096210834*^9, 3.6082020965813017`*^9}, {3.608202317719425*^9, 
   3.608202333387636*^9}, {3.6082023979384117`*^9, 3.6082024304780188`*^9}, {
   3.608203895837241*^9, 3.6082038985811453`*^9}, 3.608203938249309*^9, {
   3.6082040726627283`*^9, 3.608204105181567*^9}, {3.608204270733623*^9, 
   3.608204271045889*^9}, {3.608204339139464*^9, 3.60820434857803*^9}, {
   3.608205385914493*^9, 3.608205515445133*^9}, {3.608205574281711*^9, 
   3.608205639053937*^9}, {3.608205679856152*^9, 3.608205695270637*^9}, 
   3.608205978930296*^9, {3.608206083869872*^9, 3.608206140533264*^9}, {
   3.608206170603908*^9, 3.608206552954369*^9}, {3.6082065881293497`*^9, 
   3.608206601940482*^9}, 3.608206805709762*^9, 3.6082068715301323`*^9, 
   3.608207261813567*^9, {3.608207337710417*^9, 3.608207344431747*^9}, 
   3.608207432319302*^9, 3.608207534266992*^9, 3.6082081874820623`*^9, 
   3.6082082528438253`*^9, {3.608208336778491*^9, 3.60820835202892*^9}, {
   3.608208402912332*^9, 3.608208436741755*^9}, {3.6082084900973186`*^9, 
   3.608208535683329*^9}, 3.6082085860712748`*^9, {3.608208639369505*^9, 
   3.608208655170319*^9}, {3.608208701304961*^9, 3.60820871057127*^9}, 
   3.6082088616994*^9, {3.6082088960336943`*^9, 3.608208897924715*^9}, 
   3.6082091011849957`*^9, {3.608209292849011*^9, 3.6082092931994123`*^9}, {
   3.6082095710924997`*^9, 3.6082096222186213`*^9}, 3.608209971303936*^9, 
   3.608210666779703*^9, 3.608211701686781*^9, 3.608211821696969*^9, {
   3.6082215526364183`*^9, 3.608221553328703*^9}, {3.6082217196294193`*^9, 
   3.608221720256304*^9}, 3.608222081638592*^9, {3.6082222524551983`*^9, 
   3.608222253096155*^9}, {3.6082238346949263`*^9, 3.6082238352776823`*^9}, 
   3.608224345136756*^9, 3.608224984266374*^9, {3.608225143578019*^9, 
   3.6082251523204727`*^9}, 3.608226090463711*^9, 3.608226284069804*^9, {
   3.608226407564336*^9, 3.6082264115868597`*^9}, 3.608226500134172*^9, 
   3.60822672597677*^9, {3.6082270672592287`*^9, 3.608227076964695*^9}, {
   3.608227155033907*^9, 3.608227155200012*^9}, 3.60822721915977*^9, {
   3.608227377449988*^9, 3.6082274030250683`*^9}, 3.6082276284545183`*^9, 
   3.608227739143659*^9, {3.608227814544631*^9, 3.6082278174160233`*^9}, {
   3.6082278985654*^9, 3.608227908929591*^9}, {3.6082291429095297`*^9, 
   3.608229175134089*^9}, 3.60823006054576*^9, 3.6082303637567596`*^9, 
   3.608230573308906*^9, 3.6082423616414948`*^9, 3.6082430525372753`*^9, {
   3.60824310099352*^9, 3.608243148529737*^9}, {3.608243219804892*^9, 
   3.608243337363318*^9}, {3.60824338857384*^9, 3.6082433892495747`*^9}, 
   3.608243485597725*^9, {3.608256500229047*^9, 3.608256501341155*^9}, {
   3.608258086515444*^9, 3.608258108758542*^9}, {3.608414643105659*^9, 
   3.6084146495579433`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"coord", "=", 
   RowBox[{"Import", "[", "\"\<coordinates.csv\>\"", "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{"g", "[", "k_", "]"}], ":=", 
   RowBox[{"Graph", "[", 
    RowBox[{"nodes", ",", 
     RowBox[{"links", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
     ",", 
     RowBox[{"VertexShape", "\[Rule]", " ", "icons"}], ",", 
     RowBox[{"VertexSize", "\[Rule]", ".75"}], ",", " ", 
     RowBox[{"VertexStyle", "\[Rule]", "White"}], ",", 
     RowBox[{"VertexCoordinates", "\[Rule]", "coord"}], ",", 
     RowBox[{"VertexLabels", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"Placed", "[", 
        RowBox[{"\"\<Name\>\"", ",", "Tooltip"}], "]"}], "}"}]}], ",", 
     RowBox[{"VertexLabelStyle", "\[Rule]", 
      RowBox[{"Directive", "[", 
       RowBox[{"Black", ",", "15", ",", 
        RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
     ",", 
     RowBox[{"ImagePadding", "\[Rule]", "10"}], ",", " ", 
     RowBox[{"ImageSize", "\[Rule]", " ", "640"}], ",", " ", 
     RowBox[{"EdgeStyle", "\[Rule]", 
      RowBox[{"{", "Black", "}"}]}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{"allGraphs", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Column", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"\"\<Date: \>\"", "<>", 
         RowBox[{"dates", "\[LeftDoubleBracket]", 
          RowBox[{"T", "-", "k", "+", "1"}], "\[RightDoubleBracket]"}]}], ",", 
        RowBox[{"g", "[", 
         RowBox[{"T", "-", "k", "+", "1"}], "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"k", ",", "1", ",", 
       RowBox[{"T", "-", "1"}]}], "}"}]}], "]"}]}], 
  ";"}], "\[IndentingNewLine]", 
 RowBox[{"ListAnimate", "[", " ", 
  RowBox[{"allGraphs", ",", 
   RowBox[{"AnimationRunning", "\[Rule]", "False"}]}], "]"}]}], "Input",
 CellChangeTimes->{{3.607977812218433*^9, 3.6079778180097523`*^9}, {
   3.607977881870563*^9, 3.607977928451105*^9}, {3.6079780603876963`*^9, 
   3.607978107472754*^9}, {3.607978370990415*^9, 3.607978373530891*^9}, {
   3.607979985723448*^9, 3.607980003097787*^9}, {3.6079800855125923`*^9, 
   3.607980085611064*^9}, {3.607982568209482*^9, 3.607982568525558*^9}, {
   3.6079826055365267`*^9, 3.607982770304151*^9}, {3.607982880078272*^9, 
   3.6079829751109962`*^9}, {3.607983029690597*^9, 3.607983047576097*^9}, {
   3.607983194775172*^9, 3.60798321234365*^9}, {3.6079832770050077`*^9, 
   3.607983277091017*^9}, {3.6080528415968513`*^9, 3.60805285743474*^9}, {
   3.608202096210834*^9, 3.6082020965813017`*^9}, {3.608202317719425*^9, 
   3.608202333387636*^9}, {3.6082023979384117`*^9, 3.6082024304780188`*^9}, {
   3.608203895837241*^9, 3.6082038985811453`*^9}, 3.608203938249309*^9, {
   3.6082040726627283`*^9, 3.608204105181567*^9}, {3.608204270733623*^9, 
   3.608204271045889*^9}, {3.608204339139464*^9, 3.60820434857803*^9}, {
   3.608205385914493*^9, 3.608205515445133*^9}, {3.608205574281711*^9, 
   3.608205639053937*^9}, {3.608205679856152*^9, 3.608205695270637*^9}, 
   3.608205978930296*^9, {3.608206083869872*^9, 3.608206140533264*^9}, {
   3.608206170603908*^9, 3.608206552954369*^9}, {3.6082065881293497`*^9, 
   3.608206601940482*^9}, 3.608206805709762*^9, 3.6082068715301323`*^9, 
   3.608207261813567*^9, {3.608207337710417*^9, 3.608207344431747*^9}, 
   3.608207432319302*^9, 3.608207534266992*^9, 3.6082081874820623`*^9, 
   3.6082082528438253`*^9, {3.608208336778491*^9, 3.60820835202892*^9}, {
   3.608208402912332*^9, 3.608208436741755*^9}, {3.6082084900973186`*^9, 
   3.608208535683329*^9}, 3.6082085860712748`*^9, {3.608208639369505*^9, 
   3.608208655170319*^9}, {3.608208701304961*^9, 3.60820871057127*^9}, 
   3.6082088616994*^9, {3.6082088960336943`*^9, 3.608208897924715*^9}, 
   3.6082091011849957`*^9, {3.608209292849011*^9, 3.6082092931994123`*^9}, {
   3.6082095710924997`*^9, 3.6082096222186213`*^9}, 3.608209971303936*^9, 
   3.608210666779703*^9, 3.608211701686781*^9, 3.608211821696969*^9, {
   3.6082215526364183`*^9, 3.608221553328703*^9}, {3.6082217196294193`*^9, 
   3.608221720256304*^9}, 3.608222081638592*^9, {3.6082222524551983`*^9, 
   3.608222253096155*^9}, {3.6082238346949263`*^9, 3.6082238352776823`*^9}, 
   3.608224345136756*^9, 3.608224984266374*^9, {3.608225143578019*^9, 
   3.6082251523204727`*^9}, 3.608226090463711*^9, 3.608226284069804*^9, {
   3.608226407564336*^9, 3.6082264115868597`*^9}, 3.608226500134172*^9, 
   3.60822672597677*^9, {3.6082270672592287`*^9, 3.608227076964695*^9}, {
   3.608227155033907*^9, 3.608227155200012*^9}, 3.60822721915977*^9, {
   3.608227377449988*^9, 3.6082274030250683`*^9}, 3.6082276284545183`*^9, 
   3.608227739143659*^9, {3.608227814544631*^9, 3.6082278174160233`*^9}, {
   3.6082278985654*^9, 3.608227908929591*^9}, {3.6082291429095297`*^9, 
   3.608229175134089*^9}, 3.60823006054576*^9, 3.6082303637567596`*^9, 
   3.608230573308906*^9, 3.6082423616414948`*^9, 3.6082430525372753`*^9, {
   3.60824310099352*^9, 3.608243148529737*^9}, {3.608243219804892*^9, 
   3.6082433306038923`*^9}, {3.6082438579385653`*^9, 3.608243860570743*^9}, {
   3.6082454033876867`*^9, 3.6082454077629128`*^9}, {3.6082454499622726`*^9, 
   3.608245506481698*^9}, {3.608245538413718*^9, 3.608245589652573*^9}, {
   3.608245844079069*^9, 3.6082458445711613`*^9}, {3.608246008902788*^9, 
   3.608246185075592*^9}, {3.608246298023922*^9, 3.608246360120145*^9}, {
   3.608246437129201*^9, 3.6082464381937923`*^9}, {3.6082464761784163`*^9, 
   3.6082464812035637`*^9}, {3.6082465253893347`*^9, 3.608246568821353*^9}, {
   3.608246604578223*^9, 3.608246735436955*^9}, 3.608247420103847*^9, {
   3.608247503147881*^9, 3.60824750585672*^9}, {3.6082475833437567`*^9, 
   3.608247587314156*^9}, {3.608247801792288*^9, 3.608247832919334*^9}, {
   3.6082478751071453`*^9, 3.608247981478158*^9}, {3.608248016289901*^9, 
   3.608248035202446*^9}, {3.608248441752404*^9, 3.608248444061926*^9}, {
   3.60824848087635*^9, 3.608248516477655*^9}, {3.6082485905468884`*^9, 
   3.608248596280126*^9}, {3.6082486352839603`*^9, 3.608248644576687*^9}, {
   3.608249937926457*^9, 3.608249945359956*^9}, {3.6082509122987967`*^9, 
   3.608250913558358*^9}, 3.608256505981745*^9, {3.608256690982066*^9, 
   3.6082567134013844`*^9}, {3.608316814629781*^9, 3.608316879079144*^9}, 
   3.608317147663085*^9, {3.608321923409068*^9, 3.608321923544142*^9}}],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`i30$$ = 1, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {
    "\"min\"" :> {$CellContext`i30$$ = 1}, 
     "\"max\"" :> {$CellContext`i30$$ = 9}}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`i30$$], 1, ""}, 1, 9, 1}}, Typeset`size$$ = 
    Automatic, Typeset`update$$ = 0, Typeset`initDone$$, 
    Typeset`skipInitDone$$ = True, $CellContext`i30$126609$$ = 0}, 
    PaneBox[
     PanelBox[
      DynamicWrapperBox[GridBox[{
         {
          ItemBox[
           ItemBox[
            TagBox[
             StyleBox[GridBox[{
                {"\<\"\"\>", 
                 AnimatorBox[Dynamic[$CellContext`i30$$], {1, 9, 1},
                  AnimationRate->Automatic,
                  
                  AppearanceElements->{
                   "ProgressSlider", "PlayPauseButton", "FasterSlowerButtons",
                     "DirectionButton"},
                  AutoAction->False,
                  DisplayAllSteps->True,
                  PausedTime->0]}
               },
               AutoDelete->False,
               
               GridBoxAlignment->{
                "Columns" -> {Right, {Left}}, "ColumnsIndexed" -> {}, 
                 "Rows" -> {{Baseline}}, "RowsIndexed" -> {}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "ListAnimateLabel",
              StripOnInput->False],
             {"ControlArea", Top}],
            Alignment->{Automatic, Inherited},
            StripOnInput->False],
           Background->None,
           StripOnInput->False]},
         {
          ItemBox[
           TagBox[
            StyleBox[
             PaneBox[
              TagBox[
               PaneSelectorBox[{1->
                TagBox[GridBox[{
                   {"\<\"Date: 03/22/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1,
                     10}, {1, 12}, {1, 15}, {1, 16}, {1, 17}, {1, 19}, {1, 
                    20}, {1, 24}, {1, 34}, {3, 5}, {3, 9}, {3, 11}, {3, 12}, {
                    3, 34}, {5, 8}, {5, 9}, {5, 10}, {5, 12}, {5, 16}, {5, 
                    34}, {6, 8}, {6, 12}, {6, 34}, {7, 12}, {8, 9}, {8, 11}, {
                    8, 12}, {8, 16}, {8, 19}, {8, 27}, {8, 34}, {9, 12}, {9, 
                    17}, {9, 26}, {9, 34}, {10, 12}, {10, 18}, {11, 12}, {11, 
                    16}, {11, 26}, {12, 15}, {12, 16}, {12, 19}, {12, 20}, {
                    12, 26}, {13, 19}, {15, 16}, {16, 24}, {16, 27}, {17, 
                    18}, {19, 34}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM
CcUSBmOM6SBTbDoYMEUIIRMCopgiqk2vptkgiujly8w8rSyKYJ+0xMk5nnMe
Wt6+nXvnzsw338wzdO6T0PU3lSpV6vd7+ichKS22b9+kQa1/R/+JG9S/S+ff
0oew4otv4lf5Vf4P5MmTJ7/0FsotDx48wIqly9CnW3ckv9MJE8Z+jGtXr/7S
21Iljx49wshhw+HnVRVmXy1dGnhX9kJy4t9w5/Zt1fru3rmDTRvzkJuTg2NH
j76GHb9YThw7jhCHE3ajP4L9bQg0WxHgb4Xmzz5Y8/VqVbouX76Mbp3fhVmj
g9FPg4jq4Zg9e/Z/JVbXrPoaxmpaOEwWBIgtdtiMZuh9q2HKxM/c1vP48WP0
65MivgyxByDAbIFer4fRaMSWLVteowWKbMheD3+dAYEWm2KHxY5g2ofvn6oi
a8ZMt/WcOnkSUWHhsOqNCLTaSZ8VFn9/aHU6pKWlvUYLFLl08RJqRUTJ+mID
Xf5aPYJsDuz+dpfbegr27oXFaIKTz4N84aT4tPorPmnfvv1rtOBnWb54CUJo
30ZvPxjoYv9M+nSiKh1nTp9GWGAw7CbyKenic7FbbdBoNEhNTX1NO39eDuzb
h6xpMzDx40/wr7xvVP/+MeHekPR/QFPVR+xwElZoyQan04mCggLPb7iUnD1z
BjmUH1/MnovDBw9VWF/htWvo1zsFkcFhsBnMaNSgIXJzcz2w06eF8Y/jeOrk
KUjp2QuRoWGEU/6CVzaDCWl9++MO4X9F5diRo9i7ew/ZVeiBXf8shw8cxPiP
xiG+WQuEOYNgpT0bq2kEXx2Uk1wvOK613j4YPCBNamN55P79+4Rbp3DqxEkc
+e57FN0q8pgNc2ZlwaE3wUS1yUK5x+fPdpS2wXXZ6R7X89z1OarXYdtHD/8n
IoJDUYPwN4iwN7FTIm6XgxM8K+fOnaNYDYWR9sb7NxOeMraX3nvpy0n13KLR
470uXVWvdfnSJcRE1ZDzYrwzUD03m0zIy8ursB2fTZgAE8V+ANkQXT0CI4cO
R4c2bUv84nzWFrNS06NCq0tdUyNHiUs5rQoXYI4TZHXAz9cXgwcPrpANFy9c
QFztumSHDkF0zptylXPp0aWb1Dm2wV4cV+wjzo8gqoHMrwzkv4njP1G13lfL
lsOs0yuxSrr4THRaHRITEytkx8xp08UXeh8/DBmYLvcYi5o3bKzUKF6LbOB1
XbHGuM/13EDcqlXzlrh/757b640aMVI4Gevi3GCfmKm+JyQk4OHDh+Wy4Xph
IRrF1he9jerFiW9Yrly+gpoUXxa9AQHEH5ySE0pMhQYESqwFEO7zPhgLcrKz
3VqP8bzT2+/IuUWGhCGc6ro/5ZmB/JPQurXgWHlkTtbn8KV+gmN13eo1JfcP
HTgga8j+yQ6JpeLay5/jYurgrfjWkj+MCR3f6uBWnlylnqtBvVjJ8XrRMahX
M0b4s4G4VXx8fLn8wWfTrk0bVPnjG3i/Z2+68fN3eRtyhcvy+QcV54SL17Hv
BvVPxbHvj8gz/J2J4juSeojUAanYs2dPmWvmb81HkCMA/mR/TGQNJLbvINzd
SH5v2qwZbt26pdoOlhmUG38n7OSaVFpWLv9K+ALjonAgssFBnJRzhGv6pAmf
ynO9uveAt1cVOIh7G+lMq/lVg8PhQFJSEjZt2vTc+S6cvwAaH1/xP9fZ9H4D
BO+tJjNxXn+MyRwj/YmnZBGtZyEbLDoj2VCMtWRLsN0hMcH7YblEtYDXbteu
HSIjKJ8sFvgShlauXFk+d+zwNroT7qX06Im+vftQLsaR/8wSnzb6+wHhyrsd
E2GldXTMnw1GjPkwo9w84VlZsnARYa5BYsZVyyWuyCfso+VLlj71POfnlStX
sH37dmRmZiI5ORnR0dFy9pw/3PtyPLIO9oVLX9MGjTB5/ASk9kpBKPXMRj8t
LGTLRxmZHvHLauphGYdcfEqxQfnMub2Y7HyV7CCboiOjaF8mRASFij4XhrNf
XTHamPByDvUBWVOno0WjJtAR/pspXxbMn19hO3bt/FbwyeWPQJtd6d1oDxxv
UydNdkvPqhUr5feW4h6Wz0Pwr9gnPLdg/1Z3BGLmlKnCWYZ9MAQB1FdNmeze
Gi+TE8ePC77zGTolLwJK+jeu8SOGDnNbF2MCcwWHWeEDfCmxapEYk7pEmML9
7Zdz58pvGMPV1Nay5Ifz56UX53NU+IitJE+4xrf/a1u3sZ6fS+nRS+oU6yid
b+wXnlsEUg3hXGcO4Ulh/9auEV2SI1aDsYRfcRzY6SzV9G8/Ega82bipcNvS
fQBjofic7GCbuKYwBnpKfvrxJ6m3vIYS1/aSHOV7Bo0WXanuPFYxN9tH/WV4
YIhwRPYB65HcsygzPUdxLq5f5x7HcUe4f65PHJhroYuXuPK1pJYEB+PIkSOq
9M6fO0/mh8zbGEdc8eWyw0xcSy1/fplcL7yOhnVjKQZMJTyX8dGFvzbubanf
zcjIUKWX69vQ9MHUF/sq/iXd3O/znNVRzHnSUwd6zI7bRbclnk1apU/gsxtF
vVWbv7QSn1gplnn9+nXqEUe+qE45hSLPjJxGi/SUnOPc97BNzBVaNmmG69ev
e8QOnoXznrkWu/rxZYsWI5s4sfRS3MuRPcxbNuZsUKV7W34+zp4+g/zNW9Ai
rhGsfjqxh/sQxuLqxLM9NX+/XVQkccRxJXyWzunzmcoMN775m4K9QWab9INj
iUOokS6dkxEeHCJ9wvmz5zBudAZio2oJJ2EsZO6cu0Hd2ZQls4gnSI2y2Eve
DUyfPEW+G/thptLvUjxwbVdTE+/evYuWzVtA4+0jenm+x3Lh/A8YlzFG+n3u
I8aOGVNhG3II9zgnBKNoLd4zY/Dpk6fk+y/nzBM/2DhPKEfGZri/JnMu7j+s
5Oe6tWIEF3du3yG5t2vHTuSsWSs9WR/ixxWR48eOIYbqn5HqA2MTYyTXpu35
20qeYS5sovuKP4yYMXWaW7pv3rghPS33Gn7Eg5OTOst9xokIqivBlHfvJXfF
CdqDy0/lEe4527VtKxjFtYlxKYa4ybatW596bvXKVUpcEd4wt18w74tX6ma8
TU9Ng56w2kS1w0j8YGkx939w/wFat2gJHcUu50f2mnXltoG5fkpKivRzgcQJ
WV90eCS2bv73c8/m5W4UvHLQxfnuzroc+zJ3YxuonmdQr1S6vxg1bDi0ZAfz
+NEjRpbbjkmTJsl7LbPZDD3FTGyt2k/FUmnZsW279NQ2vTIz3bljx0t1L5m/
UGZ2Uh8Ii/qmvI97z3BZxnOem3Ad5BlleXqo3bt3w2q1wmQyQUt5EVunruRc
WbK/oADhQSGw6Ywy6yjYs7fMZzd/swkR9kBYqull1pPUsRMKC5+frZ8+cRI1
CKs4lmvXqCm9pVrJysqCl5cXvL29Ub9+fRw6ePClzx8lTlU7qibtTYcQwuX9
Zbx72b9/P2J5TknxZCWe1qRBQxynvuZFwty+TXwryTvOz/379qm2g+c0jRs3
lvwoa53ScoawhOeoNjrj6ODq8g7jRTJwQCqqelWRWGVOyX5/mXCPwvgoNXdW
lmo7WNTMv27cvCkzSG3lqkho0hxFRS9+dzF39mzhkjabDatXv/r9OuMe57oP
2T4o9fW/t2UZPDAdvn94A9MmlP3enM9mA3GvfOJT7silixfRJK6B5Ej22rWe
2upLhXnRCsL/q9RveVK+O3wYWzZv9qjO/1X5D7u/JGw=
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC
1qMIhA7HYFVAsOqMnUq4tKKCpYBQBAkzBAhYDZeQYMaAkBDydXeTlxIT4AXi
PJ26M8v//Y/3z36/3f129/cwjJ1078Rf3XbbbVPC6Z97xzyVW1Q0ZvrQEDrJ
m148YWwX+pDWrHwRv8gv8hOW+vp6rHjtdTz04EN4YORIzJw+A8eOHQu2WR2S
y5cv47k5c2HU6aFKUsKo1UGtTMagu+7GkcOHg21ewLL9n9vgstlhIhxOiw0u
qw0OixXKnvF46fkXgm1ewDL/pXkwEwaHyQK31Y40txd2oxkmtRZjRz2ICxcu
BNvEgGT5kqVwGC3w2p2CI4WODsJh0Rnw2PiJuEy583OQisNHkOFJgVmrFxyM
h/2hV6rw5wUlwTavQ7JhbSkyPT4YlGqYKZ74+MSEh3Hy+Ilgm9Zh4Xx/7tnZ
eHraDKxesRLnqqqDbVKH5OzZKmxYvx7vvP0Odn22Cw3Ewz8nqfm2BksWL8Gd
BXfC7XTBznxL/PvIxIfxny+/DLZ5AcnWT7Zg+H33Q5WYBLPBKPXCYjTBbrZA
TbVwDNX177//PthmXlMqv/4ac2bPQarHCxPVbQfZ7SQ/uKj+eZinms+thOmT
zR8F29w2cuXKFfzt3XdRkD8AWo0WFvKB3WCC02yFmzDY6LOnmXNZdcS5o4aP
xKWLl4JteitZuGABjHoDTGS/jnHojbCSpjhc0oewP7hmWOgZxsaYUp1ulP79
vWCb3iJHjhxBZnoGDNR72CgPCvLzcf89v0Om1wcn9SJss8dih8tklXO7wQwX
YdEnJePxiY/8ZOr57GefhTpZBYvJjAdGjMSeXbuxinr0vr50WDV6+KwOUQ/h
8JrtcOgpxsw2OaY53Pj04y3XfX91dTXmzJ2LHTt2/mgYuO/O7tNX4qlXRiZK
31sr119f/hc4dZQjGgO8JhupFT7ySQrhcOnNcOgIg80Fs1KLyY8+fs3319TU
IOeOHHTp0gWDBg/60XAsWlhCeWEUHBPGjce56nO4XFePqZOLYExUIYUwuMnu
FJMdPrNDMNR+V4uSlxciw+6BTa1Hb28q/k0+bE/++tZbgoFVrVHjxInO72NO
njyJ3NtzoFNr0CejFz7Y+H7T9crjGD1yFGzUF6bbXXAamtbeS7FkTFKjsbFR
nntz5RuNTvYN5X//7H6YNWsWtm7dijNnzrT8jaqqKixaVILobjGCZe3atdLn
X7x4sdNwLJw3H1ayUZesxuTHCnGh5ju5vnf3HtyVXyC86yGecjeri3Bwnvtx
sGzb+mmDl3KnKf9NcLvdyMnJQVFREZYtWybKsun9TbBarRh631BMKS7GsGHD
8NVXX90yhmpap1/n5kOToER2r97Y9slWoOGK3Ptg3QakujwyNzHf+pXP7ZQz
P5S6urrzbpNtp5N4TK1WIykpCYmJiYiNjUVhYWHLcxs2bkB8fDy69eguvkmk
50pKSnDp0s3XoK9pLUYNG4EM4tZJ7Iva81QMaZ1prd9etUZmJK4TV+PgesL8
dYWLZltpbGhoqKOYqlq1alX98OHDkZ6RAfosN7ds2QKz2YwQRShCwxQI6xqO
LiEhgicrqy/27Nlz01h4D6SyshInjh9vuXaJ4vbpqdNoDre2j4Py+mBZ2akb
vJpx1hGubwUgrU2//v3FZkW4gjRMNDI6CjHdu8n17OzsVnl1q1J99ix+T/2G
8wcx5a/nfh6+0tDQnk/8wgnUQCqNZPmhckTHxEARFoYeFFPdu3dHD1KVKpli
i+KvZxx0ej1efe3VTsNxtPyw5DjHFeeDx+YQDNxTSb4QP/mohmxct77qBq9q
bFa8sXq1rHkMYeF6mkYcmErv430KjrMecbHiG5fLhUOHDnUKjsMHy5FFHMxr
z3Z7bfT3NDo5l9mcfME4nFQHG67vE5GTVC/S09IR2TUCsd26S0+QQvWUaypz
Rkx0NMLJT/4as2nTpk7B8dE/PoSPeg1Wtp2Pk6heZ2f2lvxIszrFBofWiPw+
/equ+mpje+/749znoCNOTLO7xRdeI/WYBqusBb+HfWMg3mcMoeSbPZ9/3ik4
li9eKj06Y+A87+VLQwX1Lju2/Qt90zNhUGkk1ljZXy/OnltzPSyznn4GhsTk
Zh844CZuNiVrZD08RgtSCZtJpW3yB/HXihUrOgXHTOIqjiPGwjkxMG8Ajh+v
lHsff7hZcBlUaunn+T7jmjh2fH39pbo2w2HF0aPwUMy7KQY95IcM8gnbHK4I
Q6pgoms2t3C5P66G3DPkljE0Uv2YMHos4dBKLuiVahQ+/AjnQcszH2zchN6p
6RJjvJ/FPb2Jji8+/0KbujJ6zGixzao1wJCkknxIjO0pOGzEI2bicDthTI5L
aMGRlZXV6u/djJz55hsMHFAgM5TP5YZWmYyZ06a3eY64Svxhp76dY0VL8T9h
3Lg2z2X3yxbbmJP8dvqVeTgqIgoKhQIhFE8hzTUxmbj4VvuVfXv3Ic2XKrOU
g3ohM81+S5csaffZlTSfcMw7qZ6YlRoUPvpom2dy8/KacShaYWCbuW+J7hqJ
mMhIwvI/nEajEd/Qet6KvLL8FZmnnHYHbGaLzOgfEn+1Jwf2lyHT5UWKwQKb
SocnHms7g+Tk5optXPeiIiIQTTaHESb2QVQk1XLSOOJi5l1FaKjg02i10off
rHyxbx+y+2bJjM44eI9n0MC7rvnOL8h3KVRbMqwuWMgfkwqfaPPMHXm5YpuP
uIn5NZ1iUUezcERkhNSNmMhoKHsmICEuDqqEJCjjExFKeHbtbn+WuZFwXgwZ
/FuZpXivTUvzSCbVro83b77mdw5T3e3l8cGlJY6mfC2aNLnNM/kFA8QfV9c+
5qsE6nmT4hMo5+Opputg1enhJj4zqpv4d/HixR3GwBQzg3KZ90h4r5Bzw+v2
YH3puut+71jFUeRk9hFfOChHniya0uo+96BpGekSQ8yxzLvpNIvxXMwzjY/8
k8LcS9ddpDynMa8xjnHtcMaN5M01a2SfxE7vNlMsOQnLyhUrb/g97vv7Z/SG
S2OEhWbE4j8Utbp/6tQpifXw8HCpD7w/z3byPOmm+pcisz7NZcR57CMX1V01
xRbjyM3P6xAG5ifeW7DyHqHDIT5ZOH9BQN89QbPv7eQPF/UnZrJt6pTiVvf3
79+PqJjopnnjKj6KCAtHmsUpvQn7x0wc4eddPz9zXgUqZ8+ewcjhIySvOZ4Y
Q3FRMerrAtuLOn3yFHL7ZMOhNgiO6VOfanV/52efSZ+hoJmJ1V8fGIeFcsJC
OcXzPve8EeFdic8iEUl8Jv4IEAfHLv9urNfqZB+dsYx5aLTs0QS8DjTzDOh3
O+y0npwjz8yY0er+9u3bm+YmwRHWqtbJdcqbZKVS9sGYy1j9eR6oP7iX7peV
LbykoV6J995Onz4dMAYWnu8LCIdNqaX8YBwzW93fu3evzHyhiqb5ryV2rsLC
9YPnAH8PydzF1+/+zd0B2cB7LtMoDtzUw42g2KqoqOgQBhb+zWDo4CFQdouF
OjYBL/9pXqv7lTQr836DxNYPcAiWkC6IoplEuKy5X7Q18xXvtQQqjIVnr9ra
2g5j8MvOHTtl725q8ZPye8PVwrE7oKCgpR9nu5uUPoc2nXclLtNTT6+m+se9
fGJsHMIIc2lp6U3b9GMI43Q6ncS/Gpm/dXodtDodTCYTbDabnDM3a3RaOSYp
k5BHnHvu3Llgm95Gzp8/j4MHD+LAgTLSAygrK5M9nvLycjn3K1/nnPq5/J+C
/3f5LzkVlgk=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$20", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$7", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$27", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$20", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$13", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$27", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$17", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$19", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00
0TK1ifeuGtTVNbvruq4ao6J4Jp7xLG/AyCHqqoByiBzqs90vDOXFMDhY/ohd
9TnDfJ/99vN299Pd7ydPSo2Z+Jtu3brN+D39E5M4KyQ9PTE79nf0R2h2xkdJ
v6UvPq0X/4h38k7esjx98gQFV68ib8cOHPvpMCru3nvbJnVaGhoaMG/OXPh6
eEItk0PnpkBwUD/s3LnzbZvWKVm6eDFkTi7QypXQK9TwUGuhcpPD19cX58+f
f9vmWSXNzc0YHDkQCokURrLfU2eEnvAoCYdUJsPSpUvftolWSW1tLSIHhBMO
Gdw1OoHFqNLAXW+AXC5HZmbm2zbRahkTFwe5qwQ6hQruhMOk1UNHWJycnLBh
wwabdF++fBnHjh3rIksty47t2wUGuYsEeqUabk6ucHV0RhzhY3/ZIsnJyQgL
C8OjR48sPldfX4+a6mqb1mLZm78X8R+MRP/efRAeFIyM9Bm4ffu2TTo59xIS
EuDj44N7FRX45do1ZGdk4u6dO23P1NbWYPHX3yB68BBERQ5CRtp0XL1ypVPr
PH36FFVVVfgf2dvY0IgnVEMqab2mxiab7DdLY2Mj4RgLhUKBc+fOCXul9k44
e+p02/pZ6Rlwec8eGinzvRLO7/VAREgoysrKrFrjx4OHMH7sOIQFh6Af+WBw
eCQmxCcga8ZMLF24CNv+uwVnz5xFSUkJ7t69i+amFmxPHj9G/cN6VFZW4mb5
TZQUF6OwsBCXLl5CeXn5c2twLMWNHAUZceGSRYuQ8vEU6MnWSxcuivsnj5+A
Qa6CkS4PlRbudJnUOrj0cMQSqgUdyYkjR+Fv8oLCWQIt1T2tTAEdfaooP9Qu
Uuhob4xcR4i/enn3xMCQMExOSkba5CmYOD4RccNjMTRiEMKC+iPQ1w/eBndh
Q2BPf1y5dLltnYZHDYiLjoWauHBI+ED09QuAn6c3fikqEvf/86+Nou4yR3oQ
t5i0BrGmUipDakqKRQwNtEfxMSMgsXMQe+CrJxuUGvHdfPHfRsp3tdQNWqrt
euIA/q50lZJNblC5yogLXMQld3YVnzJHF8EPR6mnMUtzUzPGxcWLZ5jLWVdQ
QG+UlZSK+0cPHxG1V0W6GQfzPvON1Nmlw7qVvysPWvp/JraZ7DW0+vS5i373
onro7+Uj9PNajIHtUdLeehs9EODli/D+IYiLHYFpH3+CBV/Owz7iCs7tZ2UT
7Tnbz/YxF3rqjVi2cLHIDfZX8rgJkBI3sl5eh/ejb6/eKCi4ahHHvM/mQEt7
yvuto3hiHF7sz2dw6GVKRL8fhX2792D39h+Q+9cVWPTnr0UPtn7t3/AzxXXJ
9WLU1tRQf/nU4nos361bDx93k7CTL/bt1EmTcfvWLaFjwRdfIqRPkIjLyckT
Sf9xi/oeNz+m+E6iPJCKfPPU6EUMcW49i0NDOFM/mUo5/QQVd+5iCeX9vr17
O7TXkrBfzH2ohvyjIBsiQwbgGOUqSxXxRllp6Uv+fJXUEPbYqKEUV5zHKoot
3SvjSk3xzxzJ8T338zlw6GGP8AEd17KO5PstW2HSGUSs6jhWKZb476/mzRd1
0Fp58OABoohnOJ7MPjC+AgdzWNbMTOTm5sLfzw8ODg5IS0uzCQNLHfUG74dF
iL6BeclAPMX+caO8m5iYhMfE6dYI+2M4xT3nhzflscBB/PpiXLkTt3hQPvoR
BpVKBU9PT5w8edJmHLmrVgm7mZcMtIY59znGpkycZLWeJqplHyaMoxohE7nh
Sfa/Kj/4N61KLeqwRCJBSqplLrdGym+UI7R/f8qNlnrB+c7cxVgCvH1xoZNz
DvcBCuJ59oN3K0+9iMNIOFSEQalWQWfQ48iRIzbjmD9/PjQKpahF3FOzPxgP
50juipWd1rdsEc1+xNesy6xPxCrXErqYU3JmZSPAzx92dnZdMn9cPH9B1CL2
s57ykXOb40ktVyB+ZBwe1j3stE7mDK5p5vrJ+oyteJgPucadOvEzLlAPtHnz
Zty7Z/t5Q9qUaVBSD8R1yZNigNfTU9z6EbYTVIteR86ePt22H4xF6BTfeRZs
wbJu9RqbbTfLwX37BceKPCSe516O+yjOixXL//Laeutq6xBDNUTZOsey/S2f
etEDaYhPMlKndxmOjyYkQcH+Z/5QaMgfevF3/AejBH/aIjPT0oUuHeU6x5OB
fMx7pKF4ZR7p1zvwpR78dWRP3u62mOV6y/xoIN9zz8uxa6vs+mEHVNxjCQwa
EVfc/7TxOflq8cKFNq1xkfKrN/X0GlnL3nBcudO+MVdyr9YVcqO0DH1oFjDn
uHtrjpj3juPMk/J948aNr6W/tqYWcSNGirotzl9YP/VzCupl06emiHO/rpDH
1IuNHz2GfCKDTqlqs93LYGydaXRQyGgm8PBAXl5ep/V/tWCBmCHMPS7rlBOG
mSlpNEt2nmMtCfeB3NdoKScYg7fBQ8SVOV+0xF1ubm6iNzlz5ozVevlZk9Ed
OtKhIs5g/uB6lZOZJfqJrpbtW7e1xRHbz98jgkPFbMRzpZ58otFooFQqEUpz
/9WrlucaFp6NJk2aBImLK/VnLXWC8zCbZn7GUFdX1+U4bpZzvxMMvYbmDZ5b
yf9jRo3GPzd8hz69ekFBWNgW7rPcXCVIpn60I9m/dx9MFJtailUt9SCMYeb0
dHHv+y1bsGXT5i7HwZI4fgLcJMS/hEVFWAYEh+BG2Q3k0xzIZwdce3WiH5Ug
esiQDvXlZGWL826OU65Pn87KEr8f3H8AJtqT42/oXHElzatSigEjrcFY3MgH
+Xv2iHvMK2LeorjjXnt8wliLuvjcKziwr3iWrw9p7mY5/ONPgn99TZ64fv36
G8GxhvoPOfGSRq2GkvLdhfJx0783iXuzps8Qc6Gxte/6/I9/sqjrAMUUP8cX
59zJEydwrahIYJA6OGP44CE21+9XSXV1NWKiY4T9GsoBzmv2y5HWcxvu7RTE
Z4ZWf+Tt2GVR32yKIT6/4ZoxYli0+I3rrb61tvIZQvEb8Mfq3NXPYZC4uOCL
uXPb7k+bNBkSe0fRRzCWs6fb514+T40dOkzg4LxYv2at+P3B/fsYGBrWxu9/
X7e+SzHwmWZEWLjIB1En6DNxQmLbrN/U2IhxVCf5fM28l9cKi9rVx2dA/QJ6
Cxx96Nkbz5zNrqX9UlOecS0ZOybBqvMQa+UbqoH8vklF/Mj+6Nc3CAUFBW33
79+vwrBBg0WPzTHFZ4KP6ts/K+GZht/HsS9mpDx/HlH9oBpREQNFX+plMnXJ
bMlSWFAI/55+wn5zXG3buvW5Z/hcms81+Pxb4uCEzz7Nsahz+eIlcO3hIHLh
AM0bL8qKZcvFeyJHB0cstLH/NEtW5ixISSdjkMtkyJk9+6VnSktKBYcyDiXV
lzXfftuuvkbq+cbHJ8Cxux1GRseK9w8vyv2qKkRFDoS9XQ8MoTrE7ypskVOn
TsFEvZ+Keg0Z5URC/BiRiy8Kx5ifj6/okYzEAfyOoT2prKgU76h7/KG7xfnu
H9QncB5KpVIcOtS+PmskIyND9H6sKzAwEMXFxa98roJqWmhoKLp37y72r6M+
e9XKVZhAvcGtW7fafYbPIlNTU8V52OHDh9t9zhrJycmBvb09AgICOsw3PmMY
PXo08vPzbVrzWeF3jfze09a+l88+2L6iovY59J28k1+L/B+xoVyP
                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S
jYgVu0eDBTudWFBRVGygqAdiLEfF3sBu7PXf+/3wXt4UhnEEZlb8zvmZmTvz
3rz53n+/+5fLh2HD/MMtLSwsvrYXf/xD/+M+cmTo2ABr8cJj7Ki+YVbiSWth
nsIwSO/wDq+BFy9e0K1bt0x9GWaNbdu2kZ+fH7Vv356ePXtm6ssxO6Snp5NX
Jy+C/Hw9ehR18OxIy1esMPVlmQ22b99Onl5eZGljzRzZ2tuRS/XqZGlpSe07
dDD15ZkcGRkZ5P2lN1kV8WNXyZ4qVXZgw2vY2LFjTX2ZJgPml4+vL9nY2mjz
Y2XJY23btaXklJQKqU/79++nL/79BVnbKPhxdCB7h0pkoSr0n5b/bEUJiQn0
6tUrU1+uyZCdnU1NmzZlPmzsbdXmVzt3d+o/YADNmDFD57EFBQUUGx9Xzlds
Ojx9+pTGjx9Plas4Mj9ubdwoISGB4yUgPDycdu/erXXcxtSN1G9A//K+XJMj
MzOT4uLi6OXLl2rjk6dMZv6+/+EHSkpOosSkREpKSqLmLZpTWJ/eJrpa80Pa
1jRq2aolTZkyhaKjo2nJkiW0ePFiati40TueDAB8qm/fvlrja9aupSFDhtDg
wYONskGDBtHQYUNpyNChNGz4MD7XsOHDaah4nZeXR2vWrGGdiJg0Sa9Niix8
/HHij5STm0tjxoyhNm5ulCueb9iwgSaIc0yKjJQtYlIE601pr1fI9RITE7XG
vb29acSIERQTE0NLly41zpYpHpcto2XCmjRpwvM+Pj6efXtG1IwSbbqwqJlR
lJycTFZWVqwfjRs3ptWrV9O0adPkz+EzyDda/KMF63V5IDAokLIPHiz184b2
DmOOjMHDhw+pVctW8lreR8c8uJZ/jTxFjvb48eM3vVSDEBgYSDtFXF/aCOkR
wnGcscjJySEnZyfONVQi/4qNjeVxaZ6dPHWK89eKzhMwa9Ys9ieVpYoauDZQ
qxNVRJ7OnT9HB7IP0JWrV9TGkXMhfrZQqZiviRET5fcqEk9Xrlyh7iHB5FKj
OucWtf5Ym4aPHEH379+XP7Nr1y7OzyxF3vrBnz6kGzdu8HhF4en+gweFviL8
xFrk86gFSXWPXqG91OJnHz9f2adWrVrFYxWFp+UrlvPvRg4v1TrshYEva8HX
3r175c8mitgPtTR8XooBT1UQngYOHMi/W+IIZifMwbEyj8+ePVv+bFZWFjkU
5fw+vj48djrvdIXgabiI2TV5gj+BD8y/fv37k6+Yb52+9KZP/vopaxQ+j5oI
UFH8KX17OvNhW8lOjSuM1f/gferWvbscZ0q1tT9UqyrHxOaoT4jtisujHj16
REePHtUaV/Kk68jLly9T127dWIssRHwELQcfjlWqiPi7D7m6ujJnjlWrUI1a
NcldaP72HTvk483RnySeNLl68uQJ5247d+7UOkYfT78KXuu/X5/c2rbhGkZr
t9bU6LPG5OHhQeH9wqnp3/9GltZWHF9+1bUrXbhwQev85u5PV69e5fgGdcGp
U6dyr1AXNOeddPz169epWfPmPI/ARZ16ddlXoEPgq3rNGuxH0HOViJmaNWum
dn+k54b6E/z99OnTXLuQDMfeu3evZHIUMJQn4OTJkxQREcH5Q1RUFPczioMu
fcovKGCfkXpn0GYb8agSfGHuoa+m7IngOeq2vxw5onV+Q/0JtfKUlBQ6KHRN
sm3p22hLWpre4zRhqI6DowkTJtB18VuxZuuaa0qE9OjB9SEJ+w8coCZNmzBH
8BdociXhM3b2hTqOOMq+aM2zV+g6x5arV2tfj4E8HRDfe/jwYbp9+zbPgzt3
7lDemTxau3Ytzw34tyE1LEN4ys/Pp8mTJ9O1a9do3rx5tG/fPu4dbt26tdhj
4E+oP6F/8e1/x1FVp6rsM9Bql+ou4n5u4Z4H940Usaam4f1vvv3GaJ6QG23c
uJH1ITIykmt+69at41oc5sOiRYvo4sWLpcIT5jjux5w5czhORp8CuTzqRMWh
R6+ezJOfv7+sRXh0/cSV9gqe5e8PCiqMo4RvOSj4cVDw1PmrLlrnN0bH4UNS
v0XCnj176IiY11iT9KE4npS+iHPPnDmTdoh1GRzhueb3aaKn4Ak9jDbt2sp6
1FusbfB1JU6cOEFOzs5kY2er25+E/7XzcNeaG4byhPOvXLmS1q9fT3PnzuVa
Kfiav2A++xZ6B9L7KT+nFFsfLYkn1DamT59OaUW6h/xd6jHrm9c9evakuPh4
8vX1ZcsQxxUH/8AA5kMXT6gTQNcePXxkFE/QpzNnzqiNQT8w9zQBHSluL5S+
eQfdg4Zs3rxZ5/v6eIKOx8bFsU6WdEyU8E/NHEYZn3/0l4/p1m316zeUJ/Qh
UF/Hfcbv2LJlC9ejoRtpgpetQrek92LjYlljdEEfT2fPnuW5ZgwMqtMVUbZO
+Hxx/mQt5mPd9+qxDyhhKE/QB9SssJ7gnsHwGnorvYZhrXrw4EGx5zFEn4yB
Pp40Y/v1eniCbiFvuXTpkto5zC0eN5YvQ/wJmjl/wQKuU9ra2XEMrskT9N/J
xZkuXlBfu82JJ335b0koiSfsbUN+J8WdujiSY3JHR84JlQBPHb08zYKnN4EW
T0V0nzt3juMD+ImyngmerIv2c/F+HEWcgNfdgoPVzs88dfIqMe4pLZRn/SlN
rDV16tSR4ymlz2Csbr163C//7vvvqFbt2rwPzqHofez52rQpVT6XOc27N4Em
T8+fP5frBNrzqjKFhYZyLi8B8R+0XfI3PHcXObQU35Y3T0EibygppzUGnAcr
eEJs2rBRQ3kfIPcLhL/Y2NrKPRQloIsdO3aUeZV8SqrVyfr0pJz8SfCE/Yyl
jdCwMIpPUJ93K1auoBo1a1DN2rW4VwdzdnGh4JBgnbki8m2p/iLplLQ36cKl
i+W6v8CrUyeaGBFRGJMK/XhTQx2A92DxPtFEOn78OOe9mVlZ3PNdFhNDi6J/
op8WRxdadDTNnjuHUlNTee9bZlYm91dwzPHjJ8j9Xx6kUqnk2PzPH39E58+f
53O3buNWrI5jfmKuS6a5n+51MW/+fOrSpQuFhITwfX0zC5EfUa89duwYjRs3
jjzF/PD18yO/AH8eDxbahT4BesHdg2HdqbO4hoCgQAroHESBwrDfe9To0TRH
5K6ox3B9Shh0Hfmsf0AA77PS9ftRi0NukrppE8ewqKtgHwfqmG8joFHInao5
O8nrI+YeamH6gFxNM8/BeZATv62Av2AvPHoKEk8+Pj5an0O9G7U4aBrqZHHC
f5Dzoh6HdQr+hb1CbzPCeveW1z30Fj77/HOtPAE6iHoS13d/+43u3r3LNZKF
CxdyDwz+BZ16mwENlXhCLFGv/ntcz1UC9Xvs2c0+mM29AxjWA+yHNBXQT2Od
FGsUNBKPqBNivSoLwE8kntA/Rg8GvQElEJ+hdgm/kgw5oSaf5Qncq0OHDrF2
wP/xiD6GrhphaQB9JMw3ac2zsrbiPoY5AnwgHkVcA//Gnl7oY6rwJ9TyNok1
GH2ysgC+01bEmsp4U1+vx5RArQ91Uegh1wALCmuA2E+N/QUYL6vYGPfHvih3
kXhKe80+ZXkBdeOY5THcw4Hl/pJLR349wmtwxq4MysnNofyC/DL5buge5tv/
gz8B2JsF38H/GMSLHBc84X8HoJfo9yaX0bzbsXMH99bl2oGZ8yQBOg4dvXnz
pmyId7HmlQXQV6rm5CTX8NBzV9ZgzBXoV0AfULuFQcfxGvlcWQG1lwYNGvA+
cl37Dd7hd2At0dc7egfT4X/4Ss6f
                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc
mugXjcYZY0yccUVjVNDWFWdd4MIE9xZF776/m76n1lINKZ6jybmSh3PeeZ7r
udd1P/yQV5RW+EWHDh1Kvzb+pOVWRJeU5Fb9+JVxEFNV9lPel8aXQGP4GYOT
4oADDjjQRjQ2Nkp9fb1cu3ZNbty4IW/evLH3lNqMBw8eSP/+/cXX11dCQkJ0
XL9+3d7TajNu3bolCQkJyiMoKEg/L168aO9ptRkPHz5Ue/j4+CiPgIAAuXLl
ir2n1Wa8fPlSsrKGiLe3t3IIDg7RWPkckZeba/DwMnj4a3wQ7/bGzZs3Ze7c
ubJ8+XLZtm2bHD9+XG7fvq3+8/jxY3ny5Im8ePFC7dD8ulmam5tl+PACg4e7
+PpZJCY2yoiZBuv7yF0M7ue558+fy7Nnz/Q9jx49kvv37yvvc+fOyatXr9qN
x8GDB8Xd3V1cXV3Fy8tLIiIipGfPntKrVy8dCQnxkpySKJmD0uXnkcN0REaF
SnCIv4SGBRkjUMrHlkpVVZWUlZVJcXGxjB49WgoKCmTw4MEyYMAASUpKsr4v
NjZWevTooZ937txpNx4HDhwQi8Wicevh4aGfHHt6euqwWDzF1c1F3NxbhqfF
VUJCA5SHOby9PXQNzOd4T8uzfx/z3Tx2c3PT36EOtRew+aFDh2TFihUyffp0
KS0tNfxmuBQWFuqaZmcPkawhg2Rgxo/SJylOR2CQr9ohPCLYiHM/8Q/wkcDA
QI2V8PBwiYyMlOjoaImPj5c+ffrIwIEDJScnR/Ly8mTEiBFSVFQk48aNUz+z
JfD3pqYXRtw0aizk5eeIj6+nePt4yID0VKmprZGjR49qbJ06dUrOnDkjFy5c
0Di4e/euxtSniJLSYvEy4pwxctQwe0+nTUCP/Pb7Ef1ePrbEiIcWHsXFv+g5
bPGpo76+TgYZ+aqoeKQeV/1aIRYvN/HwdDX8vFLP4fPr1q2z5zTfC/JyTGwP
+fa7b9SfQHX1RHHq/L04O3eWiopyPUde8PPzk/Pnz9tzuq1i0aJFmh+7dOmi
OefEiRN6/urVq7J161bZtWuXnD17Vs9RP5ycnCQjI6Nd68L/AXmdmkZ97Nat
m34n77wP1Gdybffu3WXMmDFaz+2Jw4cPS0pKitYrNPmMGTOsfRJc1qxZI/v3
72/1WXQNz8B/5cqVtpy2FU1NTbJ27VrVDNTdsLAw5TJv3jzrPXPmzJGOHTuK
v7+/1onWQC3lOWKF+mprbN68WfUCepyaHBwcrFqDXsPE4sWLpVOnTtp3nD59
utX3PH36VHINPezs7CyJiYnS0NDQ6n0fC2iE/Px8nTvrzUAXDR061HoPGnjL
li3/WGdq9oYNG2Tfvn1aY8xzvXv3Vi7oRnSvLcGeAb8PB7QSueq/agK9E7qW
XooBZ3xyyZIleh2++BY6esGCBbakoSCXMi/sgu5uDfQS6L6uXbsqZ+aP/+GL
Li4uMnXqVL1v9uzZygMNuXPnTlvSUBAHxCpxsHv37n9dJ/bJx6bGRfuTJ4h9
1h5u5D36JLQzcUfMoR9tCXJ/SUmJzpU1fjs3kYOJY+ZKvUhNTdX5knPRuDt2
7NAaQr4GxAr7K5zr27ev3Lt3z6ZcqBX4Cn6SnZ2t/Slg3dPT0yUtLU3nTU5C
u+CP1PxVq1ZpXFVUVFjftXfvXu0zedfkyZNtygNcunRJ/YG1HD9+vLX3Jjaw
U11dndTU1Khfsc5RUVFaB+FhxraZq5YuXarn8bFly5bZnAv12+xN2YsAxAc8
1q9fL3/8pQs3bdqk+YGY4trJkyf1/OvXr3XgqxMmTFAuXEfH2BqzZs2y5h00
CfGQmZmpdqKHRRviN9RQ+KIvTQ7Yg0+wfft2a/+PP9p6v4i+NCsrS32CPY/L
ly9rzUM/4kvoKfyJfRHs9y7wRfZ7iCtsiz3gQtyZtdNWYO7USNab3zf3CIh1
4gM7sfcLqKeTJk1Su5j3oQGwRWhoqA7yNe+aMmWKzbUxtcTcu+H33wXrjg9V
V1erDsPvzPpDPiB2yNdmHGHH5ORkm/crzHP+/PnWPbvVq1frefyONTXzGXkA
bYWvMX/A/lK/fv2Uh6lBR40apT2ZPcB6l5eXW2P8yJGWvQfqCxzgxH4q/SK+
ZPoMfhcXF2fdh0Mz2Bv4PGuLX1DP36fN4bZw4UKtQ+ixmJgY5fip4NixY+oj
+FhlZaXU1tbKzJkzNTbIWdiH2ojt0L3UcnK1PerGh0DvBQ+z9r29l8v+Cb0L
1zlmX+hDPb69gM9MnDhR50odJJeSU6mXxDGcyE30We35P4KPAXQjfSSxS0+P
beACB+oNGvJzAXqR/5lQ57AFHPCrz/H/uHv27FF9hT9NmzbN5j15e4J9o40b
N9p7Gg444IADdsefMAqUuw==
                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2
qGNEHY29rC7YJhY0GnFjy+gaXMtorKNuce0l9u6///fzzvM+eO/xcB5JyPDP
HLjv3nP+c75z/n5v+IDM91KcHBwcsvX8573+H7fLyuo/6g8u/CNu1IjBA5z5
4rfcmnLDTaqkSqqkSipnevHiBT1//vznXsZr0cOHD2n+ggWUlpZGvXr2pJ7c
Uoek0rz58+jBgwc/9/JsooMHD1KDBg0IJh9t27ZttHvPHnJ2dZHfkfXq0feF
35f7OiAD9+7dk1ZWOnbsGAUFBRkxODo7UX5+Pm3fUUA6d73xfiD3OXLkSDms
vohWrFhBsS1aUHBICLdgiouLo42bNtk09uXLlxT/Tryss25kXUrs3ZsyMjJo
/PjxNGHSRBqamUF9+valBg2LzqrNb9raff1YQ3Z2dtF+OTmSi5urNLV/OTNn
lsrj0qVL5O7hTmkZ6fTV+q/o8ylTaPjw4TRg0EDqP3AADRs+jCZNnkzr1q2j
rOwsctPp6MTJE3bFsXr1almvm15H7p4exubh5UmuOjdycnKiffv2WeVx584d
SvkwhTq/24V8/HyNe1C8VfHxoQ4dO1JycjJdvHjRbhiesT60a9+eHBwdZN1o
wKDnvVV4MD9kwhbq1KWz9Nfuh97QFK+WrVvZbf2KoM/BoSEiR9q5tc3B0ZFi
mje3iV9040ai3+YwoOFZw+gou+O4f/8+hb5RQ+yiZRwOFBNbOg74vLqRkeTk
4myRF3DUrRdpdxyYOyEhoYQsmODgZ1kjsm3i1yuxl/RX8mnS+B6ede7Sxe44
QLt27SJnZ2ezZwL75cO6efr0aZt47WGfhz13cSvJy4VthiPL6Pbt28sFB2ju
3Lmk1+uNthc6gWsf32q0Kd82H6Joztw5sl7lC9GUvZo1e1Y5IXhFhw4dovT0
dIqNjaVWrVrR6NGj6fQp286hOG3dupXi4+MpKjqaohpFU7u4dpS/Od/OK/51
0dGjRykjM5OSkpLYP/SR/7379KG+Sf3kf1JykviN5P4fUD9+Jq1fP+mXxH6s
b7++1KNHDzpw4ACdP3+ehmdlUWKvRJo+fbrwP3funPTvw7zOnDkj96ZNm0Zd
u3Wl9KHpdNgOMdbKv62kKlWrWPS7traBgwbR0qVLyD/A33gvsn49unv3rszT
tm1b9j0xcv306VNq3iLW2M+nmg9t2LDhtTHkb95MLq6uRvukQ2P/rbdgd1XT
xqwS67VtQ3m5eeTp7WX0GW7cx5v358aNG7Lffv7+5OHpKfH7XYPPRayDvjLG
3Z0KduwoMwbEQfU55nRkm2RtzcUbYq+AoEDe/4GUmprKedEQ+obtZ4uWLYt8
j8ZfeDGuvLw88YmYB/sVFhZGc+bMEYwmMQ/72IZRUWXOr2BflZ/C/oKnWZ9l
xo80a9bMhNeatWvEvoIHcKr1gZ9XFW85c8Q7wKHiHm38hvmVn12yZInNGB49
eiQ5ghPbc/DwC/Tn+LOqyf5Yw6GNsRAHvJ/wvuynnnn5BwZQVZZ3xQvyBflp
0aolvc3yh2tZO/jxf8zr6+8n/Rx4Pb/v2lX0xxY6f+GC8RywrgzObWpH1DHZ
S6vnERNj5HX16lXyY9125bHA8hHLWiOOEbXxJmRq5Mcj6dOxn/K1E3l4FMWM
wBTBuVYC5+3QEfCo6utD165dswlHbm6u+FasG2vYtXs31axdy2qsa+k8NnGe
6OrmJmuCnv/9228pmn2eNrbRKxnj5+6Gc5D4hOerUzeClixdKmOxHhcehzzI
FoJ+QhaxB/Xq1xf8ITVCjfaj1PNo/uo8xowZI7wwFvHydeYVyXqtxQEMEpMU
synAEV4znAoLD1JYeLjwAK9Ro0aVDoJz1+7duxfZTJaDHizbsF1lwaE9j6FD
hxbtCceXbdhHII9BXq7F4crrjWsfRx07dZJrDw2ON8Peogss5+3i4xhrUSw2
hG1gaXSP/VLjJk3kLDDms/GfiV5p7XlZ9AOyrfyImr92ndomOKAT2Rzv/5nP
zsmgHwrHG2++SVeuXKGkD5KNsSnqGs+ePbOK43+XLtFb4WHG+gFsOeoL1UOC
y4wDdg9+2dGlKI4dO3as3K/FulY89lc1i+L6UYNl8faPP9KIkX8UHhgXERFB
t2/ftorj3PlzYueULC5cuLDsOAz+49atW1QTe2/gNXHiRAOO2iVwyPmzjmh9
FHBApxC7oCak9CyEZaM0m3Xy5Emj/8G4ZcuW0Ysy4lBxEmyuyunBa+rUqWZx
4Lprt27sZxLI2cXFRD8UjhmzZgoPHec+AQEBdPnyZas4jh8/LuMVjpUrV4ov
KxMOg1xhLsQosJfgNeOLGWZxwAYM/jCFModlit3yMOwj+igcyLmk5qTTUTU/
X5tx6Dz0r41D6QdqbvDfCkdOTo5FuVJxifaeyBDbSdi4hQsWGOXKJhw//GBy
HqiBvi4OdR6uxvP4wiIOcw19arC9gr2YMmWKCQ7skTWCfkhsrtEPS3qOeYqv
R4vDqB8GPUduVITDvL0qfg/nGBwaSimDB1P16tVFNxAr+XOMX9p5nD17VuI4
lUMsWrTILA7wbNy0CTWIamhSJ9Xqx/Xr18WPKds3+fPJZnFgPHKEaM7PVWxr
nMewDvSBLYNdC+QzBm9r9N+LFymIsTtr/AdIi0N0kHXz661fU25erklNSxuX
QD8lhzHUQT75yydyv7gfxLN58+fTpvx8E17AEFg9SGI7eS/CvD29vCQPgW+0
RvCTiYmJwq+ary/t37+fHj9+bBZHwY4CWrV6VUkcMa/yD/hpPPf29pZ8Cmdr
Dsdizis2c/6JaxVTY++jODbe9s02+Y28srCwUOpokFHorTXCPi5evJgOHz4s
v2+x7yyBg+08clBz5xGjiROxB3gHgPlBT548KaHnIr8838aNG014AUctzhdA
f+LYcO/evfSv//xb6kSQXfAuC5nFweexkXP/vFV5FuXKHGFuczjmfvmlvJPS
8kIf5D3Yd+TxHTp0oFC2w0PS0mjcuHGl6khpOGQOxoHcwl44oIfFz0PhUPu+
ZcsWKigokOsTJ04Y/VFFwQFZNEcL2DdCf20lxJbBv0AcWBdiT1trKL9UHCDI
2Zo1ayo8DtCkSZOk3lrRcSDvVTlBRcYBQly+o5S6aUXAgW9VTp06VeFx2EKV
OGzHgbr4rwHH0uXLfnIcKk4sbxyIdysaDktxe0XD8Ve2/xvKWa5QFwzi/LI4
Drx7NJdHNWnW1CoO1M5NcDg60CqOkczmUZw72gsH6kdhNcPl/RRyfaml8Nz/
PHRIzkTN7WH4LqT1260t8nr+7Lm8x1FjVF0GueX+f+w33RO+Rh3Dnt+RLlu+
XM5A1c67/O5dqcMjJ0OdR933ruJtzHUs0foN6+UdmxqDd6CQ3UePH9E7HTsY
7+v0Olq7bq3dMCjCdysDBw+i2bNnm3xfefPmTZowYQKlfpQq34HaQnu/+45S
UlLkuz5t7Ry1gZwZOTSI59m5c6e9IVTST0z/B0Y4Ieo=
                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.6569317962347014`, 
                    638.2785624969512}, {-321.7745624969511, 
                    317.2179127508527}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 2->
                TagBox[GridBox[{
                   {"\<\"Date: 03/23/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1, 10}, {
                    1, 12}, {1, 15}, {1, 16}, {1, 17}, {1, 19}, {1, 23}, {1, 
                    26}, {1, 34}, {2, 6}, {2, 8}, {3, 5}, {3, 6}, {3, 8}, {3, 
                    10}, {3, 11}, {3, 12}, {4, 12}, {5, 8}, {5, 9}, {5, 10}, {
                    5, 12}, {5, 16}, {5, 34}, {6, 8}, {6, 9}, {6, 12}, {6, 
                    26}, {6, 34}, {8, 9}, {8, 10}, {8, 12}, {8, 15}, {8, 
                    16}, {8, 19}, {8, 24}, {8, 34}, {9, 11}, {9, 12}, {9, 
                    13}, {9, 16}, {9, 17}, {9, 19}, {10, 18}, {11, 12}, {11, 
                    16}, {11, 34}, {12, 13}, {12, 15}, {12, 16}, {12, 19}, {
                    14, 16}, {15, 16}, {16, 17}, {16, 24}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2
tVTcUlFLa81lLt11dc2WOX+1zFXm+L8Bc0Tv9rkz/fbNMBkU8FZd39Dv9Xvd
p2/fPvd2+0PMz93j3YsUKTLSU/zTPTqt9YgR0emRHuKP0PTkuBiN+BEkNEwo
Cr98+ULO6OfPnx2+j9/2nnf229nZ2aSWp0+f0rt375S/HWnj96Doo5R79+7R
5MmTqWbNmtSsWTNasWIFvXnzxgST71kh169fp6FDh1L58uWpdOnStGHDBpo4
cSJptVoKELgAnxcvXuR7W78FFj179iQxtVl9fX0pMzOT0tLSGAtZPnfu3O/a
NiAXL14kHx8f0ul0PC+6dOlCUVFRjE+HDh2obt26jEX9+vXp7du3XO979B2Q
CxcukN8f/CgxMZF+GfsL9e/fn9q3b0+dOnWiuLg4mjp1KnXs2JEaN25Mr169
KhS2oW6jFEfGD7J3714qX6GCMh/MtWnTpnTnzp1CgYM5Bvj94f17u/5fyuMn
j8m3osDC3Z20er2iOqHAAvOmMK0lkA8fPtDMmTOpRYsWFBgYSAMHDqSzZ89a
7YNcT7Fu/lijBvfbBAtPTy7r06dPocEB+vHjR+or2mxu36VKlaJDhw7ZnDOQ
0WP+xs/rvDwZA2DhptGQm5sbbdu2rdBgAVm3bp2hL2I90It+QD2N49qyZUu2
GWv9gbwUfjGqfz8q4vZ/HHWeepoxY4bDvqcgKCQmJobbL3GQ6uHhQcWKFaMb
N25YxMJc/v2frTTl79NoVsZsOnHqZI77+d1XezhAoqOjc2ABG3EX/rBo0aIm
WMgxhnz69Il27drF43/ypKHvy5cvp+3btyv2NmvWLDp16pTyrYJsI5D169cb
fJ/gimosUNa8eXP2JxIHKfv27aPg4GBlTjRp0oTnUs0aNZmTP3v2jLy8vBSM
e/XqRbdu3fpm9uEK5hD0FW01950lS5akAwcOKOMpsdgoYg7ZT8wjXNu2bcvc
Cv6yTJkytGTJEqpYsSJphA+F4plq1arRtWvXvjoeeSFz5syhsLAw5kfgjZcu
XcrxzKNHj6iavz8VL16cypYty/1GTBYQEMB9x29g6C+eqWDkYPDDEo/Q0FDG
/mvhAXn58iUdO3aMjh49SidOnKDjx487rHj+zJkzzKkxt48cOcK/z58/b/IM
rjt37qSlS5fSqlWrWFeuXMnX5cuWsa+Q5cvE3xs3bqTOnTtT3759KSQkhG0G
eGzduvWrYAGBD4uMjOTvwN9Ju3RE3XEVdq7xMFw9hM9gv6mUG9TN3Y3nA+7B
n0K9vb05NoN6ijnjJf72Fr+hemELfn5+nMcAdvv37+e2oY2xsbGKneU1Fu8F
Z65h5H6uqEanNajAwUP0VaqGVUvuRp/gis6fP1/J61SuXFmJUaTv+Rq2ARtO
SUmhESNG8NURHTVqFIWFt2Eb0HrqTTi0VOBQzteXfhr2Mw0X705PT2dF3eHD
hxt+j06nNDNNTk2hxYsX0+jRozmfAalTpw5jgXFDDJ+XWOSFZC5cYLANvdYi
FrhXJ7AeP/vq9WuOyzEfFyxYwGVjx42jyB6R9Oc+USbap18/atOmDdeXWMC/
ynyGLS6bm36r131LYuudGf+YY1gb9TqrWATUrU0fsrPpt99/pxIlSii8AxIU
FGR3nowTeD1//pzKlSuX69gVgvzyuXPnaMuWLTR9+nTmM+3ataN69eqxzTVs
2JB69OjBtj9v3jzavXs3Xb16lX2JrbjKUSzeiPegDuY6yrB+Pn78mEL+GJIj
RoVqjD4Y9yZNmsTrm8QGc8tVHJBjxziosYYPh58GBq1ataJatWrxeu9h5ucw
Jta+awsLnZF/4l7tOgIL4/xOSkpS1itwbXzboj/Wegg/5K60AXjIe+DmzmCh
5v07duzgdyCXuGnTJl7nHz58qPgfCPYpkEe7efMm82Os9eB5wMtafs0WFno1
FrVrK98CN5B9io+PZxuMjo2hQQnxFJsQR7HxcRQ/JJH+JeK0tWvXMr8H32jQ
oAHXQb78/v37ytx2Bg8I8iFoF/YgnJGFCxfy9zdv3pxnWIDTVa1alcvBKwcP
TqRBov8x8QYcBgruEDc4gR789ohzQYhB4G/lfME8dsVXQMB5wXeRT1XXt4ap
2o/CdhBzd+vWLQdOrmIBgU+y5y9/Fb5tzZo17LfU5a5yTsiiRYv4HbA1VwTz
CnHU7du3c4yHK1igHjBOSEigadOmGWJVwa3Vvhb8LKxtOMeu0AEDBtDIkSNp
ypQplC04sis2AUFeCXwN8cxntEPYyVUR6x0+cpj5/j8Fv10sYsIVK1dwPu3M
r2cI+Yas51lcf8/evdw+xF15gYX5+i19Oq8dwm83bhpM/tV/NLGFMWPG5LBJ
Z7GAj8S64FvBl/7UvTt/p2IlP/L08WY/ncM2jePjI+bUD/5VKaR1a2rXIYLv
NQ5uouxvWsMC+UrwT+TnbNmFeqzUWOC6SHDN6EGxSt4CV3DU3OBw5coVqlSp
EmPRsFEj0nsb8gXIqYIXww5l3IB2yN/uAiM3EWfJ3GOlKpWptnH/CnxRHQdY
wkJjXJNdxWK+4KP9B/7FIhbO4iC/I7nJ2LFjeb38766dHAuCw2DsrHEjVnEf
NlK/QRA9zcoS3OANNRLzFjmFT6r5aoKFqIO4pK7gx3HCF4A/SN/vDBbzMjPz
HAvEWngP1kXIZeEjvIv6CJvQmNiENUXdkNDWSpvDBUetXr26dSz0hjoRnTrS
WmPOr6BgofYVPyX9lQIbNiA3MVZos0ZnX921WvYp3Xv2oL7Cj2PMsQckz45Y
wyK8fTtaKnhaQcLi7t27lJqaytw9ccgQgUcSpYp3Jouy5LRUSnFA8Vzi0CGs
ySnJNHv2bJP8mhoLrRGLtgKLZQUMC+TrEHNg7wpxBnKIaJvDqtUxr0A+Eoo8
FGJKcyyw1qr7jXhveQHDAjGg3MOBH8OaghwRuBdyB/YUeRTwG9RFnhF5OJTL
9xcWLOS3cN5HcgeMqbNy+vRp9jnAAjE29izM+1NQsLB0Xy3IMUsscCbM/Myc
PTl8+LBSH3PtwYMHOZ5xFAv1OTS1NGvezGEsHBWJBfoLBSe6fPky54wRpyI2
lvccUdR/8uQJDRs2jGOS8ePH89jK+3JttYWFmmsBC3X75LjgbJKjWMgzkPZU
YiHjGSi+g72b1oJLQxsJ/qm+b0+Rg8LeDOriPSjDeSHEU5hzsDv4FXt2gdwZ
+oF9U6zLyEUgl4k5h30PflZiIXzaADMskP+FdO3alb9rqa2yTfCJ0jb27Nlj
ojgDBDUvd1St1ceeMM4O4YydPSyQv0auFvt/2CtCHH7w4EEuk3Yh+w37Rb5C
XR+5cjlnbbUVbcIZSUv+4ltIRkaGXSyQP5S5MXOR+U9bWIAnOSOurje5UYir
64isj/0YdawMvoyzTuoy5CXzq4/fAguZV8sSsR/yXMi7wf9A4GcnTJhAERER
fPbV2ppZkDS3dmFpTlub5/ndV0ewwLkZ9FeezwoPD+ezE2ofAH/x+vVrq32y
1N/CgoG6vatXr+b+yvMRyFPDn0vujyv84ycX8pSFSSFYH3r37s02gPwGYkL4
Aux9ILarUqWKcv4qP9qXH4J1Hf+3QS3IIcsYJj/kfwH3hWE=
                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo
i0EFjVTaQqkKGk38ZTRaLaZGo0KiiUsw0hgNLnEBl0QxFIS4nd7vvnnP9woU
aWZ4Nnlfcudt9818595zvnPunfDU7IUug06n+87KPhau+j5h3bpV+V+b2EVi
fk5GqpGdxLAWyRpukgYNGjRo0KBBQx9oaWmhlJQUCg0Lo9DQUCr/oVxtSv8J
ixcvJpQ9OoOedHodP6+srFSb1oDQ2NhIZrOZfKwWsjnsZPd1cDsSEhLo9evX
atP7YFy6dIn0ej1ZYAezAbZwO+Lj6dWrV2rTGxBEvzKaTbzhvLz8/xUjb968
oWfPntHKlSvJz9+fhg4dSqWlpWrT+iA0NTXRnj17uEYhDqqrq6m1tZXHw8uX
L9Wm1ye6urvo/v37tHnzZpo1axYFBQUJ+iRr48ePp5s3b6pNtVfcu3ePqqqq
aNq0aWQwGiXOiAFRm+QalZycTO/evVObtgKwYdzn4wTuTI+gqwaTkax2m8Rf
3swWHzKZTPT48WO1qSuQl5fHbXB84itp0NixYykgMIAsNqvCBtgm6m1+fr7a
1BXIyMjgvAwGA02aNInOnz9PDQ0NFBQ8QvIrecMcIY9ER0dT50cU69AiMR7W
r1/P79XU1vBrOXe5LRY2L3h+6tQpldkLQB6GnoKTXqen3bt309u3b7lWYcyt
DluP+bCiueM9KSlJbRM4mm/domDnSF73ORi3a9eu8VxnZJol1B/vY4I3N3+T
j5nHDvrl5ORQc3OzqnbUN9TzcYcdgZ8G8ntlZWUKn3pvg51r8pw5c2jMmDFc
02AL+g4bNoyioqLo8OHDquSWuro6IcYZp+HDh/N7cXFx/B5iQtReHEXOLQ8f
8vds7hjhPok63n0eGBhILpeL7t69O2h2YPzE3586dSpduXKFj62pF53SMz2b
+eVMqbZ9+vQpbdu2jdttNAm508z8zezjw8+hH4g1Odra2qijo8PjdqBWimd1
t8PhoNOnT/MGDhh7zIEYG4h33N+/f3+v3wPdKikpoVFOpzQuX0yZQvv27eO2
oMasqKigiIgIWrp0qcftAFDzvXjxgp9j3RoeHs7ixaCYC/gd1rEPHjz41+9C
7lmQtID27t1L7R1/UfKiZIqJiaH09HQq27pV8Fe7nf+Ot1FQWNAjd+AautQf
UKsUFRfTzl27KCY2lkwWwceGDBlCf5w8Sc5Ro/j1hg0bvG4Hxo6PG6tTBlKH
tDAfLWY2oD4TfQv5UtTqrNVZlO4SaofJkydLPuANIH8EBATw/PBPrYI/HDx4
UNEffn/kyBGeN6uqf6ERrJYBT3lsoZnYut450kk/V1Xy70GfuhMnvGZHQUGB
VDNa3boKG3CN3AEOjVevSv07Ozt5LkG/FStW0OpvVys0W4ox9h7qt8LiIqYr
Qv0QFz/dKzZAE/0D/KW5sNhsNPur2eTLbICviHEyc8YMxdpje/l2fh/558ef
fyI70z4r+tuVuo0+sdNjue/hHL91/fp1j9tRxtba4lgajAYKY7oFvoWFhVLc
Y15wnpmZKb13+/Zt5k/Bghbk5dLcefOE74FGyOp9zCvWLVgbh4SE8D7Z2dke
tQFr7cjISF6jiOMu15Tly5dLfm9xx/GFCxek50uWLBHiNzKCtpRuEeozxJTb
BqtM95IWJNHGjRtp9OjRtIvpmieBWBXHHH6FvZA7d+5Iz1sfPRJqKsbP4eaz
Zs0a6Tn26MR8vqNiB02YMIHnf7uv26fY/Ioahhr5yZMn1N3d7VEbgKjoKP67
kt98k9mjpjhw4ICgAb5Cn7S0NOkZ4h1re9xftmwZ36eQ111hYWF8vwh62NXV
5XH+AGoRvk/I5h9zAW1p+rOpR7/6+nphzty6uShlkeL5zl93uuPCQYcOHSIb
0wn4KuqR1lbv5m+MOeaZ83PPxfz583vte+7cOcn3cJw7b67iOfLaiJHBPHfX
1tbSQ1YXt7e3e5W/CPg1dBV7ICI/8O0Nly9f5nUwz9fMXyZOnMjXXHIc/e0o
Xbx4cTCoK5CVlSXlPRwTExP73HNGbYx9FPg89h/8/Py4v6uNtufPeQ1iZJrO
NVGv4/VdX4APwudE/cXxzJkzg0e4D2wq2ST5u96oJydbO/T3P0ZqWqoiRo7/
fnyQ2PYOrCOwhyjuT4ETdKU/uDJdUs7HEetJNXH27Nn3c8HWSCGfhfD96f6w
du1aRTyp/Z/ajRs3+H6AmGNzc3M/6L2TbC2EGkl879ixY15m2j8wJ6j3ioqK
BvT/HtbomS4X1dTUeJGdBg0aNGjQoEHDx4W/AU6fUkQ=
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$23", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$14", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ
MRgTjSYxGkvsBY2JhVgIIsZYwHoRHXvDxN6RtizPPecs396VIKLiMDeTk3nD
ssu+73ne055zPl1iR3Qb8Lc33nhj9D/pf91ixoUmJcVM6P4P+qXVhDEJsX+n
F360mtLiN/GX/CV/yV9SRe7cuYMTJ07g7NmzKDeb61ud1yo/Z2QgMqI9vL28
EODnj+FDh+HG9Rv1rdZrkZwDBxDcOAiqhvZwdVHLUtk1xMhhw2EuL69v9epc
pqZMgkMDO+g1WnjoDfA2usPZXoVAXz+cOX26vtWrW6moQEL/GOjVGnjqjPDS
u8Hb4Aa9iwYBnt7Iysysbw3rXGZ+MgOO79jBw1UPT70R7vTT1ckFjbx9ceHc
+fpWr87lVH4+QoObQqtygsFZA70TxbCjMyaOHYfyP2H8shw6kINeXbshJCAQ
wbSmJKfgwb179a3Wa5Hi4mIcP3YcaWvW4seNP+C3a9fqW6XXImWlZUjfshUJ
8fEIaRKM4KAmeO/dPti/f399q1bncvbMWSSNGAm1kzNcHJ2g5bpLOdrR3gH+
Pr5/GsyPHz/G0u+WomWz5tAQVh1h9KCc7Gkwwuiqg7vOAKeGDhgzMgkVL3kG
39WoUaNw69atOtX9RSU3Jxfv9+0HLWHUOrtIjXXT6mDUuMprL6q7Pm4e0Dmr
pSYdOpjzUueMHj0ab775JpYvX17HCGovO7Zth6+3D9SE00nlCDXVGz3h8iEu
xdjYrozToNbK73wPwwYNhvkF+4bCwkIkJiYiJiYGR48efU1oapYHDx6gW5eu
UFFssm2bhTRF54hI+Ll7wp1weRJW5hpuZGdeRsLMdxHo5Ys8ytu1lXtUv1JT
U7FkyRLptVgqiL9VvbO8vDycP//6eMz6tPVwoVhl23bu2Am//rIXSxZ8i0Ye
PtA7usCXOaSrAV5aPTzUrnDn5aKFTuWMqRNSanXG1atXMX36dKxcuVJyhMlk
EpyMV8FcVlYmf5uWloaIiAicOnWqzrEW0tk9u/cQrF4enli9YqW8v/Dr+dA7
OMPoqIaXRi/LhzGrdXBz0sBba4C7sxZN/QJx9vSZGs84c+YMxo0bhy1btgg2
FsbLr5mfMVb+qXyWSZzcxcVFMJ+u435k69atcKPcy/bt1TNKeloT3XPS0OFQ
v+MAb8LJuHxd3QSrl1qPruHt0SmsLYwqFxhopYxPRlFRUbX7c4wmJycjOztb
cCl2ZVsqWPm1rV+zTgaDAfb29oiKisL169frBGtpaSniqPfhvtbTzR0b0zbI
+78XXEPfnr1gIJ7sq3Mj33WFn9GDfqd8TX48f9ZczPv8C/Fx9m0jxXcXiv/Z
s2cjJydH9GNOlpWVhcmTJ+PIkSOyb0lJiWA0VWJVbHo4N1fqvVLg1q1aAx31
nka9XuwwMD4Bjx4+emW8WRmZ8Kb64tigIfr36Yv7tyw55EjOIbRpESq5mPOU
sgxUk7gXzNm7H2fy8tEutLX0SRwLjo6U09Vq6ElH9sOBAwciOjraGoNKrJrL
yZ4lpYJNmRVsJo46OGEALpw5J78vn79IcoMnnamn/kRH587/at4L43v86LHc
7eULl7CNeOKg2HjY//sd6et2bd9pvd/MbTuozzVK3ZVaVLm0VKPatw5HwaUr
KCeuufTbRWgbGgYPo5vEm4ODA1QqFezs7PDWW2+hR48ekptYlFhljsp4GbeZ
fJtl04aN0Dg4ImnwMNy4fA0fJ0+Gzt6J8iP5j0YntS+QdDx18mStsR7Ytw+9
KS8NjI1DYtwALPjya8z9bBa6RnZEl/YdxNam4hJUlJqwfNESqrUuT2HlpaF+
cGTiEBQ9sPhWaWERTlA9+n7D95gzZ47EKddWxhkeHo558+ZJbLJtldgtJaxl
FEclT4rkfk2E/7PpqXKXHCvjho2U/MA5g+PIm+7dQ6eH6m07jB/7Qa3q/TWK
x6hu3eFir5Ie1s/DC0PiB+KbOXOxbsUqxPWLRpBfAFI+GC+2477Wg2KS77Uq
3sS4BDy8e1/2NRWVPHUO249reUFBAS5cuIBHjx5Z/Vhsy/XGXCH5/Ae6o/t3
7spe73bvKXHhyfWOMDNWrgceZFtvqoXM69jXPMmPfsne81y8a1etRiNfPyTG
D5AZDO8t+9M+jX39Bb+a/CmqSzecO3Ua/Xr3sXJGZXH88nu+xEE+nfYJnjwk
P+WrLrfEpCJKTVGE87aSkyVe6ePbt24jlvJk8gfj8Muu3QgkHdwYm84IN4pX
xsp1kPFK7iD7GununYgPjSUuWvUMW+HPxhK355niJx9+hGmTpshd8WIbss3V
tHwo/86eMRM3Cn6TGFW4I89vmDvzjI7viN/j2F7yzQKYyfd5cUyaKmPR1n9t
66uFV8CSp0zlmJg8UfqPyDZtZYbAZzA+rgdc293Ixgped1eLn/G8MKhRIM6d
PVeDLxegRUiIzE+b+DeSuOVczHqHUw4eM3wkRhAP5s/y806Qr51GML1WfNmb
7oHzmcbREgfsW+wLTQODsH71WlSUUU0xV1gxWvOwDXeyXSzsD9OnfQyDlu9d
KxyVzwpw94IP2diD6x/hFj5n42N8P9yfbty48Zl4169Lk77O19MLwY0aY8qE
ichI34bFZB/OV6kfThP8sRTDrGP6ps2CiesO2zg0pBm+ozzMOU3xcbY55xf+
bE9mlgUDfZfruYKpOqy2eCenTBIf5XuX2OQ5INVyT+I03oSTbczc1RavG/m1
k4MKI4YPrxZrOflYTHR/RLZth0+Juy74ep747KJ587FyyVI0DwqW85ztHLB0
0WL5zlez54jfMh7G3Z78jXNY7q8HEN6yFeUsR/lOgJeP+GBkeDvK/Zbev9xc
XqNtFbzFhU8QT3VCW3mO3KHOYMXrTjHMnNWzin0ZL88dunTubI0fW3ny5Ana
t4tA06Am6N2jJ5o3CZb6zbZLnfoRhg4YJOex/+Ydt/Q5k4gbqukOPaTWq5EQ
HUN59J7EXdaODLRpGWq1s470ZRtxz8z9jK0/14T35Il8mQ9xTvH38hZ/Zj04
X4U2DkF0917CYz3Ulvjl2JJFeJl3tSIdbtz447Mc3n8P8db+70ejkZ8/9bRO
MNDezpTnwluFYeE389G2VWsMIr7GehbRvcf0e99qWyc7e8EvtdKyIXZQLLRo
EiIxzHzASDZmLpqVtct67jNjtzKtrlm9Bq6kdwDVjAFx8ZKf2Vd4pj80YSAO
Zu9FP+KznLP4LlgXqUkUvxriBUGBjWvsnfisk/n5WLliBQYPGiR/zz19eFhr
tGrRUuY3LBfIRi2aNZc5lTv1EK7ED7+kGs1qmhgD70W5aQP1jy0oFtjnjMT7
OJ/t3Lnz+XhJ+E5HJyUJBw1v3Qabf9yETpEdrPOxcWPGorSoGNm7diHEP5Du
U4uwZi0Q1bkr3Mm+4hN0T7WdFXC94OeZCxcuRJdOnWXeeIfqPkv61nTp942C
VUP5UyfciYUiE2WV3Obh/QcY1D9O+iNPwtyEuErmzz/XCu+Vy1fQrm1bmS30
7fMeLl+8hNmfz4IjxZCO8vWszz4XP2A9pyanyHyfecGyhYsRQnbSUe7w8/HF
sWPHaoXXVpgLMB9iuX37NnoQB3Nmn6+Mk9YtW+LYUcu+jNVUQfFJejMPj6d8
7k5YfSjGmJtxv6f4Uk2xe3D/AZkbsX8NHpSIIsoxJ/NPIoxiknPvtvSfrPpl
Eqf3opieSXzz5PE8RLQJhzN9L8Df/5X6YuazY5JGQ0O+wnfMuvhSHlmxdJnc
s4l7N9K3uKzU8pPuafjAwXBtSDHs7IoQqnN79+6VvZTnK9VhZfkpPd3abydQ
7D4gX+HPl323DGGhrXDksKV35Fyxm/LjhFGjcfO36zhF/RjnSp4Hh1HueZXZ
5oply6En3+UcoqecwPrMmf0FCsmO0q9S7mecJaYyea7P709IGgtNAwfyZ63U
tX3Uj9jirerTimTs2El9rUHwdu/aDVfJv1lu3bgpn92/e5dyhFk42NXzF3Hp
tIVL7fxpu9RA9oEoqjXcX7+M8H3y83q2rYKXucCTx4UW/elcM/kxx6/yZKyY
8knK2PFwtVNJ/LJ9lZ7edk5RnY0P5x6CN3EfxutDPpSxM8OyKadv5dkbveZ+
k7kqc/SKMrPwIjX5HefnkSNGWLnqiwjPCHl2xWeLj1HsJlJM3VT+nYK5QvyK
/zML3orKOzBhKvE014ZUpx01wi15pqhITXiv/35d7Mp6c47mWllwpeApvWz7
Dz7y8MFctKO6yc/Y3cg31q1dZz2ntvNgjssPp0ylOqCR/MR5qndUL5zKP2k9
51l4K0ifjydNFbzuKrXU4+rqYXV4ubeY+8UcOY/9mn0qLiYWq1aspNx4FJcv
XZKczTMl9uXd2zPQk2oR8w3m8LF0P2wPmfHRvSszzefJhvXrJWYZK/sy/1uU
w7mH5TP2YY6hZ+HlHzOpJ2R/Njo4S31U5sW2sfqsHM14mJMxZvYtzpHu1Ns2
pt6nedNmwgFaE3flZ87MM5n/cN/eqX0kDvy6T3ST/bhm1NKnU6gfs6eeietg
KHGO7N3ZlrrHcVNuyRfPxEsya/oMylf20Dd0EryXyC4stv5VHV5lZnXiP3kY
NmSozIJYB66/nIv4DmRRrKrebgA1+VCgjx9i3uuHIzm5gpHnQcp+pvI/8ujq
ZE/2HkRQHxFJd7aJOI5iN7m7cqU3/x9eBbMiixcsFH7t8K+30blDJ5lp1Aav
7G+27HP39h2krVuHIYmD0bFDR7Rs3kJs3KRxEFpRbepJfCCJ+tU15Ot3blrq
D9uCv6/MN8uq6RueJWyTixcv1qxfVftU+iT774zUVIwcPgJbNm+WXlDZQ5mz
Po97KMLf5fvKJ8576NAhmely/uNnEjzvsupnrr7XfBmpDdaqvS3XwIePHlnq
c+Ucw3Z+Xtv9nqeX7bOHV8VbG1tYbWszu7DNiwp22zr0vL6wur1NlflW2cf2
eYTye3X71lZs966tTsrfsx5Kz62cqTwHUl6/CF5l/6q2VPZ/eg726v78/yz/
BSduaxo=
                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC
1qMIhA7HYFVAsOqMnUq4tKKCpYBQBAkzBAhYDZeQYMaAkBDydXeTlxIT4AXi
PJ26M8v//Y/3z36/3f129/cwjJ1078Rf3XbbbVPC6Z97xzyVW1Q0ZvrQEDrJ
m148YWwX+pDWrHwRv8gv8hOW+vp6rHjtdTz04EN4YORIzJw+A8eOHQu2WR2S
y5cv47k5c2HU6aFKUsKo1UGtTMagu+7GkcOHg21ewLL9n9vgstlhIhxOiw0u
qw0OixXKnvF46fkXgm1ewDL/pXkwEwaHyQK31Y40txd2oxkmtRZjRz2ICxcu
BNvEgGT5kqVwGC3w2p2CI4WODsJh0Rnw2PiJuEy583OQisNHkOFJgVmrFxyM
h/2hV6rw5wUlwTavQ7JhbSkyPT4YlGqYKZ74+MSEh3Hy+Ilgm9Zh4Xx/7tnZ
eHraDKxesRLnqqqDbVKH5OzZKmxYvx7vvP0Odn22Cw3Ewz8nqfm2BksWL8Gd
BXfC7XTBznxL/PvIxIfxny+/DLZ5AcnWT7Zg+H33Q5WYBLPBKPXCYjTBbrZA
TbVwDNX177//PthmXlMqv/4ac2bPQarHCxPVbQfZ7SQ/uKj+eZinms+thOmT
zR8F29w2cuXKFfzt3XdRkD8AWo0WFvKB3WCC02yFmzDY6LOnmXNZdcS5o4aP
xKWLl4JteitZuGABjHoDTGS/jnHojbCSpjhc0oewP7hmWOgZxsaYUp1ulP79
vWCb3iJHjhxBZnoGDNR72CgPCvLzcf89v0Om1wcn9SJss8dih8tklXO7wQwX
YdEnJePxiY/8ZOr57GefhTpZBYvJjAdGjMSeXbuxinr0vr50WDV6+KwOUQ/h
8JrtcOgpxsw2OaY53Pj04y3XfX91dTXmzJ2LHTt2/mgYuO/O7tNX4qlXRiZK
31sr119f/hc4dZQjGgO8JhupFT7ySQrhcOnNcOgIg80Fs1KLyY8+fs3319TU
IOeOHHTp0gWDBg/60XAsWlhCeWEUHBPGjce56nO4XFePqZOLYExUIYUwuMnu
FJMdPrNDMNR+V4uSlxciw+6BTa1Hb28q/k0+bE/++tZbgoFVrVHjxInO72NO
njyJ3NtzoFNr0CejFz7Y+H7T9crjGD1yFGzUF6bbXXAamtbeS7FkTFKjsbFR
nntz5RuNTvYN5X//7H6YNWsWtm7dijNnzrT8jaqqKixaVILobjGCZe3atdLn
X7x4sdNwLJw3H1ayUZesxuTHCnGh5ju5vnf3HtyVXyC86yGecjeri3Bwnvtx
sGzb+mmDl3KnKf9NcLvdyMnJQVFREZYtWybKsun9TbBarRh631BMKS7GsGHD
8NVXX90yhmpap1/n5kOToER2r97Y9slWoOGK3Ptg3QakujwyNzHf+pXP7ZQz
P5S6urrzbpNtp5N4TK1WIykpCYmJiYiNjUVhYWHLcxs2bkB8fDy69eguvkmk
50pKSnDp0s3XoK9pLUYNG4EM4tZJ7Iva81QMaZ1prd9etUZmJK4TV+PgesL8
dYWLZltpbGhoqKOYqlq1alX98OHDkZ6RAfosN7ds2QKz2YwQRShCwxQI6xqO
LiEhgicrqy/27Nlz01h4D6SyshInjh9vuXaJ4vbpqdNoDre2j4Py+mBZ2akb
vJpx1hGubwUgrU2//v3FZkW4gjRMNDI6CjHdu8n17OzsVnl1q1J99ix+T/2G
8wcx5a/nfh6+0tDQnk/8wgnUQCqNZPmhckTHxEARFoYeFFPdu3dHD1KVKpli
i+KvZxx0ej1efe3VTsNxtPyw5DjHFeeDx+YQDNxTSb4QP/mohmxct77qBq9q
bFa8sXq1rHkMYeF6mkYcmErv430KjrMecbHiG5fLhUOHDnUKjsMHy5FFHMxr
z3Z7bfT3NDo5l9mcfME4nFQHG67vE5GTVC/S09IR2TUCsd26S0+QQvWUaypz
Rkx0NMLJT/4as2nTpk7B8dE/PoSPeg1Wtp2Pk6heZ2f2lvxIszrFBofWiPw+
/equ+mpje+/749znoCNOTLO7xRdeI/WYBqusBb+HfWMg3mcMoeSbPZ9/3ik4
li9eKj06Y+A87+VLQwX1Lju2/Qt90zNhUGkk1ljZXy/OnltzPSyznn4GhsTk
Zh844CZuNiVrZD08RgtSCZtJpW3yB/HXihUrOgXHTOIqjiPGwjkxMG8Ajh+v
lHsff7hZcBlUaunn+T7jmjh2fH39pbo2w2HF0aPwUMy7KQY95IcM8gnbHK4I
Q6pgoms2t3C5P66G3DPkljE0Uv2YMHos4dBKLuiVahQ+/AjnQcszH2zchN6p
6RJjvJ/FPb2Jji8+/0KbujJ6zGixzao1wJCkknxIjO0pOGzEI2bicDthTI5L
aMGRlZXV6u/djJz55hsMHFAgM5TP5YZWmYyZ06a3eY64Svxhp76dY0VL8T9h
3Lg2z2X3yxbbmJP8dvqVeTgqIgoKhQIhFE8hzTUxmbj4VvuVfXv3Ic2XKrOU
g3ohM81+S5csaffZlTSfcMw7qZ6YlRoUPvpom2dy8/KacShaYWCbuW+J7hqJ
mMhIwvI/nEajEd/Qet6KvLL8FZmnnHYHbGaLzOgfEn+1Jwf2lyHT5UWKwQKb
SocnHms7g+Tk5optXPeiIiIQTTaHESb2QVQk1XLSOOJi5l1FaKjg02i10off
rHyxbx+y+2bJjM44eI9n0MC7rvnOL8h3KVRbMqwuWMgfkwqfaPPMHXm5YpuP
uIn5NZ1iUUezcERkhNSNmMhoKHsmICEuDqqEJCjjExFKeHbtbn+WuZFwXgwZ
/FuZpXivTUvzSCbVro83b77mdw5T3e3l8cGlJY6mfC2aNLnNM/kFA8QfV9c+
5qsE6nmT4hMo5+Opputg1enhJj4zqpv4d/HixR3GwBQzg3KZ90h4r5Bzw+v2
YH3puut+71jFUeRk9hFfOChHniya0uo+96BpGekSQ8yxzLvpNIvxXMwzjY/8
k8LcS9ddpDynMa8xjnHtcMaN5M01a2SfxE7vNlMsOQnLyhUrb/g97vv7Z/SG
S2OEhWbE4j8Utbp/6tQpifXw8HCpD7w/z3byPOmm+pcisz7NZcR57CMX1V01
xRbjyM3P6xAG5ifeW7DyHqHDIT5ZOH9BQN89QbPv7eQPF/UnZrJt6pTiVvf3
79+PqJjopnnjKj6KCAtHmsUpvQn7x0wc4eddPz9zXgUqZ8+ewcjhIySvOZ4Y
Q3FRMerrAtuLOn3yFHL7ZMOhNgiO6VOfanV/52efSZ+hoJmJ1V8fGIeFcsJC
OcXzPve8EeFdic8iEUl8Jv4IEAfHLv9urNfqZB+dsYx5aLTs0QS8DjTzDOh3
O+y0npwjz8yY0er+9u3bm+YmwRHWqtbJdcqbZKVS9sGYy1j9eR6oP7iX7peV
LbykoV6J995Onz4dMAYWnu8LCIdNqaX8YBwzW93fu3evzHyhiqb5ryV2rsLC
9YPnAH8PydzF1+/+zd0B2cB7LtMoDtzUw42g2KqoqOgQBhb+zWDo4CFQdouF
OjYBL/9pXqv7lTQr836DxNYPcAiWkC6IoplEuKy5X7Q18xXvtQQqjIVnr9ra
2g5j8MvOHTtl725q8ZPye8PVwrE7oKCgpR9nu5uUPoc2nXclLtNTT6+m+se9
fGJsHMIIc2lp6U3b9GMI43Q6ncS/Gpm/dXodtDodTCYTbDabnDM3a3RaOSYp
k5BHnHvu3Llgm95Gzp8/j4MHD+LAgTLSAygrK5M9nvLycjn3K1/nnPq5/J+C
/3f5LzkVlgk=
                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 3->
                TagBox[GridBox[{
                   {"\<\"Date: 03/24/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1,
                     10}, {1, 11}, {1, 12}, {1, 15}, {1, 16}, {1, 19}, {1, 
                    34}, {2, 5}, {2, 9}, {2, 19}, {3, 6}, {3, 12}, {3, 34}, {
                    5, 8}, {5, 10}, {5, 11}, {5, 12}, {5, 15}, {5, 16}, {5, 
                    26}, {5, 34}, {6, 8}, {6, 9}, {6, 10}, {6, 12}, {6, 16}, {
                    8, 9}, {8, 10}, {8, 11}, {8, 12}, {8, 15}, {8, 16}, {8, 
                    17}, {8, 19}, {8, 34}, {9, 10}, {9, 12}, {9, 15}, {9, 
                    17}, {9, 34}, {10, 12}, {10, 18}, {10, 19}, {11, 12}, {11,
                     34}, {12, 15}, {12, 16}, {12, 19}, {12, 24}, {12, 34}, {
                    15, 16}, {15, 26}, {16, 25}, {19, 23}, {22, 26}}}, {
                    EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc
mugXjcYZY0yccUVjVNDWFWdd4MIE9xZF776/m76n1lINKZ6jybmSh3PeeZ7r
udd1P/yQV5RW+EWHDh1Kvzb+pOVWRJeU5Fb9+JVxEFNV9lPel8aXQGP4GYOT
4oADDjjQRjQ2Nkp9fb1cu3ZNbty4IW/evLH3lNqMBw8eSP/+/cXX11dCQkJ0
XL9+3d7TajNu3bolCQkJyiMoKEg/L168aO9ptRkPHz5Ue/j4+CiPgIAAuXLl
ir2n1Wa8fPlSsrKGiLe3t3IIDg7RWPkckZeba/DwMnj4a3wQ7/bGzZs3Ze7c
ubJ8+XLZtm2bHD9+XG7fvq3+8/jxY3ny5Im8ePFC7dD8ulmam5tl+PACg4e7
+PpZJCY2yoiZBuv7yF0M7ue558+fy7Nnz/Q9jx49kvv37yvvc+fOyatXr9qN
x8GDB8Xd3V1cXV3Fy8tLIiIipGfPntKrVy8dCQnxkpySKJmD0uXnkcN0REaF
SnCIv4SGBRkjUMrHlkpVVZWUlZVJcXGxjB49WgoKCmTw4MEyYMAASUpKsr4v
NjZWevTooZ937txpNx4HDhwQi8Wicevh4aGfHHt6euqwWDzF1c1F3NxbhqfF
VUJCA5SHOby9PXQNzOd4T8uzfx/z3Tx2c3PT36EOtRew+aFDh2TFihUyffp0
KS0tNfxmuBQWFuqaZmcPkawhg2Rgxo/SJylOR2CQr9ohPCLYiHM/8Q/wkcDA
QI2V8PBwiYyMlOjoaImPj5c+ffrIwIEDJScnR/Ly8mTEiBFSVFQk48aNUz+z
JfD3pqYXRtw0aizk5eeIj6+nePt4yID0VKmprZGjR49qbJ06dUrOnDkjFy5c
0Di4e/euxtSniJLSYvEy4pwxctQwe0+nTUCP/Pb7Ef1ePrbEiIcWHsXFv+g5
bPGpo76+TgYZ+aqoeKQeV/1aIRYvN/HwdDX8vFLP4fPr1q2z5zTfC/JyTGwP
+fa7b9SfQHX1RHHq/L04O3eWiopyPUde8PPzk/Pnz9tzuq1i0aJFmh+7dOmi
OefEiRN6/urVq7J161bZtWuXnD17Vs9RP5ycnCQjI6Nd68L/AXmdmkZ97Nat
m34n77wP1Gdybffu3WXMmDFaz+2Jw4cPS0pKitYrNPmMGTOsfRJc1qxZI/v3
72/1WXQNz8B/5cqVtpy2FU1NTbJ27VrVDNTdsLAw5TJv3jzrPXPmzJGOHTuK
v7+/1onWQC3lOWKF+mprbN68WfUCepyaHBwcrFqDXsPE4sWLpVOnTtp3nD59
utX3PH36VHINPezs7CyJiYnS0NDQ6n0fC2iE/Px8nTvrzUAXDR061HoPGnjL
li3/WGdq9oYNG2Tfvn1aY8xzvXv3Vi7oRnSvLcGeAb8PB7QSueq/agK9E7qW
XooBZ3xyyZIleh2++BY6esGCBbakoSCXMi/sgu5uDfQS6L6uXbsqZ+aP/+GL
Li4uMnXqVL1v9uzZygMNuXPnTlvSUBAHxCpxsHv37n9dJ/bJx6bGRfuTJ4h9
1h5u5D36JLQzcUfMoR9tCXJ/SUmJzpU1fjs3kYOJY+ZKvUhNTdX5knPRuDt2
7NAaQr4GxAr7K5zr27ev3Lt3z6ZcqBX4Cn6SnZ2t/Slg3dPT0yUtLU3nTU5C
u+CP1PxVq1ZpXFVUVFjftXfvXu0zedfkyZNtygNcunRJ/YG1HD9+vLX3Jjaw
U11dndTU1Khfsc5RUVFaB+FhxraZq5YuXarn8bFly5bZnAv12+xN2YsAxAc8
1q9fL3/8pQs3bdqk+YGY4trJkyf1/OvXr3XgqxMmTFAuXEfH2BqzZs2y5h00
CfGQmZmpdqKHRRviN9RQ+KIvTQ7Yg0+wfft2a/+PP9p6v4i+NCsrS32CPY/L
ly9rzUM/4kvoKfyJfRHs9y7wRfZ7iCtsiz3gQtyZtdNWYO7USNab3zf3CIh1
4gM7sfcLqKeTJk1Su5j3oQGwRWhoqA7yNe+aMmWKzbUxtcTcu+H33wXrjg9V
V1erDsPvzPpDPiB2yNdmHGHH5ORkm/crzHP+/PnWPbvVq1frefyONTXzGXkA
bYWvMX/A/lK/fv2Uh6lBR40apT2ZPcB6l5eXW2P8yJGWvQfqCxzgxH4q/SK+
ZPoMfhcXF2fdh0Mz2Bv4PGuLX1DP36fN4bZw4UKtQ+ixmJgY5fip4NixY+oj
+FhlZaXU1tbKzJkzNTbIWdiH2ojt0L3UcnK1PerGh0DvBQ+z9r29l8v+Cb0L
1zlmX+hDPb69gM9MnDhR50odJJeSU6mXxDGcyE30We35P4KPAXQjfSSxS0+P
beACB+oNGvJzAXqR/5lQ57AFHPCrz/H/uHv27FF9hT9NmzbN5j15e4J9o40b
N9p7Gg444IADdsefMAqUuw==
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m
XplhKmXN1AjSOFOUjehYM86IzDg5o6CJAbIjjAu5pKC/zvnuEg8fJS3cFs7M
4bvc7y7nd7+z/L7zwua/mLNQ7+LissxCf3JyCzLz83NXPGmkfyavWJ4330AH
SbLySQzJkAzJP1KuX/8ZixbnITUtFevWr8eZM2e0NmnA0tV1CdnZj4NTjaK+
/n54Zs4cfPvdd4TxutYm/q60tDRh6pQHhO1WNzehtmE2GF2N4pzRbEJ6ejrK
ysq0NrVfqa+vxb0TUoW9FjcrqY1wSGpR1GYV83en3IMrV69qbfJtUnXiBOJi
x8jrYHOuw9wEDl6TiMhRaGtv09psB6mrq0NkVKS0DmQr22u1ucl+5bgWNpoz
uZoRFDwCDY0NWpvuIKd/+AF2uw8MJpPqSxbCYOlnXcwWVxH3tXW1Wpt+m2zd
ulVaD/rmVjk2nOHgeVerBR5enqipqdHabKeycNECgcU2TMKi+JXiW+xTfMw4
2PdOnTqltclOpZ3iNjEpHgajUbLfNkxgYR9zlTEpWDhGqqqrtTa5X9m37xuy
n2PA4uBPvAasbL/OoBfrdpxy3GDIlStXBnxP0YfbYaT1EHEir4eLXidi28fX
juGBAYhPTMArrxbg4sWLf4PVjlJZeQShYaGY9cwsfP31V3d0T3d3NybfnwG9
Xi/5D+Vek9kVOTk52LVrl8jPFy5cwNVBqn+3bt3CvNx5KjcyuZqQkpKM9wvf
Q119Xb/3HTlSQdfyWlhEnBvNVCeCgvBTV9eg2N1XGhoa4OXtBbPVVc73VujI
NxhTQFAAcufPRUXFYdy82SPZT2u3ZOmzmJgxQfi+1U32J7o+f9kyTTCwrFq1
ypFf2H7lFQaTxPcMRh2ypmRhzbq1uGd8inTOZJDyk03KRz52O74/dkwTDJ2d
nYiLi4NefNd+eJKswu/kGO5b64yEI5B86uTJk5rgqKysVONCsU/J+c5Uqt/O
z+uMeiQkJuLatWuDjoPfWVJSggdoD6F8c73RoNrbH2dyphwr6RMnDjqGvnK4
ogIv5eeL/CvWSKeDxer8+ztTrnvexB8fefRR7C7djYuUc7WU8+fPY8eOHcjI
yIDNZnPwud9S9kfGIn0DF8TGxoocUlurLc+9ceMGDh06hIWLFwnerdh3p3HD
/sn32Kmuz6T6+sWXX2iKh6WxsREbNmxAWlqawKLsvfvmBWc5gnOyyNNmI/HK
cSgkzq9174G5yMGDBzFj1kz4D79L2Kej787+xBgUHM7wqD5Hufvo0aOa4ugt
p0+fFr2quPg4tV6KvUY/fmaT6+rY2LG4fPmy1ubfJrxGJbtL8OT06fDw9FBz
t7PY4bm1xAn+6XKK9u4rVr6G0THRDvVVWQvOFzX/ol4j853ikmJMe3Ca4GsK
ptlz52ht2h8W5j7LiAfHUT05phGP/C9KT0+P1iY4COe81W+9hYmTJom+a1JS
ksidscTfma+mpI7H+LRUMSbfnYyYsWOQSvUvOycb8QkJSExIlO6jOVaubdFj
YhAdHY3omBjBRzi3Zt4/GaWfl/5tOObN+3UPyxoYGIjnlizBxo0bsWbtGmG3
wkE416RPSsfmzZuJRx7G62+8jszJmWo9Y308+wkUffQhCgsLMf3pp2hv6e3w
/KKior8cQ0FBgXi2j483Nm3ahPLyfWhualbnlz6/VNQypU++6NnF4jz30HJz
czF79mwkjksU+16FFzJ/+mDbNvUZ3Dfcv38/lr7wvLTPpHy1Z8+evwwD117R
RyBetK3XexXZ+cnHak3mfYfZbEb4qAi8uXq1sKuqqkrwxvX0HOb2/BzGwjXP
3cMdx48fd3hed083ZsycIe/zA3Gi6s/3r74sKxN7CZ1ej9dWrlTPc69E6R+8
/e47Eg7uyco1mONkXHISwsLDkZWVhdaWVnHty6+8rO7pTRYzjCaT6D/0FY7F
SffdJ67l2Ovo6PjDGKqrqzEieKTYr7G/PPjwQ9iyZQtuEobe0nXpEqZMnSK+
r+gte3uhhPZDVdVVVINr0NbWhuqT1dj58U6Miook/moSzzMTn12+fPlt762t
/RELFixAZNRoEWeMZQLtFy/RewYq9fX1iBwdJWJW4aBKn3Lj25tw4MAB7N27
V2h5eTk+/exTjI2LFZzcTDZyzIaGhWH79u2Eo53yVbzK2ZXfNjIzM1FcXCz2
xzyy7i4tFfEv9cPMKk/k/x957LEB9eZaW1uRnJys9vf5myh9Vz4WeOScI/YU
tI9V3snz3LMVPJbmPDw9EUB5jecFRprnY1bhrzqdQ45S8plyPatBVp7Ly8u7
43rE/uTn5wt3d3eKQ094ki2e3p6i5+blxaOknLt87N7SSOrrZyf1hV0e/Yf7
wZ/4nS/lJf+7/AlPAEYGB2HkyBE0jkAw+WxwSDBCQkMQEiIrHYdHhFFchSE0
IpTyRaj4DSsqahQiwkMxl3jWQLh7e3s7zp49K5T7hqyNjfIojhtVbWJtYm1y
0JaWZtIWaWxupnVuEbHSW/k9vfUc67lzpNLY0XFOcMfOzg4xDsmQDMn/W34B
PbxqvA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$25", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$19", Automatic, Center], 
                    DynamicLocation["VertexID$23", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$22", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo
i0EFjVTaQqkKGk38ZTRaLaZGo0KiiUsw0hgNLnEBl0QxFIS4nd7vvnnP9woU
aWZ4Nnlfcudt9818595zvnPunfDU7IUug06n+87KPhau+j5h3bpV+V+b2EVi
fk5GqpGdxLAWyRpukgYNGjRo0KBBQx9oaWmhlJQUCg0Lo9DQUCr/oVxtSv8J
ixcvJpQ9OoOedHodP6+srFSb1oDQ2NhIZrOZfKwWsjnsZPd1cDsSEhLo9evX
atP7YFy6dIn0ej1ZYAezAbZwO+Lj6dWrV2rTGxBEvzKaTbzhvLz8/xUjb968
oWfPntHKlSvJz9+fhg4dSqWlpWrT+iA0NTXRnj17uEYhDqqrq6m1tZXHw8uX
L9Wm1ye6urvo/v37tHnzZpo1axYFBQUJ+iRr48ePp5s3b6pNtVfcu3ePqqqq
aNq0aWQwGiXOiAFRm+QalZycTO/evVObtgKwYdzn4wTuTI+gqwaTkax2m8Rf
3swWHzKZTPT48WO1qSuQl5fHbXB84itp0NixYykgMIAsNqvCBtgm6m1+fr7a
1BXIyMjgvAwGA02aNInOnz9PDQ0NFBQ8QvIrecMcIY9ER0dT50cU69AiMR7W
r1/P79XU1vBrOXe5LRY2L3h+6tQpldkLQB6GnoKTXqen3bt309u3b7lWYcyt
DluP+bCiueM9KSlJbRM4mm/domDnSF73ORi3a9eu8VxnZJol1B/vY4I3N3+T
j5nHDvrl5ORQc3OzqnbUN9TzcYcdgZ8G8ntlZWUKn3pvg51r8pw5c2jMmDFc
02AL+g4bNoyioqLo8OHDquSWuro6IcYZp+HDh/N7cXFx/B5iQtReHEXOLQ8f
8vds7hjhPok63n0eGBhILpeL7t69O2h2YPzE3586dSpduXKFj62pF53SMz2b
+eVMqbZ9+vQpbdu2jdttNAm508z8zezjw8+hH4g1Odra2qijo8PjdqBWimd1
t8PhoNOnT/MGDhh7zIEYG4h33N+/f3+v3wPdKikpoVFOpzQuX0yZQvv27eO2
oMasqKigiIgIWrp0qcftAFDzvXjxgp9j3RoeHs7ixaCYC/gd1rEPHjz41+9C
7lmQtID27t1L7R1/UfKiZIqJiaH09HQq27pV8Fe7nf+Ot1FQWNAjd+AautQf
UKsUFRfTzl27KCY2lkwWwceGDBlCf5w8Sc5Ro/j1hg0bvG4Hxo6PG6tTBlKH
tDAfLWY2oD4TfQv5UtTqrNVZlO4SaofJkydLPuANIH8EBATw/PBPrYI/HDx4
UNEffn/kyBGeN6uqf6ERrJYBT3lsoZnYut450kk/V1Xy70GfuhMnvGZHQUGB
VDNa3boKG3CN3AEOjVevSv07Ozt5LkG/FStW0OpvVys0W4ox9h7qt8LiIqYr
Qv0QFz/dKzZAE/0D/KW5sNhsNPur2eTLbICviHEyc8YMxdpje/l2fh/558ef
fyI70z4r+tuVuo0+sdNjue/hHL91/fp1j9tRxtba4lgajAYKY7oFvoWFhVLc
Y15wnpmZKb13+/Zt5k/Bghbk5dLcefOE74FGyOp9zCvWLVgbh4SE8D7Z2dke
tQFr7cjISF6jiOMu15Tly5dLfm9xx/GFCxek50uWLBHiNzKCtpRuEeozxJTb
BqtM95IWJNHGjRtp9OjRtIvpmieBWBXHHH6FvZA7d+5Iz1sfPRJqKsbP4eaz
Zs0a6Tn26MR8vqNiB02YMIHnf7uv26fY/Ioahhr5yZMn1N3d7VEbgKjoKP67
kt98k9mjpjhw4ICgAb5Cn7S0NOkZ4h1re9xftmwZ36eQ111hYWF8vwh62NXV
5XH+AGoRvk/I5h9zAW1p+rOpR7/6+nphzty6uShlkeL5zl93uuPCQYcOHSIb
0wn4KuqR1lbv5m+MOeaZ83PPxfz583vte+7cOcn3cJw7b67iOfLaiJHBPHfX
1tbSQ1YXt7e3e5W/CPg1dBV7ICI/8O0Nly9f5nUwz9fMXyZOnMjXXHIc/e0o
Xbx4cTCoK5CVlSXlPRwTExP73HNGbYx9FPg89h/8/Py4v6uNtufPeQ1iZJrO
NVGv4/VdX4APwudE/cXxzJkzg0e4D2wq2ST5u96oJydbO/T3P0ZqWqoiRo7/
fnyQ2PYOrCOwhyjuT4ETdKU/uDJdUs7HEetJNXH27Nn3c8HWSCGfhfD96f6w
du1aRTyp/Z/ajRs3+H6AmGNzc3M/6L2TbC2EGkl879ixY15m2j8wJ6j3ioqK
BvT/HtbomS4X1dTUeJGdBg0aNGjQoEHDx4W/AU6fUkQ=
                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 4->
                TagBox[GridBox[{
                   {"\<\"Date: 03/25/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1,
                     10}, {1, 11}, {1, 12}, {1, 15}, {1, 16}, {1, 19}, {1, 
                    34}, {2, 8}, {3, 6}, {3, 9}, {3, 10}, {3, 11}, {3, 12}, {
                    3, 16}, {3, 34}, {4, 12}, {5, 6}, {5, 8}, {5, 15}, {5, 
                    26}, {5, 34}, {6, 7}, {6, 8}, {6, 9}, {6, 12}, {6, 16}, {
                    6, 34}, {7, 11}, {7, 34}, {8, 9}, {8, 10}, {8, 11}, {8, 
                    12}, {8, 15}, {8, 16}, {8, 21}, {8, 34}, {9, 10}, {9, 12},
                     {9, 15}, {9, 16}, {9, 19}, {9, 34}, {10, 19}, {12, 13}, {
                    12, 15}, {12, 16}, {12, 19}, {12, 34}, {15, 16}, {16, 
                    19}, {16, 34}, {17, 19}, {22, 26}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY
gQQBDKaJCEhIKGpxYyhbBSoxKoYQCKmIUaYg1BYghsQetjH49Hzn3XN7/WSD
C4+HK/VIx3e+6/P9Z58/PiMnZbKfj4/PdAf/SRk/8+P8/PGzUgP44lezvpqU
4c8nPZg/ZMbNmpoaagwMqq6upqqqKjnHPVw/f/5czl+8ePHOZWwoQ1YQjhUV
FSYmEM7/F7CAnj17Rps2baLk5GTq1KkT9ejRgzIzM+n06dMmnnctZ10MmwGD
KisradLkycSmLuzr70d+/v5yHtMkhjZv2dJosQADfAA0f/58kTkgyEF2Z7Bw
UGiIsI+fL0VGR9Hx48dNu2tMNqb+cOPGDWrTpo3oQDHYgoPk6G+3UXBYqGCc
Nm2aaX+NEcf+/fvJx9eXHIbs9hCn4LCxbhx8jns+fn70M/YXjWEaxxoDK449
e/bIettZdoeBwWHoRBm21bFjR/EjUGPCoT5+4cIFiomJIRvbEOR3GLalmAIc
dsE5YsQI088bm10plnHjxoms4tssvzM8TDDg2j8wQJ5tMWIWfgsfedfyg93p
0uXL1PmDriKvH8sNfQSyf/j4uuJwZm62+IbGqje1K9Xn63wHcug6gq5du0ZH
jhyhY8eOybNr16/T2HFjKbZFLNntdgoJDaXEzp1o5XffSX7XmOsJu9L10Fqo
Lox1shEvQQ8ePKA5c+ZQdHS0mfcGDRpEN2/elOdlZWV06NAhwXf//n2P5z5r
/nkZaW6ry5YeP35Mw4YNE9m7d+9Oo0aNop49e8r1hAkT6v2ep+OTylheXk5n
z56VWKOM67t379arG9CiRYtE5jFjxtCUKVOob58+lJeXRwMGDKAmTZrId3UN
1A5fN1+oH+E77muvMR8yREVFUVxcnHCLFi2oefPmtHXr1lrvKoOAEe8mJSVR
RkaGy6c5v4WHh9OsWbPIZrPRiRMn5F2r3Fa/aChrHLTKbL3W51i3U6dOiQ7A
586do5MnT4qs7r9RWTZu3Cg4Zs6cSYGBgeRwOMSfY2Njafr06RQZGSl6fR25
3fnJkyfihw8fPhSGPSs/Yn746BE9Yn769Kn4uepc9afvyjeYNRaAkCPgG337
9hU9BAcHS/4rKCigrl27UufOneV/1udbSq/CANqxY4fYSOvWraV2a9u2rRzB
CQkJch+M+9Zn+q6+g3Xv37+/qR/gSkxMlFoP6+/g3BAQEECjvviCBg4cKDY2
cuTIWnp3x4CaRGOe4qnPD2EvGzZskNy5efNmsXfl7du307Zt2+Qcz3GOo5X1
GfqhnTt3it5AsPsItptpWb+nMORqxuEb4E9Lly+jrLxc+s2YNPqh9AdTPuQL
teG9e/fS8OHDqUOHDtS7d29avny5qbf6al+NR54i7U137tpJSZ8n09dFS6UO
Bw7U5LPnFVJi1y6UkNiBOrK+xqen05kzZ8zfY01DQkLMmOBv9FajR48WrC/z
c12Hffv2SYxHfO/Vq5esRZcuXaiwsFCevyoWYp3UDqCbT5M+o5lzZlPEe9Fk
49oP9d+kL6dSy/h4kQ32jJq2Xbt2Ejfgq7BFyB4UFCRxwel0SmzA++vXrzft
sK7/XWXUxvhWUVGR6LG4uFgY17CvhvRkGu8Qp8LCwly5bspkapXQlgJYF6id
PmUdfTJ4EMX+JI7mFs6lrKws8ZOJEydKPocupEbhIxg4gAnfQuxuyHq+LG83
JPaBoI8+nOukZ7UFiszJKcPl2p+vm8U2p8zsLPo8NYU+MfwdGKZOnSo6BH7I
DfkR3xSPNf9rnntbDEKcat++veQ42FLT95tRXsEMCuZ6HH2GD/eyKaNGUmZO
NqVxjod8iHlHjx6le/fuiZ0h1wADGLpRfZSUlDRYH2+KA4Q5jvQW3E+gJh/5
29HUu99Hch7I2CLZX+A3qGtbtmwp765du1Z+u27dOpHbl/texGn4usZo+I83
cCiW1atXu3yV+yOs/0f9f0nL/rBCfAR6gVzAVVFZQTnZ2XKNnAhdgnbv3k1D
hw4V3WCmtXDhQsnF3sKgOFCvoIZCrAUO+PrcBfPFx8VvoBOu4a9yP3Lx4kWp
23B/1apVpk7hA8ip2od4Q3Z3HFeuXJFew844YEtjM8ZTQscOlJ2fR/0+7k/R
TZvIvXtGr4GYBRyoC27dumXKraR5wVsYNO4eOHBA4g3mOtAHfLopx6mmzd+n
jEkTBQ/i2JAhQ+jOnTt09epVqZ2BJScnx5RZa/i3bU/WntNa58KeIVMg+0NE
dJTUIciFyOeY5yD+6ixBazLYFK5btWpl1iCQ3VN97atwuNf6t2/flvyMWIP8
8UH3D2nytC/JF7HKMgOVOSjHJT+OS+hxMWNcuXIllZaWvpV+8L+1qdzcXFlX
2JXkYLajHlznQAdWDDbmEOQUu0PeS01NNfWJOrfai3Meq85BqHmxxshd0Ed7
9u0ly4okPumc0IrFyXka+Rt1FLDk5+f/x7ervacPdxzoNSCPylXy5xJavHSp
nFsxqH0hLodwLexEPcy/wdx67feufPjci/ND91kKepHQ0FDJxVlcQ/FTM2fo
TB32hXweHhkhuR3zQ3OOyM/e437xH0bP7m3fAKlOsGeBPgh+WlZeRjFcXyFO
QQc6f0Z+37htC4VGhNfyG3nOmAdwTH5WzyzJm/ZFhoqKuRax6kLqFJl5unLE
im+/IT/uEQON/QI8xxH1fdGKYlPP3sRhnR3h/Pr169SG+w4fltNu7AuIb7At
7fn7PpEPa542bqzLp4x9D+D1M+r7yz9eNnXtzThs3TfT+GvGJ2Odf967F1VU
VZJmnSvl5dSa8SK/KBbZx+HfZnMN+S5wqF2h9pY8yH7hbvvf/+mP8k51DffA
Na73S/+yQeoXa56ET0VxjaZ7t297/8OdsNeE+hV1uzMspNb69v1FP3rEPUSN
4OD6CeuMc76TPHxYLftyGL6kOvFkD2jVr8wUMIPHnMJY17/+bRc143oPvota
18mx1Ik9Js6LOB48eND0W1eOeC4Mwp6hAznUYZf8iHyKvhCzCOw3eNrfrTVV
5bMqwVDFNcTS4uXSI6FOtxn2ERQcbPakSxYvroVBcOg82vgeahO8qz0tGNdr
1qzxOA7U0joXB53452n6ddJnkhes+5aCw6ix0tPTa9WT7muiz3bt2iV9vfu8
Z/DgwR6Pwfp/MW/7esliijB6uQAjN1v3K7X+w/xXfVVlscZqvY/3unXrJr5l
nTOgJ8Ns3NM4JMZwfS11kyXGyF4rxxnpM/hZyohUmYGoDb0s5ijNmzfPNaNg
ewS/Dduy7iOkpaW54gtyG8uP2Sf0gDoDe/y5M76ip5UV+Me19lZexqDDhw+L
XensSnFgvuVJ21K/wJ6G7uUHMQbkYFzHxf+UStaXuuyojnV4FQ7YFuYkqDWB
QWvn2bNne9SuNF9jztEWdYexb4l9gd+NT6cfy/7livdGTG1oLgbpGsGGEHP1
2/Hx8XT+/HmPxyy1rcuXLtGCBQtoRkGB1Lgqz5t8V7+B2IXaBt+vC8P/qXHR
vwEsx0/M
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW
CQMoXUCwoLiIyiwdBQFdxgKzCOg6DmujI4hAIMDZ8513z+V/j0cqiM56mJ/7
8t69f/n+c75T/lsz4+m0wQF+fn7ZTv4vLX1su6ys9PE9gviPxPE5mRmB/OFe
bh244Uu6iVy7du3/vv2JzZ3F5o+K9e3E5urVqzcdB79dvnyZLl265HHf76nd
br2B/Prrr7Rp0yZ68cUX6bXXXqPDhw/L9/n5+ZSXl3fHMbgT2ED2799P7dq1
o5CQEAL1o8XGxtLs2bPd+nPlyh3H4LfGBnL06FFq2rSp4OEMdZLTFcrXUHI4
HRQUFEQLFi0q0ViwQbQrjOvttMfbic3MmTMFF5fLRaHhYeQIc0lz8me/wACq
36gh/XzulyKPByzATyZG+O52YXQ7sFHp1q2bW2ecrDMWLmghrD8hrEf4vHvP
v4o8Hrgb1++//55++uknexzVoz8SNl27dhVswsLCPLDRFsz47Pz44yKPB1m2
bJnwVbVq1Sg5OZmef/552rdvn/27eTWfK6zf3wIb1W/Is88+K9iEh4cLNqER
4eRge4J9BQQHUd0G9enoyRNFGk+lQ4cO0if4yt/fXz5HRUVRz549affu3R7z
v2LxPPwhmreorkGu8O/efuFWYqNzUYHu16xZU+YfavEM7Am44LsZuTPdcyyG
Pq5cuVL0Rn1eYGAgORwO23aHDRtGx44d81g75gU5dOiQ6N2cOXNo+/btdP78
efrkk0/om2++8Zj/rcbG3IuTJ0/SL7+4OfbTTz+luLg4CgwKtNcTGu6icZMm
0nmObfLxPBXQN123E9XJ7777jrZs2UITJ06k5s2bCz7BwcHC+ei/fv36tP3D
7dfnxM/lzsylsmXL2nPA/WlpaZSenk4VKlSgV1555Ya1lxYbUy+3bttK3VJT
KblDe3ooKZHSBz1Jb729mnaxri9kfz11+jSav3ABHfrqq5uO6z0H2IL6I4ja
xoULF+R67tw5epV1qUWLFm7cOUaArZUpW0bGhixessSNB8cOoYwfMISO4bvu
3btL/HXXXXfR6dOnbyk2+ew7IHPnziUHc2vaYz2pV5/HqVffPtI6de1Cnbt1
pfSMDMrJzpHYePVbb9HGjRuFH7744gv68ssvJUaEjn300Ue0Zs0a+uCDDyjv
4kWbu+CXFi9eLD4csTT45eDBg/Z8z549S+PHj5c1B3OcGczXqDLRtIrxiU+4
X2IG8D9s22XhAxzBVUOGDBE7hT7eSmwgmzdtpoCAAGp2b3N6vH8/2Q9/tqHo
cmWpQeNG1C45iVJ5f/r06SMN60Lr16+f6PTAgQNp0KBBlMH49e/fn3r16iX3
7dixw57PqVOnxDb/OnYsrV+/njp37kxTpkzx0CXIm2++STFsI4gRwGuP9u5F
VapXE5/oYK5TvXEZ+oO5TJ48+Ya1lwYbCLhFY98WcS2pt4VNAPwI44MWxFwJ
PYdviY6OpipVqlCtWrXonnvuoQYNGlDDhg2pXr168nedOnXkd3wH3TFlxowZ
wqWdOnWidevWSQOvaXyjGG3avJlc7BOhK7379aXadetQoCNEfIGDdQUxBXRG
+WnatGk+111cbMx4HfLMM8/YPiKUx8RcMocOEV2pcXdt2Tv/wOs8DHzQwJ+4
Qt/Ai7gCP1wDrfuXL19Ox9nnZGZm0ksvvSTx0oYNGyR3hY8x56rxMT5PmDhB
9MbP348S26dQh86d3HNkbJC3ABfFBlfYsq81l1RvIF8xp1asWFHySIwDvsGc
ata5m9qlJFPG4EG08o3XafqMv9MAtpukpCTRDzwDO8f+wf9K3MwNfSAWgj9J
SkyUfB26MHLkSMrOzqbPP//cjodv5m9xH3DQuDuCOWfE6KepFs8JOuzgcTCm
4p+Tk3PT9ZYGm3Hjxkn/kZGRbttFLol41+HOuR/i9V02uAD6BhvA+sC/O3fu
pK1bt0r9Aj55165dtHfvXsFE/RAE/AsuQn1D5+arNgQu1rzWFRkh/AK9xV6N
zskW/alWowZVrlyZGjVqJHwF7H3FNiW2Kf792InjVBt7gdgLemr5ANgV9gZ2
8t7770lfvmLSogqwA2ePZQ5GbqBYSayLNVlrmPi3SW59gZ8Ov56jOK0YPIr9
QsdHOtNAxhg49+jRQ/R4z5498vytwOaK5VPXvPeuey6Mi50jMSbhjA2+b5+S
4hGzFzcXNLEZPHgwTZgwgZZwnPLjjz9Kv3mX8mxc/vacOzcJYn0Vf2Tk/A4j
Hhe/wDiBY9SmELd//fXX0o/3HIuLTf5VNwc/9fQo6dsjfwTHMT7gU8QoOl5p
aggqR44cEV/72Wefyd+Xrbhqxqxc95pZX5xWjh9scY2NjZXX4p4w9l/gNOg1
MMIa4uPjJT7yXndxsYHk8bxa3d+G/AI8sQnjMbEfrVu3lvhM+ylN/UD9Ifio
VatWwim6z/M4xvZnP414F2v3R54W4C/+2mHos/gnS5fAieDGjh07Ck8CJ+Az
evRoj3VrzFlcbA5zDlk+tqLsg2lT4BuMM2vWrAL7KE7TOSIGBnefOOHO299e
8w8KY74FLuCT2KpVqBXHv3G8Z7FVKot9KS7m/gXyvfCVZ86cEf+nuRV8pubx
GqeUBJutH35IgSHBMi+PsdmeypUrZ+/rrcLGzNlkfOagmAoxEjMAg9QeaTR4
+DBKebgjte/0MD01aiQltH1QbM27bgQsxrN/hRw/fpyaNWtmcw94DaK+qyTY
vL/+n6Iz3rUqxFpt2rSx/ZL9TCmwgU2hP7WtAwcPUI3q1cmfbQexQkf2y30H
PCG2VI7ximR/VKFSLI3OzqLwqEi3Xlu6DVuL5hwUuZvKggUL7JgU+mTyTkmw
2bv/3xRdvpy7tmnYFOKtCJ5PD+bMfdb44O68/Mvi34qNDf+7xLhcuOTmriPH
jlLrNvGWf3RSJK8T+hLENnE/68lw1pcnMtLlilgGtqY1WOCD5/pyTmOuHdwO
mwI2VatWtc+HSmpT5y9eoBatWwn3hXhxHjgRc8AeLnx5iYUP5zrY9xJicxnP
89/IR8Q38pjQgao1qtMT6QNFXxH7BlscHMN6A5uHPSEGFB/O88LcNrM9moLY
QGuIyOfMOkVJsDnBz9fi/C2Ax/ewK2t/MCfwAOY8ZbrvPK6o2ORb+zdrzuzr
MQOPAZuOqVyJnhycKeNAX+IfSOAcN9Cdu1i+XP058s4kzq1gnwcOHKCFCxdK
7IdcRX3V0KFDbZ0pjt6YWO5gfxHodMdZynUhiGt4XpiT8rPEW8xzs+bOsccs
Lj6Q/eyjyrMeAm9bTy180jMHUaOmTcjF68vgz4/1eVxycNiT07JzsSee27vr
3qeFixfZNVSzntq4cWO7flMcbLxl8tQpdkyM+By2BRtLePABdz5jxVvCf6xb
UWXK0G7jPKE4GEEyoBtWHu0Z77qEd0cx78bFu3mobVIijcrKorr160nsE2Lh
0pLnd+lKPiUmJ9u46BVnRagZe6+9OHoDQUzX7L77xC84rbwFYyxdtozzrGs0
5KnhouOqy3JOx79j/Jv17e2z1T9BTp89I/UxrM/EBuOirufgOK5s+fJiW+Aj
1Pwqc6yDuP2Rbl2ljoTxX16+TPpb8eqrVIPzTdSZUftAnqtj3uBfi4nN2nfX
Ci6mXpevUIH+8+237ue4/WVMDt8T4OG/UG9D/RNSFL2B4My4+6M97DjFqZwW
5j4n1bNS9I97HkxsJ/l2rbtri4/v1j2VBj6ZIXHPqZ9/ttd16uRJqTOba0X+
WpJzBrOOnZzk1kkXx5FaN0MNU5+BoO7UMq6lzE9rj7gvNzfXJza+4jvEj6iB
Cv8yJ4TJeKGcl4RJbuKy8gA7joDtsA1VrV6NhrLu6pkqcskFzLsquhbvNRak
D0XBBmdD8HVmzQz+b+OGDfYzei/ek9CzcMVmwIABPvs381EIaqE4t9RzPzn7
Y65HDS2I+QG5PvbGO9dGg2+HX8D5wYgRIyROx5xRL0f9VscuSm2gKNhA/ssx
Ue3atYW7zPWmpKTYazKx2bZtm6zFrMumpqb63CPTJ6xYsYLKMHfrONAXfT8F
dRzUXrBWh5V3+6pFwNawZzinQm0dvlrPrbYa8U1JsTH9GO5D3d/UA61jbrB0
RmvZsFvIhvXr7TqAYoO9vBn2uE6dOtWuI0NXTFzGjBlj7zVycZflAxUPGxec
K1sxMM7LcT/qy6iNad+TJk3y4Btda1HrNzoPCGqHeuaPtUZERMjf2EMTfxNP
nKt62xTOW7yxgWCeiLuUW4CL2iueRR1dn1FBHo4zHs23lZ/lHQTuIyoy0q71
qMAn1a1bV8ZJSEiQ+qu53qJwsWkbS5culTlizqrj+Bv2hfNu836zzy5dutyA
Dd7H8aUzL7zwgn1WoToJu8FZzNq1a+25o2lNC+ek4F7E5hoPIp7R8wzFE/fr
GQQENTLsEe7BeRB4UX233lOY3iguTqsuH2b5JTlr4T3VOfviDewXdEvx1D60
Nuvtk9Re8YzqZJMmTehjK17E/RcvXrRxwflGZcYNNoUYGHkU6tRjxo2jyVOe
o9ffeIOuWfyOeMy0GZ0zzncqVapk8+C3Vgziy2d6y7x588TW9XwlzPDZ4AVT
x26IY9nW9Gwaz2gtEGcHvu7HHuh+o4E7NR/2peO9e/e+jqWVC6UZXFbQ3Mx3
PVAvwzkgnoeOrl69ulC9QcyFe7Em2L5pF8OHD/dZk9e+8M6GvItkcbXmKzgH
17l5jw99WMQ2gv0Dt3mf2Zv3rlq1SuxN54S9i4mJoX0WdxQlrjS5FJ9z2dbR
D7gIvK1j+xLoLGqpahNmfKJ+SGMS77njTNZ+V8t6VwFnwrBzc0zzObUVX7+Z
3//www9yVqx+TGvh06dPtzE23wf01bRWpn5V9wo8sGXz5gLfiVbBuymmnuMs
X8/TlFt87SvyAn3PRd+rAl4qvuZrxjfe/Zo2gPxHbVXrCm3btrX9scaPhelO
Qb76qpdP8SU4B0IcgZhk/vz5tr4UNibknXfekdoozg6RJ3jncEVtul4I/C10
GbqvZ8XgG9TXC8K9NM2X6H55f1dYnG2+QwC/gmbuZ0nmp/3hTBO2jXhSbRUx
HOR2vdteEDZmTOf9XWG6Y3JFac6nTH+alZVl2yneqVDeLIxjbiU2v1fB3uC9
Ln3P5E+5c/I/2V7k8Q==
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa
RnEZDXXSxopoFjEumDZpJbFgQUWcqp0qaatxQZPaqXZqANEgFU1YFfTp+34Y
p5mABQ0cnfGZOXCXj3Pe53u35/2wzsxJeeFbw4YNW/Bd+pEyY+G4+fNn5KV+
h97E572UOfPb9CLy1sUf4iEe4iEEbty4obUJuNHdjfN19bjafEVrU+4albt2
I+WpJIxQ/QiOisGaVavR0tKitVkDQtn2UjhMFhiHhyJK8cKhM8KmN2Laj6ei
o71Da/P6hcaLjYiOiILTaodfVuAy28TlcTihDwkVHB8EVO7cDdlkhUdywmOT
EHC64ZNccDtk4ZP583K1NrFf2F2xk+w1wetUEKmoUG0yvOQLl80Bh9GMvJde
1trEfqH58mXEjoyG4fEwRBAPjqmAywPZbIUpNBzlZX/Q2sR+44OS9yFb7LCE
6eGkGFPtMozEK2dONq5du6a1eQPCzvIKZKQ/i6QJE5H0ZCIKXluN1tY2rc1C
N/XVY8eO4+jRo6itrUVdXR3q6+vRcOECLl68iKamJrS1teHmTa0t7RtsX05W
tshfmeqpU3bCbrdD9Xjg8/owMjIKY2NikZ76I8yelYmVy1egsmIXOjvunxjq
6urGy7kLIBvM8FLtcVsdcNqp9tjscMkyrEYT1VQJil2inOjpFbLeDJ/DhR8m
TkLhrwpw5p9ntKaBn6/Ih0S5qpAfuC9HuFRE+gJQ3VSDyH6byQwnceL+wFy4
xjIHv536B+U616j4+Hg0NFzQjENZaanoyyr1MbvBhCkpaag5VoMTx2tQfaga
B/YfQFVlFVIn/QAWnQGq7IKHuVB9ChAXH3FhH5nNZmRlZVGtuj7kHPbuqYLq
UiDbyI5wHTKnz8Lly829rl22eKno1dzDFep3Hoo9H8Ug+0TsAflLkiQUbyke
Ug4fVn8In0eFRM836fWY/fyLuNJ8tde1zaTJJyZMgJV4cGx5iYtKekQxkaay
OKiPU8w5XZC4LlAsHjp0aEg4tLe3I/mZSTCQD8wGI5YuWYbWlr7rfhX7jTQI
x4/QhqSnAqQPI+iKdPb0cfark3LJQjXh6e8n9unXb5ZHG8YHxyHkkUeRm/NT
Ua/6wk1qFksWLYaddBPrdPYHa1wf5fqX+aFQrrsoZ1TyiULf26kuZM+e0+c9
m5ubcelS0z3zaG1txca3irD+zfX4+yen77j2iy9aMGZ0rKhTrAM5P5gH+4Nr
NNffVSt/gQ1vbYApTEfa0S3WsO+2bioWvm+he1TsKMfagjWY82IWYqJHIz8/
H3v37r1nLtevd+FS4yV0dHTecd3Bg9Wil/gUN7xcq8hG3y0ebsqP4MgYfH71
c7F2XUGh0LtO4sC5zz5KmvgUEim3eB/M4XoYw8JF7OXkzCPtcOyeefQXv3z1
NVgoh9ySLDh8GVdeynMp3IjFCxZ+df3KV2EOJb8wD8olrtGS0SJqnZV4eOlv
UyenoKioCI20j0MB9tWkp5NEvMtWG/ykzUW9otxwU07IBgve2fT1Ovv6mnWi
F/HloMtKvfUJmt/nZ+fi4J/+POR6uHJXpfAB57fKeUE8PLJTvHYSj4Bbxdkz
/+r1bwvXrMWoEdGYnjEDv333vSHb+96wrmAtDDRvc85Gqj7x2+9yC/s51p+h
+so53BdYw2utjTs7O5E2OVX0BsncM4tzbHNccQ9hXbyB6t39Dt7LsdGxwmbe
f7Y/QDOsk/QIv+eras+9183BBve/wtWF4hzHR72c6yZf7BfuIz7Klb9U/01r
M/uFrq4urKK661c8Ijc8t3S7yHn67MlgAg7/9cHgwjiwbz+CMXFCJ7IvWLvz
mQ/r3oDHizfWvU59+8E4Q2w4fwG52Tm346undnnEnMh6edbM52mWPz9k9tTW
1qG8vKLfs9ueXXvw/u9Kbr/f9t42REd8T+S9i3LeQbUswueHLjwccXFjcPjw
kcEy/TZOn/4HPSsOOp0OMTExWLZsOQ4f6fu5tZ/WYfyYscLmn8yeS+9rxefn
/v0pZk6dcXsesZNveIYyGo2QaJ6vqhrcOrZ9eymGPzYcfr8fJpMJoY9Tj6Pn
pqWloaxsx9fOnvJ+tlDMiQ6zRdgcHTlC9HhGJ2mWEvLTiECUmN8dDofgYrFY
EBsbi7Nne+/z3wSamv6DKWnpCCUuJr0BbspXnn2sZIeNbE0IxmP9G+vx0ZGP
8JtfvwuFNQjnM2lE/t5LNWr/H/d95Z6nak5h6rPPwULzueKi+9G+sL8XLcob
NB6M9rZ2bN1cjMRxE3rONM099ZRnVT7vYW0acHsh095KfNZDc56N5nd+vf2D
3/d6T54B5mXPg1GnJ+6kc4l/ZCASH3/8yaByYfDMsGXjZiSMCcJGmlTUUNpv
0fO4T9BsxzGnKAqsNiuWLFl6x/vxHDshYTys5DebxQoTaf1pGdNFDxoKXLly
Fe9s3ooo1S/mOaGjyAcOux1er4qQkBCkp0/pl9beR31Gov2QaO7icy8H+bGs
dMfgk/gf1NfVYWPRRsTRnGAIDYOR8sdgMCA5efKAZulXVuQLn3hofrRQ3iWS
Jm7T4Oz6s88aUUjzacZzGcjMfEH0m4GA4ys5KVnsA8emQWdA8Zatg2PsIKOm
5iTleYQ4HzbTLD56VDT13QatzborlGwrEfnOecLxtWL5K/fF//sHiu7ubszN
mgMdn48QDy/pyZMnT2lt1l2B60PwiSAee+RRcXb59tubtDbprnHi+AnqI9PI
N3Nx7lxtr2tuaj3EP8T/xX8Bd1txeg==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m
XplhKmXN1AjSOFOUjehYM86IzDg5o6CJAbIjjAu5pKC/zvnuEg8fJS3cFs7M
4bvc7y7nd7+z/L7zwua/mLNQ7+LissxCf3JyCzLz83NXPGmkfyavWJ4330AH
SbLySQzJkAzJP1KuX/8ZixbnITUtFevWr8eZM2e0NmnA0tV1CdnZj4NTjaK+
/n54Zs4cfPvdd4TxutYm/q60tDRh6pQHhO1WNzehtmE2GF2N4pzRbEJ6ejrK
ysq0NrVfqa+vxb0TUoW9FjcrqY1wSGpR1GYV83en3IMrV69qbfJtUnXiBOJi
x8jrYHOuw9wEDl6TiMhRaGtv09psB6mrq0NkVKS0DmQr22u1ucl+5bgWNpoz
uZoRFDwCDY0NWpvuIKd/+AF2uw8MJpPqSxbCYOlnXcwWVxH3tXW1Wpt+m2zd
ulVaD/rmVjk2nOHgeVerBR5enqipqdHabKeycNECgcU2TMKi+JXiW+xTfMw4
2PdOnTqltclOpZ3iNjEpHgajUbLfNkxgYR9zlTEpWDhGqqqrtTa5X9m37xuy
n2PA4uBPvAasbL/OoBfrdpxy3GDIlStXBnxP0YfbYaT1EHEir4eLXidi28fX
juGBAYhPTMArrxbg4sWLf4PVjlJZeQShYaGY9cwsfP31V3d0T3d3NybfnwG9
Xi/5D+Vek9kVOTk52LVrl8jPFy5cwNVBqn+3bt3CvNx5KjcyuZqQkpKM9wvf
Q119Xb/3HTlSQdfyWlhEnBvNVCeCgvBTV9eg2N1XGhoa4OXtBbPVVc73VujI
NxhTQFAAcufPRUXFYdy82SPZT2u3ZOmzmJgxQfi+1U32J7o+f9kyTTCwrFq1
ypFf2H7lFQaTxPcMRh2ypmRhzbq1uGd8inTOZJDyk03KRz52O74/dkwTDJ2d
nYiLi4NefNd+eJKswu/kGO5b64yEI5B86uTJk5rgqKysVONCsU/J+c5Uqt/O
z+uMeiQkJuLatWuDjoPfWVJSggdoD6F8c73RoNrbH2dyphwr6RMnDjqGvnK4
ogIv5eeL/CvWSKeDxer8+ztTrnvexB8fefRR7C7djYuUc7WU8+fPY8eOHcjI
yIDNZnPwud9S9kfGIn0DF8TGxoocUlurLc+9ceMGDh06hIWLFwnerdh3p3HD
/sn32Kmuz6T6+sWXX2iKh6WxsREbNmxAWlqawKLsvfvmBWc5gnOyyNNmI/HK
cSgkzq9174G5yMGDBzFj1kz4D79L2Kej787+xBgUHM7wqD5Hufvo0aOa4ugt
p0+fFr2quPg4tV6KvUY/fmaT6+rY2LG4fPmy1ubfJrxGJbtL8OT06fDw9FBz
t7PY4bm1xAn+6XKK9u4rVr6G0THRDvVVWQvOFzX/ol4j853ikmJMe3Ca4GsK
ptlz52ht2h8W5j7LiAfHUT05phGP/C9KT0+P1iY4COe81W+9hYmTJom+a1JS
ksidscTfma+mpI7H+LRUMSbfnYyYsWOQSvUvOycb8QkJSExIlO6jOVaubdFj
YhAdHY3omBjBRzi3Zt4/GaWfl/5tOObN+3UPyxoYGIjnlizBxo0bsWbtGmG3
wkE416RPSsfmzZuJRx7G62+8jszJmWo9Y308+wkUffQhCgsLMf3pp2hv6e3w
/KKior8cQ0FBgXi2j483Nm3ahPLyfWhualbnlz6/VNQypU++6NnF4jz30HJz
czF79mwkjksU+16FFzJ/+mDbNvUZ3Dfcv38/lr7wvLTPpHy1Z8+evwwD117R
RyBetK3XexXZ+cnHak3mfYfZbEb4qAi8uXq1sKuqqkrwxvX0HOb2/BzGwjXP
3cMdx48fd3hed083ZsycIe/zA3Gi6s/3r74sKxN7CZ1ej9dWrlTPc69E6R+8
/e47Eg7uyco1mONkXHISwsLDkZWVhdaWVnHty6+8rO7pTRYzjCaT6D/0FY7F
SffdJ67l2Ovo6PjDGKqrqzEieKTYr7G/PPjwQ9iyZQtuEobe0nXpEqZMnSK+
r+gte3uhhPZDVdVVVINr0NbWhuqT1dj58U6Miook/moSzzMTn12+fPlt762t
/RELFixAZNRoEWeMZQLtFy/RewYq9fX1iBwdJWJW4aBKn3Lj25tw4MAB7N27
V2h5eTk+/exTjI2LFZzcTDZyzIaGhWH79u2Eo53yVbzK2ZXfNjIzM1FcXCz2
xzyy7i4tFfEv9cPMKk/k/x957LEB9eZaW1uRnJys9vf5myh9Vz4WeOScI/YU
tI9V3snz3LMVPJbmPDw9EUB5jecFRprnY1bhrzqdQ45S8plyPatBVp7Ly8u7
43rE/uTn5wt3d3eKQ094ki2e3p6i5+blxaOknLt87N7SSOrrZyf1hV0e/Yf7
wZ/4nS/lJf+7/AlPAEYGB2HkyBE0jkAw+WxwSDBCQkMQEiIrHYdHhFFchSE0
IpTyRaj4DSsqahQiwkMxl3jWQLh7e3s7zp49K5T7hqyNjfIojhtVbWJtYm1y
0JaWZtIWaWxupnVuEbHSW/k9vfUc67lzpNLY0XFOcMfOzg4xDsmQDMn/W34B
PbxqvA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK
0tjkH4Fo/zjj5CBYY6DYgIVhjJgKSqVDkg/EHEcw8TWCwoCnc+7ut+0Cjib7
+Vdn5uzju99+97fnnte92pSsyFUigUDwiRxfIpNzA9evT86LEuOXoLzs1BQL
/OCN6oJKF+F/4UX+unkT6o8fh0uXLsHQ0NBrnbu7u5u9P3r0CJJWpICVxgYk
chlYW1tDeHg4XLhw4bVwfLFzJ0yarIWzLc0QFRMN5G7EIVPIQSqVsu+Ojo7Q
2dnJK0dXdxdYazRsvo15ebr5lQqQj1OBXKkEJapKpWLj2dnZvLI8fPgQpk57
Gz5H26zJygSBUAAylZKpQqVjIRUKheDj4wMDAwO8sVQePAhqyzcgYXkifBgd
ZWCRonJ2IRWJRODl5QVPnz7lhaN01y4QSyUgElsgjyXELlsKIolYZxP1OGYX
hVzBWGiNioqKeOEo3LbN4KNkCysbGzj/ayss+ygBhMimRBYVqlwmZ/e5u7tD
T0+P2Tk25uex54vlunlilsZBZGwMpKanQdFnxbByVSrYvWmPa6QAS7RXVFQU
dHR0mJ3j0+JiHYdMyjQF5+3uuQunzp4BzYTxbCwZ80vnjRvwU0MDNDU1QW9v
r9k5qqqrQUp5A/+vBfqJ16yZsH5DDri5T4VpMzwhOXUlzPV7F1akrYK4+GXg
OGkSODs7g5OTE5SWlsKzZ8/MwkFr7eLqCgILEUgwf0lkMlBbWbL4IPvQ9QUf
LITzv/8Gge+FgAVeI14Z3isWi5m9YmNj4SbWhrFKfX09e56xCnF+qVIOqjfU
LH7rfvwBvjl0CILeD2GxZUFqoVMu/zo4OMD+r/ePiYXyt5+/P2i1WrC1tWXP
newyGZy0zuzzx2vXwKHqKvALCgRPb+8R3Cp9XFmQjTDusrKyxhRXVPcuXrwI
tbW1cOzYMRgaHIKKykrmq02/nAKXKVNGMHAan5AA5ZUVMA/9ieoDXXNzc4Oy
sjI4d+7cmOxksBfGS9+TJxCPeVeprzujac6GDez+juvXIWxhhMmYQqGAHTt2
wO3bt1/Zv+/cucN6hRKMEa2LC/Npejb5s24thIb5oqKjDb/r6uqC/Px8mDhx
4r++h/eq1WrwmD4datHm/0UaGxshLS0NMjMzR9hAgjFE/ixEJu6aX4D/iGcQ
U3l5OfijHxr/3j84CI58fxTu3bv3Qo6KigpITExk/rNNXwuMlcW5RGJiF//A
gOc+j3JhA+bFJUuWsHup75g5+x1ISFoOpzGHDheqr1euXGE+SzbhcmlBQcFz
fcRY/QKez8LJQP8AVB+uhkis97PnzgGtqwuszczQjWGvcf/+fbh8+TIUY+6v
xrzb19dn8vvNmze/FEtwcPALWTih/rj38WO4desWW6f09HTm25Tj2traWC4Y
rYcejYXWSIG5T4bxIcb8TH4cEhLy0izD5eTJkyzGXiRbt25luYv1lBjTUpyb
rTnWLBleU6APU30IDgp6ZZaXlS1btrC5iYX6J6pNZAcFfqeeistr8+fP551l
DeZ+Zgd9j8vVcGYX+q5nmTd3Hu8s5JO0BqzHxflV2Pt6enuBxnYCSDE2FXoW
6nX5lMHBQcyTHqynJBZimuEzC8jDlybEG/yY3m2wB72O+Z8vobijnkao77dp
ztCIBWxsY8GmEfFlrho4mly9ehXs7O1Y38SxJK1cwcZKdpeNYGlpaeGN5cSJ
Eyxm5Hq/pfnyMA+TfFv13QiWqqoq3liO1tToar4+funzrq/2sLGGxp/ZXonq
L/V1NJabm8sby969ew15jfaJApEQqo/WsLG2P9vBZrwG5NhHqPR7tdTUVN5Y
cnJyDHWVyytn9T7RffdvcHR2YvVaoWdJSk7ijSUmJobNoaTcgv+f+uCOa9fY
GNVVT68ZhtxDNvOZ4wv9/f28sISFhen6aqxDtO+g/tW4/wnH+Ob2+hRrdg5v
wV0e9rH0/+gMg3yTO9Pw9fU16VdTML65+kAslIupLzW3UG9hb2/P1oZ6Z2JZ
vHixyT15m/IZC9UGMe431dZW0PZHm9lZ2tvbmT2Ig5TmXL16NRvjbLN7zx6D
XcTo3+Qz+7G/Nbc0NzczmxifgW3fvp2NcT3X4ZojIMBaJdXXbJZ/MB+bWw4c
OMDWRS6XG+yyb98+E5bTZ86weJajTej8g+75sqTE7Cxc/092kWEvJ8E8UldX
x8a4NaK6rNFo2DjHm5GRYXYWOpPk9nxkGzrzaW1tNWFhZxO4h6MaQMz0Tnsh
c0tycrIhtxCLnZ0d3MD9rDEL7WMozrm4JxZPT0+zswTgfoezC62PK/YxdL5q
zEKyaNEiXT+MvMTi4eFhtjMhTtatW6c7K9Of80RGRhrGaC5uvsLCQpP7AgMD
zcpBQnv6uLg4dh4TGhrK8o0xB8fy4MEDtt8lu0VERLB9H19Cc3Fn2RTLpMN5
6Bq3fq9DhjOQGrONRf4B2vW0QQ==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$7", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$7", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$7", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$21", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$17", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$22", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1
mhT4w2T7x1ZNNwtWWhSktdvE7Gqa7MqhqLFCTd1sUBRFEakC8bYezz7P8x3M
wICWDmCT+SUfM7zH976/97nfmZiSEbdK6eLikqXHP3HJObMzM5M3LFPjP1Eb
1qamqPCLPz7h+FAjOOGEE0444YQTT8Tx48fhUOUh+Pnn+081vrOzAw4ePACN
jY0DvLOBQWdnJ7ydlAh6gwFUaiVER0dBS8vlPuccOXwYvKdMBqXKBcwWM2ze
snmQdusYEOeYxYuA0iO1Tgtag46/+wf4waVLl+zOqTlcA8+bR/I4ndEAao2G
v2dkpA/y7vuH9vZ2WLBwgbx/vckoP9Tm50/cm23mVFdXw/ARw0GhVILR1cTn
pFKrIDsnGwICA+Gd1JVDxObpQJznzY9mfnqTAQxWnG24T/OF5uaLPOf7k9+D
CduVKhWON4FGi7qhcIGCgnzuv3btGuq+N6SsTBlKar2ivaMDoiXOrgJHe7wN
stx9ofVqK8t+0iRPbtPq9fxZWJhv8+4OPE/faX7wbtp78Pjx4yFi2BPEec7c
ubxn5mq0L2uJt8Td128qXL16FZqRu5f3ZG7LLyiwu0ZS8h+5Pz0jY5DZ2Qfp
dtScOQJnoxGMqKvCJ/G34mw04adJ5I2faMc0Z6rPFGj7qQ3Onj0Du3Z9bneN
zKxMQR8Mgj6sWbNmkFnaogPlPDtqtmjPtvLsTd5k993t3XuKF1y6bN/PZ2b9
WeZM43Ui9w/SVw8yWwHtHe0QMTuyS7f7+Ug6PwV918WLF2zWSF+TLnO2PkuK
E8x99QeDyvkn9LHhEeE2nPuWcV+8DRi7XAW5e3tBU9N5XmPr1q1iLNQL9uFq
sjkrvcg97U/vDwrntrY2mBk+S+ZsEO2YbNbGnp/y0Vn5QHrnZK8/cIxraGiA
iRMmYv6i7n2uqPNpaWkD6ueJ8yyRswbzMFkHrWTxy3n39PNeqPO3bt2C4qIi
G99hoyfSmqLcs7OzB4Rza2srzJwlcHZRKmDs+HGQuXYtmFBHKRftL+8ej+jn
CwsLOd99cdxYUGk1NnqhMwl5Dq1L/EkGrriP06dPO5TzlStXIGxGGO9HoVKC
2cMC1TXV3Fe8cyfmWBremyN4S/Ft/fr1/P6XPTGnwTUlndCivat0Goh/LQFe
8nwZ1LiupCc1NTWO49x6BULCQkU5K8Fj9GiuLU+cOAEhoSFw6tQp2LNnD+j0
Ot7Dr+WtwnrEgDXc0aNHoaqyCrRc1+hlX6DFdVyHucHGjRuhuLiI6z3a27zo
aHj48KFjOKOcg0NCBM545h4vjIaaI4fhUFUV1hEjuH38hAnw439Pw27mru+3
3EnOdG4q9GPbt+/g9ZfGxYn+0yTHrkjMFxrPnYOFixbx2pzz+vliDLzoEM5k
z8EhwbI9j0LOpNsPHjyAv3zyCeZoUWxfVEOMGz8efiC5l5cxd0n3fklco3cp
sAb7dNs2Xj91VaocM4gz1WnRWOdRzvDPA/+CsJkzuH9agD+cP3/eYZynW3Ee
/eIYqD1ay32PHj2Sx733fpowBp+x6H/qkXtZeTnrnsT9yfFb8Esk5x07BDmn
rFwp+HHRl1G/BvX/r9s+hfzCAj5r5uw/zbGcg6d3cR7zAtTV17E9k81Zoxb/
J35G0RdZLBY4duwYlO/dy7H1aeydxpCcP/vbZ/zO5ORkuY6VYtTiJbFQX18P
oaGhMBlzWolzU1OTQzgTNm3aJNyTaLXsL08i56rqanAf/hwUYTy1xvXr16G2
thbOnGmAKrT53Nw8WDB/PrYdgdLdu8H9OXfQoB+yla+tPVMsKCou5vclJSXJ
9xU61Bn3EcMhCP1LTGwsnKw7CT6+vsK9TWAAXLhwwd72+42oqChZd1PfXcVt
uXl5Qg7t48O+/Pbt22zn9kBnsX//frYHqY7qnp/pUJZkz5SLlezaxfMS3060
0m0T37eQby+r2Is1SLq8J+Lc3Nxsd+1fgwLMF6T1lbivzVu2cHsW5ijUTjq9
MCYGrmNd0hf+8e237Au75zQG0YdpdTr4u6g/Emf2YeLdw/IVb6D/OgB+qM8B
QYHcFhgUBJcv93032V/cuHGDY4R0J0if0r3mupxs/j9o+nS4d+9er+/Y9803
rOMKzKm627NG5Lxzp1Brv5mYKOsExemRZjN4/n4SvJOaCmcbG2HCS7/jfvI5
LS0tA8JZws2bN5H7QiEP1wt3oWT3hMysLPCc5Ant7R125369bx9zVqrVQiyz
yt053yTOn4uc33rLyg4E3+g2bBgc/O47iE+IZ39HbeTPBkrO3UE2HIP6zH5G
vAfO/TCP+z7CMzjWzbcTKr7+CtzchyFnlW3tIOZhxLmkpITHvo56LPsw0W8n
p6TAdoxlwZgHhoh5cWhY2IDLuTvu3r0LsehLre/8NuRuhPv373O8s+H8lcRZ
zT6A/INUlxJnPc4v+ULg/MaKFbIPoXg30mIG8ygLfJz/MZzDeDzS/Dz3z8Dc
ZLA5S7hz5w4seWVJ1/0W5gw563NsxpTtLWfOlHtInCUdpzbK3UtLS3nsa8uX
d/ltMe5TbffvQ/+BiMgIzr2Z84yh4yyBdP6VV18V5S7o/LrsddxXUVHBtahC
re7ht1XUhnH4i9IveWxCQoKck9A9CtV2lJvlYO1F9+5S/TMrPJxrg2cBxH1p
3FLR3vVcJ9FZWDw8WKY9OGMb3auWlZXx/GXxy0Q5GzknId0mH0Z68L+GBh7L
nCPCe9jQUIO4S/snX6RQKDDf6nnnQH6beHwpypnugazzF/J7oei3DmB8pths
GeXB/REREXyn8yyC7D3OirskX4OV36Y79NLS3fIcyusph3HBc7LOyxMxdlMu
wvVlZCT/JvQs487dLu7W9+FK0a9RLd4ddXV1MAbrOvKLRjdXPielUsnvoDt4
+v3htwDK1xKWxwt5M8qRcw43N6xDy3qdQzUV1atSrUefc+fO498ffksgnc/7
MJfrFfqtqLKy8olz6O4vZnEsePtMhdVYb9C9qRNOOOGEE0444URf+D9r9xb3

                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo
aC9aDYuyoGhxiSBKDDFawAU1irS0PaXtPL/zOMNcnXvv3Hz3XS944Dh3Zv7l
fP9/1n/0DI+dF+Xo4OAQ71r3Z15YQlBcXFjiX851N8GJf0eGO9X98K9j3zrG
Q2qmZqqjX79+0YMHD2jXrl20aNEiWrNmDV29epXevXtna9F009OnT2ny5MnU
smVLGjJkCF24cIGx4L5Lly507tw5W4tolkpLS6lPnz4E0wTPnDmT3rx5Qzt3
7qRWrVopz0+dOmVrUU1SZGQkyzl06FBavHgxhYaGUlJSEq1atYqWLFlCQUFB
5OTkRB4eHvT69Wtbi6tJb9++pQ4dOlB4eDjt3buXYmJiaO7cuTRp0iSaMWMG
PwemHTt2UIsWLSgjI+N/kev79+9UWFhInz590tUetg05R40apeiPFvfs2ZOW
LVtGr169srr8W7dupf79+1P79u2pd+/erCMVFRW6+k+dOtUkDoxZWVlpVQwg
6LTW/L6+vrqwjB492iQOV1dXys/PtyqG9PR0ZT7oMNjZ2ZltE89WrlxpdoyJ
Eycq/bVwuLm5sV+zJkVERJhcSx8fH7NjHDp0iNsCv6OjI6+BXPF8/Pjx9Pv3
b6viWL58uUkcw4cPNysD7Cs4OFizf5s2bejevXtWxQDavHmzSRzTpk3TNU51
dTXFxcVR165dqV27dsyIHffv37cygn/p5cuXHKMgM3RBbERwIEeyhOCLP378
SLW1tVaS2Djdvn3bILcQH7N7926jfSDntWvX6OzZs1RVVUVfvnyhkydPUlpa
GvuOixcv8m+8R36F6+XLl3XHpj+lr1+/0unTpyk5OZkOHjzIOZIxKi8vp7Fj
xyqYQ0JC2EZmzZplUkclf8nNzbUKhg8fPvDY8PFPnjzh66NHjzTzITzz9vY2
8NW4Aj/2RfZVfJaWL4YNYZ7/iu7evctrifittXaYb8KECXTnzh2lz+zZszVj
BXxuTk4O3bx5U7ExYKnfDthwDQwMpJ8/fzYaw/r16w3Gx3yYAyxxQN4hXoOQ
54nMWuvcr18/3pOEhAQDv1Efh8QVxJ3G0IoVKxrEcGMs7TIzMzkPx2/UR2qc
Xl5enN+iPeon2EpAQEADHwj51bkCYtOPHz/+CAPyQbUuyJhaLDmKxPUjR45Q
r169+H7kyJEsB2IGatnExET2b2iPdS4uLuacXnDj6ufnR1FRUQZzqHVWL+Xl
5XF8Rf+BAwca+BwtFh0TrOPGjaN9+/Zxrn7jxg06evQo24vsDTBhH3D//Plz
OnHihIFNYD+fPXumrA14w4YNFuNYuHChsg+wR3M4sB9YS/WetW7dmoYNG8a+
Qa137u7u7K+xPmJTNTU1XHdIG9RaILW/Qz5jCZWVlXGugL7z58/neNSjRw+z
OMT2BwwYQG3btm3QBvKjVsHeTJkyRfG5uOLMBPFRsGVlZbEsCxYsUPpjTWBP
eunAgQNKX8Tvhw8fmo1Zat+ybds29leQDeuAvU1JSaH9+/dzjd6pU6cGfcDX
r19nf4y4IvEoNjZWed+xY0eLcnrJzzt37sw5xZkzZ8ziUNs51jw6Opp9E/Qe
9P79eyX2iF+S/ROb6N69OxUVFdGtW7fo27dv3A9rInO4uLjQixcvdGFA7ob5
0Q9xDwS5tOKZll6Jj9y4caNiz0LTp083ux6oe9UxD/so77B3sH09BP3z9PTk
fvB7IKmpTeFQM87T4E9hJ3v27FHGxm+s0YgRI4zy4MGD+axR6PDhwzRo0CC2
DfhA5GvmCLlSQUGBkvfEx8ezjYtv14sDjHwWZzjwldu3b+ecasuWLbRu3TrO
D7QY7zAnfDX2ATqF/niHuL9p0yYeB1fkw8YoNTWV/aH4JrSH76qvN3oY8yH+
6W1vKc+ZM8cojsePH3Pu2rdvX257/vx5Xle1T9I7D/zU8ePHuRZGbgMdhe03
ljEWxoTvNkfw3dLOVB5nipH7NiWScxqpEfTiQBwtKSmxtfhMnz9/5rrCUhsX
hp42BULdp87TLGX4jaZAsNPG+JTVq1fbGgIT/LnolJbflWfqHENdU6EetfbZ
oB7y9/dXbFyrjkKeLs/VLHgR13HmZkuCjePcRS231n4gd1Njqa9b2dnZNsWB
8x3UcTgjvHTpEufhY8aMMZAxLCyMawq5Rz6OuHPlyhXugzM1fOtpagS51TiQ
z0sNDkZebg/fjuUbjtjxsWPHDOpEfBPDd8CmTurazJ5xIB4g3xB7Bw7Ibm84
UBdCp+T8AzZtjzjEPvBNFTKj9rZHvVJ/q8W5Dr5TqM+t8duecIi/Qv6F781y
Dx9sTziEcYaLM4Bu3bopOOwxfoidQ8eABfWwqW9TTYWWLl2q5IdgdTzHWS7O
yO1Br9auXWtQt+J/wtRnIpaeI9uKcJaFcw/8rxH+jw2EmhHfLPE/SDj7aqZm
+gf4z9WA
                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ
MRgTjSYxGkvsBY2JhVgIIsZYwHoRHXvDxN6RtizPPecs396VIKLiMDeTk3nD
ssu+73ne055zPl1iR3Qb8Lc33nhj9D/pf91ixoUmJcVM6P4P+qXVhDEJsX+n
F360mtLiN/GX/CV/yV9SRe7cuYMTJ07g7NmzKDeb61ud1yo/Z2QgMqI9vL28
EODnj+FDh+HG9Rv1rdZrkZwDBxDcOAiqhvZwdVHLUtk1xMhhw2EuL69v9epc
pqZMgkMDO+g1WnjoDfA2usPZXoVAXz+cOX26vtWrW6moQEL/GOjVGnjqjPDS
u8Hb4Aa9iwYBnt7Iysysbw3rXGZ+MgOO79jBw1UPT70R7vTT1ckFjbx9ceHc
+fpWr87lVH4+QoObQqtygsFZA70TxbCjMyaOHYfyP2H8shw6kINeXbshJCAQ
wbSmJKfgwb179a3Wa5Hi4mIcP3YcaWvW4seNP+C3a9fqW6XXImWlZUjfshUJ
8fEIaRKM4KAmeO/dPti/f399q1bncvbMWSSNGAm1kzNcHJ2g5bpLOdrR3gH+
Pr5/GsyPHz/G0u+WomWz5tAQVh1h9KCc7Gkwwuiqg7vOAKeGDhgzMgkVL3kG
39WoUaNw69atOtX9RSU3Jxfv9+0HLWHUOrtIjXXT6mDUuMprL6q7Pm4e0Dmr
pSYdOpjzUueMHj0ab775JpYvX17HCGovO7Zth6+3D9SE00nlCDXVGz3h8iEu
xdjYrozToNbK73wPwwYNhvkF+4bCwkIkJiYiJiYGR48efU1oapYHDx6gW5eu
UFFssm2bhTRF54hI+Ll7wp1weRJW5hpuZGdeRsLMdxHo5Ys8ytu1lXtUv1JT
U7FkyRLptVgqiL9VvbO8vDycP//6eMz6tPVwoVhl23bu2Am//rIXSxZ8i0Ye
PtA7usCXOaSrAV5aPTzUrnDn5aKFTuWMqRNSanXG1atXMX36dKxcuVJyhMlk
EpyMV8FcVlYmf5uWloaIiAicOnWqzrEW0tk9u/cQrF4enli9YqW8v/Dr+dA7
OMPoqIaXRi/LhzGrdXBz0sBba4C7sxZN/QJx9vSZGs84c+YMxo0bhy1btgg2
FsbLr5mfMVb+qXyWSZzcxcVFMJ+u435k69atcKPcy/bt1TNKeloT3XPS0OFQ
v+MAb8LJuHxd3QSrl1qPruHt0SmsLYwqFxhopYxPRlFRUbX7c4wmJycjOztb
cCl2ZVsqWPm1rV+zTgaDAfb29oiKisL169frBGtpaSniqPfhvtbTzR0b0zbI
+78XXEPfnr1gIJ7sq3Mj33WFn9GDfqd8TX48f9ZczPv8C/Fx9m0jxXcXiv/Z
s2cjJydH9GNOlpWVhcmTJ+PIkSOyb0lJiWA0VWJVbHo4N1fqvVLg1q1aAx31
nka9XuwwMD4Bjx4+emW8WRmZ8Kb64tigIfr36Yv7tyw55EjOIbRpESq5mPOU
sgxUk7gXzNm7H2fy8tEutLX0SRwLjo6U09Vq6ElH9sOBAwciOjraGoNKrJrL
yZ4lpYJNmRVsJo46OGEALpw5J78vn79IcoMnnamn/kRH587/at4L43v86LHc
7eULl7CNeOKg2HjY//sd6et2bd9pvd/MbTuozzVK3ZVaVLm0VKPatw5HwaUr
KCeuufTbRWgbGgYPo5vEm4ODA1QqFezs7PDWW2+hR48ekptYlFhljsp4GbeZ
fJtl04aN0Dg4ImnwMNy4fA0fJ0+Gzt6J8iP5j0YntS+QdDx18mStsR7Ytw+9
KS8NjI1DYtwALPjya8z9bBa6RnZEl/YdxNam4hJUlJqwfNESqrUuT2HlpaF+
cGTiEBQ9sPhWaWERTlA9+n7D95gzZ47EKddWxhkeHo558+ZJbLJtldgtJaxl
FEclT4rkfk2E/7PpqXKXHCvjho2U/MA5g+PIm+7dQ6eH6m07jB/7Qa3q/TWK
x6hu3eFir5Ie1s/DC0PiB+KbOXOxbsUqxPWLRpBfAFI+GC+2477Wg2KS77Uq
3sS4BDy8e1/2NRWVPHUO249reUFBAS5cuIBHjx5Z/Vhsy/XGXCH5/Ae6o/t3
7spe73bvKXHhyfWOMDNWrgceZFtvqoXM69jXPMmPfsne81y8a1etRiNfPyTG
D5AZDO8t+9M+jX39Bb+a/CmqSzecO3Ua/Xr3sXJGZXH88nu+xEE+nfYJnjwk
P+WrLrfEpCJKTVGE87aSkyVe6ePbt24jlvJk8gfj8Muu3QgkHdwYm84IN4pX
xsp1kPFK7iD7GununYgPjSUuWvUMW+HPxhK355niJx9+hGmTpshd8WIbss3V
tHwo/86eMRM3Cn6TGFW4I89vmDvzjI7viN/j2F7yzQKYyfd5cUyaKmPR1n9t
66uFV8CSp0zlmJg8UfqPyDZtZYbAZzA+rgdc293Ixgped1eLn/G8MKhRIM6d
PVeDLxegRUiIzE+b+DeSuOVczHqHUw4eM3wkRhAP5s/y806Qr51GML1WfNmb
7oHzmcbREgfsW+wLTQODsH71WlSUUU0xV1gxWvOwDXeyXSzsD9OnfQyDlu9d
KxyVzwpw94IP2diD6x/hFj5n42N8P9yfbty48Zl4169Lk77O19MLwY0aY8qE
ichI34bFZB/OV6kfThP8sRTDrGP6ps2CiesO2zg0pBm+ozzMOU3xcbY55xf+
bE9mlgUDfZfruYKpOqy2eCenTBIf5XuX2OQ5INVyT+I03oSTbczc1RavG/m1
k4MKI4YPrxZrOflYTHR/RLZth0+Juy74ep747KJ587FyyVI0DwqW85ztHLB0
0WL5zlez54jfMh7G3Z78jXNY7q8HEN6yFeUsR/lOgJeP+GBkeDvK/Zbev9xc
XqNtFbzFhU8QT3VCW3mO3KHOYMXrTjHMnNWzin0ZL88dunTubI0fW3ny5Ana
t4tA06Am6N2jJ5o3CZb6zbZLnfoRhg4YJOex/+Ydt/Q5k4gbqukOPaTWq5EQ
HUN59J7EXdaODLRpGWq1s470ZRtxz8z9jK0/14T35Il8mQ9xTvH38hZ/Zj04
X4U2DkF0917CYz3Ulvjl2JJFeJl3tSIdbtz447Mc3n8P8db+70ejkZ8/9bRO
MNDezpTnwluFYeE389G2VWsMIr7GehbRvcf0e99qWyc7e8EvtdKyIXZQLLRo
EiIxzHzASDZmLpqVtct67jNjtzKtrlm9Bq6kdwDVjAFx8ZKf2Vd4pj80YSAO
Zu9FP+KznLP4LlgXqUkUvxriBUGBjWvsnfisk/n5WLliBQYPGiR/zz19eFhr
tGrRUuY3LBfIRi2aNZc5lTv1EK7ED7+kGs1qmhgD70W5aQP1jy0oFtjnjMT7
OJ/t3Lnz+XhJ+E5HJyUJBw1v3Qabf9yETpEdrPOxcWPGorSoGNm7diHEP5Du
U4uwZi0Q1bkr3Mm+4hN0T7WdFXC94OeZCxcuRJdOnWXeeIfqPkv61nTp942C
VUP5UyfciYUiE2WV3Obh/QcY1D9O+iNPwtyEuErmzz/XCu+Vy1fQrm1bmS30
7fMeLl+8hNmfz4IjxZCO8vWszz4XP2A9pyanyHyfecGyhYsRQnbSUe7w8/HF
sWPHaoXXVpgLMB9iuX37NnoQB3Nmn6+Mk9YtW+LYUcu+jNVUQfFJejMPj6d8
7k5YfSjGmJtxv6f4Uk2xe3D/AZkbsX8NHpSIIsoxJ/NPIoxiknPvtvSfrPpl
Eqf3opieSXzz5PE8RLQJhzN9L8Df/5X6YuazY5JGQ0O+wnfMuvhSHlmxdJnc
s4l7N9K3uKzU8pPuafjAwXBtSDHs7IoQqnN79+6VvZTnK9VhZfkpPd3abydQ
7D4gX+HPl323DGGhrXDksKV35Fyxm/LjhFGjcfO36zhF/RjnSp4Hh1HueZXZ
5oply6En3+UcoqecwPrMmf0FCsmO0q9S7mecJaYyea7P709IGgtNAwfyZ63U
tX3Uj9jirerTimTs2El9rUHwdu/aDVfJv1lu3bgpn92/e5dyhFk42NXzF3Hp
tIVL7fxpu9RA9oEoqjXcX7+M8H3y83q2rYKXucCTx4UW/elcM/kxx6/yZKyY
8knK2PFwtVNJ/LJ9lZ7edk5RnY0P5x6CN3EfxutDPpSxM8OyKadv5dkbveZ+
k7kqc/SKMrPwIjX5HefnkSNGWLnqiwjPCHl2xWeLj1HsJlJM3VT+nYK5QvyK
/zML3orKOzBhKvE014ZUpx01wi15pqhITXiv/35d7Mp6c47mWllwpeApvWz7
Dz7y8MFctKO6yc/Y3cg31q1dZz2ntvNgjssPp0ylOqCR/MR5qndUL5zKP2k9
51l4K0ifjydNFbzuKrXU4+rqYXV4ubeY+8UcOY/9mn0qLiYWq1aspNx4FJcv
XZKczTMl9uXd2zPQk2oR8w3m8LF0P2wPmfHRvSszzefJhvXrJWYZK/sy/1uU
w7mH5TP2YY6hZ+HlHzOpJ2R/Njo4S31U5sW2sfqsHM14mJMxZvYtzpHu1Ns2
pt6nedNmwgFaE3flZ87MM5n/cN/eqX0kDvy6T3ST/bhm1NKnU6gfs6eeietg
KHGO7N3ZlrrHcVNuyRfPxEsya/oMylf20Dd0EryXyC4stv5VHV5lZnXiP3kY
NmSozIJYB66/nIv4DmRRrKrebgA1+VCgjx9i3uuHIzm5gpHnQcp+pvI/8ujq
ZE/2HkRQHxFJd7aJOI5iN7m7cqU3/x9eBbMiixcsFH7t8K+30blDJ5lp1Aav
7G+27HP39h2krVuHIYmD0bFDR7Rs3kJs3KRxEFpRbepJfCCJ+tU15Ot3blrq
D9uCv6/MN8uq6RueJWyTixcv1qxfVftU+iT774zUVIwcPgJbNm+WXlDZQ5mz
Po97KMLf5fvKJ8576NAhmely/uNnEjzvsupnrr7XfBmpDdaqvS3XwIePHlnq
c+Ucw3Z+Xtv9nqeX7bOHV8VbG1tYbWszu7DNiwp22zr0vL6wur1NlflW2cf2
eYTye3X71lZs966tTsrfsx5Kz62cqTwHUl6/CF5l/6q2VPZ/eg726v78/yz/
BSduaxo=
                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00
0TK1ifeuGtTVNbvruq4ao6J4Jp7xLG/AyCHqqoByiBzqs90vDOXFMDhY/ohd
9TnDfJ/99vN299Pd7ydPSo2Z+Jtu3brN+D39E5M4KyQ9PTE79nf0R2h2xkdJ
v6UvPq0X/4h38k7esjx98gQFV68ib8cOHPvpMCru3nvbJnVaGhoaMG/OXPh6
eEItk0PnpkBwUD/s3LnzbZvWKVm6eDFkTi7QypXQK9TwUGuhcpPD19cX58+f
f9vmWSXNzc0YHDkQCokURrLfU2eEnvAoCYdUJsPSpUvftolWSW1tLSIHhBMO
Gdw1OoHFqNLAXW+AXC5HZmbm2zbRahkTFwe5qwQ6hQruhMOk1UNHWJycnLBh
wwabdF++fBnHjh3rIksty47t2wUGuYsEeqUabk6ucHV0RhzhY3/ZIsnJyQgL
C8OjR48sPldfX4+a6mqb1mLZm78X8R+MRP/efRAeFIyM9Bm4ffu2TTo59xIS
EuDj44N7FRX45do1ZGdk4u6dO23P1NbWYPHX3yB68BBERQ5CRtp0XL1ypVPr
PH36FFVVVfgf2dvY0IgnVEMqab2mxiab7DdLY2Mj4RgLhUKBc+fOCXul9k44
e+p02/pZ6Rlwec8eGinzvRLO7/VAREgoysrKrFrjx4OHMH7sOIQFh6Af+WBw
eCQmxCcga8ZMLF24CNv+uwVnz5xFSUkJ7t69i+amFmxPHj9G/cN6VFZW4mb5
TZQUF6OwsBCXLl5CeXn5c2twLMWNHAUZceGSRYuQ8vEU6MnWSxcuivsnj5+A
Qa6CkS4PlRbudJnUOrj0cMQSqgUdyYkjR+Fv8oLCWQIt1T2tTAEdfaooP9Qu
Uuhob4xcR4i/enn3xMCQMExOSkba5CmYOD4RccNjMTRiEMKC+iPQ1w/eBndh
Q2BPf1y5dLltnYZHDYiLjoWauHBI+ED09QuAn6c3fikqEvf/86+Nou4yR3oQ
t5i0BrGmUipDakqKRQwNtEfxMSMgsXMQe+CrJxuUGvHdfPHfRsp3tdQNWqrt
euIA/q50lZJNblC5yogLXMQld3YVnzJHF8EPR6mnMUtzUzPGxcWLZ5jLWVdQ
QG+UlZSK+0cPHxG1V0W6GQfzPvON1Nmlw7qVvysPWvp/JraZ7DW0+vS5i373
onro7+Uj9PNajIHtUdLeehs9EODli/D+IYiLHYFpH3+CBV/Owz7iCs7tZ2UT
7Tnbz/YxF3rqjVi2cLHIDfZX8rgJkBI3sl5eh/ejb6/eKCi4ahHHvM/mQEt7
yvuto3hiHF7sz2dw6GVKRL8fhX2792D39h+Q+9cVWPTnr0UPtn7t3/AzxXXJ
9WLU1tRQf/nU4nos361bDx93k7CTL/bt1EmTcfvWLaFjwRdfIqRPkIjLyckT
Sf9xi/oeNz+m+E6iPJCKfPPU6EUMcW49i0NDOFM/mUo5/QQVd+5iCeX9vr17
O7TXkrBfzH2ohvyjIBsiQwbgGOUqSxXxRllp6Uv+fJXUEPbYqKEUV5zHKoot
3SvjSk3xzxzJ8T338zlw6GGP8AEd17KO5PstW2HSGUSs6jhWKZb476/mzRd1
0Fp58OABoohnOJ7MPjC+AgdzWNbMTOTm5sLfzw8ODg5IS0uzCQNLHfUG74dF
iL6BeclAPMX+caO8m5iYhMfE6dYI+2M4xT3nhzflscBB/PpiXLkTt3hQPvoR
BpVKBU9PT5w8edJmHLmrVgm7mZcMtIY59znGpkycZLWeJqplHyaMoxohE7nh
Sfa/Kj/4N61KLeqwRCJBSqplLrdGym+UI7R/f8qNlnrB+c7cxVgCvH1xoZNz
DvcBCuJ59oN3K0+9iMNIOFSEQalWQWfQ48iRIzbjmD9/PjQKpahF3FOzPxgP
50juipWd1rdsEc1+xNesy6xPxCrXErqYU3JmZSPAzx92dnZdMn9cPH9B1CL2
s57ykXOb40ktVyB+ZBwe1j3stE7mDK5p5vrJ+oyteJgPucadOvEzLlAPtHnz
Zty7Z/t5Q9qUaVBSD8R1yZNigNfTU9z6EbYTVIteR86ePt22H4xF6BTfeRZs
wbJu9RqbbTfLwX37BceKPCSe516O+yjOixXL//Laeutq6xBDNUTZOsey/S2f
etEDaYhPMlKndxmOjyYkQcH+Z/5QaMgfevF3/AejBH/aIjPT0oUuHeU6x5OB
fMx7pKF4ZR7p1zvwpR78dWRP3u62mOV6y/xoIN9zz8uxa6vs+mEHVNxjCQwa
EVfc/7TxOflq8cKFNq1xkfKrN/X0GlnL3nBcudO+MVdyr9YVcqO0DH1oFjDn
uHtrjpj3juPMk/J948aNr6W/tqYWcSNGirotzl9YP/VzCupl06emiHO/rpDH
1IuNHz2GfCKDTqlqs93LYGydaXRQyGgm8PBAXl5ep/V/tWCBmCHMPS7rlBOG
mSlpNEt2nmMtCfeB3NdoKScYg7fBQ8SVOV+0xF1ubm6iNzlz5ozVevlZk9Ed
OtKhIs5g/uB6lZOZJfqJrpbtW7e1xRHbz98jgkPFbMRzpZ58otFooFQqEUpz
/9WrlucaFp6NJk2aBImLK/VnLXWC8zCbZn7GUFdX1+U4bpZzvxMMvYbmDZ5b
yf9jRo3GPzd8hz69ekFBWNgW7rPcXCVIpn60I9m/dx9MFJtailUt9SCMYeb0
dHHv+y1bsGXT5i7HwZI4fgLcJMS/hEVFWAYEh+BG2Q3k0xzIZwdce3WiH5Ug
esiQDvXlZGWL826OU65Pn87KEr8f3H8AJtqT42/oXHElzatSigEjrcFY3MgH
+Xv2iHvMK2LeorjjXnt8wliLuvjcKziwr3iWrw9p7mY5/ONPgn99TZ64fv36
G8GxhvoPOfGSRq2GkvLdhfJx0783iXuzps8Qc6Gxte/6/I9/sqjrAMUUP8cX
59zJEydwrahIYJA6OGP44CE21+9XSXV1NWKiY4T9GsoBzmv2y5HWcxvu7RTE
Z4ZWf+Tt2GVR32yKIT6/4ZoxYli0+I3rrb61tvIZQvEb8Mfq3NXPYZC4uOCL
uXPb7k+bNBkSe0fRRzCWs6fb514+T40dOkzg4LxYv2at+P3B/fsYGBrWxu9/
X7e+SzHwmWZEWLjIB1En6DNxQmLbrN/U2IhxVCf5fM28l9cKi9rVx2dA/QJ6
Cxx96Nkbz5zNrqX9UlOecS0ZOybBqvMQa+UbqoH8vklF/Mj+6Nc3CAUFBW33
79+vwrBBg0WPzTHFZ4KP6ts/K+GZht/HsS9mpDx/HlH9oBpREQNFX+plMnXJ
bMlSWFAI/55+wn5zXG3buvW5Z/hcms81+Pxb4uCEzz7Nsahz+eIlcO3hIHLh
AM0bL8qKZcvFeyJHB0cstLH/NEtW5ixISSdjkMtkyJk9+6VnSktKBYcyDiXV
lzXfftuuvkbq+cbHJ8Cxux1GRseK9w8vyv2qKkRFDoS9XQ8MoTrE7ypskVOn
TsFEvZ+Keg0Z5URC/BiRiy8Kx5ifj6/okYzEAfyOoT2prKgU76h7/KG7xfnu
H9QncB5KpVIcOtS+PmskIyND9H6sKzAwEMXFxa98roJqWmhoKLp37y72r6M+
e9XKVZhAvcGtW7fafYbPIlNTU8V52OHDh9t9zhrJycmBvb09AgICOsw3PmMY
PXo08vPzbVrzWeF3jfze09a+l88+2L6iovY59J28k1+L/B+xoVyP
                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2
qGNEHY29rC7YJhY0GnFjy+gaXMtorKNuce0l9u6///fzzvM+eO/xcB5JyPDP
HLjv3nP+c75z/n5v+IDM91KcHBwcsvX8573+H7fLyuo/6g8u/CNu1IjBA5z5
4rfcmnLDTaqkSqqkSipnevHiBT1//vznXsZr0cOHD2n+ggWUlpZGvXr2pJ7c
Uoek0rz58+jBgwc/9/JsooMHD1KDBg0IJh9t27ZttHvPHnJ2dZHfkfXq0feF
35f7OiAD9+7dk1ZWOnbsGAUFBRkxODo7UX5+Pm3fUUA6d73xfiD3OXLkSDms
vohWrFhBsS1aUHBICLdgiouLo42bNtk09uXLlxT/Tryss25kXUrs3ZsyMjJo
/PjxNGHSRBqamUF9+valBg2LzqrNb9raff1YQ3Z2dtF+OTmSi5urNLV/OTNn
lsrj0qVL5O7hTmkZ6fTV+q/o8ylTaPjw4TRg0EDqP3AADRs+jCZNnkzr1q2j
rOwsctPp6MTJE3bFsXr1almvm15H7p4exubh5UmuOjdycnKiffv2WeVx584d
SvkwhTq/24V8/HyNe1C8VfHxoQ4dO1JycjJdvHjRbhiesT60a9+eHBwdZN1o
wKDnvVV4MD9kwhbq1KWz9Nfuh97QFK+WrVvZbf2KoM/BoSEiR9q5tc3B0ZFi
mje3iV9040ai3+YwoOFZw+gou+O4f/8+hb5RQ+yiZRwOFBNbOg74vLqRkeTk
4myRF3DUrRdpdxyYOyEhoYQsmODgZ1kjsm3i1yuxl/RX8mnS+B6ede7Sxe44
QLt27SJnZ2ezZwL75cO6efr0aZt47WGfhz13cSvJy4VthiPL6Pbt28sFB2ju
3Lmk1+uNthc6gWsf32q0Kd82H6Joztw5sl7lC9GUvZo1e1Y5IXhFhw4dovT0
dIqNjaVWrVrR6NGj6fQp286hOG3dupXi4+MpKjqaohpFU7u4dpS/Od/OK/51
0dGjRykjM5OSkpLYP/SR/7379KG+Sf3kf1JykviN5P4fUD9+Jq1fP+mXxH6s
b7++1KNHDzpw4ACdP3+ehmdlUWKvRJo+fbrwP3funPTvw7zOnDkj96ZNm0Zd
u3Wl9KHpdNgOMdbKv62kKlWrWPS7traBgwbR0qVLyD/A33gvsn49unv3rszT
tm1b9j0xcv306VNq3iLW2M+nmg9t2LDhtTHkb95MLq6uRvukQ2P/rbdgd1XT
xqwS67VtQ3m5eeTp7WX0GW7cx5v358aNG7Lffv7+5OHpKfH7XYPPRayDvjLG
3Z0KduwoMwbEQfU55nRkm2RtzcUbYq+AoEDe/4GUmprKedEQ+obtZ4uWLYt8
j8ZfeDGuvLw88YmYB/sVFhZGc+bMEYwmMQ/72IZRUWXOr2BflZ/C/oKnWZ9l
xo80a9bMhNeatWvEvoIHcKr1gZ9XFW85c8Q7wKHiHm38hvmVn12yZInNGB49
eiQ5ghPbc/DwC/Tn+LOqyf5Yw6GNsRAHvJ/wvuynnnn5BwZQVZZ3xQvyBflp
0aolvc3yh2tZO/jxf8zr6+8n/Rx4Pb/v2lX0xxY6f+GC8RywrgzObWpH1DHZ
S6vnERNj5HX16lXyY9125bHA8hHLWiOOEbXxJmRq5Mcj6dOxn/K1E3l4FMWM
wBTBuVYC5+3QEfCo6utD165dswlHbm6u+FasG2vYtXs31axdy2qsa+k8NnGe
6OrmJmuCnv/9228pmn2eNrbRKxnj5+6Gc5D4hOerUzeClixdKmOxHhcehzzI
FoJ+QhaxB/Xq1xf8ITVCjfaj1PNo/uo8xowZI7wwFvHydeYVyXqtxQEMEpMU
synAEV4znAoLD1JYeLjwAK9Ro0aVDoJz1+7duxfZTJaDHizbsF1lwaE9j6FD
hxbtCceXbdhHII9BXq7F4crrjWsfRx07dZJrDw2ON8Peogss5+3i4xhrUSw2
hG1gaXSP/VLjJk3kLDDms/GfiV5p7XlZ9AOyrfyImr92ndomOKAT2Rzv/5nP
zsmgHwrHG2++SVeuXKGkD5KNsSnqGs+ePbOK43+XLtFb4WHG+gFsOeoL1UOC
y4wDdg9+2dGlKI4dO3as3K/FulY89lc1i+L6UYNl8faPP9KIkX8UHhgXERFB
t2/ftorj3PlzYueULC5cuLDsOAz+49atW1QTe2/gNXHiRAOO2iVwyPmzjmh9
FHBApxC7oCak9CyEZaM0m3Xy5Emj/8G4ZcuW0Ysy4lBxEmyuyunBa+rUqWZx
4Lprt27sZxLI2cXFRD8UjhmzZgoPHec+AQEBdPnyZas4jh8/LuMVjpUrV4ov
KxMOg1xhLsQosJfgNeOLGWZxwAYM/jCFModlit3yMOwj+igcyLmk5qTTUTU/
X5tx6Dz0r41D6QdqbvDfCkdOTo5FuVJxifaeyBDbSdi4hQsWGOXKJhw//GBy
HqiBvi4OdR6uxvP4wiIOcw19arC9gr2YMmWKCQ7skTWCfkhsrtEPS3qOeYqv
R4vDqB8GPUduVITDvL0qfg/nGBwaSimDB1P16tVFNxAr+XOMX9p5nD17VuI4
lUMsWrTILA7wbNy0CTWIamhSJ9Xqx/Xr18WPKds3+fPJZnFgPHKEaM7PVWxr
nMewDvSBLYNdC+QzBm9r9N+LFymIsTtr/AdIi0N0kHXz661fU25erklNSxuX
QD8lhzHUQT75yydyv7gfxLN58+fTpvx8E17AEFg9SGI7eS/CvD29vCQPgW+0
RvCTiYmJwq+ary/t37+fHj9+bBZHwY4CWrV6VUkcMa/yD/hpPPf29pZ8Cmdr
Dsdizis2c/6JaxVTY++jODbe9s02+Y28srCwUOpokFHorTXCPi5evJgOHz4s
v2+x7yyBg+08clBz5xGjiROxB3gHgPlBT548KaHnIr8838aNG014AUctzhdA
f+LYcO/evfSv//xb6kSQXfAuC5nFweexkXP/vFV5FuXKHGFuczjmfvmlvJPS
8kIf5D3Yd+TxHTp0oFC2w0PS0mjcuHGl6khpOGQOxoHcwl44oIfFz0PhUPu+
ZcsWKigokOsTJ04Y/VFFwQFZNEcL2DdCf20lxJbBv0AcWBdiT1trKL9UHCDI
2Zo1ayo8DtCkSZOk3lrRcSDvVTlBRcYBQly+o5S6aUXAgW9VTp06VeFx2EKV
OGzHgbr4rwHH0uXLfnIcKk4sbxyIdysaDktxe0XD8Ve2/xvKWa5QFwzi/LI4
Drx7NJdHNWnW1CoO1M5NcDg60CqOkczmUZw72gsH6kdhNcPl/RRyfaml8Nz/
PHRIzkTN7WH4LqT1260t8nr+7Lm8x1FjVF0GueX+f+w33RO+Rh3Dnt+RLlu+
XM5A1c67/O5dqcMjJ0OdR933ruJtzHUs0foN6+UdmxqDd6CQ3UePH9E7HTsY
7+v0Olq7bq3dMCjCdysDBw+i2bNnm3xfefPmTZowYQKlfpQq34HaQnu/+45S
UlLkuz5t7Ry1gZwZOTSI59m5c6e9IVTST0z/B0Y4Ieo=
                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 5->
                TagBox[GridBox[{
                   {"\<\"Date: 03/26/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 3}, {1, 5}, {1, 6}, {1, 7}, {1, 8}, {1, 9}, {1,
                     10}, {1, 12}, {1, 13}, {1, 14}, {1, 15}, {1, 16}, {1, 
                    18}, {1, 19}, {1, 21}, {1, 23}, {1, 26}, {1, 34}, {3, 
                    6}, {3, 9}, {3, 11}, {3, 16}, {3, 23}, {4, 19}, {5, 6}, {
                    5, 8}, {5, 11}, {5, 12}, {5, 34}, {6, 9}, {6, 11}, {6, 
                    12}, {6, 16}, {6, 34}, {8, 9}, {8, 10}, {8, 11}, {8, 
                    12}, {8, 15}, {8, 16}, {8, 34}, {9, 11}, {9, 12}, {9, 
                    15}, {9, 16}, {9, 19}, {9, 34}, {10, 12}, {10, 16}, {10, 
                    18}, {10, 19}, {11, 12}, {11, 16}, {11, 19}, {12, 15}, {
                    12, 16}, {12, 19}, {12, 34}, {14, 16}, {15, 16}, {16, 
                    17}, {16, 19}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW
CQMoXUCwoLiIyiwdBQFdxgKzCOg6DmujI4hAIMDZ8513z+V/j0cqiM56mJ/7
8t69f/n+c75T/lsz4+m0wQF+fn7ZTv4vLX1su6ys9PE9gviPxPE5mRmB/OFe
bh244Uu6iVy7du3/vv2JzZ3F5o+K9e3E5urVqzcdB79dvnyZLl265HHf76nd
br2B/Prrr7Rp0yZ68cUX6bXXXqPDhw/L9/n5+ZSXl3fHMbgT2ED2799P7dq1
o5CQEAL1o8XGxtLs2bPd+nPlyh3H4LfGBnL06FFq2rSp4OEMdZLTFcrXUHI4
HRQUFEQLFi0q0ViwQbQrjOvttMfbic3MmTMFF5fLRaHhYeQIc0lz8me/wACq
36gh/XzulyKPByzATyZG+O52YXQ7sFHp1q2bW2ecrDMWLmghrD8hrEf4vHvP
v4o8Hrgb1++//55++uknexzVoz8SNl27dhVswsLCPLDRFsz47Pz44yKPB1m2
bJnwVbVq1Sg5OZmef/552rdvn/27eTWfK6zf3wIb1W/Is88+K9iEh4cLNqER
4eRge4J9BQQHUd0G9enoyRNFGk+lQ4cO0if4yt/fXz5HRUVRz549affu3R7z
v2LxPPwhmreorkGu8O/efuFWYqNzUYHu16xZU+YfavEM7Am44LsZuTPdcyyG
Pq5cuVL0Rn1eYGAgORwO23aHDRtGx44d81g75gU5dOiQ6N2cOXNo+/btdP78
efrkk0/om2++8Zj/rcbG3IuTJ0/SL7+4OfbTTz+luLg4CgwKtNcTGu6icZMm
0nmObfLxPBXQN123E9XJ7777jrZs2UITJ06k5s2bCz7BwcHC+ei/fv36tP3D
7dfnxM/lzsylsmXL2nPA/WlpaZSenk4VKlSgV1555Ya1lxYbUy+3bttK3VJT
KblDe3ooKZHSBz1Jb729mnaxri9kfz11+jSav3ABHfrqq5uO6z0H2IL6I4ja
xoULF+R67tw5epV1qUWLFm7cOUaArZUpW0bGhixessSNB8cOoYwfMISO4bvu
3btL/HXXXXfR6dOnbyk2+ew7IHPnziUHc2vaYz2pV5/HqVffPtI6de1Cnbt1
pfSMDMrJzpHYePVbb9HGjRuFH7744gv68ssvJUaEjn300Ue0Zs0a+uCDDyjv
4kWbu+CXFi9eLD4csTT45eDBg/Z8z549S+PHj5c1B3OcGczXqDLRtIrxiU+4
X2IG8D9s22XhAxzBVUOGDBE7hT7eSmwgmzdtpoCAAGp2b3N6vH8/2Q9/tqHo
cmWpQeNG1C45iVJ5f/r06SMN60Lr16+f6PTAgQNp0KBBlMH49e/fn3r16iX3
7dixw57PqVOnxDb/OnYsrV+/njp37kxTpkzx0CXIm2++STFsI4gRwGuP9u5F
VapXE5/oYK5TvXEZ+oO5TJ48+Ya1lwYbCLhFY98WcS2pt4VNAPwI44MWxFwJ
PYdviY6OpipVqlCtWrXonnvuoQYNGlDDhg2pXr168nedOnXkd3wH3TFlxowZ
wqWdOnWidevWSQOvaXyjGG3avJlc7BOhK7379aXadetQoCNEfIGDdQUxBXRG
+WnatGk+111cbMx4HfLMM8/YPiKUx8RcMocOEV2pcXdt2Tv/wOs8DHzQwJ+4
Qt/Ai7gCP1wDrfuXL19Ox9nnZGZm0ksvvSTx0oYNGyR3hY8x56rxMT5PmDhB
9MbP348S26dQh86d3HNkbJC3ABfFBlfYsq81l1RvIF8xp1asWFHySIwDvsGc
ata5m9qlJFPG4EG08o3XafqMv9MAtpukpCTRDzwDO8f+wf9K3MwNfSAWgj9J
SkyUfB26MHLkSMrOzqbPP//cjodv5m9xH3DQuDuCOWfE6KepFs8JOuzgcTCm
4p+Tk3PT9ZYGm3Hjxkn/kZGRbttFLol41+HOuR/i9V02uAD6BhvA+sC/O3fu
pK1bt0r9Aj55165dtHfvXsFE/RAE/AsuQn1D5+arNgQu1rzWFRkh/AK9xV6N
zskW/alWowZVrlyZGjVqJHwF7H3FNiW2Kf792InjVBt7gdgLemr5ANgV9gZ2
8t7770lfvmLSogqwA2ePZQ5GbqBYSayLNVlrmPi3SW59gZ8Ov56jOK0YPIr9
QsdHOtNAxhg49+jRQ/R4z5498vytwOaK5VPXvPeuey6Mi50jMSbhjA2+b5+S
4hGzFzcXNLEZPHgwTZgwgZZwnPLjjz9Kv3mX8mxc/vacOzcJYn0Vf2Tk/A4j
Hhe/wDiBY9SmELd//fXX0o/3HIuLTf5VNwc/9fQo6dsjfwTHMT7gU8QoOl5p
aggqR44cEV/72Wefyd+Xrbhqxqxc95pZX5xWjh9scY2NjZXX4p4w9l/gNOg1
MMIa4uPjJT7yXndxsYHk8bxa3d+G/AI8sQnjMbEfrVu3lvhM+ylN/UD9Ifio
VatWwim6z/M4xvZnP414F2v3R54W4C/+2mHos/gnS5fAieDGjh07Ck8CJ+Az
evRoj3VrzFlcbA5zDlk+tqLsg2lT4BuMM2vWrAL7KE7TOSIGBnefOOHO299e
8w8KY74FLuCT2KpVqBXHv3G8Z7FVKot9KS7m/gXyvfCVZ86cEf+nuRV8pubx
GqeUBJutH35IgSHBMi+PsdmeypUrZ+/rrcLGzNlkfOagmAoxEjMAg9QeaTR4
+DBKebgjte/0MD01aiQltH1QbM27bgQsxrN/hRw/fpyaNWtmcw94DaK+qyTY
vL/+n6Iz3rUqxFpt2rSx/ZL9TCmwgU2hP7WtAwcPUI3q1cmfbQexQkf2y30H
PCG2VI7ximR/VKFSLI3OzqLwqEi3Xlu6DVuL5hwUuZvKggUL7JgU+mTyTkmw
2bv/3xRdvpy7tmnYFOKtCJ5PD+bMfdb44O68/Mvi34qNDf+7xLhcuOTmriPH
jlLrNvGWf3RSJK8T+hLENnE/68lw1pcnMtLlilgGtqY1WOCD5/pyTmOuHdwO
mwI2VatWtc+HSmpT5y9eoBatWwn3hXhxHjgRc8AeLnx5iYUP5zrY9xJicxnP
89/IR8Q38pjQgao1qtMT6QNFXxH7BlscHMN6A5uHPSEGFB/O88LcNrM9moLY
QGuIyOfMOkVJsDnBz9fi/C2Ax/ewK2t/MCfwAOY8ZbrvPK6o2ORb+zdrzuzr
MQOPAZuOqVyJnhycKeNAX+IfSOAcN9Cdu1i+XP058s4kzq1gnwcOHKCFCxdK
7IdcRX3V0KFDbZ0pjt6YWO5gfxHodMdZynUhiGt4XpiT8rPEW8xzs+bOsccs
Lj6Q/eyjyrMeAm9bTy180jMHUaOmTcjF68vgz4/1eVxycNiT07JzsSee27vr
3qeFixfZNVSzntq4cWO7flMcbLxl8tQpdkyM+By2BRtLePABdz5jxVvCf6xb
UWXK0G7jPKE4GEEyoBtWHu0Z77qEd0cx78bFu3mobVIijcrKorr160nsE2Lh
0pLnd+lKPiUmJ9u46BVnRagZe6+9OHoDQUzX7L77xC84rbwFYyxdtozzrGs0
5KnhouOqy3JOx79j/Jv17e2z1T9BTp89I/UxrM/EBuOirufgOK5s+fJiW+Aj
1Pwqc6yDuP2Rbl2ljoTxX16+TPpb8eqrVIPzTdSZUftAnqtj3uBfi4nN2nfX
Ci6mXpevUIH+8+237ue4/WVMDt8T4OG/UG9D/RNSFL2B4My4+6M97DjFqZwW
5j4n1bNS9I97HkxsJ/l2rbtri4/v1j2VBj6ZIXHPqZ9/ttd16uRJqTOba0X+
WpJzBrOOnZzk1kkXx5FaN0MNU5+BoO7UMq6lzE9rj7gvNzfXJza+4jvEj6iB
Cv8yJ4TJeKGcl4RJbuKy8gA7joDtsA1VrV6NhrLu6pkqcskFzLsquhbvNRak
D0XBBmdD8HVmzQz+b+OGDfYzei/ek9CzcMVmwIABPvs381EIaqE4t9RzPzn7
Y65HDS2I+QG5PvbGO9dGg2+HX8D5wYgRIyROx5xRL0f9VscuSm2gKNhA/ssx
Ue3atYW7zPWmpKTYazKx2bZtm6zFrMumpqb63CPTJ6xYsYLKMHfrONAXfT8F
dRzUXrBWh5V3+6pFwNawZzinQm0dvlrPrbYa8U1JsTH9GO5D3d/UA61jbrB0
RmvZsFvIhvXr7TqAYoO9vBn2uE6dOtWuI0NXTFzGjBlj7zVycZflAxUPGxec
K1sxMM7LcT/qy6iNad+TJk3y4Btda1HrNzoPCGqHeuaPtUZERMjf2EMTfxNP
nKt62xTOW7yxgWCeiLuUW4CL2iueRR1dn1FBHo4zHs23lZ/lHQTuIyoy0q71
qMAn1a1bV8ZJSEiQ+qu53qJwsWkbS5culTlizqrj+Bv2hfNu836zzy5dutyA
Dd7H8aUzL7zwgn1WoToJu8FZzNq1a+25o2lNC+ek4F7E5hoPIp7R8wzFE/fr
GQQENTLsEe7BeRB4UX233lOY3iguTqsuH2b5JTlr4T3VOfviDewXdEvx1D60
Nuvtk9Re8YzqZJMmTehjK17E/RcvXrRxwflGZcYNNoUYGHkU6tRjxo2jyVOe
o9ffeIOuWfyOeMy0GZ0zzncqVapk8+C3Vgziy2d6y7x588TW9XwlzPDZ4AVT
x26IY9nW9Gwaz2gtEGcHvu7HHuh+o4E7NR/2peO9e/e+jqWVC6UZXFbQ3Mx3
PVAvwzkgnoeOrl69ulC9QcyFe7Em2L5pF8OHD/dZk9e+8M6GvItkcbXmKzgH
17l5jw99WMQ2gv0Dt3mf2Zv3rlq1SuxN54S9i4mJoX0WdxQlrjS5FJ9z2dbR
D7gIvK1j+xLoLGqpahNmfKJ+SGMS77njTNZ+V8t6VwFnwrBzc0zzObUVX7+Z
3//www9yVqx+TGvh06dPtzE23wf01bRWpn5V9wo8sGXz5gLfiVbBuymmnuMs
X8/TlFt87SvyAn3PRd+rAl4qvuZrxjfe/Zo2gPxHbVXrCm3btrX9scaPhelO
Qb76qpdP8SU4B0IcgZhk/vz5tr4UNibknXfekdoozg6RJ3jncEVtul4I/C10
GbqvZ8XgG9TXC8K9NM2X6H55f1dYnG2+QwC/gmbuZ0nmp/3hTBO2jXhSbRUx
HOR2vdteEDZmTOf9XWG6Y3JFac6nTH+alZVl2yneqVDeLIxjbiU2v1fB3uC9
Ln3P5E+5c/I/2V7k8Q==
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2
tVTcUlFLa81lLt11dc2WOX+1zFXm+L8Bc0Tv9rkz/fbNMBkU8FZd39Dv9Xvd
p2/fPvd2+0PMz93j3YsUKTLSU/zTPTqt9YgR0emRHuKP0PTkuBiN+BEkNEwo
Cr98+ULO6OfPnx2+j9/2nnf229nZ2aSWp0+f0rt375S/HWnj96Doo5R79+7R
5MmTqWbNmtSsWTNasWIFvXnzxgST71kh169fp6FDh1L58uWpdOnStGHDBpo4
cSJptVoKELgAnxcvXuR7W78FFj179iQxtVl9fX0pMzOT0tLSGAtZPnfu3O/a
NiAXL14kHx8f0ul0PC+6dOlCUVFRjE+HDh2obt26jEX9+vXp7du3XO979B2Q
CxcukN8f/CgxMZF+GfsL9e/fn9q3b0+dOnWiuLg4mjp1KnXs2JEaN25Mr169
KhS2oW6jFEfGD7J3714qX6GCMh/MtWnTpnTnzp1CgYM5Bvj94f17u/5fyuMn
j8m3osDC3Z20er2iOqHAAvOmMK0lkA8fPtDMmTOpRYsWFBgYSAMHDqSzZ89a
7YNcT7Fu/lijBvfbBAtPTy7r06dPocEB+vHjR+or2mxu36VKlaJDhw7ZnDOQ
0WP+xs/rvDwZA2DhptGQm5sbbdu2rdBgAVm3bp2hL2I90It+QD2N49qyZUu2
GWv9gbwUfjGqfz8q4vZ/HHWeepoxY4bDvqcgKCQmJobbL3GQ6uHhQcWKFaMb
N25YxMJc/v2frTTl79NoVsZsOnHqZI77+d1XezhAoqOjc2ABG3EX/rBo0aIm
WMgxhnz69Il27drF43/ypKHvy5cvp+3btyv2NmvWLDp16pTyrYJsI5D169cb
fJ/gimosUNa8eXP2JxIHKfv27aPg4GBlTjRp0oTnUs0aNZmTP3v2jLy8vBSM
e/XqRbdu3fpm9uEK5hD0FW01950lS5akAwcOKOMpsdgoYg7ZT8wjXNu2bcvc
Cv6yTJkytGTJEqpYsSJphA+F4plq1arRtWvXvjoeeSFz5syhsLAw5kfgjZcu
XcrxzKNHj6iavz8VL16cypYty/1GTBYQEMB9x29g6C+eqWDkYPDDEo/Q0FDG
/mvhAXn58iUdO3aMjh49SidOnKDjx487rHj+zJkzzKkxt48cOcK/z58/b/IM
rjt37qSlS5fSqlWrWFeuXMnX5cuWsa+Q5cvE3xs3bqTOnTtT3759KSQkhG0G
eGzduvWrYAGBD4uMjOTvwN9Ju3RE3XEVdq7xMFw9hM9gv6mUG9TN3Y3nA+7B
n0K9vb05NoN6ijnjJf72Fr+hemELfn5+nMcAdvv37+e2oY2xsbGKneU1Fu8F
Z65h5H6uqEanNajAwUP0VaqGVUvuRp/gis6fP1/J61SuXFmJUaTv+Rq2ARtO
SUmhESNG8NURHTVqFIWFt2Eb0HrqTTi0VOBQzteXfhr2Mw0X705PT2dF3eHD
hxt+j06nNDNNTk2hxYsX0+jRozmfAalTpw5jgXFDDJ+XWOSFZC5cYLANvdYi
FrhXJ7AeP/vq9WuOyzEfFyxYwGVjx42jyB6R9Oc+USbap18/atOmDdeXWMC/
ynyGLS6bm36r131LYuudGf+YY1gb9TqrWATUrU0fsrPpt99/pxIlSii8AxIU
FGR3nowTeD1//pzKlSuX69gVgvzyuXPnaMuWLTR9+nTmM+3ataN69eqxzTVs
2JB69OjBtj9v3jzavXs3Xb16lX2JrbjKUSzeiPegDuY6yrB+Pn78mEL+GJIj
RoVqjD4Y9yZNmsTrm8QGc8tVHJBjxziosYYPh58GBq1ataJatWrxeu9h5ucw
Jta+awsLnZF/4l7tOgIL4/xOSkpS1itwbXzboj/Wegg/5K60AXjIe+DmzmCh
5v07duzgdyCXuGnTJl7nHz58qPgfCPYpkEe7efMm82Os9eB5wMtafs0WFno1
FrVrK98CN5B9io+PZxuMjo2hQQnxFJsQR7HxcRQ/JJH+JeK0tWvXMr8H32jQ
oAHXQb78/v37ytx2Bg8I8iFoF/YgnJGFCxfy9zdv3pxnWIDTVa1alcvBKwcP
TqRBov8x8QYcBgruEDc4gR789ohzQYhB4G/lfME8dsVXQMB5wXeRT1XXt4ap
2o/CdhBzd+vWLQdOrmIBgU+y5y9/Fb5tzZo17LfU5a5yTsiiRYv4HbA1VwTz
CnHU7du3c4yHK1igHjBOSEigadOmGWJVwa3Vvhb8LKxtOMeu0AEDBtDIkSNp
ypQplC04sis2AUFeCXwN8cxntEPYyVUR6x0+cpj5/j8Fv10sYsIVK1dwPu3M
r2cI+Yas51lcf8/evdw+xF15gYX5+i19Oq8dwm83bhpM/tV/NLGFMWPG5LBJ
Z7GAj8S64FvBl/7UvTt/p2IlP/L08WY/ncM2jePjI+bUD/5VKaR1a2rXIYLv
NQ5uouxvWsMC+UrwT+TnbNmFeqzUWOC6SHDN6EGxSt4CV3DU3OBw5coVqlSp
EmPRsFEj0nsb8gXIqYIXww5l3IB2yN/uAiM3EWfJ3GOlKpWptnH/CnxRHQdY
wkJjXJNdxWK+4KP9B/7FIhbO4iC/I7nJ2LFjeb38766dHAuCw2DsrHEjVnEf
NlK/QRA9zcoS3OANNRLzFjmFT6r5aoKFqIO4pK7gx3HCF4A/SN/vDBbzMjPz
HAvEWngP1kXIZeEjvIv6CJvQmNiENUXdkNDWSpvDBUetXr26dSz0hjoRnTrS
WmPOr6BgofYVPyX9lQIbNiA3MVZos0ZnX921WvYp3Xv2oL7Cj2PMsQckz45Y
wyK8fTtaKnhaQcLi7t27lJqaytw9ccgQgUcSpYp3Jouy5LRUSnFA8Vzi0CGs
ySnJNHv2bJP8mhoLrRGLtgKLZQUMC+TrEHNg7wpxBnKIaJvDqtUxr0A+Eoo8
FGJKcyyw1qr7jXhveQHDAjGg3MOBH8OaghwRuBdyB/YUeRTwG9RFnhF5OJTL
9xcWLOS3cN5HcgeMqbNy+vRp9jnAAjE29izM+1NQsLB0Xy3IMUsscCbM/Myc
PTl8+LBSH3PtwYMHOZ5xFAv1OTS1NGvezGEsHBWJBfoLBSe6fPky54wRpyI2
lvccUdR/8uQJDRs2jGOS8ePH89jK+3JttYWFmmsBC3X75LjgbJKjWMgzkPZU
YiHjGSi+g72b1oJLQxsJ/qm+b0+Rg8LeDOriPSjDeSHEU5hzsDv4FXt2gdwZ
+oF9U6zLyEUgl4k5h30PflZiIXzaADMskP+FdO3alb9rqa2yTfCJ0jb27Nlj
ojgDBDUvd1St1ceeMM4O4YydPSyQv0auFvt/2CtCHH7w4EEuk3Yh+w37Rb5C
XR+5cjlnbbUVbcIZSUv+4ltIRkaGXSyQP5S5MXOR+U9bWIAnOSOurje5UYir
64isj/0YdawMvoyzTuoy5CXzq4/fAguZV8sSsR/yXMi7wf9A4GcnTJhAERER
fPbV2ppZkDS3dmFpTlub5/ndV0ewwLkZ9FeezwoPD+ezE2ofAH/x+vVrq32y
1N/CgoG6vatXr+b+yvMRyFPDn0vujyv84ycX8pSFSSFYH3r37s02gPwGYkL4
Aux9ILarUqWKcv4qP9qXH4J1Hf+3QS3IIcsYJj/kfwH3hWE=
                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2
qGNEHY29rC7YJhY0GnFjy+gaXMtorKNuce0l9u6///fzzvM+eO/xcB5JyPDP
HLjv3nP+c75z/n5v+IDM91KcHBwcsvX8573+H7fLyuo/6g8u/CNu1IjBA5z5
4rfcmnLDTaqkSqqkSipnevHiBT1//vznXsZr0cOHD2n+ggWUlpZGvXr2pJ7c
Uoek0rz58+jBgwc/9/JsooMHD1KDBg0IJh9t27ZttHvPHnJ2dZHfkfXq0feF
35f7OiAD9+7dk1ZWOnbsGAUFBRkxODo7UX5+Pm3fUUA6d73xfiD3OXLkSDms
vohWrFhBsS1aUHBICLdgiouLo42bNtk09uXLlxT/Tryss25kXUrs3ZsyMjJo
/PjxNGHSRBqamUF9+valBg2LzqrNb9raff1YQ3Z2dtF+OTmSi5urNLV/OTNn
lsrj0qVL5O7hTmkZ6fTV+q/o8ylTaPjw4TRg0EDqP3AADRs+jCZNnkzr1q2j
rOwsctPp6MTJE3bFsXr1almvm15H7p4exubh5UmuOjdycnKiffv2WeVx584d
SvkwhTq/24V8/HyNe1C8VfHxoQ4dO1JycjJdvHjRbhiesT60a9+eHBwdZN1o
wKDnvVV4MD9kwhbq1KWz9Nfuh97QFK+WrVvZbf2KoM/BoSEiR9q5tc3B0ZFi
mje3iV9040ai3+YwoOFZw+gou+O4f/8+hb5RQ+yiZRwOFBNbOg74vLqRkeTk
4myRF3DUrRdpdxyYOyEhoYQsmODgZ1kjsm3i1yuxl/RX8mnS+B6ede7Sxe44
QLt27SJnZ2ezZwL75cO6efr0aZt47WGfhz13cSvJy4VthiPL6Pbt28sFB2ju
3Lmk1+uNthc6gWsf32q0Kd82H6Joztw5sl7lC9GUvZo1e1Y5IXhFhw4dovT0
dIqNjaVWrVrR6NGj6fQp286hOG3dupXi4+MpKjqaohpFU7u4dpS/Od/OK/51
0dGjRykjM5OSkpLYP/SR/7379KG+Sf3kf1JykviN5P4fUD9+Jq1fP+mXxH6s
b7++1KNHDzpw4ACdP3+ehmdlUWKvRJo+fbrwP3funPTvw7zOnDkj96ZNm0Zd
u3Wl9KHpdNgOMdbKv62kKlWrWPS7traBgwbR0qVLyD/A33gvsn49unv3rszT
tm1b9j0xcv306VNq3iLW2M+nmg9t2LDhtTHkb95MLq6uRvukQ2P/rbdgd1XT
xqwS67VtQ3m5eeTp7WX0GW7cx5v358aNG7Lffv7+5OHpKfH7XYPPRayDvjLG
3Z0KduwoMwbEQfU55nRkm2RtzcUbYq+AoEDe/4GUmprKedEQ+obtZ4uWLYt8
j8ZfeDGuvLw88YmYB/sVFhZGc+bMEYwmMQ/72IZRUWXOr2BflZ/C/oKnWZ9l
xo80a9bMhNeatWvEvoIHcKr1gZ9XFW85c8Q7wKHiHm38hvmVn12yZInNGB49
eiQ5ghPbc/DwC/Tn+LOqyf5Yw6GNsRAHvJ/wvuynnnn5BwZQVZZ3xQvyBflp
0aolvc3yh2tZO/jxf8zr6+8n/Rx4Pb/v2lX0xxY6f+GC8RywrgzObWpH1DHZ
S6vnERNj5HX16lXyY9125bHA8hHLWiOOEbXxJmRq5Mcj6dOxn/K1E3l4FMWM
wBTBuVYC5+3QEfCo6utD165dswlHbm6u+FasG2vYtXs31axdy2qsa+k8NnGe
6OrmJmuCnv/9228pmn2eNrbRKxnj5+6Gc5D4hOerUzeClixdKmOxHhcehzzI
FoJ+QhaxB/Xq1xf8ITVCjfaj1PNo/uo8xowZI7wwFvHydeYVyXqtxQEMEpMU
synAEV4znAoLD1JYeLjwAK9Ro0aVDoJz1+7duxfZTJaDHizbsF1lwaE9j6FD
hxbtCceXbdhHII9BXq7F4crrjWsfRx07dZJrDw2ON8Peogss5+3i4xhrUSw2
hG1gaXSP/VLjJk3kLDDms/GfiV5p7XlZ9AOyrfyImr92ndomOKAT2Rzv/5nP
zsmgHwrHG2++SVeuXKGkD5KNsSnqGs+ePbOK43+XLtFb4WHG+gFsOeoL1UOC
y4wDdg9+2dGlKI4dO3as3K/FulY89lc1i+L6UYNl8faPP9KIkX8UHhgXERFB
t2/ftorj3PlzYueULC5cuLDsOAz+49atW1QTe2/gNXHiRAOO2iVwyPmzjmh9
FHBApxC7oCak9CyEZaM0m3Xy5Emj/8G4ZcuW0Ysy4lBxEmyuyunBa+rUqWZx
4Lprt27sZxLI2cXFRD8UjhmzZgoPHec+AQEBdPnyZas4jh8/LuMVjpUrV4ov
KxMOg1xhLsQosJfgNeOLGWZxwAYM/jCFModlit3yMOwj+igcyLmk5qTTUTU/
X5tx6Dz0r41D6QdqbvDfCkdOTo5FuVJxifaeyBDbSdi4hQsWGOXKJhw//GBy
HqiBvi4OdR6uxvP4wiIOcw19arC9gr2YMmWKCQ7skTWCfkhsrtEPS3qOeYqv
R4vDqB8GPUduVITDvL0qfg/nGBwaSimDB1P16tVFNxAr+XOMX9p5nD17VuI4
lUMsWrTILA7wbNy0CTWIamhSJ9Xqx/Xr18WPKds3+fPJZnFgPHKEaM7PVWxr
nMewDvSBLYNdC+QzBm9r9N+LFymIsTtr/AdIi0N0kHXz661fU25erklNSxuX
QD8lhzHUQT75yydyv7gfxLN58+fTpvx8E17AEFg9SGI7eS/CvD29vCQPgW+0
RvCTiYmJwq+ary/t37+fHj9+bBZHwY4CWrV6VUkcMa/yD/hpPPf29pZ8Cmdr
Dsdizis2c/6JaxVTY++jODbe9s02+Y28srCwUOpokFHorTXCPi5evJgOHz4s
v2+x7yyBg+08clBz5xGjiROxB3gHgPlBT548KaHnIr8838aNG014AUctzhdA
f+LYcO/evfSv//xb6kSQXfAuC5nFweexkXP/vFV5FuXKHGFuczjmfvmlvJPS
8kIf5D3Yd+TxHTp0oFC2w0PS0mjcuHGl6khpOGQOxoHcwl44oIfFz0PhUPu+
ZcsWKigokOsTJ04Y/VFFwQFZNEcL2DdCf20lxJbBv0AcWBdiT1trKL9UHCDI
2Zo1ayo8DtCkSZOk3lrRcSDvVTlBRcYBQly+o5S6aUXAgW9VTp06VeFx2EKV
OGzHgbr4rwHH0uXLfnIcKk4sbxyIdysaDktxe0XD8Ve2/xvKWa5QFwzi/LI4
Drx7NJdHNWnW1CoO1M5NcDg60CqOkczmUZw72gsH6kdhNcPl/RRyfaml8Nz/
PHRIzkTN7WH4LqT1260t8nr+7Lm8x1FjVF0GueX+f+w33RO+Rh3Dnt+RLlu+
XM5A1c67/O5dqcMjJ0OdR933ruJtzHUs0foN6+UdmxqDd6CQ3UePH9E7HTsY
7+v0Olq7bq3dMCjCdysDBw+i2bNnm3xfefPmTZowYQKlfpQq34HaQnu/+45S
UlLkuz5t7Ry1gZwZOTSI59m5c6e9IVTST0z/B0Y4Ieo=
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z
Mi9ZK1PLxvK6RiPHympWWZrTmGMJNk05TqCiIIIGJqDAx8cze+9zzscXIgLm
/PJd6+Wc73De9zzvfvd+9rNffWbu6Gm/uueee/J+S39GT/5jv7lzJ88f8xv6
kTZ/3tTMX9NNDHUXdX6Iu+1u+z+05uZmBKkHAgGcOF6ID/d/gG8Ki3Dtat2N
LwdbgBaltwSDCFKXOdT7ID+/g1hbaP5gcxCBxiZ89P4HGJiaBnO0Hqm9EzFj
UibWr3oRX3xyEBWlZfROIGwgYQw0Uw+gqakJTXRlrAHCHAg2y7x3ojU1NpKd
CDN9O29OLqJ7RMBmMMGuN8EcEQV7pB4Jbj/GZgzHsvxF2Pf2Ozj1/X9Qf7VW
xnBjuwaaA2gk3Iwy2BK8o3jZvk3XG5CdNRVuq126y2yD22iBU2eCW2+GLVIH
a7QBvbwx6JeYjKzHJ2PL5jdw/Kuv8dOVK8pcARUz+0QX8YpPqr7VUWO/lW81
NCJnejYsOgMsegOcJgu8hNlnssNjtMJlMAt+Nz1n21v1RtiNZiTE9ULek3Px
z6NHZZ5GXn8X8ZaUlKCwsFDG3qqxL3ALEN6Z06YLBo/NAY/FrmCk7iW8jNlr
sskanAYLHOQzDsJvovVFR/RENo2tYx8JtnTZvqtXr8bGjRs7N0Z9h+Ntlmpf
B9mQ7esxqRi5M14Vt5vwiq3NVlmbITIaGYMG4/zZUnVOdBpvdXU1Vq5ciaPq
/tyyBVvx5mTPgIW4wUk4XNTdJgWfR8XatvN6PGRvc5QOQwcN6RbeoqIirFu3
DnV17XBn29YS5g+3wmuwIoa6rw1etr2F8A5jvGe6hpdjbM+ePdi7d68yrIMx
mo91Fq9PxfszzCpeK3HHiIFdx1tbW4u1a9aguLhYfjM/dDium3j9hhvxDu8k
Xvke9dqfruKzjz9Bwe7dqK+rF27gHhpHlzp653JllXC95rfatZnwzpkxU3Lb
zfzXp3aP5rth/jvsJv4b4grBGeTELf3sDyWYOG4Cnpg5GxUVFQqUZiUv/lRz
BTu3bUfmxEmSbx8dNx7bNm9B9aXLoXVzrppB+cJIse622G7AG975uYu600JX
etcUrUPG4CE41wZveNfwtnBOpNudb24lzrRh+bOLcb2hIeQLDXS/Yf16eJwu
6HtGCr8aekbBa3Vg2cJFwpka3ulTssS+dwwv7yPlvw/ffR+D09IpX+rxxoZN
6jYr/z9y5AhS+iTDQHM6aH7OS6wPbDoj4n0x+JR8SPyX8sVs8gdeD/PvL45X
db+DnxygfN4Huvsj0D8pGd8eLwr5Dbddu3bBZDDCajLDZbMLVv6Gl3g+msZs
eGV9mP/Ogo3wyju/AN7WsFbuTxMPjBk+Ur4b6/Fh99YdYvcAa1nqzG+M126l
mCBNYFNzLX+D7cu5bNOrG1r9d+o0iR22Mec3t5qDOZ/56Nod+wZVXdxI9li2
eInkbo7nF1euIhsF5N2mgKJHGS/riMSERBiiouF1OMUfeL8Zl49+a/7Aemda
5hThM9FoNCdrBb/FIXj9ZnuX8bLGZG3M7bt/f4eUpD6Cd7jGJfxeIKho/RZF
mzGnvfzSy3CSL0Te10PiSU/xxtpwaf6zwh3iv00BTJs8BTbSXoKX9I7oyWgj
YlTMXcUrGlH1hZ3bd4hPGslua59/gRwQoXc1n6mj/FFTU4P62jrs2LoNWZMe
x5D+AzB+9Fi89vJ61P5YrfgC+xDhnU35whylF3+wkw/7bU7Bxzb2dcO+mi9w
X/3CKol5xrt4QT6qLlTgwvlyfP/Nt9i/fz+eW7ECj02ciDGjx2DF8udk34tP
ncLZ4tO4+mONWoe1rq+R9DrzA2tfiTeTgivW6pIaw2vqeryFa/C9BXtD9vU5
XBg6cDDS+6QgOb43nE4nTCYTTEYToohzbRbS3i43xo8agz9veh2XL1apSQKt
+oz8jOsLjsHnly7H5lc2IMkfByf5h4N8ojv8wFib1XrgQvkFZFM8cxxx/HAO
cNI+uuhe6i+KFyfFi521LN3biNOMEZFSG8yYnIV/HStUcqOQmVJzZk9R8DKf
f3XkKPrT+u2k1znnerph33Au42f8/3Wr1yA9ORVeu1M4k+3hVvcyvHspfnyU
05z0fXPPaKRTDfbWxtdx5XJ1KF/kTJ0u/JExYBBGPjgUDtbjNC+vn23RHbxs
32Y1B3O/XluPU9+dxCHKG+9R7fpM7lyxh0tqrVa8/CyEneLfQpi55pmbMwd/
3VOA7VveQkb6IMnFNjUHsi8znhiXR/B1h381H+b9k1pR21PGT/cL856GnXJB
W7w+i2LbBxxuWIkDmKusxMHsJy76rmgG6sx3OvIbtrNZp8dYyke5M3MQ7/FL
ndyleFO5QcvHnJOCxEPMufz7zKli0c024ta2/sBY+Xm8y4vMRx5DWu8k+W2V
WtgqeSLy3vvhd7rxYPpAPDRiFP60ZBk2v7oRkx5+VPSRxsFdzW98biT2JawS
K01KDO7bXYAYu0uwtYeX++C+acR9F+W8KYv0JduT+YV9Npf0A3PDS6vWSJ9F
/tw/ua/EK+eX29eTyrkMY+bzjqULFsKm7nVbvH6yjykiCsvzF0FrnEcOf3aI
+kGcKTlNmnQbJo5/GKmknzh+eS2aPuqu/4bj5dqC8z431usjh2SIT7bHD2xb
9uH33t6LSxWV+Ig469CBT3Gt/loI/+zsmdD3UDSynIcQv/uYdwiTw9B1frip
fakxZ/psjnZ9QcObEtcb86j+GDU4Q/iBny1fvDTEPXNn58Kk6TPhbwUP/2Zd
cdv2VXmtqb4Bi+bnSy7wqtzeFq+D/hdrdwtvWKg+ZD+3UW5IeCAOFZR7uD39
ZJ6i1QkDY3UIZotoUI63XwQvtdKSM3iQdIzEBNuEMIXzrWZf/p+T/DGG9pg5
j8+U4rx+nFPr2nm5T4h9JT+ouF2qjSXHheEVzKzpud6MVs5LOuMP3L48/AUS
Y+MFL+dj7XyR5+M6QmzFz9Xvs714j9k3E3yxOP3fH2SevJxc4TjOhW33p706
Q85LzK3nD2WnS0O6pF28aq44+sUR0TkOrr0MCg7RhKwn2DZqTWHkOtOuaHav
ijmJ1llWek7xB8qNpp460ZJiV3Xfb1YbaecPNhozcsAQlJd0jLdF1WplZ8/h
kbHjEEV8L7mYsMW6veJ/bFeu0eO8Pkya8AhWLnsOvfyxEvu874kPxKP8fJnM
kzsrB1btvE+Nt1DcmTvAG9k5vNyb+cyUrgc/PoDRGcNVf9JTDOhD+z522Ajs
3rELNZd+xCXKFWlUl2r5NyE2DqVnzir+MCeX1hYViref4W0nhjkePGH+UH4r
f2hz5FNGcfNMbp74Ln/DT1rBQhogOzMrdDZSU3UZj42bIHHloNhPiu+F8jLF
vgW795Ce1sFKupn/x/U/c4BcVRv/bA0qP7B9+Hyn7MyN+ld+avU8a0qyTdFX
x1F47GvRrH/b9z4efWic+KlgUvXwomcWSJ7gOoLzLD/ntSQnJqGqUtHv165d
w8L5C2AnHEb6n45szVe7ilt4w6xoIy2G+RpFdeGojGEoLz0fwtfemfUBqnEm
jHkI6SmpSCNtnZqQhAF0TYrrJTEl5+TUtfsXlq9ANdl3DdV7bBOu8fsQ3srK
ytCc12k9fMayds1aPEy5OaFXb1jJ1nLeoq7dqXKMFsvMvyMzhqKSfK2jxvX8
H373e4knHuNQNZhWg7GN+cyBaww77TGv48vDf8c7f9kDE43hfe+X2g811TXt
zs/a9eTJk9i6dSuenvcU0vqmim9wTW4iu/N4p9UGHdVcIwgvnzN21N7b9y7i
/TESI8zZJuIrI+V/PuuR+oh9UNUCXOfYKY8c+/IoSohvGXuPe+9Dfn5+h9/Q
Gu/txYqL+PzgISxdvBjDhw5DXEws9PTdiPt7YNmSpZ2a5xSvf8ubeGntWiwh
ffbUnCdEF7LOTk/pi5TeiaJpPZRDuI5uuH5dxv3j88N447XXUVVV1anvtG18
fn+i6AQ2bdiIgrcL5Oz5dlodacUL5eUo+aEYXx87hhOFhYS14bbmvNvutttp
/wM7Ipn7
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM
CcUSBmOM6SBTbDoYMEUIIRMCopgiqk2vptkgiujly8w8rSyKYJ+0xMk5nnMe
Wt6+nXvnzsw338wzdO6T0PU3lSpV6vd7+ichKS22b9+kQa1/R/+JG9S/S+ff
0oew4otv4lf5Vf4P5MmTJ7/0FsotDx48wIqly9CnW3ckv9MJE8Z+jGtXr/7S
21Iljx49wshhw+HnVRVmXy1dGnhX9kJy4t9w5/Zt1fru3rmDTRvzkJuTg2NH
j76GHb9YThw7jhCHE3ajP4L9bQg0WxHgb4Xmzz5Y8/VqVbouX76Mbp3fhVmj
g9FPg4jq4Zg9e/Z/JVbXrPoaxmpaOEwWBIgtdtiMZuh9q2HKxM/c1vP48WP0
65MivgyxByDAbIFer4fRaMSWLVteowWKbMheD3+dAYEWm2KHxY5g2ofvn6oi
a8ZMt/WcOnkSUWHhsOqNCLTaSZ8VFn9/aHU6pKWlvUYLFLl08RJqRUTJ+mID
Xf5aPYJsDuz+dpfbegr27oXFaIKTz4N84aT4tPorPmnfvv1rtOBnWb54CUJo
30ZvPxjoYv9M+nSiKh1nTp9GWGAw7CbyKenic7FbbdBoNEhNTX1NO39eDuzb
h6xpMzDx40/wr7xvVP/+MeHekPR/QFPVR+xwElZoyQan04mCggLPb7iUnD1z
BjmUH1/MnovDBw9VWF/htWvo1zsFkcFhsBnMaNSgIXJzcz2w06eF8Y/jeOrk
KUjp2QuRoWGEU/6CVzaDCWl9++MO4X9F5diRo9i7ew/ZVeiBXf8shw8cxPiP
xiG+WQuEOYNgpT0bq2kEXx2Uk1wvOK613j4YPCBNamN55P79+4Rbp3DqxEkc
+e57FN0q8pgNc2ZlwaE3wUS1yUK5x+fPdpS2wXXZ6R7X89z1OarXYdtHD/8n
IoJDUYPwN4iwN7FTIm6XgxM8K+fOnaNYDYWR9sb7NxOeMraX3nvpy0n13KLR
470uXVWvdfnSJcRE1ZDzYrwzUD03m0zIy8ursB2fTZgAE8V+ANkQXT0CI4cO
R4c2bUv84nzWFrNS06NCq0tdUyNHiUs5rQoXYI4TZHXAz9cXgwcPrpANFy9c
QFztumSHDkF0zptylXPp0aWb1Dm2wV4cV+wjzo8gqoHMrwzkv4njP1G13lfL
lsOs0yuxSrr4THRaHRITEytkx8xp08UXeh8/DBmYLvcYi5o3bKzUKF6LbOB1
XbHGuM/13EDcqlXzlrh/757b640aMVI4Gevi3GCfmKm+JyQk4OHDh+Wy4Xph
IRrF1he9jerFiW9Yrly+gpoUXxa9AQHEH5ySE0pMhQYESqwFEO7zPhgLcrKz
3VqP8bzT2+/IuUWGhCGc6ro/5ZmB/JPQurXgWHlkTtbn8KV+gmN13eo1JfcP
HTgga8j+yQ6JpeLay5/jYurgrfjWkj+MCR3f6uBWnlylnqtBvVjJ8XrRMahX
M0b4s4G4VXx8fLn8wWfTrk0bVPnjG3i/Z2+68fN3eRtyhcvy+QcV54SL17Hv
BvVPxbHvj8gz/J2J4juSeojUAanYs2dPmWvmb81HkCMA/mR/TGQNJLbvINzd
SH5v2qwZbt26pdoOlhmUG38n7OSaVFpWLv9K+ALjonAgssFBnJRzhGv6pAmf
ynO9uveAt1cVOIh7G+lMq/lVg8PhQFJSEjZt2vTc+S6cvwAaH1/xP9fZ9H4D
BO+tJjNxXn+MyRwj/YmnZBGtZyEbLDoj2VCMtWRLsN0hMcH7YblEtYDXbteu
HSIjKJ8sFvgShlauXFk+d+zwNroT7qX06Im+vftQLsaR/8wSnzb6+wHhyrsd
E2GldXTMnw1GjPkwo9w84VlZsnARYa5BYsZVyyWuyCfso+VLlj71POfnlStX
sH37dmRmZiI5ORnR0dFy9pw/3PtyPLIO9oVLX9MGjTB5/ASk9kpBKPXMRj8t
LGTLRxmZHvHLauphGYdcfEqxQfnMub2Y7HyV7CCboiOjaF8mRASFij4XhrNf
XTHamPByDvUBWVOno0WjJtAR/pspXxbMn19hO3bt/FbwyeWPQJtd6d1oDxxv
UydNdkvPqhUr5feW4h6Wz0Pwr9gnPLdg/1Z3BGLmlKnCWYZ9MAQB1FdNmeze
Gi+TE8ePC77zGTolLwJK+jeu8SOGDnNbF2MCcwWHWeEDfCmxapEYk7pEmML9
7Zdz58pvGMPV1Nay5Ifz56UX53NU+IitJE+4xrf/a1u3sZ6fS+nRS+oU6yid
b+wXnlsEUg3hXGcO4Ulh/9auEV2SI1aDsYRfcRzY6SzV9G8/Ega82bipcNvS
fQBjofic7GCbuKYwBnpKfvrxJ6m3vIYS1/aSHOV7Bo0WXanuPFYxN9tH/WV4
YIhwRPYB65HcsygzPUdxLq5f5x7HcUe4f65PHJhroYuXuPK1pJYEB+PIkSOq
9M6fO0/mh8zbGEdc8eWyw0xcSy1/fplcL7yOhnVjKQZMJTyX8dGFvzbubanf
zcjIUKWX69vQ9MHUF/sq/iXd3O/znNVRzHnSUwd6zI7bRbclnk1apU/gsxtF
vVWbv7QSn1gplnn9+nXqEUe+qE45hSLPjJxGi/SUnOPc97BNzBVaNmmG69ev
e8QOnoXznrkWu/rxZYsWI5s4sfRS3MuRPcxbNuZsUKV7W34+zp4+g/zNW9Ai
rhGsfjqxh/sQxuLqxLM9NX+/XVQkccRxJXyWzunzmcoMN775m4K9QWab9INj
iUOokS6dkxEeHCJ9wvmz5zBudAZio2oJJ2EsZO6cu0Hd2ZQls4gnSI2y2Eve
DUyfPEW+G/thptLvUjxwbVdTE+/evYuWzVtA4+0jenm+x3Lh/A8YlzFG+n3u
I8aOGVNhG3II9zgnBKNoLd4zY/Dpk6fk+y/nzBM/2DhPKEfGZri/JnMu7j+s
5Oe6tWIEF3du3yG5t2vHTuSsWSs9WR/ixxWR48eOIYbqn5HqA2MTYyTXpu35
20qeYS5sovuKP4yYMXWaW7pv3rghPS33Gn7Eg5OTOst9xokIqivBlHfvJXfF
CdqDy0/lEe4527VtKxjFtYlxKYa4ybatW596bvXKVUpcEd4wt18w74tX6ma8
TU9Ng56w2kS1w0j8YGkx939w/wFat2gJHcUu50f2mnXltoG5fkpKivRzgcQJ
WV90eCS2bv73c8/m5W4UvHLQxfnuzroc+zJ3YxuonmdQr1S6vxg1bDi0ZAfz
+NEjRpbbjkmTJsl7LbPZDD3FTGyt2k/FUmnZsW279NQ2vTIz3bljx0t1L5m/
UGZ2Uh8Ii/qmvI97z3BZxnOem3Ad5BlleXqo3bt3w2q1wmQyQUt5EVunruRc
WbK/oADhQSGw6Ywy6yjYs7fMZzd/swkR9kBYqull1pPUsRMKC5+frZ8+cRI1
CKs4lmvXqCm9pVrJysqCl5cXvL29Ub9+fRw6ePClzx8lTlU7qibtTYcQwuX9
Zbx72b9/P2J5TknxZCWe1qRBQxynvuZFwty+TXwryTvOz/379qm2g+c0jRs3
lvwoa53ScoawhOeoNjrj6ODq8g7jRTJwQCqqelWRWGVOyX5/mXCPwvgoNXdW
lmo7WNTMv27cvCkzSG3lqkho0hxFRS9+dzF39mzhkjabDatXv/r9OuMe57oP
2T4o9fW/t2UZPDAdvn94A9MmlP3enM9mA3GvfOJT7silixfRJK6B5Ej22rWe
2upLhXnRCsL/q9RveVK+O3wYWzZv9qjO/1X5D7u/JGw=
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa
RFEQolFB1EkbNWhBrSEqyKJjbU21LnHHFdzFuOP66zmX9whGhffQ5KUzOTOX
7/HxvXvPfn7nfCiGTew76lctWrSY8jv60TdheqfJkxOSon5Dv/wpaerIYb+m
D37WxTfxC/2odPXKFWwuLET6x59gafZi7N+3z9ksOUznzpzFgJg4uLZsBZ1C
BYWbJ3RKFT7NzsazZ8+czZ5d9OTJE4wYmgCFpxRmrR5etAwKNcmhhkIuR3Fx
sbNZtIsqT1UiuG0A1HIFjCoNvHUGeGl08DGY4ObmhuTkZGezaBf9c/dumPUG
mIl/tVQOC/FvVuugJ5mkEimGDx/ubBbtonPnziGI7KEhewgZhF+pYCSbeLh7
YOrUqc5m0W6aNnkKJG7u5FNGGNVamMgeKokMJpMJ5eXlzmbPbqquqkL8gEFQ
eEigpHjXSuTw0huRszzH2aw5TA/u38fWoiKkpc7C4sxFOHjgoLNZcpju3b2H
ypOncPTbb7Fv717s3/sN3bvrbLYcpo/S5sCHYsOiNcJfb4beU47ZySnOZssh
unvnDsI7d4XExRUmpQa+GiP0FB/t/QNwhOzz/0KHKA6CfP1FzTBSHfdW6WDR
GCBp7Yq8vDxns2c3FeSvF5iKa7i3Ri9ksKj1kLt5IPXPqc5mz27KmJcOmau7
wFR+FBv+OhN8yCZamRKjR47G02dPnc1ik1RbW4uxw0eKmtfW5I0gb19hD/Yt
L60B0VFR4pmfO104dx7t2wZCK1ci2OKPbh06wY/sYZKrBWaMeCcCDx48cDab
TdKhAwdgorhgTGXRmxAf0x/tffxFfOhItujoaDx+/PhH5eHp09f32/y166CR
KaCnXsOLYnxcwgiEdwwT8aEh7BsSEoLLly+/AW5fpELqPYcNG4a4uDgUFBS8
ljzJSTMFpmK/8iabDI6OxfiEkTDJVNBT3EulUiQkJODSpUtvUAIgNycHKoUS
Ek9PyGUysZYvW96sva5du4awjqHkPyrhW4zVe4V1xcoly9C5XQhhXm39WTH9
YnDh/IU3IsP169fxdnA7qGVy6NQaGLWEralnCA4IRGVlpcP7rcxdATnZgnG6
gWKal5l8a/K497A0MwsTRo+Fxegl+l0p9SFRfSJx9vSZ15bj+NFjCLT4iX7H
hzA1n6tXqaFVKlFRUeHQXjdIJ106doKa8q3oyakX5L1YJi3Fy6ihw7Dxy/VY
nJ6Bzh3IZmQXGcnSp1eEmKu8Dl27ehV/DAoW/szn+nv5iPj08/bB0SNHHNor
LycXcnfP72Ugn/I1eZGOlHWy0LV7aBgKvliHff/6N5KmJcKbel/u47mff11a
OG++yC/MA58lc/XA3DlzHJrN3Ll9Gz06dxEyCDxCV+ad5wp8tRjNdfmL7gf7
+CH3s6Xie5yj/0N4/k3NgVavWIm4vtGI6NETn2V/irsO9gmFGwoEnza9ixkJ
+amYk1iXiWTQK1UC/7I8i9IXOsznferLqi5cELJvK9qKVbl5mPthGmZ9kIJN
hRtxs6YGtQ9qm6WX22SL6IjI+prBuhd8W2shX7mv5Xssn4X7dc4B9Oyc1NmE
8e3T2RHy8/DwcPhbfCmO63QmI9zJtZVjkucyHdu9jcT3p+BM5WmH5Vj/Zb6I
WTPxyzyz3k3a72VouLgusj3Y3zgHS9q4IXHKVNy/d69JXcXExKB169aQengK
GWy53ct2Dl21Vpk6BLdHwfoNdstQW/tQ5E7+Puc6MRexyvFDGXgJf6OexJds
xvMT/g7nyoT4oY3W+LS0NLi6ukJNdhj/7jjkr1mLQTFxwsZ8trA1nS3O1+hE
frQYTVSTk+zCDtu3b4dcUlcvOBbYrzjOOTZeZg+uJX4Gs7AF+0Zbb4uoWS5v
tUL8kPiXnsEzVLVaDblcjqQZSbhntd3Ed8fX+6uYj5FOeD8tnc+ftZzXPSXo
2bMntm7b1qgc6enpUNPzSrKlluxs08erlq0/ZB9kWdmn1aQ7s8FI9b3fC/tX
VVUhNDQUHh4eSExMrMfJlwnTdAhqJ+zLcnBuN1tzJOuxe1gX4VsSqk8e5Idq
jUbMYnm/lxHnD+63szMWIbp3H8Er+6dKIhW2MahI7w1quzhXpRWxyTHKNXjS
exOws7yiXs8NKTU1FS1btkRKSgruUM9vo6+3fCX8Uvgq+wLnRuvifLO5oBCn
Tp7E+xMmQsl2kcrg4e6OAKpVa9asEXP0V9FD6o3KS0uRmpyCHl26Cr5ZN3pr
HjaRHbif4t6qW6cwzJv7MY4ebnzmsGTJEmRlZeHhw4fP3U+eMVPEOeuqof9y
DeT5Rs2NmvpnS0pKRPxZvLwhI/2yr0X3jRLycP+QtTADkydOwo7ikhfOZ/xX
UV6OirJylG4vRnnJDuyu2IkD+/bjyKHDuHHteqP8N0Y3a24iont4fZ6vs7um
Lr5JZ2OoF7313XcoLd6BXXSmjQ4fOoSszEXoTX1cm1YudO0t+tIAH1/wK72F
89OfO6e6qhrTKJcuX7qMcGMuThCGY9pVWobVOSuQR1i6gj43l0pILwZ1Xf0x
WXMUL84hXLsY48VGRol7PN9fMO95/q4SFltLtsghnM9y8Oy2nX8A1v7ti+ee
20n40t3VDUrySbZzQf4G0c/EvtMHkrdaw5NWv96RzcYimQsWEqb2rMMKVixn
y1c2TKTylMGH8q6cfGhAXP9X7mXjga8N+akhXDBo4CCoCX/oKK9yLTl+rM4e
qTOToeW8JqGeMDBYYG1HiethZERvwbOtltrylA0XMTbluQzjdwXFQ//YOIfO
4Jo8dvQYSEkHOo1W6GIk9Zi22cg/Nm8WedZMZ8ndPB2qtza6WH1R9EYmjbZO
Bmu+Enaw1kTOgzZf05I+B/QfYPf+zCvnKa4lepaB9BAa0gEnjh+vf+bSxYui
HzBQnpG6ulO++shhOThvjRo+Ah4ubYRNRL21ymLDIymUy6LJb/nvXD8GDRho
9/48k2bZjSSDguwQ0q49viFM2pA4Z0dSrtCRzRXu5Lf9YvGsGXMArguDY/vT
HoSzVHW2YB8bMSRB9AFMq7gvJRnYrwaTn9tDnJPYF9UUW6wb9s/ibdtf+uwn
ZAPu2XluwjXwYnW1w3IwsQ9PmTBJ+Jc/2Zht8ZfZH9b//fNVq4UPq6hfjx80
uMn9CgsKRA70otpqJt0YCctuWJf/yue3Fn0t5DBZa/ymvxfazTv3RLt27ULR
V0UoKylFZvoCkS8ZY9lw75rP/1p/jp/ZW8gxdMiQRvc9QDYMopjjesSzQoNU
iSWLshv9Dr/X4XcHjEu47/0gcbpdMty6dQvx8fHQEE4y6ev6mIa13Gitg4yj
y6k2cb8u8JWbu6jljVFmRgbcWreBnuyhoF54wUfzGsUtTJyjR9C+PC+R0RlD
yHftqSNXrlxBYGAgXFxcyOdl0JPutNYrz/N9tAax3Fu2QnLiDPGdqJ4R+MNv
f49ZqbMa3XvTxo31+Gs2PduUDDZaQBjZhXABv0fv3rXbS/HhD4nr6J49ezB/
/nyMGzMWA6Nj0KtLN4QEBCOAsHpb8iH2aX5Pwe8smLaRb3EOPd1Eb/jo0SOU
Ei7csmULHtspA9MxqosdOnYUWHz69OnNml0y9r1OGO3C+fM4cew4Duz/L4q3
bsPhgwd/0v9dOXv2LMrKykR9/oV+vvQ/oI9Lbg==
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$7", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$14", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$21", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$23", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$23", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$14", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq
YlXcakWty6h1qa1LsdrOqNWiKOJSOy4Vpy6AWteqiKCoYP4558aXJhBCQGbm
m/N9ly+8vHfv+d89y3/OjdfIcYPebvzSSy+9Z01/BsV90H38+LjU15rQPz1S
JySOtKAPEc8HX9RUVKChRKPRoLKyUowKmvfp06cGg6/x4O+fPXvWYOuKtV8Q
B+v0+PFjXL16FRs2bMCYMWMQExMDpVIJe3t7WFhYiMGfvb290bNnT4wePRpr
1qxBYWGheJbn+F/h4PWvXLmCRYsWITw8HLS1BoN1t7S0hJWVlRj8ma9VvS80
NBQLFy4Uc/Gc/y0cbB8XL17EuHHjYG1trdOnadOmaNGiBdzc3NC1a1fEx8dj
8uTJSE9PF4M/JyQkiO/4Hr6Xn9F/nvfp/PnzePLkyX8Ux61btzB37lzxfnnt
xo0bo2XLloiIiMDMmTNx6tQps+c6c+YMZs2ahcjISDEHz8Vz8r7x9Zs3bwp/
e66liWE+DvbN48ePo127drr35+DggP79+yMvL89s3WuSY8eOYcCAAWJOaX7G
d/ToUbE28ITiwiOjw1wcbLNffvmlzoZsbGyEbeTm5r6w/lXlyJEj6Natm1hD
sjWOHeXlJaxJvXE8evQIS5Ys0b0jFxcXTJ06tcH1ryrTp08XPiSt+8kn81Fa
etcoltpw8D4sXrxYN5darcb27dvrrFNFZYWw9Z9+/BFHDh3GRfLjBw8e1Prc
7t274eHhoVt/4cJ59F6LyWfKzcbB/sX7qR8b2VbrIz+S/i/37AVZKyfIHZzh
K/fEzGlpuHfvXo3P8Po3btwQeahRo0Y6PdauXUX+UmaAxRQO1rlZs2a6fWBd
6iPso9OnfASXlvYIVKqgVnhDKfNAaEAQ9mfvN/pMWVkZdu7cabAXFhaNn/uL
FQ4dyjYLx+3btxEdHS2ec3Z2xo4dO+qFgeUmvdO34+Lh7uiCUF9/hPkGQO2l
hB+NPbt2V7v/2rVrwv+kGMxDLpdj5Mg40sVJ/N+2bTjdV6DDYgwHcx7OA1Ic
Z397ESkm2xk3egxkjEPljyBvFXzkCgSq/PDD3n0G93I+6dOnT7Vcn52dLb6f
NStN7AdfnzZtMuXjUoHFGI4LFy6I+Mo2ybG1IWTj+vW0Bz7waSMXvuHl5o5X
+/XHubP54nv2+c2bN4v3LulvZ2eH2NhYkXeFjhptfo+J6SF0s7KyRH7+SaP7
wXsxatQoMU+rVq1w+PBhs/R8TBzCFM8re/gQq5avwNhR7+Dd0WMxMeU95B7S
5h7miRMnTjTYA+aS8+bNM5jj2TN+7xrKLwd1uTI+Po5iakk1HNevXxd7wbbZ
r1+/WvV/QnE5e1825mXMw8oVK0Su/Oqrr/B1VhZ2fPONsJufTvyEosIio89z
7OjVq5cBhqioKJ0dVcWh0TwUn199tb/QkblRUdEvBjg4zmVmZoq5OE7VxjV4
73Io3qgVSrS0tIEjxSOHVvZoTe/KzdkF3u5yBJFfd4iMxsA+fbEicxnyz5zF
4/JyEW/XrVtnYEe8/yNGjBCx1vh6kk9XUCw9KDgmP7dgwRydLTAO1ov5DNte
SEhIrXtRSjY9Ki4Bra2bw9tFBk+XNpC3kcG5tSNcaXA8Unl6w5t8QuHoCpWb
HL27dEfatGnCdvX5u5+fn8i3pt+bFodGo/WHtm0jhK6hoSE6bsw42KakGMXx
ypQ8JHv/YsNGeLVxR7BKjTcH/RkfjH8fKeNSkJz0Doa8PhgRQSHwVXgh0McP
YRSnQihOObawq1Z7dOnSBTk5ObW+NwmHdk80yMj4WMf5uW6RcGzatEnHAX/+
+eca57ty+TKmTJqMYP9ARIdHYP3adbh967bBPbkHc9EuPBIeLm4IUQcggGIV
x10rSyuDWiMuLq5GOzKN4zHOnTuF5s2bi7nWUzxkv2AcXBPxNVdX1xrnKr5X
jLGUCywbW8CHbGYdYai+ngarVq6Ewk0GFe2HL93nQLWF/h7wnruSDzFXN1f0
cUh+IpO1EfNx7cV+wTh69+4t7I05c01y6cJFyOgdN7e2QWJ8ItnXo2r3XPv1
OhJHxsOttRPc6V4bvXqRRyMa7sRjFeRLk/6aSn5WWk8coDpfm0u43mf+wzh8
fHyE7yUmJtY419Url9G7e08MGRxL8d94bjl29BjCA4Nh16w5mlg0McCgVHgi
dtBgRIWFQ077ofL0wrrVa3XP8n4fpz3aSPx0/vwFOEExu0KX26ri0CApKUHo
zPlGwsFxrEmTJkhNTa0RR1lpGXZ9uws5Bw7hfnGJ0XtWrlgJqyaWBvo3pThv
Z90Mk96biKKCIsydnQGVhydc7FujW4fOyFy0GN98nYX3U8ajQ1Q7ODm0Fs8l
JSWhuPh+DTgqqd7/QNgo92EkHJxXGEdtfKriaSXu3i022gfYunUrwsMM+yZ2
ti3g4eSK9sHh+P4fWl74oOQBZs1IF1zFpZWDiHsezm5o1bS5uDag7ysYMiQW
Gzdu1NmuMRzp6dNFLuQ94d4H4+DP5uAwJqWlpaIfIpPJDHo+nEvU3j7wJB2T
E5Nw7+7v9UbJ/RJ8PGMm2ZoX5UwF+vSMwez0j7F39x6c/+U8SkoM99tcHObY
lTHJz88XfE6/1mlGsdtD5o4Ayh3hVGe4O7sKW6oqxffvY8uWbcRltuD06dMm
1zFlV8wFJLtSqVS1+nlVYTtq3769gR3ZU4z1llOdpA4U3Nxf6UNDhS/WbazT
+6kdh4Z4QXU/NyfuSsL5fMqUKQZ25OTkhH5/6gtP4uQhfgFiBPmqBaauHTrh
wA/Ga7/64+C4271a3JXyIPdDfu99VZezZ89i4MCBBnYUFhaGffv24XBuLtpH
REHm5IIApS+CiLNwXOoc/Qfs3fN9g+HQcizjeZA5t8RLuC4zJhw/uG+ob0fD
hg3DyZMnxffsaz/s3YvBAwfBifgv5/QAH18E+/mj/8t98beVq8zOe6ZwMC/J
z/8nbG21vIT7IRIvYZ7D19j/OfboSzlx7QkTJgjOIunPcYF7y9zPqSpXrlzF
h6lTiJMoIXdxhT9h4djKeS85KZlqzosviAOYM2cm6VqdJ/K+cG+B7SU4OFj3
PNsR+44+z+7UqRP2799f7fyCbbSwoFDk5cqKSmzfloWYzt0FR2SepfLyggfV
Jb1ielF9c6ReOCTeHhERLnQNCws14O28L1LfkHkk68l2FBQUZMgtKP4sXfqZ
0bXu3rmLyRNTMZR4y8kTWlvjXDBq5NtwpnznLVfA28tb9KRjh7whaoW64mC/
yMs7oKujFi7MMKijWNi22D84twcEBBjYEQ9r66bac5geMXhr+HAsW/aZ4Pjc
O2XZQzksmOKU3K0NoiMiMYvy2sOyh7hx/QbmzJyN9m2j4UZxRO4hhwfVggsW
LKD62rzzAS0ObV07YMArQkfm/lXrWu29z5CcnFyt1uE6ceuWrUgYMVLEVbum
NmTvckSGhOGPXbvjtVcG4q2hw9C9azco6X07UwyOpnr2253f6c5luLd2Lv8c
5s6ZC1/aU659Q6nW2rFzp9k4OGfk5eUIPsV6JSYmGO0zsPD5jNRXt7W1FTGN
r7HcvHETu777O94aMhSeru6ERYZAiq9K4hVsMz5KJRSeCvip1Vi9eo3RHgrj
eTflXchc3dDa3gH9iEtdunTJDCRPBA4pZ3A84lrKVB9u9uzZutjFZ31VhfFs
3rRZ8HNniq8han8Eke5eXp5QKBSY+tFHQt+a5Ny5f6EvxWEXR2dhZ/Pnzccj
I7VMVUlL+1BXy86YMVX04Uz1Re/cuYMOHTqI+7l3b6zHXkHxKHvvPrzx+hC4
OjjClmorW4oPw4ePIK5dbFIfjincK1IRX5HR/FFto3DmtPGcJcmOHVk6f23X
LopiRKHJvqgkJ06cED09qZ/BZ1HV9KEa9tbNW1SP5CBzcSY+XfRpjTm0qhQU
FAoew/WtK+X/oW8ORdFl430uPttRq/2ex9Jm9H+O2f12fmdSjufB8ddUf5H9
mfOlKU5Tdf6DBw+ic8dOaEO+4uzohGVLl1WLX4yB+1CSHuvXrxbnBnU9x9E/
i/L19UVWVpZZepojHAeWZi4RMc6OYsowinlXr/6q+577/GwL0vpLliyq8zmO
JPyOly9fbsBrJ02a1GBYOPeMHfMXWBPHCAkKxsXnnIXPDvjMQh9DWRnXYXU/
V5OE8z7XGlK/iONyx44dceDAgQbBcrnoMkYnj0Y61Yfbtm1Djx49dLGfe7Tc
My4vf2AUQ11wsLANsO/r103ML7if3RDntnuJJzPv4tgi1QTcs+b4ou2ZGMdQ
VxziPvJNjsnMJ6QzN+YHnC/ZF9PS0gRWc4X5PnNrPqthviRxUeZGGRkZ+O23
36rEjRf/HYC+cJ1RUFCAlJQUHR4pb/L/XItJv8vgep/x8eDP/LsMrjn5HrZT
6XcRkr1y3uX8zmvUVer7Oxlei7klnzcwBzPoG5Jt8F5JfRge/Jmv6deSPLg2
434789/66P+iOCRhLlPxvGfPPsn7xOd8HDMdHR0Fl+D3zp85dnM9w3X0559/
Tny1SDzbEL/F0jyv0f/fx78BrPedhw==
                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m
XplhKmXN1AjSOFOUjehYM86IzDg5o6CJAbIjjAu5pKC/zvnuEg8fJS3cFs7M
4bvc7y7nd7+z/L7zwua/mLNQ7+LissxCf3JyCzLz83NXPGmkfyavWJ4330AH
SbLySQzJkAzJP1KuX/8ZixbnITUtFevWr8eZM2e0NmnA0tV1CdnZj4NTjaK+
/n54Zs4cfPvdd4TxutYm/q60tDRh6pQHhO1WNzehtmE2GF2N4pzRbEJ6ejrK
ysq0NrVfqa+vxb0TUoW9FjcrqY1wSGpR1GYV83en3IMrV69qbfJtUnXiBOJi
x8jrYHOuw9wEDl6TiMhRaGtv09psB6mrq0NkVKS0DmQr22u1ucl+5bgWNpoz
uZoRFDwCDY0NWpvuIKd/+AF2uw8MJpPqSxbCYOlnXcwWVxH3tXW1Wpt+m2zd
ulVaD/rmVjk2nOHgeVerBR5enqipqdHabKeycNECgcU2TMKi+JXiW+xTfMw4
2PdOnTqltclOpZ3iNjEpHgajUbLfNkxgYR9zlTEpWDhGqqqrtTa5X9m37xuy
n2PA4uBPvAasbL/OoBfrdpxy3GDIlStXBnxP0YfbYaT1EHEir4eLXidi28fX
juGBAYhPTMArrxbg4sWLf4PVjlJZeQShYaGY9cwsfP31V3d0T3d3NybfnwG9
Xi/5D+Vek9kVOTk52LVrl8jPFy5cwNVBqn+3bt3CvNx5KjcyuZqQkpKM9wvf
Q119Xb/3HTlSQdfyWlhEnBvNVCeCgvBTV9eg2N1XGhoa4OXtBbPVVc73VujI
NxhTQFAAcufPRUXFYdy82SPZT2u3ZOmzmJgxQfi+1U32J7o+f9kyTTCwrFq1
ypFf2H7lFQaTxPcMRh2ypmRhzbq1uGd8inTOZJDyk03KRz52O74/dkwTDJ2d
nYiLi4NefNd+eJKswu/kGO5b64yEI5B86uTJk5rgqKysVONCsU/J+c5Uqt/O
z+uMeiQkJuLatWuDjoPfWVJSggdoD6F8c73RoNrbH2dyphwr6RMnDjqGvnK4
ogIv5eeL/CvWSKeDxer8+ztTrnvexB8fefRR7C7djYuUc7WU8+fPY8eOHcjI
yIDNZnPwud9S9kfGIn0DF8TGxoocUlurLc+9ceMGDh06hIWLFwnerdh3p3HD
/sn32Kmuz6T6+sWXX2iKh6WxsREbNmxAWlqawKLsvfvmBWc5gnOyyNNmI/HK
cSgkzq9174G5yMGDBzFj1kz4D79L2Kej787+xBgUHM7wqD5Hufvo0aOa4ugt
p0+fFr2quPg4tV6KvUY/fmaT6+rY2LG4fPmy1ubfJrxGJbtL8OT06fDw9FBz
t7PY4bm1xAn+6XKK9u4rVr6G0THRDvVVWQvOFzX/ol4j853ikmJMe3Ca4GsK
ptlz52ht2h8W5j7LiAfHUT05phGP/C9KT0+P1iY4COe81W+9hYmTJom+a1JS
ksidscTfma+mpI7H+LRUMSbfnYyYsWOQSvUvOycb8QkJSExIlO6jOVaubdFj
YhAdHY3omBjBRzi3Zt4/GaWfl/5tOObN+3UPyxoYGIjnlizBxo0bsWbtGmG3
wkE416RPSsfmzZuJRx7G62+8jszJmWo9Y308+wkUffQhCgsLMf3pp2hv6e3w
/KKior8cQ0FBgXi2j483Nm3ahPLyfWhualbnlz6/VNQypU++6NnF4jz30HJz
czF79mwkjksU+16FFzJ/+mDbNvUZ3Dfcv38/lr7wvLTPpHy1Z8+evwwD117R
RyBetK3XexXZ+cnHak3mfYfZbEb4qAi8uXq1sKuqqkrwxvX0HOb2/BzGwjXP
3cMdx48fd3hed083ZsycIe/zA3Gi6s/3r74sKxN7CZ1ej9dWrlTPc69E6R+8
/e47Eg7uyco1mONkXHISwsLDkZWVhdaWVnHty6+8rO7pTRYzjCaT6D/0FY7F
SffdJ67l2Ovo6PjDGKqrqzEieKTYr7G/PPjwQ9iyZQtuEobe0nXpEqZMnSK+
r+gte3uhhPZDVdVVVINr0NbWhuqT1dj58U6Miook/moSzzMTn12+fPlt762t
/RELFixAZNRoEWeMZQLtFy/RewYq9fX1iBwdJWJW4aBKn3Lj25tw4MAB7N27
V2h5eTk+/exTjI2LFZzcTDZyzIaGhWH79u2Eo53yVbzK2ZXfNjIzM1FcXCz2
xzyy7i4tFfEv9cPMKk/k/x957LEB9eZaW1uRnJys9vf5myh9Vz4WeOScI/YU
tI9V3snz3LMVPJbmPDw9EUB5jecFRprnY1bhrzqdQ45S8plyPatBVp7Ly8u7
43rE/uTn5wt3d3eKQ094ki2e3p6i5+blxaOknLt87N7SSOrrZyf1hV0e/Yf7
wZ/4nS/lJf+7/AlPAEYGB2HkyBE0jkAw+WxwSDBCQkMQEiIrHYdHhFFchSE0
IpTyRaj4DSsqahQiwkMxl3jWQLh7e3s7zp49K5T7hqyNjfIojhtVbWJtYm1y
0JaWZtIWaWxupnVuEbHSW/k9vfUc67lzpNLY0XFOcMfOzg4xDsmQDMn/W34B
PbxqvA==
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq
DIpmgeAZKDUqAuItaqxoBDWpmJQVo8gRVFTw4FA8opxP3u5FBASWwApf9qlq
uqd3pufHTPfT7zv2MxZO+OK9QYMGRX5IfyZMj/GOiJi+NOQDOvBZunjWjPep
IaEipMI6YZNNNtnUj2pubkZTUxMaGhpQX1+P+ro6atfzY1aamhoHGrFTrYpb
hrCg8Zg8IRRTQkIxKXgCwkMnYmpomLmP2pOCx6Pg2vWBRm1VdVUlRvsYIRzu
ApVQAm+VBoFGP/jpDfCittFTB4W7CO4OLlgTHz/QuK06kpMDqcAdEwPH4WZJ
Caqrq/Ds2VPUPnmCmpoa/PviBY4ePASZQIjwkIkDjduqtK3b4DTEDutWfd3l
ObW1tRjpaYC/wQslxUX9SNe52NqLnL8ALkMdcPzwkU7OaOZ/6169wszwT+Dh
5IwDmZn9C9mJHj54AD9PPTRiKX69cKHbc9O3bYPzUDvsTEvrJ7quded2GeQ0
b0PGBuLRw4fdnpt77Bhc7R2wevnyfqLrWjdL/4F4hABzZ86yeG5VZSXG+4/G
tIlheP78eT/Qda3zZ3+GxNkVU0PCcO/OHVRVVeHB/QryxipUPnpEpZLXTx7X
4FJeHkbpvWh96njfQConKxMqDzF0EiWMah2MWh30cjV5th4+Gi28lRr4KD2p
1kInVkIjksOX+tm66KgzP52GKTER35tM2JyUhJRNm6hOxpbkFOzYshVbU75H
qikJyZu+w8X8/D5xb0lO4nuKTqaBp0TB+XVSdUutgl5K/WJ2zNpqOof65Qrc
r6hoN05DfQOCA8bQurWH0+BhcPxoKBx5PQzDqf2mDKM14oTRvkbUVFf3mnvP
rp0t3Gp6zsQmY0VjZqc+VhvoWM9+5/0t3OXtuU8eOw6Zq4hihWBk7c3Awaxs
8sss5FDJzthvLvsz+W+BRn9aU664cb33McOZ06donkiIRd3CrGph7LzopAp4
qzW0Bu63GyeZ5sTwwXZ8XljSxoT1EDq6YMO6db3mvvb3VahF0m5Z2xatWIFQ
8szHtP+/Vu2TxwgbNw4i8qVTubkW73mztBQejgLMm2XZw7rS3bt3oRLLeszN
4piVcbHtxqioKIdKJMEogzcKCyy/+7vkW1JXtmcEWdwzuhLz4U8nh/M4sCfc
YmcB9v24u90Yv/92iffPCJ/Wo3syL/L3NkJJ97yY13tfydi7FyLy8FY+8hGD
XPMWs0YoR4CXLyru3Wt3fVbGPnrvzoiNXNyj+7FYZ+HsOTwmOnn8RK+56yi3
mUK5gcxFSN6h5X5n4N5h9j59S1tEa8m0fsNb15sSN3LuTd8m9Oh+jY2NiF4U
gRFD7PvEzXQxPw8+ai2kzh6c+c3z1kIrUkJIcWBcTDTP2Tpq7apVNE/cEGQM
wMqlsVizIh7LlyxFPLVXUGF1fGwclscswZKIxYhasAiBvgEQUh7CYp6+6q8r
V7BwzlzI3UTEKid2NRTUZv/PlpQUNDV2nmOu/2YtlO5imkcySF3ceJzG3p3s
df26LfCAZIQ7HYv4vityckXu0b5zM9XX13H+0DFBFLe4Ye2yFbSO7nd7zeED
Bzi3gc0p2pfMc6uN58vbHmv4O2TvVDzCDadOWPbNnqq5uQmxUVEQ2A3HoawD
Fs+/RX7M/MhAXAbac3Ud9i5dR1+i2EHlLkMAeUpJUbHVuNl8iPkqAi6MO9sy
9wvKP6dPCac5JW7hauGTq81ru5XXXAwSNc0VD8wnT7GmmE99+flsuH7s1CNu
ptO5J2lP8oCW4i/+3Ns9X3PN5pG3zJOvc7WHFH9cvmx17nkzZv4vbqbU5GTa
613ouQt53NiRm8WbbM0y5oNZWVZlZmLfrWIiIns8T9oqe38GwkNCyS+Ytwhb
54mE1qCW4iD2TSn/fJ7VmZnYN7e46OhecTO9fPmS79+mhER4Ud6hpxgybfNW
5J87x/3qXYlxx0b1nvu1ym7dwlijHwwKJc9N37U49+Io4nboE/edsjIE+fmT
N/YfN5sngj4+bxZnM4/2Uqj6jzuKcTsSd06vxyktKcFob993xv0n+Whqkgk/
UM6dvm0H5d3JGOcXwGPbiHnzsTstHenbd2B7ymbs3bULT5/WdjnWL+fOYnvq
Zp5LJqxey/dOLflfqikFe3bu5vc4dviQVbh3padB6uYGPa0fPc1Fg1KFkToD
Rnn5wEfjyb9JjNR7QSOWIMjfn3L58i7HiopYCInAlWISGoues1Gn59ezvdOg
0FCuIMbs6Z9ZhZvlisVFRRQrtCnFxbwUFxfhNvlC2e3bKC4sxK2bpd2OVVFe
juvXruJGQQEKb9xAUaG5mNuFlMcVUJ5WZhVum2yyySabbLKm/gPFJxGE
                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa
RnEZDXXSxopoFjEumDZpJbFgQUWcqp0qaatxQZPaqXZqANEgFU1YFfTp+34Y
p5mABQ0cnfGZOXCXj3Pe53u35/2wzsxJeeFbw4YNW/Bd+pEyY+G4+fNn5KV+
h97E572UOfPb9CLy1sUf4iEe4iEEbty4obUJuNHdjfN19bjafEVrU+4albt2
I+WpJIxQ/QiOisGaVavR0tKitVkDQtn2UjhMFhiHhyJK8cKhM8KmN2Laj6ei
o71Da/P6hcaLjYiOiILTaodfVuAy28TlcTihDwkVHB8EVO7cDdlkhUdywmOT
EHC64ZNccDtk4ZP583K1NrFf2F2xk+w1wetUEKmoUG0yvOQLl80Bh9GMvJde
1trEfqH58mXEjoyG4fEwRBAPjqmAywPZbIUpNBzlZX/Q2sR+44OS9yFb7LCE
6eGkGFPtMozEK2dONq5du6a1eQPCzvIKZKQ/i6QJE5H0ZCIKXluN1tY2rc1C
N/XVY8eO4+jRo6itrUVdXR3q6+vRcOECLl68iKamJrS1teHmTa0t7RtsX05W
tshfmeqpU3bCbrdD9Xjg8/owMjIKY2NikZ76I8yelYmVy1egsmIXOjvunxjq
6urGy7kLIBvM8FLtcVsdcNqp9tjscMkyrEYT1VQJil2inOjpFbLeDJ/DhR8m
TkLhrwpw5p9ntKaBn6/Ih0S5qpAfuC9HuFRE+gJQ3VSDyH6byQwnceL+wFy4
xjIHv536B+U616j4+Hg0NFzQjENZaanoyyr1MbvBhCkpaag5VoMTx2tQfaga
B/YfQFVlFVIn/QAWnQGq7IKHuVB9ChAXH3FhH5nNZmRlZVGtuj7kHPbuqYLq
UiDbyI5wHTKnz8Lly829rl22eKno1dzDFep3Hoo9H8Ug+0TsAflLkiQUbyke
Ug4fVn8In0eFRM836fWY/fyLuNJ8tde1zaTJJyZMgJV4cGx5iYtKekQxkaay
OKiPU8w5XZC4LlAsHjp0aEg4tLe3I/mZSTCQD8wGI5YuWYbWlr7rfhX7jTQI
x4/QhqSnAqQPI+iKdPb0cfark3LJQjXh6e8n9unXb5ZHG8YHxyHkkUeRm/NT
Ua/6wk1qFksWLYaddBPrdPYHa1wf5fqX+aFQrrsoZ1TyiULf26kuZM+e0+c9
m5ubcelS0z3zaG1txca3irD+zfX4+yen77j2iy9aMGZ0rKhTrAM5P5gH+4Nr
NNffVSt/gQ1vbYApTEfa0S3WsO+2bioWvm+he1TsKMfagjWY82IWYqJHIz8/
H3v37r1nLtevd+FS4yV0dHTecd3Bg9Wil/gUN7xcq8hG3y0ebsqP4MgYfH71
c7F2XUGh0LtO4sC5zz5KmvgUEim3eB/M4XoYw8JF7OXkzCPtcOyeefQXv3z1
NVgoh9ySLDh8GVdeynMp3IjFCxZ+df3KV2EOJb8wD8olrtGS0SJqnZV4eOlv
UyenoKioCI20j0MB9tWkp5NEvMtWG/ykzUW9otxwU07IBgve2fT1Ovv6mnWi
F/HloMtKvfUJmt/nZ+fi4J/+POR6uHJXpfAB57fKeUE8PLJTvHYSj4Bbxdkz
/+r1bwvXrMWoEdGYnjEDv333vSHb+96wrmAtDDRvc85Gqj7x2+9yC/s51p+h
+so53BdYw2utjTs7O5E2OVX0BsncM4tzbHNccQ9hXbyB6t39Dt7LsdGxwmbe
f7Y/QDOsk/QIv+eras+9183BBve/wtWF4hzHR72c6yZf7BfuIz7Klb9U/01r
M/uFrq4urKK661c8Ijc8t3S7yHn67MlgAg7/9cHgwjiwbz+CMXFCJ7IvWLvz
mQ/r3oDHizfWvU59+8E4Q2w4fwG52Tm346undnnEnMh6edbM52mWPz9k9tTW
1qG8vKLfs9ueXXvw/u9Kbr/f9t42REd8T+S9i3LeQbUswueHLjwccXFjcPjw
kcEy/TZOn/4HPSsOOp0OMTExWLZsOQ4f6fu5tZ/WYfyYscLmn8yeS+9rxefn
/v0pZk6dcXsesZNveIYyGo2QaJ6vqhrcOrZ9eymGPzYcfr8fJpMJoY9Tj6Pn
pqWloaxsx9fOnvJ+tlDMiQ6zRdgcHTlC9HhGJ2mWEvLTiECUmN8dDofgYrFY
EBsbi7Nne+/z3wSamv6DKWnpCCUuJr0BbspXnn2sZIeNbE0IxmP9G+vx0ZGP
8JtfvwuFNQjnM2lE/t5LNWr/H/d95Z6nak5h6rPPwULzueKi+9G+sL8XLcob
NB6M9rZ2bN1cjMRxE3rONM099ZRnVT7vYW0acHsh095KfNZDc56N5nd+vf2D
3/d6T54B5mXPg1GnJ+6kc4l/ZCASH3/8yaByYfDMsGXjZiSMCcJGmlTUUNpv
0fO4T9BsxzGnKAqsNiuWLFl6x/vxHDshYTys5DebxQoTaf1pGdNFDxoKXLly
Fe9s3ooo1S/mOaGjyAcOux1er4qQkBCkp0/pl9beR31Gov2QaO7icy8H+bGs
dMfgk/gf1NfVYWPRRsTRnGAIDYOR8sdgMCA5efKAZulXVuQLn3hofrRQ3iWS
Jm7T4Oz6s88aUUjzacZzGcjMfEH0m4GA4ys5KVnsA8emQWdA8Zatg2PsIKOm
5iTleYQ4HzbTLD56VDT13QatzborlGwrEfnOecLxtWL5K/fF//sHiu7ubszN
mgMdn48QDy/pyZMnT2lt1l2B60PwiSAee+RRcXb59tubtDbprnHi+AnqI9PI
N3Nx7lxtr2tuaj3EP8T/xX8Bd1txeg==
                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC
1qMIhA7HYFVAsOqMnUq4tKKCpYBQBAkzBAhYDZeQYMaAkBDydXeTlxIT4AXi
PJ26M8v//Y/3z36/3f129/cwjJ1078Rf3XbbbVPC6Z97xzyVW1Q0ZvrQEDrJ
m148YWwX+pDWrHwRv8gv8hOW+vp6rHjtdTz04EN4YORIzJw+A8eOHQu2WR2S
y5cv47k5c2HU6aFKUsKo1UGtTMagu+7GkcOHg21ewLL9n9vgstlhIhxOiw0u
qw0OixXKnvF46fkXgm1ewDL/pXkwEwaHyQK31Y40txd2oxkmtRZjRz2ICxcu
BNvEgGT5kqVwGC3w2p2CI4WODsJh0Rnw2PiJuEy583OQisNHkOFJgVmrFxyM
h/2hV6rw5wUlwTavQ7JhbSkyPT4YlGqYKZ74+MSEh3Hy+Ilgm9Zh4Xx/7tnZ
eHraDKxesRLnqqqDbVKH5OzZKmxYvx7vvP0Odn22Cw3Ewz8nqfm2BksWL8Gd
BXfC7XTBznxL/PvIxIfxny+/DLZ5AcnWT7Zg+H33Q5WYBLPBKPXCYjTBbrZA
TbVwDNX177//PthmXlMqv/4ac2bPQarHCxPVbQfZ7SQ/uKj+eZinms+thOmT
zR8F29w2cuXKFfzt3XdRkD8AWo0WFvKB3WCC02yFmzDY6LOnmXNZdcS5o4aP
xKWLl4JteitZuGABjHoDTGS/jnHojbCSpjhc0oewP7hmWOgZxsaYUp1ulP79
vWCb3iJHjhxBZnoGDNR72CgPCvLzcf89v0Om1wcn9SJss8dih8tklXO7wQwX
YdEnJePxiY/8ZOr57GefhTpZBYvJjAdGjMSeXbuxinr0vr50WDV6+KwOUQ/h
8JrtcOgpxsw2OaY53Pj04y3XfX91dTXmzJ2LHTt2/mgYuO/O7tNX4qlXRiZK
31sr119f/hc4dZQjGgO8JhupFT7ySQrhcOnNcOgIg80Fs1KLyY8+fs3319TU
IOeOHHTp0gWDBg/60XAsWlhCeWEUHBPGjce56nO4XFePqZOLYExUIYUwuMnu
FJMdPrNDMNR+V4uSlxciw+6BTa1Hb28q/k0+bE/++tZbgoFVrVHjxInO72NO
njyJ3NtzoFNr0CejFz7Y+H7T9crjGD1yFGzUF6bbXXAamtbeS7FkTFKjsbFR
nntz5RuNTvYN5X//7H6YNWsWtm7dijNnzrT8jaqqKixaVILobjGCZe3atdLn
X7x4sdNwLJw3H1ayUZesxuTHCnGh5ju5vnf3HtyVXyC86yGecjeri3Bwnvtx
sGzb+mmDl3KnKf9NcLvdyMnJQVFREZYtWybKsun9TbBarRh631BMKS7GsGHD
8NVXX90yhmpap1/n5kOToER2r97Y9slWoOGK3Ptg3QakujwyNzHf+pXP7ZQz
P5S6urrzbpNtp5N4TK1WIykpCYmJiYiNjUVhYWHLcxs2bkB8fDy69eguvkmk
50pKSnDp0s3XoK9pLUYNG4EM4tZJ7Iva81QMaZ1prd9etUZmJK4TV+PgesL8
dYWLZltpbGhoqKOYqlq1alX98OHDkZ6RAfosN7ds2QKz2YwQRShCwxQI6xqO
LiEhgicrqy/27Nlz01h4D6SyshInjh9vuXaJ4vbpqdNoDre2j4Py+mBZ2akb
vJpx1hGubwUgrU2//v3FZkW4gjRMNDI6CjHdu8n17OzsVnl1q1J99ix+T/2G
8wcx5a/nfh6+0tDQnk/8wgnUQCqNZPmhckTHxEARFoYeFFPdu3dHD1KVKpli
i+KvZxx0ej1efe3VTsNxtPyw5DjHFeeDx+YQDNxTSb4QP/mohmxct77qBq9q
bFa8sXq1rHkMYeF6mkYcmErv430KjrMecbHiG5fLhUOHDnUKjsMHy5FFHMxr
z3Z7bfT3NDo5l9mcfME4nFQHG67vE5GTVC/S09IR2TUCsd26S0+QQvWUaypz
Rkx0NMLJT/4as2nTpk7B8dE/PoSPeg1Wtp2Pk6heZ2f2lvxIszrFBofWiPw+
/equ+mpje+/749znoCNOTLO7xRdeI/WYBqusBb+HfWMg3mcMoeSbPZ9/3ik4
li9eKj06Y+A87+VLQwX1Lju2/Qt90zNhUGkk1ljZXy/OnltzPSyznn4GhsTk
Zh844CZuNiVrZD08RgtSCZtJpW3yB/HXihUrOgXHTOIqjiPGwjkxMG8Ajh+v
lHsff7hZcBlUaunn+T7jmjh2fH39pbo2w2HF0aPwUMy7KQY95IcM8gnbHK4I
Q6pgoms2t3C5P66G3DPkljE0Uv2YMHos4dBKLuiVahQ+/AjnQcszH2zchN6p
6RJjvJ/FPb2Jji8+/0KbujJ6zGixzao1wJCkknxIjO0pOGzEI2bicDthTI5L
aMGRlZXV6u/djJz55hsMHFAgM5TP5YZWmYyZ06a3eY64Svxhp76dY0VL8T9h
3Lg2z2X3yxbbmJP8dvqVeTgqIgoKhQIhFE8hzTUxmbj4VvuVfXv3Ic2XKrOU
g3ohM81+S5csaffZlTSfcMw7qZ6YlRoUPvpom2dy8/KacShaYWCbuW+J7hqJ
mMhIwvI/nEajEd/Qet6KvLL8FZmnnHYHbGaLzOgfEn+1Jwf2lyHT5UWKwQKb
SocnHms7g+Tk5optXPeiIiIQTTaHESb2QVQk1XLSOOJi5l1FaKjg02i10off
rHyxbx+y+2bJjM44eI9n0MC7rvnOL8h3KVRbMqwuWMgfkwqfaPPMHXm5YpuP
uIn5NZ1iUUezcERkhNSNmMhoKHsmICEuDqqEJCjjExFKeHbtbn+WuZFwXgwZ
/FuZpXivTUvzSCbVro83b77mdw5T3e3l8cGlJY6mfC2aNLnNM/kFA8QfV9c+
5qsE6nmT4hMo5+Opputg1enhJj4zqpv4d/HixR3GwBQzg3KZ90h4r5Bzw+v2
YH3puut+71jFUeRk9hFfOChHniya0uo+96BpGekSQ8yxzLvpNIvxXMwzjY/8
k8LcS9ddpDynMa8xjnHtcMaN5M01a2SfxE7vNlMsOQnLyhUrb/g97vv7Z/SG
S2OEhWbE4j8Utbp/6tQpifXw8HCpD7w/z3byPOmm+pcisz7NZcR57CMX1V01
xRbjyM3P6xAG5ifeW7DyHqHDIT5ZOH9BQN89QbPv7eQPF/UnZrJt6pTiVvf3
79+PqJjopnnjKj6KCAtHmsUpvQn7x0wc4eddPz9zXgUqZ8+ewcjhIySvOZ4Y
Q3FRMerrAtuLOn3yFHL7ZMOhNgiO6VOfanV/52efSZ+hoJmJ1V8fGIeFcsJC
OcXzPve8EeFdic8iEUl8Jv4IEAfHLv9urNfqZB+dsYx5aLTs0QS8DjTzDOh3
O+y0npwjz8yY0er+9u3bm+YmwRHWqtbJdcqbZKVS9sGYy1j9eR6oP7iX7peV
LbykoV6J995Onz4dMAYWnu8LCIdNqaX8YBwzW93fu3evzHyhiqb5ryV2rsLC
9YPnAH8PydzF1+/+zd0B2cB7LtMoDtzUw42g2KqoqOgQBhb+zWDo4CFQdouF
OjYBL/9pXqv7lTQr836DxNYPcAiWkC6IoplEuKy5X7Q18xXvtQQqjIVnr9ra
2g5j8MvOHTtl725q8ZPye8PVwrE7oKCgpR9nu5uUPoc2nXclLtNTT6+m+se9
fGJsHMIIc2lp6U3b9GMI43Q6ncS/Gpm/dXodtDodTCYTbDabnDM3a3RaOSYp
k5BHnHvu3Llgm95Gzp8/j4MHD+LAgTLSAygrK5M9nvLycjn3K1/nnPq5/J+C
/3f5LzkVlgk=
                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 6->
                TagBox[GridBox[{
                   {"\<\"Date: 03/27/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1,
                     12}, {1, 13}, {1, 15}, {1, 16}, {1, 19}, {1, 20}, {1, 
                    34}, {2, 6}, {2, 8}, {3, 4}, {3, 6}, {3, 8}, {3, 16}, {4, 
                    12}, {4, 34}, {5, 9}, {5, 12}, {5, 16}, {5, 34}, {6, 8}, {
                    6, 9}, {6, 12}, {6, 15}, {6, 16}, {7, 26}, {8, 10}, {8, 
                    12}, {8, 15}, {8, 19}, {8, 34}, {9, 10}, {9, 11}, {9, 
                    12}, {9, 15}, {9, 16}, {9, 19}, {10, 16}, {10, 34}, {11, 
                    12}, {11, 15}, {11, 27}, {11, 34}, {12, 13}, {12, 14}, {
                    12, 15}, {12, 16}, {12, 19}, {12, 34}, {13, 17}, {13, 
                    19}, {15, 16}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc
mugXjcYZY0yccUVjVNDWFWdd4MIE9xZF776/m76n1lINKZ6jybmSh3PeeZ7r
udd1P/yQV5RW+EWHDh1Kvzb+pOVWRJeU5Fb9+JVxEFNV9lPel8aXQGP4GYOT
4oADDjjQRjQ2Nkp9fb1cu3ZNbty4IW/evLH3lNqMBw8eSP/+/cXX11dCQkJ0
XL9+3d7TajNu3bolCQkJyiMoKEg/L168aO9ptRkPHz5Ue/j4+CiPgIAAuXLl
ir2n1Wa8fPlSsrKGiLe3t3IIDg7RWPkckZeba/DwMnj4a3wQ7/bGzZs3Ze7c
ubJ8+XLZtm2bHD9+XG7fvq3+8/jxY3ny5Im8ePFC7dD8ulmam5tl+PACg4e7
+PpZJCY2yoiZBuv7yF0M7ue558+fy7Nnz/Q9jx49kvv37yvvc+fOyatXr9qN
x8GDB8Xd3V1cXV3Fy8tLIiIipGfPntKrVy8dCQnxkpySKJmD0uXnkcN0REaF
SnCIv4SGBRkjUMrHlkpVVZWUlZVJcXGxjB49WgoKCmTw4MEyYMAASUpKsr4v
NjZWevTooZ937txpNx4HDhwQi8Wicevh4aGfHHt6euqwWDzF1c1F3NxbhqfF
VUJCA5SHOby9PXQNzOd4T8uzfx/z3Tx2c3PT36EOtRew+aFDh2TFihUyffp0
KS0tNfxmuBQWFuqaZmcPkawhg2Rgxo/SJylOR2CQr9ohPCLYiHM/8Q/wkcDA
QI2V8PBwiYyMlOjoaImPj5c+ffrIwIEDJScnR/Ly8mTEiBFSVFQk48aNUz+z
JfD3pqYXRtw0aizk5eeIj6+nePt4yID0VKmprZGjR49qbJ06dUrOnDkjFy5c
0Di4e/euxtSniJLSYvEy4pwxctQwe0+nTUCP/Pb7Ef1ePrbEiIcWHsXFv+g5
bPGpo76+TgYZ+aqoeKQeV/1aIRYvN/HwdDX8vFLP4fPr1q2z5zTfC/JyTGwP
+fa7b9SfQHX1RHHq/L04O3eWiopyPUde8PPzk/Pnz9tzuq1i0aJFmh+7dOmi
OefEiRN6/urVq7J161bZtWuXnD17Vs9RP5ycnCQjI6Nd68L/AXmdmkZ97Nat
m34n77wP1Gdybffu3WXMmDFaz+2Jw4cPS0pKitYrNPmMGTOsfRJc1qxZI/v3
72/1WXQNz8B/5cqVtpy2FU1NTbJ27VrVDNTdsLAw5TJv3jzrPXPmzJGOHTuK
v7+/1onWQC3lOWKF+mprbN68WfUCepyaHBwcrFqDXsPE4sWLpVOnTtp3nD59
utX3PH36VHINPezs7CyJiYnS0NDQ6n0fC2iE/Px8nTvrzUAXDR061HoPGnjL
li3/WGdq9oYNG2Tfvn1aY8xzvXv3Vi7oRnSvLcGeAb8PB7QSueq/agK9E7qW
XooBZ3xyyZIleh2++BY6esGCBbakoSCXMi/sgu5uDfQS6L6uXbsqZ+aP/+GL
Li4uMnXqVL1v9uzZygMNuXPnTlvSUBAHxCpxsHv37n9dJ/bJx6bGRfuTJ4h9
1h5u5D36JLQzcUfMoR9tCXJ/SUmJzpU1fjs3kYOJY+ZKvUhNTdX5knPRuDt2
7NAaQr4GxAr7K5zr27ev3Lt3z6ZcqBX4Cn6SnZ2t/Slg3dPT0yUtLU3nTU5C
u+CP1PxVq1ZpXFVUVFjftXfvXu0zedfkyZNtygNcunRJ/YG1HD9+vLX3Jjaw
U11dndTU1Khfsc5RUVFaB+FhxraZq5YuXarn8bFly5bZnAv12+xN2YsAxAc8
1q9fL3/8pQs3bdqk+YGY4trJkyf1/OvXr3XgqxMmTFAuXEfH2BqzZs2y5h00
CfGQmZmpdqKHRRviN9RQ+KIvTQ7Yg0+wfft2a/+PP9p6v4i+NCsrS32CPY/L
ly9rzUM/4kvoKfyJfRHs9y7wRfZ7iCtsiz3gQtyZtdNWYO7USNab3zf3CIh1
4gM7sfcLqKeTJk1Su5j3oQGwRWhoqA7yNe+aMmWKzbUxtcTcu+H33wXrjg9V
V1erDsPvzPpDPiB2yNdmHGHH5ORkm/crzHP+/PnWPbvVq1frefyONTXzGXkA
bYWvMX/A/lK/fv2Uh6lBR40apT2ZPcB6l5eXW2P8yJGWvQfqCxzgxH4q/SK+
ZPoMfhcXF2fdh0Mz2Bv4PGuLX1DP36fN4bZw4UKtQ+ixmJgY5fip4NixY+oj
+FhlZaXU1tbKzJkzNTbIWdiH2ojt0L3UcnK1PerGh0DvBQ+z9r29l8v+Cb0L
1zlmX+hDPb69gM9MnDhR50odJJeSU6mXxDGcyE30We35P4KPAXQjfSSxS0+P
beACB+oNGvJzAXqR/5lQ57AFHPCrz/H/uHv27FF9hT9NmzbN5j15e4J9o40b
N9p7Gg444IADdsefMAqUuw==
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo
i0EFjVTaQqkKGk38ZTRaLaZGo0KiiUsw0hgNLnEBl0QxFIS4nd7vvnnP9woU
aWZ4Nnlfcudt9818595zvnPunfDU7IUug06n+87KPhau+j5h3bpV+V+b2EVi
fk5GqpGdxLAWyRpukgYNGjRo0KBBQx9oaWmhlJQUCg0Lo9DQUCr/oVxtSv8J
ixcvJpQ9OoOedHodP6+srFSb1oDQ2NhIZrOZfKwWsjnsZPd1cDsSEhLo9evX
atP7YFy6dIn0ej1ZYAezAbZwO+Lj6dWrV2rTGxBEvzKaTbzhvLz8/xUjb968
oWfPntHKlSvJz9+fhg4dSqWlpWrT+iA0NTXRnj17uEYhDqqrq6m1tZXHw8uX
L9Wm1ye6urvo/v37tHnzZpo1axYFBQUJ+iRr48ePp5s3b6pNtVfcu3ePqqqq
aNq0aWQwGiXOiAFRm+QalZycTO/evVObtgKwYdzn4wTuTI+gqwaTkax2m8Rf
3swWHzKZTPT48WO1qSuQl5fHbXB84itp0NixYykgMIAsNqvCBtgm6m1+fr7a
1BXIyMjgvAwGA02aNInOnz9PDQ0NFBQ8QvIrecMcIY9ER0dT50cU69AiMR7W
r1/P79XU1vBrOXe5LRY2L3h+6tQpldkLQB6GnoKTXqen3bt309u3b7lWYcyt
DluP+bCiueM9KSlJbRM4mm/domDnSF73ORi3a9eu8VxnZJol1B/vY4I3N3+T
j5nHDvrl5ORQc3OzqnbUN9TzcYcdgZ8G8ntlZWUKn3pvg51r8pw5c2jMmDFc
02AL+g4bNoyioqLo8OHDquSWuro6IcYZp+HDh/N7cXFx/B5iQtReHEXOLQ8f
8vds7hjhPok63n0eGBhILpeL7t69O2h2YPzE3586dSpduXKFj62pF53SMz2b
+eVMqbZ9+vQpbdu2jdttNAm508z8zezjw8+hH4g1Odra2qijo8PjdqBWimd1
t8PhoNOnT/MGDhh7zIEYG4h33N+/f3+v3wPdKikpoVFOpzQuX0yZQvv27eO2
oMasqKigiIgIWrp0qcftAFDzvXjxgp9j3RoeHs7ixaCYC/gd1rEPHjz41+9C
7lmQtID27t1L7R1/UfKiZIqJiaH09HQq27pV8Fe7nf+Ot1FQWNAjd+AautQf
UKsUFRfTzl27KCY2lkwWwceGDBlCf5w8Sc5Ro/j1hg0bvG4Hxo6PG6tTBlKH
tDAfLWY2oD4TfQv5UtTqrNVZlO4SaofJkydLPuANIH8EBATw/PBPrYI/HDx4
UNEffn/kyBGeN6uqf6ERrJYBT3lsoZnYut450kk/V1Xy70GfuhMnvGZHQUGB
VDNa3boKG3CN3AEOjVevSv07Ozt5LkG/FStW0OpvVys0W4ox9h7qt8LiIqYr
Qv0QFz/dKzZAE/0D/KW5sNhsNPur2eTLbICviHEyc8YMxdpje/l2fh/558ef
fyI70z4r+tuVuo0+sdNjue/hHL91/fp1j9tRxtba4lgajAYKY7oFvoWFhVLc
Y15wnpmZKb13+/Zt5k/Bghbk5dLcefOE74FGyOp9zCvWLVgbh4SE8D7Z2dke
tQFr7cjISF6jiOMu15Tly5dLfm9xx/GFCxek50uWLBHiNzKCtpRuEeozxJTb
BqtM95IWJNHGjRtp9OjRtIvpmieBWBXHHH6FvZA7d+5Iz1sfPRJqKsbP4eaz
Zs0a6Tn26MR8vqNiB02YMIHnf7uv26fY/Ioahhr5yZMn1N3d7VEbgKjoKP67
kt98k9mjpjhw4ICgAb5Cn7S0NOkZ4h1re9xftmwZ36eQ111hYWF8vwh62NXV
5XH+AGoRvk/I5h9zAW1p+rOpR7/6+nphzty6uShlkeL5zl93uuPCQYcOHSIb
0wn4KuqR1lbv5m+MOeaZ83PPxfz583vte+7cOcn3cJw7b67iOfLaiJHBPHfX
1tbSQ1YXt7e3e5W/CPg1dBV7ICI/8O0Nly9f5nUwz9fMXyZOnMjXXHIc/e0o
Xbx4cTCoK5CVlSXlPRwTExP73HNGbYx9FPg89h/8/Py4v6uNtufPeQ1iZJrO
NVGv4/VdX4APwudE/cXxzJkzg0e4D2wq2ST5u96oJydbO/T3P0ZqWqoiRo7/
fnyQ2PYOrCOwhyjuT4ETdKU/uDJdUs7HEetJNXH27Nn3c8HWSCGfhfD96f6w
du1aRTyp/Z/ajRs3+H6AmGNzc3M/6L2TbC2EGkl879ixY15m2j8wJ6j3ioqK
BvT/HtbomS4X1dTUeJGdBg0aNGjQoEHDx4W/AU6fUkQ=
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa
WuNbVWLIgISig/F1qbmTTqs6D6qj1rzf/+179vHf6ya5SSvRt95eayf3TP/5
z3f28O39nzqpD/bL9PHy8vq7Rf3plzKl88SJKVP7+6mNO6dOykj1VT/ilfZS
ip1Xr16l8uiVK1fKdd1fSUU8Pf/y5cuMiy7YJ/sr+3luBoxEvv/+e/rkk0/o
t99+c+B06RL/LyoqorfffrtMY97sWhaMIO+//z6lpqZSdHQ0RUZGUtOmTWnu
3Ll0/vx5Pj516lSaMmVKmbG/mdWTZxHf+vjjj6lRo0akwhf5+/tTYGAg+fj4
8DZwgxw+fJiys7OdfLCyn7Gi7AgCHICH3W5ntVqtZLPZGCvsLygooG+//Zb6
9u1LkydPpp9//pnx/avHqdIwEhs6c+YMRUVFMR6Cja7AaNy4cZScnMy/oatW
reJr9Rhf2c97IzE6ffo0RUREMEa6HVWpUoXxQHwaM2YMWSwWCggIYB/csmWL
iRG0OL+7EVIZGJ07d47jM/CA3QhG2K5fvz5NmDCBateuzXEK+/r06cPX4PqL
Fy/SJZX3PMUDWP7+++/066+/sr+ePXvWSX/88Uf65ZdfeHzkVZzvKW6YD+ZS
Fv8vDSNdnn32WX5+2Iqfnx//7969O8do+CH24XiDBg0Ys3379pljQ7766iva
u3cv5ebm0rJly2j27Nk0adIkGjVqFA0ePJjuu+8+6tmzJ3Xs2JFat25NcXFx
nCPwDmCnothu3LgxtWjRgtq2bUudOnWiu+66i/r378/jjFbjTZs2jfPtypUr
mY8cPXqUsYX8GRjJ9ZDz6n3u37+ftm3bRu+88w7jERYWxnODb91zzz0UFBRk
5jj4436FDeYHHgDBu8bvmjVrsh96e3ubMcud4rh+jmyL4j5yvLSx5BzY/R13
3MHvR2zVU590hxF8A/Lmm29SQkIC2wtwwXs6efIkv/+7776batSowfPFcYlJ
r732Gl/7n4MHqVevXvwb7xLH9WcrSX19fc24B/xDQ0P5/tWqVaOQkBCqWrUq
BQcHs6/Ddj0ZUzhKeHg4ffjhhx7jUxxGkA8++IDfO3jiyJEjacSIEWzPMTEx
HI/wHLAJ/IcOHDjQvDcEsaRLly7MuXEd5odna968OWM3aNAgzoMzZsygefPm
0YoVK2j9+vXMH1555RW23YMK5+PHjzNvBTcDr8c9Tp06xTwMx1999VXavn07
bd68mV588UVasmQJPfnkk8xjMzMzmYd07tyZYmNjTY7y9NNP/yGMRFJSUni8
9LR0atiwIeOhq/DIxMREM3/pcRGCWJOWlsbYIL4cOXLE5OOeCuIy/BRxZtiw
YYztaoNTeCqYE2IRMITttWnTxpxjeTH6/PPP2Y+ARZaKOeHKxr2Urfr4+VLV
0BBqEteUMkeP4lh44cIFJ2z0/IXjkvs2btxonleWuX355ZfUsmVLql69Ots1
fGXs2LF8zFN+qgtwxnzeeOMNp3mXFaNNmzbxOPD1lq1a0ZjscdSnf18aMmI4
Jaen0cDBD9Dr+/aa1wInd/n366+/5jgCzoBcfcWD+egKvDEurv3hhx/MvI/7
CT5lzU979uzhZ0PeFZzLY0cTJ040aw7/wAC6rXYUxbVoTlHRdclWJYi8VIwM
iwinZS88z/MXQR2CmLJmzRre3rVrF4+zYMEC3oafST7w5JkEA1cRPlpWjITD
gq/AT4C5Jzjp9xXp0KED5wr4SZDi0QFWC3n7+lCAzcr+5uXjzdhZ1H74QVJS
EsdGxC3JI/Pnz2efwG/kQYjYRVmfqTjsyloHiq3v3LmT57VhwwYnjEoTwQh9
IeRw+Bnyl9WualZDfQL8qd/AAdSlZw9KyUjnGnfo0KGc06Dp6emML+4P3MD1
kA/vvfde034qs77VuSNyHfiLyGeffUYbcnIYNyj8ATHno48+ug4j5Fnke8Rr
V4xgPy/v3kWHjx2lv9WsQVZ1HPwFCr6C2AOOCd9CLgJPQEwCd0YO99THbpRK
rwayY8cOzrfgFJAePXpcx1ex3b59e66LZO4QPAuuBZfQMYK/WdT/k4rvbM7L
I2/lc+CO8EdRjAvuc+LECWoW34weffRRHhM+98QTT1Q6Rg4/vZZbYPOoFYBX
hMrdpl0YfQ34EnjrF1984YQRnk/HiK9RiuurKftCLs7Pz3fir7r6Gny2bkw9
+u7MdzzmoSOHaf3GDaX6e0VLnnoOX38/jrVe3l7sJ97Gc4gdIbajLwQRXwOH
Rc0lmIqCL6JuRV2KPIw4Ay6GWgUKm0RtiZwRUS2C6tSLpuyJEygzazSNGz+e
xj6YTSPHZNHIrCzH/4rWrGs6StlOluIz4DFWladjG91OXXt0p4SOiQ41ngc1
KepOEbEj2AmwACauGNWqVYtjm4iegyHgLUuXLGWu5+0HzunneD94Jx7UVBWq
qI2VDfmqPNSuQwLt3vM6P8NFbY3HlXcIRqjRG6v6GL4ovTSb4WuI5bAzPt/I
DxIDEet79+7Nduqn8LQHVyFLkJ35QqAW97FP365otRr3x3/5DV/DvB6e9g86
Z8RnqRdEdV+D9OvXz+SQZkxScQwxCrWmbkMQ1Jf16tXja3Ce3cDGzxJIvopH
MU4GVrDtysDGfDdqHpiPv8pBnIvUb2CFeWL+A1Q9iHpc52fuBDUq7EGPSXh2
1Pe7d+92sruzik+hFyb48Pl4Nyr+4d41FUe3GLwhwJhXZWEEPOD7IeFhVKPW
beSn/MxX2bzFsCn8x3OMV/FT7KAkbjlnzhzu2yC/C0aI9ahTdbub/fjjjv6t
HdjYWX2U7Q5VMT13SwHlKB6WW1BAAx4YRF5qf2BJvqeOWeyGD1itjK2uVuN/
oJqPxaZtG/ZQEkawafj/jJkzKX/bVtqUn0tr16+juObxPC+5HvaFHv2hQ4ec
bEF+u/of+hrSv4YyRoWF165R2rO3ozcUIDxTvafkjDTaur2ImiiOFKZyXMs2
rWmH4p6Dhw9je9LnLnMDVjalds1undaogBEwNDgZ/Fn2B2q+rGMVYPgVxkaN
sGz5C7TgX4soqm4dCousxrX5voMHKPZ2VUMpvodzbcGONYyFCxeWiJHYiI4R
5gP/e1nxLZELKq61ateOx5d3FRwaQluKClU+ddRuglucwqtA4Yt45C6O4/0h
1kudKL1N6bPCz6VnJcd8cK663hf5EzWkur9ulxL7ML/2KqfnbS3gehO5DPfD
GKPHjaWn5s8z58rnq9+PPPJIsRhJTIegr6VjhPgkMZvPU1ji3oIR4l5MwwaU
o+od9heb1fSF0PBw5pHR9WP4PNfnwL5U9U6WLl3KvKROnTr0zDPP0EMPPcS1
Dnp+ixcv5l4d8gPWH3DMX80pLTODFi5+jtq0b8f839VGvXy8aFjyCPqn4vq8
ZiH5TJ2bkJhIK1avYtwC7FaOmThHaoTS7Ah1lmCEd4f3iR63yEXF68EtxH9g
RyER4VT08g62Z44/xnuJiY1l/wuqeouZU3TFGAVGPxM91latWvFvcApgJL1O
2Da4qxwLVGMVGbadMTLTyR7ERjGPLooj5mw2+mIKD4sxrxRVhwNf2Lp5vto/
a9asEjGSbXBNwYhrEVW7YF7X7OgytUWdr8YXvxf7xXyAE3CrHV2X8rduoYzR
o657BhMjNUZeQT6Pi34C+t4Q8DHcP0/ViBCsA8OWIFinCVB8pKBwG2+jF6GP
L3PCO0E8QoyePmsm3RIWyjYObr3nwH6Ka9mC7y/25SlG6J01adLE7JHgP+z/
m2++cfK1trAjvAMjf2JesOHsCeNp647ttDEvl7bv2kmjx44x46InGMXHx5cZ
o1QXjCxGPpd8FaHi9CLlr4XK7jbl59Fmdb+OXe5kG7ZpnNdTjFBz3HrrrSZH
QuwEZnrP/tLVKw5fU8+n+w/7tNoXqnIa4lNoZAT3w91xbJ23oMYUf8L6IuS9
995jHxeMEJd0jBCPCg0+kpaepvEQgzPo3FHNCzVsjahaFB1bn98peIpVm5f4
4EzFEUrDCPwAMUhyLa5DfNIFtU1Cp46mr7njJLBx/C+Otwgfx/iCEewI/U3I
u+++y+9I1g5xTGLVW2+9xXmu0OAjaanOXMXq7n5GfjD5v+s7MzB67LHHeMzi
vueArF27lvOt9IZwnaxHiCD3x8OX/3B96fi/UfFNCPIp1qohWJ/T+6pYO8Ia
gmCEY1iTg8iax5+h06dPL9WOsF6uvxP8XrRokRNGiNng0kteeJ7z54o1q8us
K/+9hhVjnP70Ux4X3wlIHsM6CL7RkX7DgQMHTEwQM1evXs1rXRB8S7B8+XLe
B11VjvksV8+BMbAWWBxGIujhS10r645Sh8h5S59fRn3vv5+5B9aVhql4Wm5N
SaaBSUlcTw8ZMoRtAr8HDBjAvaokl2NYV8cxxHD9GLZFR5RjHsOhw4fzmFKP
uMMIfX+s/UpOAz7ou31qvGc5b85Tc5x85X9J0eNAT7Y4jLBOJzW81Pvo/Qr/
lvOOHj9OduMbLX/Ed+Rau93MuXruNXNMkI3Vse1Q2ba6fBv3R5VjdpDkT5tZ
33N8Drp+npxjDZ6N73vkec3Yoq1Boz+J8wQn/JbvQF19Et8RxTVrxt9zWARX
l1wh9YbU71Krmj08l+0/U/WxsR5oNfrzFpfcCuxQ7wWHVKVu3brRsWPH3MYj
EfSk9ToN3Ehfr3etWSD4NgLnyTt0nQOU6zSjXq1olTUMxA0r1ni0vG9yNMUl
O3ft6lRr6M8oPcVTirPpfSP4GbgkvmtxxUjWXUvDiHmuekewJ5uqvW6UzZSk
qPnQF5LvyWwufFZ4bCfFu12/33LFCGvQ4mfCi/ANnmvc0nvZEFn/docRxkga
MpiOnDhO+w8e4O+GKkORp8AbsJbm78Jr8f4wzzu7d3MboyFiU3rOF4zAF1zx
ce1hIsaVhNHkh6fQzSBYN46sHumEkcXo48COuvXsYZ5bHEbo5XL/wPj+E36m
r1MWhxN6Pqb9GX1BiUPYj/Usvk8x49z49VnH84G/YM0d/RGZn7+xBgCMEjt3
KhYj8RvggW/zEI+wRvnSSy+ZGLr7jkME30MAC3Ot3MdQg28sWvyc4z6V+E0E
5KeffuI6h+flc22e6FVgX0ZmZrEYyT4I1tjQk8D3RCWJfj3We5H7UOdB161b
x/ji+zqsp18w+gXuvieqKJF7o07GHDE/6Dql2M7JyTHXrf8v5ZP/AozBoMg=

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00
0TK1ifeuGtTVNbvruq4ao6J4Jp7xLG/AyCHqqoByiBzqs90vDOXFMDhY/ohd
9TnDfJ/99vN299Pd7ydPSo2Z+Jtu3brN+D39E5M4KyQ9PTE79nf0R2h2xkdJ
v6UvPq0X/4h38k7esjx98gQFV68ib8cOHPvpMCru3nvbJnVaGhoaMG/OXPh6
eEItk0PnpkBwUD/s3LnzbZvWKVm6eDFkTi7QypXQK9TwUGuhcpPD19cX58+f
f9vmWSXNzc0YHDkQCokURrLfU2eEnvAoCYdUJsPSpUvftolWSW1tLSIHhBMO
Gdw1OoHFqNLAXW+AXC5HZmbm2zbRahkTFwe5qwQ6hQruhMOk1UNHWJycnLBh
wwabdF++fBnHjh3rIksty47t2wUGuYsEeqUabk6ucHV0RhzhY3/ZIsnJyQgL
C8OjR48sPldfX4+a6mqb1mLZm78X8R+MRP/efRAeFIyM9Bm4ffu2TTo59xIS
EuDj44N7FRX45do1ZGdk4u6dO23P1NbWYPHX3yB68BBERQ5CRtp0XL1ypVPr
PH36FFVVVfgf2dvY0IgnVEMqab2mxiab7DdLY2Mj4RgLhUKBc+fOCXul9k44
e+p02/pZ6Rlwec8eGinzvRLO7/VAREgoysrKrFrjx4OHMH7sOIQFh6Af+WBw
eCQmxCcga8ZMLF24CNv+uwVnz5xFSUkJ7t69i+amFmxPHj9G/cN6VFZW4mb5
TZQUF6OwsBCXLl5CeXn5c2twLMWNHAUZceGSRYuQ8vEU6MnWSxcuivsnj5+A
Qa6CkS4PlRbudJnUOrj0cMQSqgUdyYkjR+Fv8oLCWQIt1T2tTAEdfaooP9Qu
Uuhob4xcR4i/enn3xMCQMExOSkba5CmYOD4RccNjMTRiEMKC+iPQ1w/eBndh
Q2BPf1y5dLltnYZHDYiLjoWauHBI+ED09QuAn6c3fikqEvf/86+Nou4yR3oQ
t5i0BrGmUipDakqKRQwNtEfxMSMgsXMQe+CrJxuUGvHdfPHfRsp3tdQNWqrt
euIA/q50lZJNblC5yogLXMQld3YVnzJHF8EPR6mnMUtzUzPGxcWLZ5jLWVdQ
QG+UlZSK+0cPHxG1V0W6GQfzPvON1Nmlw7qVvysPWvp/JraZ7DW0+vS5i373
onro7+Uj9PNajIHtUdLeehs9EODli/D+IYiLHYFpH3+CBV/Owz7iCs7tZ2UT
7Tnbz/YxF3rqjVi2cLHIDfZX8rgJkBI3sl5eh/ejb6/eKCi4ahHHvM/mQEt7
yvuto3hiHF7sz2dw6GVKRL8fhX2792D39h+Q+9cVWPTnr0UPtn7t3/AzxXXJ
9WLU1tRQf/nU4nos361bDx93k7CTL/bt1EmTcfvWLaFjwRdfIqRPkIjLyckT
Sf9xi/oeNz+m+E6iPJCKfPPU6EUMcW49i0NDOFM/mUo5/QQVd+5iCeX9vr17
O7TXkrBfzH2ohvyjIBsiQwbgGOUqSxXxRllp6Uv+fJXUEPbYqKEUV5zHKoot
3SvjSk3xzxzJ8T338zlw6GGP8AEd17KO5PstW2HSGUSs6jhWKZb476/mzRd1
0Fp58OABoohnOJ7MPjC+AgdzWNbMTOTm5sLfzw8ODg5IS0uzCQNLHfUG74dF
iL6BeclAPMX+caO8m5iYhMfE6dYI+2M4xT3nhzflscBB/PpiXLkTt3hQPvoR
BpVKBU9PT5w8edJmHLmrVgm7mZcMtIY59znGpkycZLWeJqplHyaMoxohE7nh
Sfa/Kj/4N61KLeqwRCJBSqplLrdGym+UI7R/f8qNlnrB+c7cxVgCvH1xoZNz
DvcBCuJ59oN3K0+9iMNIOFSEQalWQWfQ48iRIzbjmD9/PjQKpahF3FOzPxgP
50juipWd1rdsEc1+xNesy6xPxCrXErqYU3JmZSPAzx92dnZdMn9cPH9B1CL2
s57ykXOb40ktVyB+ZBwe1j3stE7mDK5p5vrJ+oyteJgPucadOvEzLlAPtHnz
Zty7Z/t5Q9qUaVBSD8R1yZNigNfTU9z6EbYTVIteR86ePt22H4xF6BTfeRZs
wbJu9RqbbTfLwX37BceKPCSe516O+yjOixXL//Laeutq6xBDNUTZOsey/S2f
etEDaYhPMlKndxmOjyYkQcH+Z/5QaMgfevF3/AejBH/aIjPT0oUuHeU6x5OB
fMx7pKF4ZR7p1zvwpR78dWRP3u62mOV6y/xoIN9zz8uxa6vs+mEHVNxjCQwa
EVfc/7TxOflq8cKFNq1xkfKrN/X0GlnL3nBcudO+MVdyr9YVcqO0DH1oFjDn
uHtrjpj3juPMk/J948aNr6W/tqYWcSNGirotzl9YP/VzCupl06emiHO/rpDH
1IuNHz2GfCKDTqlqs93LYGydaXRQyGgm8PBAXl5ep/V/tWCBmCHMPS7rlBOG
mSlpNEt2nmMtCfeB3NdoKScYg7fBQ8SVOV+0xF1ubm6iNzlz5ozVevlZk9Ed
OtKhIs5g/uB6lZOZJfqJrpbtW7e1xRHbz98jgkPFbMRzpZ58otFooFQqEUpz
/9WrlucaFp6NJk2aBImLK/VnLXWC8zCbZn7GUFdX1+U4bpZzvxMMvYbmDZ5b
yf9jRo3GPzd8hz69ekFBWNgW7rPcXCVIpn60I9m/dx9MFJtailUt9SCMYeb0
dHHv+y1bsGXT5i7HwZI4fgLcJMS/hEVFWAYEh+BG2Q3k0xzIZwdce3WiH5Ug
esiQDvXlZGWL826OU65Pn87KEr8f3H8AJtqT42/oXHElzatSigEjrcFY3MgH
+Xv2iHvMK2LeorjjXnt8wliLuvjcKziwr3iWrw9p7mY5/ONPgn99TZ64fv36
G8GxhvoPOfGSRq2GkvLdhfJx0783iXuzps8Qc6Gxte/6/I9/sqjrAMUUP8cX
59zJEydwrahIYJA6OGP44CE21+9XSXV1NWKiY4T9GsoBzmv2y5HWcxvu7RTE
Z4ZWf+Tt2GVR32yKIT6/4ZoxYli0+I3rrb61tvIZQvEb8Mfq3NXPYZC4uOCL
uXPb7k+bNBkSe0fRRzCWs6fb514+T40dOkzg4LxYv2at+P3B/fsYGBrWxu9/
X7e+SzHwmWZEWLjIB1En6DNxQmLbrN/U2IhxVCf5fM28l9cKi9rVx2dA/QJ6
Cxx96Nkbz5zNrqX9UlOecS0ZOybBqvMQa+UbqoH8vklF/Mj+6Nc3CAUFBW33
79+vwrBBg0WPzTHFZ4KP6ts/K+GZht/HsS9mpDx/HlH9oBpREQNFX+plMnXJ
bMlSWFAI/55+wn5zXG3buvW5Z/hcms81+Pxb4uCEzz7Nsahz+eIlcO3hIHLh
AM0bL8qKZcvFeyJHB0cstLH/NEtW5ixISSdjkMtkyJk9+6VnSktKBYcyDiXV
lzXfftuuvkbq+cbHJ8Cxux1GRseK9w8vyv2qKkRFDoS9XQ8MoTrE7ypskVOn
TsFEvZ+Keg0Z5URC/BiRiy8Kx5ifj6/okYzEAfyOoT2prKgU76h7/KG7xfnu
H9QncB5KpVIcOtS+PmskIyND9H6sKzAwEMXFxa98roJqWmhoKLp37y72r6M+
e9XKVZhAvcGtW7fafYbPIlNTU8V52OHDh9t9zhrJycmBvb09AgICOsw3PmMY
PXo08vPzbVrzWeF3jfze09a+l88+2L6iovY59J28k1+L/B+xoVyP
                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$20", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$4", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$7", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$27", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$14", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$13", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$13", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC
1qMIhA7HYFVAsOqMnUq4tKKCpYBQBAkzBAhYDZeQYMaAkBDydXeTlxIT4AXi
PJ26M8v//Y/3z36/3f129/cwjJ1078Rf3XbbbVPC6Z97xzyVW1Q0ZvrQEDrJ
m148YWwX+pDWrHwRv8gv8hOW+vp6rHjtdTz04EN4YORIzJw+A8eOHQu2WR2S
y5cv47k5c2HU6aFKUsKo1UGtTMagu+7GkcOHg21ewLL9n9vgstlhIhxOiw0u
qw0OixXKnvF46fkXgm1ewDL/pXkwEwaHyQK31Y40txd2oxkmtRZjRz2ICxcu
BNvEgGT5kqVwGC3w2p2CI4WODsJh0Rnw2PiJuEy583OQisNHkOFJgVmrFxyM
h/2hV6rw5wUlwTavQ7JhbSkyPT4YlGqYKZ74+MSEh3Hy+Ilgm9Zh4Xx/7tnZ
eHraDKxesRLnqqqDbVKH5OzZKmxYvx7vvP0Odn22Cw3Ewz8nqfm2BksWL8Gd
BXfC7XTBznxL/PvIxIfxny+/DLZ5AcnWT7Zg+H33Q5WYBLPBKPXCYjTBbrZA
TbVwDNX177//PthmXlMqv/4ac2bPQarHCxPVbQfZ7SQ/uKj+eZinms+thOmT
zR8F29w2cuXKFfzt3XdRkD8AWo0WFvKB3WCC02yFmzDY6LOnmXNZdcS5o4aP
xKWLl4JteitZuGABjHoDTGS/jnHojbCSpjhc0oewP7hmWOgZxsaYUp1ulP79
vWCb3iJHjhxBZnoGDNR72CgPCvLzcf89v0Om1wcn9SJss8dih8tklXO7wQwX
YdEnJePxiY/8ZOr57GefhTpZBYvJjAdGjMSeXbuxinr0vr50WDV6+KwOUQ/h
8JrtcOgpxsw2OaY53Pj04y3XfX91dTXmzJ2LHTt2/mgYuO/O7tNX4qlXRiZK
31sr119f/hc4dZQjGgO8JhupFT7ySQrhcOnNcOgIg80Fs1KLyY8+fs3319TU
IOeOHHTp0gWDBg/60XAsWlhCeWEUHBPGjce56nO4XFePqZOLYExUIYUwuMnu
FJMdPrNDMNR+V4uSlxciw+6BTa1Hb28q/k0+bE/++tZbgoFVrVHjxInO72NO
njyJ3NtzoFNr0CejFz7Y+H7T9crjGD1yFGzUF6bbXXAamtbeS7FkTFKjsbFR
nntz5RuNTvYN5X//7H6YNWsWtm7dijNnzrT8jaqqKixaVILobjGCZe3atdLn
X7x4sdNwLJw3H1ayUZesxuTHCnGh5ju5vnf3HtyVXyC86yGecjeri3Bwnvtx
sGzb+mmDl3KnKf9NcLvdyMnJQVFREZYtWybKsun9TbBarRh631BMKS7GsGHD
8NVXX90yhmpap1/n5kOToER2r97Y9slWoOGK3Ptg3QakujwyNzHf+pXP7ZQz
P5S6urrzbpNtp5N4TK1WIykpCYmJiYiNjUVhYWHLcxs2bkB8fDy69eguvkmk
50pKSnDp0s3XoK9pLUYNG4EM4tZJ7Iva81QMaZ1prd9etUZmJK4TV+PgesL8
dYWLZltpbGhoqKOYqlq1alX98OHDkZ6RAfosN7ds2QKz2YwQRShCwxQI6xqO
LiEhgicrqy/27Nlz01h4D6SyshInjh9vuXaJ4vbpqdNoDre2j4Py+mBZ2akb
vJpx1hGubwUgrU2//v3FZkW4gjRMNDI6CjHdu8n17OzsVnl1q1J99ix+T/2G
8wcx5a/nfh6+0tDQnk/8wgnUQCqNZPmhckTHxEARFoYeFFPdu3dHD1KVKpli
i+KvZxx0ej1efe3VTsNxtPyw5DjHFeeDx+YQDNxTSb4QP/mohmxct77qBq9q
bFa8sXq1rHkMYeF6mkYcmErv430KjrMecbHiG5fLhUOHDnUKjsMHy5FFHMxr
z3Z7bfT3NDo5l9mcfME4nFQHG67vE5GTVC/S09IR2TUCsd26S0+QQvWUaypz
Rkx0NMLJT/4as2nTpk7B8dE/PoSPeg1Wtp2Pk6heZ2f2lvxIszrFBofWiPw+
/equ+mpje+/749znoCNOTLO7xRdeI/WYBqusBb+HfWMg3mcMoeSbPZ9/3ik4
li9eKj06Y+A87+VLQwX1Lju2/Qt90zNhUGkk1ljZXy/OnltzPSyznn4GhsTk
Zh844CZuNiVrZD08RgtSCZtJpW3yB/HXihUrOgXHTOIqjiPGwjkxMG8Ajh+v
lHsff7hZcBlUaunn+T7jmjh2fH39pbo2w2HF0aPwUMy7KQY95IcM8gnbHK4I
Q6pgoms2t3C5P66G3DPkljE0Uv2YMHos4dBKLuiVahQ+/AjnQcszH2zchN6p
6RJjvJ/FPb2Jji8+/0KbujJ6zGixzao1wJCkknxIjO0pOGzEI2bicDthTI5L
aMGRlZXV6u/djJz55hsMHFAgM5TP5YZWmYyZ06a3eY64Svxhp76dY0VL8T9h
3Lg2z2X3yxbbmJP8dvqVeTgqIgoKhQIhFE8hzTUxmbj4VvuVfXv3Ic2XKrOU
g3ohM81+S5csaffZlTSfcMw7qZ6YlRoUPvpom2dy8/KacShaYWCbuW+J7hqJ
mMhIwvI/nEajEd/Qet6KvLL8FZmnnHYHbGaLzOgfEn+1Jwf2lyHT5UWKwQKb
SocnHms7g+Tk5optXPeiIiIQTTaHESb2QVQk1XLSOOJi5l1FaKjg02i10off
rHyxbx+y+2bJjM44eI9n0MC7rvnOL8h3KVRbMqwuWMgfkwqfaPPMHXm5YpuP
uIn5NZ1iUUezcERkhNSNmMhoKHsmICEuDqqEJCjjExFKeHbtbn+WuZFwXgwZ
/FuZpXivTUvzSCbVro83b77mdw5T3e3l8cGlJY6mfC2aNLnNM/kFA8QfV9c+
5qsE6nmT4hMo5+Opputg1enhJj4zqpv4d/HixR3GwBQzg3KZ90h4r5Bzw+v2
YH3puut+71jFUeRk9hFfOChHniya0uo+96BpGekSQ8yxzLvpNIvxXMwzjY/8
k8LcS9ddpDynMa8xjnHtcMaN5M01a2SfxE7vNlMsOQnLyhUrb/g97vv7Z/SG
S2OEhWbE4j8Utbp/6tQpifXw8HCpD7w/z3byPOmm+pcisz7NZcR57CMX1V01
xRbjyM3P6xAG5ifeW7DyHqHDIT5ZOH9BQN89QbPv7eQPF/UnZrJt6pTiVvf3
79+PqJjopnnjKj6KCAtHmsUpvQn7x0wc4eddPz9zXgUqZ8+ewcjhIySvOZ4Y
Q3FRMerrAtuLOn3yFHL7ZMOhNgiO6VOfanV/52efSZ+hoJmJ1V8fGIeFcsJC
OcXzPve8EeFdic8iEUl8Jv4IEAfHLv9urNfqZB+dsYx5aLTs0QS8DjTzDOh3
O+y0npwjz8yY0er+9u3bm+YmwRHWqtbJdcqbZKVS9sGYy1j9eR6oP7iX7peV
LbykoV6J995Onz4dMAYWnu8LCIdNqaX8YBwzW93fu3evzHyhiqb5ryV2rsLC
9YPnAH8PydzF1+/+zd0B2cB7LtMoDtzUw42g2KqoqOgQBhb+zWDo4CFQdouF
OjYBL/9pXqv7lTQr836DxNYPcAiWkC6IoplEuKy5X7Q18xXvtQQqjIVnr9ra
2g5j8MvOHTtl725q8ZPye8PVwrE7oKCgpR9nu5uUPoc2nXclLtNTT6+m+se9
fGJsHMIIc2lp6U3b9GMI43Q6ncS/Gpm/dXodtDodTCYTbDabnDM3a3RaOSYp
k5BHnHvu3Llgm95Gzp8/j4MHD+LAgTLSAygrK5M9nvLycjn3K1/nnPq5/J+C
/3f5LzkVlgk=
                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 7->
                TagBox[GridBox[{
                   {"\<\"Date: 03/28/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1,
                     10}, {1, 11}, {1, 12}, {1, 15}, {1, 16}, {1, 17}, {1, 
                    18}, {1, 19}, {1, 20}, {1, 25}, {1, 34}, {2, 6}, {2, 8}, {
                    3, 8}, {3, 11}, {3, 12}, {3, 16}, {3, 34}, {4, 12}, {5, 
                    6}, {5, 8}, {5, 10}, {5, 11}, {5, 16}, {5, 34}, {6, 8}, {
                    6, 9}, {6, 10}, {6, 11}, {6, 12}, {8, 9}, {8, 10}, {8, 
                    11}, {8, 12}, {8, 13}, {8, 15}, {8, 16}, {8, 22}, {8, 
                    26}, {8, 34}, {9, 11}, {9, 16}, {9, 22}, {10, 16}, {10, 
                    34}, {11, 12}, {11, 19}, {11, 22}, {11, 34}, {12, 13}, {
                    12, 15}, {12, 16}, {12, 17}, {12, 19}, {12, 34}, {13, 
                    19}, {15, 16}, {15, 19}, {16, 18}, {22, 34}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc
mugXjcYZY0yccUVjVNDWFWdd4MIE9xZF776/m76n1lINKZ6jybmSh3PeeZ7r
udd1P/yQV5RW+EWHDh1Kvzb+pOVWRJeU5Fb9+JVxEFNV9lPel8aXQGP4GYOT
4oADDjjQRjQ2Nkp9fb1cu3ZNbty4IW/evLH3lNqMBw8eSP/+/cXX11dCQkJ0
XL9+3d7TajNu3bolCQkJyiMoKEg/L168aO9ptRkPHz5Ue/j4+CiPgIAAuXLl
ir2n1Wa8fPlSsrKGiLe3t3IIDg7RWPkckZeba/DwMnj4a3wQ7/bGzZs3Ze7c
ubJ8+XLZtm2bHD9+XG7fvq3+8/jxY3ny5Im8ePFC7dD8ulmam5tl+PACg4e7
+PpZJCY2yoiZBuv7yF0M7ue558+fy7Nnz/Q9jx49kvv37yvvc+fOyatXr9qN
x8GDB8Xd3V1cXV3Fy8tLIiIipGfPntKrVy8dCQnxkpySKJmD0uXnkcN0REaF
SnCIv4SGBRkjUMrHlkpVVZWUlZVJcXGxjB49WgoKCmTw4MEyYMAASUpKsr4v
NjZWevTooZ937txpNx4HDhwQi8Wicevh4aGfHHt6euqwWDzF1c1F3NxbhqfF
VUJCA5SHOby9PXQNzOd4T8uzfx/z3Tx2c3PT36EOtRew+aFDh2TFihUyffp0
KS0tNfxmuBQWFuqaZmcPkawhg2Rgxo/SJylOR2CQr9ohPCLYiHM/8Q/wkcDA
QI2V8PBwiYyMlOjoaImPj5c+ffrIwIEDJScnR/Ly8mTEiBFSVFQk48aNUz+z
JfD3pqYXRtw0aizk5eeIj6+nePt4yID0VKmprZGjR49qbJ06dUrOnDkjFy5c
0Di4e/euxtSniJLSYvEy4pwxctQwe0+nTUCP/Pb7Ef1ePrbEiIcWHsXFv+g5
bPGpo76+TgYZ+aqoeKQeV/1aIRYvN/HwdDX8vFLP4fPr1q2z5zTfC/JyTGwP
+fa7b9SfQHX1RHHq/L04O3eWiopyPUde8PPzk/Pnz9tzuq1i0aJFmh+7dOmi
OefEiRN6/urVq7J161bZtWuXnD17Vs9RP5ycnCQjI6Nd68L/AXmdmkZ97Nat
m34n77wP1Gdybffu3WXMmDFaz+2Jw4cPS0pKitYrNPmMGTOsfRJc1qxZI/v3
72/1WXQNz8B/5cqVtpy2FU1NTbJ27VrVDNTdsLAw5TJv3jzrPXPmzJGOHTuK
v7+/1onWQC3lOWKF+mprbN68WfUCepyaHBwcrFqDXsPE4sWLpVOnTtp3nD59
utX3PH36VHINPezs7CyJiYnS0NDQ6n0fC2iE/Px8nTvrzUAXDR061HoPGnjL
li3/WGdq9oYNG2Tfvn1aY8xzvXv3Vi7oRnSvLcGeAb8PB7QSueq/agK9E7qW
XooBZ3xyyZIleh2++BY6esGCBbakoSCXMi/sgu5uDfQS6L6uXbsqZ+aP/+GL
Li4uMnXqVL1v9uzZygMNuXPnTlvSUBAHxCpxsHv37n9dJ/bJx6bGRfuTJ4h9
1h5u5D36JLQzcUfMoR9tCXJ/SUmJzpU1fjs3kYOJY+ZKvUhNTdX5knPRuDt2
7NAaQr4GxAr7K5zr27ev3Lt3z6ZcqBX4Cn6SnZ2t/Slg3dPT0yUtLU3nTU5C
u+CP1PxVq1ZpXFVUVFjftXfvXu0zedfkyZNtygNcunRJ/YG1HD9+vLX3Jjaw
U11dndTU1Khfsc5RUVFaB+FhxraZq5YuXarn8bFly5bZnAv12+xN2YsAxAc8
1q9fL3/8pQs3bdqk+YGY4trJkyf1/OvXr3XgqxMmTFAuXEfH2BqzZs2y5h00
CfGQmZmpdqKHRRviN9RQ+KIvTQ7Yg0+wfft2a/+PP9p6v4i+NCsrS32CPY/L
ly9rzUM/4kvoKfyJfRHs9y7wRfZ7iCtsiz3gQtyZtdNWYO7USNab3zf3CIh1
4gM7sfcLqKeTJk1Su5j3oQGwRWhoqA7yNe+aMmWKzbUxtcTcu+H33wXrjg9V
V1erDsPvzPpDPiB2yNdmHGHH5ORkm/crzHP+/PnWPbvVq1frefyONTXzGXkA
bYWvMX/A/lK/fv2Uh6lBR40apT2ZPcB6l5eXW2P8yJGWvQfqCxzgxH4q/SK+
ZPoMfhcXF2fdh0Mz2Bv4PGuLX1DP36fN4bZw4UKtQ+ixmJgY5fip4NixY+oj
+FhlZaXU1tbKzJkzNTbIWdiH2ojt0L3UcnK1PerGh0DvBQ+z9r29l8v+Cb0L
1zlmX+hDPb69gM9MnDhR50odJJeSU6mXxDGcyE30We35P4KPAXQjfSSxS0+P
beACB+oNGvJzAXqR/5lQ57AFHPCrz/H/uHv27FF9hT9NmzbN5j15e4J9o40b
N9p7Gg444IADdsefMAqUuw==
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh
mBmlUPZYI3s6EksPYo1YkgiCLCLWIG0bWzHooChr8s35fe+d67z73o1Ep3v+
6a/qy73v3nO+833nfMvvnJtWY6OGjPdwc3ObbhF/hoyZ1XfatDHRQz3Fj37R
M8aNNYmbL+2Mh/QrOdCjR49o27ZtNGXKFIqMjKR27dpRSEgIeXt7M+Mez/AO
bdAWfar/34oLevLkCa1atYq6d+9O7u7uhOWtC6MP+kIGZP3S9ODBA5o2bRpZ
rVYn3Xx9fVm3kSNH0oQJE2jWrFnMuMczvEMbV/0mTZpE9+/f/9n1f//+PS1b
toz8/PwcdGjZsiXNmTOHTp48Se/evfukHLRBW/RBX1UWZGOM2sj5HKqoqKDw
8HCHMfv27UtHjhyh6upqqhY2fhaLvjk5OSxLld21a1e6fPlyvemPcXbv3k0B
AQHaGO3bt+exnz59yu+rqqpYpzrLttsBhqzDhw6xbHVtdu3aVS92xMfHk8lk
0uJyxowZ9PbtW1q3fh3FrI7RbJV24F7Sixcv6OrVq1ReXu4Qx1J31fYdO3dQ
9Jxoev3mDY8h8wbGhg4/hWJjYx3mZt++ffz84cOH1LBRQ1oq/FhvhyTM49Ah
Q6hlixYUFhpGEf0jKCkpiT58+ODQB2sJOijWIiAokOMGtHfvXvL399fGHzx4
8GfZsGfPHm0dGjRoQCXFJdpcnz9/nvwDA2hD7AaXdmzcuNFlLgPPmzePXr9+
betn9ytQ3tE8UWe8ND/Cc8Se2WzW+s6cObNONsAPZE5CPiw8Xej0PigkmNZv
WO9kR2Fh4ce+flYb+4P9yMPTRJ6enrQzM1OzQ1JeXh6PtX//fv595swZaiHW
Up0D9MXYtSHkuy5dumjxgHXRE/JIUHCQkx3Iy6gV6Otj9XVi2IN3Q4cOpZcv
XzrYkZuXS75Wmx2bNm0ii8Wi6e/h4aHFC3SrTU5G7pb9Z8+e7bKNkR2I6wED
BtjWwt+XLFYba3b42ezo0KED/ReYxMGOHLYDcaCuAfBMdnY2RUdHa8+WLl1a
ow2opdInkP/eiNxRFzswx5hr9LcKP3Kww9dHW4/wruGcv1Q7dmbuJA+Th4MN
nTt3puvXr/N75EiZk6FjTXV/4sSJmgzUByMysgPXtWvXcn9vHwvPv+ZX4t5i
X48pUVNYL2lHUVERNWrUyMGGESNG8LyohBiS74FzXNHjx4/Jx8eH2/Tv39/Q
Bld2sC12nYC9UIshx8Jr4MfsY7eheVgYXbxwQeuTnJzsFAvLly/X8rGeoBvH
n9AVOuspJiZGkwW7ayKZr9atd14P0AWh5++//top57b5bRs6fPgwt8F6TPj2
Wyf8u3DhItsgVUKWC1Cfm5urtYfOeurWrRu/a9WqlVZvWZwyL1UfbPfll8tt
62G3wxUueSJwxuYtW2j8uHE0ZswYSkhMpDv37vI7rFmvXr0cbWzThtdF5l2e
H8iVtV9hiS2BnVXCfkbmtblz52pzbES3bt3i2piQkPBxzFriwpMnTlCzZs0c
bBg1ahTl5+dz/KL2fYqAk+X6qfG+detWTebx48e158hXWVlZXEMwT+CDBw+y
TwcGBtLkyZN5XOAV+R6M38iV+Ufz6fTp08zHjh2jqKi/O9Rn4IVx48exzJVi
L4V8sGDBAvY94BIpD+OrsQAdpYyMjAztOfaZMnbgt5L+8a9/Gu7lzAJDuH3G
HtCI3T3cbTLx2935PeqSrAPQUeYk6C4Je2aJ+SUBz506dYqOHj1KBScL6ITw
h4KCAiopKaHt27eTv8Dxs0SdRO4qKyvj2L927RpdFXxFYNyrdsY66PctnTp1
Yj/C+7Lz5+jSpUsUnxBPFqEb9rilZ0t5TIxXUHCC8oUMxPerV680n5c5EfZJ
QozJnK35ew3xcfv2bQppEML4FXZkHzhAhwRehX/AJ1B7cI1ZFcP1WLUBeTNr
fxa3Rxv439nSUq4hVpGba6pb2l5HXLFHlvlBksTHqINGfauQK+zPZP1ITEqk
YcOGcbwBw4Hh82YvL64Det9AvfY0i3YiRsAm0d7dzZ369OnDc++j4ERVZ5VZ
F8HYy0MmdJf0KTwl5co1uivyJ/JVakoqRUREcF8vobuXtzeZvMzC13U2CDtN
3mYyixrvCbZ4k1nUSA8vW8z36PkV41v/AH9tPdTxXOmi4q262CH7Y/85f/58
nnv4TaRiB/ZBHvY9i1qfvYTO3iIXScZvjmV7PH/Vsyf7P2SMHTuW/VaOZ0TS
DvSRVJNfqfJwHT16tA0/iTlt3LgxZaSn8/49KipK23dpeVX4kKo/2yDWA+vy
N5FvM7ZtpS3//p7rZfiX4exr6Ne7d2+qrKyscU6lX8EvJLmKc1dU+aySOnbs
yDlSYtcr5VdozZo1vD6qDZ4ih+ptAMMG+NN3Yo8hCXmO58bXwn7pJ/DYxYsX
a9TFVZy7yruu6MfKH6nT7zrZao3VdpY2aNAg59oi8IUrG6QdJmFjnIIFLoq8
a7PDhzyFn6DGXrBjSSNylXeN6qBK8Cy8GzhwoG2+hc/ocxLi3E2slZENRnY8
ePiQwgQONnna/BLnwIhDIzKqg0a4xMEOe4wAW+nPzCRG+iK0Gccu4liy2R4P
kmGDu5gDaYeM5K0iRkxiXpCDgWPUMfWk4pJ0EZ+ScI6jx4kf16Faw7yQu2LF
Cs77Ug7O0oG3rlVUUKMmjW05Svg4GPpaRBwFBAdTUFAQ15wA4TO+Viutj411
GKeouIjzTW5OLv9Wx9QzdHSFE0F63K4nYAIZW5KDhX6owyDg9DQxN2npm2hT
RjpzmuD0zZspY8tmzkm4glPTvqNTp085yC8uKeb6Ie0wIuAliduhs570+yi0
B45KTEikZWJ/Bv91yKkixw4fPpzSBd5MSU2ltLQ0+l7kUOANYKr8Y/mMzXIE
Hgb2yBLY5YDg7IPZfN2+Yzv78xbB8I3Zc6L5nGH69OmMYVNSUihVyMUVnCj2
L9jnqvuolStXOtnhal+7evVqp5rAMS78ykvUD8Ql9j7A4vAvrE/Tpk2pSZMm
fA1tFkrNmzen0FDbFfUGeAvtcF6Mvqhj6GsWfgiZ+A095HMwxsReDL4m8YPR
vhaEvbvUFfhgyZIlDjkJMhcvXszzGyR0mTtvHmMt7LeBK+BjwL6lAvedPXuW
ys6Vcf4sFffyCrxcKOIYDJyLOoErzqwQN3FxcYyd8QyywefOneMzyNqcM4DU
cx/kcHUNMJ/QD3Tjxg0KFvtzrLWk/9y5Q3/+61/oD3/8hiL+NID6Sx4QSRF2
jhS/I0W+7/fNN5SxOcNhbMwBxpb7dz3V5dwHpJ7DSe7Xr5/tW549/l2dl9y4
eZN+Y89XbjiHUthdMNZVXduk5CTuJ2Uil+JMWJ6Fq9gW9zjblX0/dQ4Hwpmj
3Pcgr+F8T55D1mTHdbFGoc3DtDrog3M4sZ/APc5/rAKT4/xWxkRySnKNdqiY
PTMzU6sL0A361IQhJeHbk/xuw+fUhY7n1LADsbphwwZnO0w2fKvaAf18P2XH
ieO8j1LXA4Sx5fdE1BdgsbqQ/ruBjI2P6xGsfTcA3bgp7GjxcT0s9vNDa2AA
71dVO8xshwu/0tmB3NGwYUMtz7s6M68Nqd9xMBdyDOQYi8AYcfFxWtuKH36g
Jl80dYotI167bq3DWMhFyOdSV4ylfseJ1dX/upL+uxq+Czx79ozrL2JfEvIi
ci3yKXKPIRcWMX4CFlLp+fPnVFxsk4kx6vO7miR8I1K/c+LcH3W1vgkyIVuO
g/yaaf/mU19k9N0Z9bI2ucOIjL4743tNfX53Vgm1aNGiRRp+kdy6dWs+q8QZ
l9H+RS8HbYFb0VeVBdkLFy6slZyfSvfu3aOpU6ca/l9Gjx49GBtjD42zCzDu
8QzvjP4vA+cDd+/e/dn11xNwGs7/gJ8/9/9k0BcyjDDfL03IP8Dh2GcCk7Zt
25ZrJbAwGPd4hndog7b6nPUrEf0PgDEpiA==
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC
1qMIhA7HYFVAsOqMnUq4tKKCpYBQBAkzBAhYDZeQYMaAkBDydXeTlxIT4AXi
PJ26M8v//Y/3z36/3f129/cwjJ1078Rf3XbbbVPC6Z97xzyVW1Q0ZvrQEDrJ
m148YWwX+pDWrHwRv8gv8hOW+vp6rHjtdTz04EN4YORIzJw+A8eOHQu2WR2S
y5cv47k5c2HU6aFKUsKo1UGtTMagu+7GkcOHg21ewLL9n9vgstlhIhxOiw0u
qw0OixXKnvF46fkXgm1ewDL/pXkwEwaHyQK31Y40txd2oxkmtRZjRz2ICxcu
BNvEgGT5kqVwGC3w2p2CI4WODsJh0Rnw2PiJuEy583OQisNHkOFJgVmrFxyM
h/2hV6rw5wUlwTavQ7JhbSkyPT4YlGqYKZ74+MSEh3Hy+Ilgm9Zh4Xx/7tnZ
eHraDKxesRLnqqqDbVKH5OzZKmxYvx7vvP0Odn22Cw3Ewz8nqfm2BksWL8Gd
BXfC7XTBznxL/PvIxIfxny+/DLZ5AcnWT7Zg+H33Q5WYBLPBKPXCYjTBbrZA
TbVwDNX177//PthmXlMqv/4ac2bPQarHCxPVbQfZ7SQ/uKj+eZinms+thOmT
zR8F29w2cuXKFfzt3XdRkD8AWo0WFvKB3WCC02yFmzDY6LOnmXNZdcS5o4aP
xKWLl4JteitZuGABjHoDTGS/jnHojbCSpjhc0oewP7hmWOgZxsaYUp1ulP79
vWCb3iJHjhxBZnoGDNR72CgPCvLzcf89v0Om1wcn9SJss8dih8tklXO7wQwX
YdEnJePxiY/8ZOr57GefhTpZBYvJjAdGjMSeXbuxinr0vr50WDV6+KwOUQ/h
8JrtcOgpxsw2OaY53Pj04y3XfX91dTXmzJ2LHTt2/mgYuO/O7tNX4qlXRiZK
31sr119f/hc4dZQjGgO8JhupFT7ySQrhcOnNcOgIg80Fs1KLyY8+fs3319TU
IOeOHHTp0gWDBg/60XAsWlhCeWEUHBPGjce56nO4XFePqZOLYExUIYUwuMnu
FJMdPrNDMNR+V4uSlxciw+6BTa1Hb28q/k0+bE/++tZbgoFVrVHjxInO72NO
njyJ3NtzoFNr0CejFz7Y+H7T9crjGD1yFGzUF6bbXXAamtbeS7FkTFKjsbFR
nntz5RuNTvYN5X//7H6YNWsWtm7dijNnzrT8jaqqKixaVILobjGCZe3atdLn
X7x4sdNwLJw3H1ayUZesxuTHCnGh5ju5vnf3HtyVXyC86yGecjeri3Bwnvtx
sGzb+mmDl3KnKf9NcLvdyMnJQVFREZYtWybKsun9TbBarRh631BMKS7GsGHD
8NVXX90yhmpap1/n5kOToER2r97Y9slWoOGK3Ptg3QakujwyNzHf+pXP7ZQz
P5S6urrzbpNtp5N4TK1WIykpCYmJiYiNjUVhYWHLcxs2bkB8fDy69eguvkmk
50pKSnDp0s3XoK9pLUYNG4EM4tZJ7Iva81QMaZ1prd9etUZmJK4TV+PgesL8
dYWLZltpbGhoqKOYqlq1alX98OHDkZ6RAfosN7ds2QKz2YwQRShCwxQI6xqO
LiEhgicrqy/27Nlz01h4D6SyshInjh9vuXaJ4vbpqdNoDre2j4Py+mBZ2akb
vJpx1hGubwUgrU2//v3FZkW4gjRMNDI6CjHdu8n17OzsVnl1q1J99ix+T/2G
8wcx5a/nfh6+0tDQnk/8wgnUQCqNZPmhckTHxEARFoYeFFPdu3dHD1KVKpli
i+KvZxx0ej1efe3VTsNxtPyw5DjHFeeDx+YQDNxTSb4QP/mohmxct77qBq9q
bFa8sXq1rHkMYeF6mkYcmErv430KjrMecbHiG5fLhUOHDnUKjsMHy5FFHMxr
z3Z7bfT3NDo5l9mcfME4nFQHG67vE5GTVC/S09IR2TUCsd26S0+QQvWUaypz
Rkx0NMLJT/4as2nTpk7B8dE/PoSPeg1Wtp2Pk6heZ2f2lvxIszrFBofWiPw+
/equ+mpje+/749znoCNOTLO7xRdeI/WYBqusBb+HfWMg3mcMoeSbPZ9/3ik4
li9eKj06Y+A87+VLQwX1Lju2/Qt90zNhUGkk1ljZXy/OnltzPSyznn4GhsTk
Zh844CZuNiVrZD08RgtSCZtJpW3yB/HXihUrOgXHTOIqjiPGwjkxMG8Ajh+v
lHsff7hZcBlUaunn+T7jmjh2fH39pbo2w2HF0aPwUMy7KQY95IcM8gnbHK4I
Q6pgoms2t3C5P66G3DPkljE0Uv2YMHos4dBKLuiVahQ+/AjnQcszH2zchN6p
6RJjvJ/FPb2Jji8+/0KbujJ6zGixzao1wJCkknxIjO0pOGzEI2bicDthTI5L
aMGRlZXV6u/djJz55hsMHFAgM5TP5YZWmYyZ06a3eY64Svxhp76dY0VL8T9h
3Lg2z2X3yxbbmJP8dvqVeTgqIgoKhQIhFE8hzTUxmbj4VvuVfXv3Ic2XKrOU
g3ohM81+S5csaffZlTSfcMw7qZ6YlRoUPvpom2dy8/KacShaYWCbuW+J7hqJ
mMhIwvI/nEajEd/Qet6KvLL8FZmnnHYHbGaLzOgfEn+1Jwf2lyHT5UWKwQKb
SocnHms7g+Tk5optXPeiIiIQTTaHESb2QVQk1XLSOOJi5l1FaKjg02i10off
rHyxbx+y+2bJjM44eI9n0MC7rvnOL8h3KVRbMqwuWMgfkwqfaPPMHXm5YpuP
uIn5NZ1iUUezcERkhNSNmMhoKHsmICEuDqqEJCjjExFKeHbtbn+WuZFwXgwZ
/FuZpXivTUvzSCbVro83b77mdw5T3e3l8cGlJY6mfC2aNLnNM/kFA8QfV9c+
5qsE6nmT4hMo5+Opputg1enhJj4zqpv4d/HixR3GwBQzg3KZ90h4r5Bzw+v2
YH3puut+71jFUeRk9hFfOChHniya0uo+96BpGekSQ8yxzLvpNIvxXMwzjY/8
k8LcS9ddpDynMa8xjnHtcMaN5M01a2SfxE7vNlMsOQnLyhUrb/g97vv7Z/SG
S2OEhWbE4j8Utbp/6tQpifXw8HCpD7w/z3byPOmm+pcisz7NZcR57CMX1V01
xRbjyM3P6xAG5ifeW7DyHqHDIT5ZOH9BQN89QbPv7eQPF/UnZrJt6pTiVvf3
79+PqJjopnnjKj6KCAtHmsUpvQn7x0wc4eddPz9zXgUqZ8+ewcjhIySvOZ4Y
Q3FRMerrAtuLOn3yFHL7ZMOhNgiO6VOfanV/52efSZ+hoJmJ1V8fGIeFcsJC
OcXzPve8EeFdic8iEUl8Jv4IEAfHLv9urNfqZB+dsYx5aLTs0QS8DjTzDOh3
O+y0npwjz8yY0er+9u3bm+YmwRHWqtbJdcqbZKVS9sGYy1j9eR6oP7iX7peV
LbykoV6J995Onz4dMAYWnu8LCIdNqaX8YBwzW93fu3evzHyhiqb5ryV2rsLC
9YPnAH8PydzF1+/+zd0B2cB7LtMoDtzUw42g2KqoqOgQBhb+zWDo4CFQdouF
OjYBL/9pXqv7lTQr836DxNYPcAiWkC6IoplEuKy5X7Q18xXvtQQqjIVnr9ra
2g5j8MvOHTtl725q8ZPye8PVwrE7oKCgpR9nu5uUPoc2nXclLtNTT6+m+se9
fGJsHMIIc2lp6U3b9GMI43Q6ncS/Gpm/dXodtDodTCYTbDabnDM3a3RaOSYp
k5BHnHvu3Llgm95Gzp8/j4MHD+LAgTLSAygrK5M9nvLycjn3K1/nnPq5/J+C
/3f5LzkVlgk=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$20", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$25", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$2", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$22", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$22", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$22", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$13", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$13", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$22", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa
WuNbVWLIgISig/F1qbmTTqs6D6qj1rzf/+179vHf6ya5SSvRt95eayf3TP/5
z3f28O39nzqpD/bL9PHy8vq7Rf3plzKl88SJKVP7+6mNO6dOykj1VT/ilfZS
ip1Xr16l8uiVK1fKdd1fSUU8Pf/y5cuMiy7YJ/sr+3luBoxEvv/+e/rkk0/o
t99+c+B06RL/LyoqorfffrtMY97sWhaMIO+//z6lpqZSdHQ0RUZGUtOmTWnu
3Ll0/vx5Pj516lSaMmVKmbG/mdWTZxHf+vjjj6lRo0akwhf5+/tTYGAg+fj4
8DZwgxw+fJiys7OdfLCyn7Gi7AgCHICH3W5ntVqtZLPZGCvsLygooG+//Zb6
9u1LkydPpp9//pnx/avHqdIwEhs6c+YMRUVFMR6Cja7AaNy4cZScnMy/oatW
reJr9Rhf2c97IzE6ffo0RUREMEa6HVWpUoXxQHwaM2YMWSwWCggIYB/csmWL
iRG0OL+7EVIZGJ07d47jM/CA3QhG2K5fvz5NmDCBateuzXEK+/r06cPX4PqL
Fy/SJZX3PMUDWP7+++/066+/sr+ePXvWSX/88Uf65ZdfeHzkVZzvKW6YD+ZS
Fv8vDSNdnn32WX5+2Iqfnx//7969O8do+CH24XiDBg0Ys3379pljQ7766iva
u3cv5ebm0rJly2j27Nk0adIkGjVqFA0ePJjuu+8+6tmzJ3Xs2JFat25NcXFx
nCPwDmCnothu3LgxtWjRgtq2bUudOnWiu+66i/r378/jjFbjTZs2jfPtypUr
mY8cPXqUsYX8GRjJ9ZDz6n3u37+ftm3bRu+88w7jERYWxnODb91zzz0UFBRk
5jj4436FDeYHHgDBu8bvmjVrsh96e3ubMcud4rh+jmyL4j5yvLSx5BzY/R13
3MHvR2zVU590hxF8A/Lmm29SQkIC2wtwwXs6efIkv/+7776batSowfPFcYlJ
r732Gl/7n4MHqVevXvwb7xLH9WcrSX19fc24B/xDQ0P5/tWqVaOQkBCqWrUq
BQcHs6/Ddj0ZUzhKeHg4ffjhhx7jUxxGkA8++IDfO3jiyJEjacSIEWzPMTEx
HI/wHLAJ/IcOHDjQvDcEsaRLly7MuXEd5odna968OWM3aNAgzoMzZsygefPm
0YoVK2j9+vXMH1555RW23YMK5+PHjzNvBTcDr8c9Tp06xTwMx1999VXavn07
bd68mV588UVasmQJPfnkk8xjMzMzmYd07tyZYmNjTY7y9NNP/yGMRFJSUni8
9LR0atiwIeOhq/DIxMREM3/pcRGCWJOWlsbYIL4cOXLE5OOeCuIy/BRxZtiw
YYztaoNTeCqYE2IRMITttWnTxpxjeTH6/PPP2Y+ARZaKOeHKxr2Urfr4+VLV
0BBqEteUMkeP4lh44cIFJ2z0/IXjkvs2btxonleWuX355ZfUsmVLql69Ots1
fGXs2LF8zFN+qgtwxnzeeOMNp3mXFaNNmzbxOPD1lq1a0ZjscdSnf18aMmI4
Jaen0cDBD9Dr+/aa1wInd/n366+/5jgCzoBcfcWD+egKvDEurv3hhx/MvI/7
CT5lzU979uzhZ0PeFZzLY0cTJ040aw7/wAC6rXYUxbVoTlHRdclWJYi8VIwM
iwinZS88z/MXQR2CmLJmzRre3rVrF4+zYMEC3oafST7w5JkEA1cRPlpWjITD
gq/AT4C5Jzjp9xXp0KED5wr4SZDi0QFWC3n7+lCAzcr+5uXjzdhZ1H74QVJS
EsdGxC3JI/Pnz2efwG/kQYjYRVmfqTjsyloHiq3v3LmT57VhwwYnjEoTwQh9
IeRw+Bnyl9WualZDfQL8qd/AAdSlZw9KyUjnGnfo0KGc06Dp6emML+4P3MD1
kA/vvfde034qs77VuSNyHfiLyGeffUYbcnIYNyj8ATHno48+ug4j5Fnke8Rr
V4xgPy/v3kWHjx2lv9WsQVZ1HPwFCr6C2AOOCd9CLgJPQEwCd0YO99THbpRK
rwayY8cOzrfgFJAePXpcx1ex3b59e66LZO4QPAuuBZfQMYK/WdT/k4rvbM7L
I2/lc+CO8EdRjAvuc+LECWoW34weffRRHhM+98QTT1Q6Rg4/vZZbYPOoFYBX
hMrdpl0YfQ34EnjrF1984YQRnk/HiK9RiuurKftCLs7Pz3fir7r6Gny2bkw9
+u7MdzzmoSOHaf3GDaX6e0VLnnoOX38/jrVe3l7sJ97Gc4gdIbajLwQRXwOH
Rc0lmIqCL6JuRV2KPIw4Ay6GWgUKm0RtiZwRUS2C6tSLpuyJEygzazSNGz+e
xj6YTSPHZNHIrCzH/4rWrGs6StlOluIz4DFWladjG91OXXt0p4SOiQ41ngc1
KepOEbEj2AmwACauGNWqVYtjm4iegyHgLUuXLGWu5+0HzunneD94Jx7UVBWq
qI2VDfmqPNSuQwLt3vM6P8NFbY3HlXcIRqjRG6v6GL4ovTSb4WuI5bAzPt/I
DxIDEet79+7Nduqn8LQHVyFLkJ35QqAW97FP365otRr3x3/5DV/DvB6e9g86
Z8RnqRdEdV+D9OvXz+SQZkxScQwxCrWmbkMQ1Jf16tXja3Ce3cDGzxJIvopH
MU4GVrDtysDGfDdqHpiPv8pBnIvUb2CFeWL+A1Q9iHpc52fuBDUq7EGPSXh2
1Pe7d+92sruzik+hFyb48Pl4Nyr+4d41FUe3GLwhwJhXZWEEPOD7IeFhVKPW
beSn/MxX2bzFsCn8x3OMV/FT7KAkbjlnzhzu2yC/C0aI9ahTdbub/fjjjv6t
HdjYWX2U7Q5VMT13SwHlKB6WW1BAAx4YRF5qf2BJvqeOWeyGD1itjK2uVuN/
oJqPxaZtG/ZQEkawafj/jJkzKX/bVtqUn0tr16+juObxPC+5HvaFHv2hQ4ec
bEF+u/of+hrSv4YyRoWF165R2rO3ozcUIDxTvafkjDTaur2ImiiOFKZyXMs2
rWmH4p6Dhw9je9LnLnMDVjalds1undaogBEwNDgZ/Fn2B2q+rGMVYPgVxkaN
sGz5C7TgX4soqm4dCousxrX5voMHKPZ2VUMpvodzbcGONYyFCxeWiJHYiI4R
5gP/e1nxLZELKq61ateOx5d3FRwaQluKClU+ddRuglucwqtA4Yt45C6O4/0h
1kudKL1N6bPCz6VnJcd8cK663hf5EzWkur9ulxL7ML/2KqfnbS3gehO5DPfD
GKPHjaWn5s8z58rnq9+PPPJIsRhJTIegr6VjhPgkMZvPU1ji3oIR4l5MwwaU
o+od9heb1fSF0PBw5pHR9WP4PNfnwL5U9U6WLl3KvKROnTr0zDPP0EMPPcS1
Dnp+ixcv5l4d8gPWH3DMX80pLTODFi5+jtq0b8f839VGvXy8aFjyCPqn4vq8
ZiH5TJ2bkJhIK1avYtwC7FaOmThHaoTS7Ah1lmCEd4f3iR63yEXF68EtxH9g
RyER4VT08g62Z44/xnuJiY1l/wuqeouZU3TFGAVGPxM91latWvFvcApgJL1O
2Da4qxwLVGMVGbadMTLTyR7ERjGPLooj5mw2+mIKD4sxrxRVhwNf2Lp5vto/
a9asEjGSbXBNwYhrEVW7YF7X7OgytUWdr8YXvxf7xXyAE3CrHV2X8rduoYzR
o657BhMjNUZeQT6Pi34C+t4Q8DHcP0/ViBCsA8OWIFinCVB8pKBwG2+jF6GP
L3PCO0E8QoyePmsm3RIWyjYObr3nwH6Ka9mC7y/25SlG6J01adLE7JHgP+z/
m2++cfK1trAjvAMjf2JesOHsCeNp647ttDEvl7bv2kmjx44x46InGMXHx5cZ
o1QXjCxGPpd8FaHi9CLlr4XK7jbl59Fmdb+OXe5kG7ZpnNdTjFBz3HrrrSZH
QuwEZnrP/tLVKw5fU8+n+w/7tNoXqnIa4lNoZAT3w91xbJ23oMYUf8L6IuS9
995jHxeMEJd0jBCPCg0+kpaepvEQgzPo3FHNCzVsjahaFB1bn98peIpVm5f4
4EzFEUrDCPwAMUhyLa5DfNIFtU1Cp46mr7njJLBx/C+Otwgfx/iCEewI/U3I
u+++y+9I1g5xTGLVW2+9xXmu0OAjaanOXMXq7n5GfjD5v+s7MzB67LHHeMzi
vueArF27lvOt9IZwnaxHiCD3x8OX/3B96fi/UfFNCPIp1qohWJ/T+6pYO8Ia
gmCEY1iTg8iax5+h06dPL9WOsF6uvxP8XrRokRNGiNng0kteeJ7z54o1q8us
K/+9hhVjnP70Ux4X3wlIHsM6CL7RkX7DgQMHTEwQM1evXs1rXRB8S7B8+XLe
B11VjvksV8+BMbAWWBxGIujhS10r645Sh8h5S59fRn3vv5+5B9aVhql4Wm5N
SaaBSUlcTw8ZMoRtAr8HDBjAvaokl2NYV8cxxHD9GLZFR5RjHsOhw4fzmFKP
uMMIfX+s/UpOAz7ou31qvGc5b85Tc5x85X9J0eNAT7Y4jLBOJzW81Pvo/Qr/
lvOOHj9OduMbLX/Ed+Rau93MuXruNXNMkI3Vse1Q2ba6fBv3R5VjdpDkT5tZ
33N8Drp+npxjDZ6N73vkec3Yoq1Boz+J8wQn/JbvQF19Et8RxTVrxt9zWARX
l1wh9YbU71Krmj08l+0/U/WxsR5oNfrzFpfcCuxQ7wWHVKVu3brRsWPH3MYj
EfSk9ToN3Ehfr3etWSD4NgLnyTt0nQOU6zSjXq1olTUMxA0r1ni0vG9yNMUl
O3ft6lRr6M8oPcVTirPpfSP4GbgkvmtxxUjWXUvDiHmuekewJ5uqvW6UzZSk
qPnQF5LvyWwufFZ4bCfFu12/33LFCGvQ4mfCi/ANnmvc0nvZEFn/docRxkga
MpiOnDhO+w8e4O+GKkORp8AbsJbm78Jr8f4wzzu7d3MboyFiU3rOF4zAF1zx
ce1hIsaVhNHkh6fQzSBYN46sHumEkcXo48COuvXsYZ5bHEbo5XL/wPj+E36m
r1MWhxN6Pqb9GX1BiUPYj/Usvk8x49z49VnH84G/YM0d/RGZn7+xBgCMEjt3
KhYj8RvggW/zEI+wRvnSSy+ZGLr7jkME30MAC3Ot3MdQg28sWvyc4z6V+E0E
5KeffuI6h+flc22e6FVgX0ZmZrEYyT4I1tjQk8D3RCWJfj3We5H7UOdB161b
x/ji+zqsp18w+gXuvieqKJF7o07GHDE/6Dql2M7JyTHXrf8v5ZP/AozBoMg=

                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag["Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], Selectable -> False], BaseStyle -> 
                    "ImageGraphics", ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY
gQQBDKaJCEhIKGpxYyhbBSoxKoYQCKmIUaYg1BYghsQetjH49Hzn3XN7/WSD
C4+HK/VIx3e+6/P9Z58/PiMnZbKfj4/PdAf/SRk/8+P8/PGzUgP44lezvpqU
4c8nPZg/ZMbNmpoaagwMqq6upqqqKjnHPVw/f/5czl+8ePHOZWwoQ1YQjhUV
FSYmEM7/F7CAnj17Rps2baLk5GTq1KkT9ejRgzIzM+n06dMmnnctZ10MmwGD
KisradLkycSmLuzr70d+/v5yHtMkhjZv2dJosQADfAA0f/58kTkgyEF2Z7Bw
UGiIsI+fL0VGR9Hx48dNu2tMNqb+cOPGDWrTpo3oQDHYgoPk6G+3UXBYqGCc
Nm2aaX+NEcf+/fvJx9eXHIbs9hCn4LCxbhx8jns+fn70M/YXjWEaxxoDK449
e/bIettZdoeBwWHoRBm21bFjR/EjUGPCoT5+4cIFiomJIRvbEOR3GLalmAIc
dsE5YsQI088bm10plnHjxoms4tssvzM8TDDg2j8wQJ5tMWIWfgsfedfyg93p
0uXL1PmDriKvH8sNfQSyf/j4uuJwZm62+IbGqje1K9Xn63wHcug6gq5du0ZH
jhyhY8eOybNr16/T2HFjKbZFLNntdgoJDaXEzp1o5XffSX7XmOsJu9L10Fqo
Lox1shEvQQ8ePKA5c+ZQdHS0mfcGDRpEN2/elOdlZWV06NAhwXf//n2P5z5r
/nkZaW6ry5YeP35Mw4YNE9m7d+9Oo0aNop49e8r1hAkT6v2ep+OTylheXk5n
z56VWKOM67t379arG9CiRYtE5jFjxtCUKVOob58+lJeXRwMGDKAmTZrId3UN
1A5fN1+oH+E77muvMR8yREVFUVxcnHCLFi2oefPmtHXr1lrvKoOAEe8mJSVR
RkaGy6c5v4WHh9OsWbPIZrPRiRMn5F2r3Fa/aChrHLTKbL3W51i3U6dOiQ7A
586do5MnT4qs7r9RWTZu3Cg4Zs6cSYGBgeRwOMSfY2Njafr06RQZGSl6fR25
3fnJkyfihw8fPhSGPSs/Yn746BE9Yn769Kn4uepc9afvyjeYNRaAkCPgG337
9hU9BAcHS/4rKCigrl27UufOneV/1udbSq/CANqxY4fYSOvWraV2a9u2rRzB
CQkJch+M+9Zn+q6+g3Xv37+/qR/gSkxMlFoP6+/g3BAQEECjvviCBg4cKDY2
cuTIWnp3x4CaRGOe4qnPD2EvGzZskNy5efNmsXfl7du307Zt2+Qcz3GOo5X1
GfqhnTt3it5AsPsItptpWb+nMORqxuEb4E9Lly+jrLxc+s2YNPqh9AdTPuQL
teG9e/fS8OHDqUOHDtS7d29avny5qbf6al+NR54i7U137tpJSZ8n09dFS6UO
Bw7U5LPnFVJi1y6UkNiBOrK+xqen05kzZ8zfY01DQkLMmOBv9FajR48WrC/z
c12Hffv2SYxHfO/Vq5esRZcuXaiwsFCevyoWYp3UDqCbT5M+o5lzZlPEe9Fk
49oP9d+kL6dSy/h4kQ32jJq2Xbt2Ejfgq7BFyB4UFCRxwel0SmzA++vXrzft
sK7/XWXUxvhWUVGR6LG4uFgY17CvhvRkGu8Qp8LCwly5bspkapXQlgJYF6id
PmUdfTJ4EMX+JI7mFs6lrKws8ZOJEydKPocupEbhIxg4gAnfQuxuyHq+LG83
JPaBoI8+nOukZ7UFiszJKcPl2p+vm8U2p8zsLPo8NYU+MfwdGKZOnSo6BH7I
DfkR3xSPNf9rnntbDEKcat++veQ42FLT95tRXsEMCuZ6HH2GD/eyKaNGUmZO
NqVxjod8iHlHjx6le/fuiZ0h1wADGLpRfZSUlDRYH2+KA4Q5jvQW3E+gJh/5
29HUu99Hch7I2CLZX+A3qGtbtmwp765du1Z+u27dOpHbl/texGn4usZo+I83
cCiW1atXu3yV+yOs/0f9f0nL/rBCfAR6gVzAVVFZQTnZ2XKNnAhdgnbv3k1D
hw4V3WCmtXDhQsnF3sKgOFCvoIZCrAUO+PrcBfPFx8VvoBOu4a9yP3Lx4kWp
23B/1apVpk7hA8ip2od4Q3Z3HFeuXJFew844YEtjM8ZTQscOlJ2fR/0+7k/R
TZvIvXtGr4GYBRyoC27dumXKraR5wVsYNO4eOHBA4g3mOtAHfLopx6mmzd+n
jEkTBQ/i2JAhQ+jOnTt09epVqZ2BJScnx5RZa/i3bU/WntNa58KeIVMg+0NE
dJTUIciFyOeY5yD+6ixBazLYFK5btWpl1iCQ3VN97atwuNf6t2/flvyMWIP8
8UH3D2nytC/JF7HKMgOVOSjHJT+OS+hxMWNcuXIllZaWvpV+8L+1qdzcXFlX
2JXkYLajHlznQAdWDDbmEOQUu0PeS01NNfWJOrfai3Meq85BqHmxxshd0Ed7
9u0ly4okPumc0IrFyXka+Rt1FLDk5+f/x7ervacPdxzoNSCPylXy5xJavHSp
nFsxqH0hLodwLexEPcy/wdx67feufPjci/ND91kKepHQ0FDJxVlcQ/FTM2fo
TB32hXweHhkhuR3zQ3OOyM/e437xH0bP7m3fAKlOsGeBPgh+WlZeRjFcXyFO
QQc6f0Z+37htC4VGhNfyG3nOmAdwTH5WzyzJm/ZFhoqKuRax6kLqFJl5unLE
im+/IT/uEQON/QI8xxH1fdGKYlPP3sRhnR3h/Pr169SG+w4fltNu7AuIb7At
7fn7PpEPa542bqzLp4x9D+D1M+r7yz9eNnXtzThs3TfT+GvGJ2Odf967F1VU
VZJmnSvl5dSa8SK/KBbZx+HfZnMN+S5wqF2h9pY8yH7hbvvf/+mP8k51DffA
Na73S/+yQeoXa56ET0VxjaZ7t297/8OdsNeE+hV1uzMspNb69v1FP3rEPUSN
4OD6CeuMc76TPHxYLftyGL6kOvFkD2jVr8wUMIPHnMJY17/+bRc143oPvota
18mx1Ik9Js6LOB48eND0W1eOeC4Mwp6hAznUYZf8iHyKvhCzCOw3eNrfrTVV
5bMqwVDFNcTS4uXSI6FOtxn2ERQcbPakSxYvroVBcOg82vgeahO8qz0tGNdr
1qzxOA7U0joXB53452n6ddJnkhes+5aCw6ix0tPTa9WT7muiz3bt2iV9vfu8
Z/DgwR6Pwfp/MW/7esliijB6uQAjN1v3K7X+w/xXfVVlscZqvY/3unXrJr5l
nTOgJ8Ns3NM4JMZwfS11kyXGyF4rxxnpM/hZyohUmYGoDb0s5ijNmzfPNaNg
ewS/Dduy7iOkpaW54gtyG8uP2Sf0gDoDe/y5M76ip5UV+Me19lZexqDDhw+L
XensSnFgvuVJ21K/wJ6G7uUHMQbkYFzHxf+UStaXuuyojnV4FQ7YFuYkqDWB
QWvn2bNne9SuNF9jztEWdYexb4l9gd+NT6cfy/7livdGTG1oLgbpGsGGEHP1
2/Hx8XT+/HmPxyy1rcuXLtGCBQtoRkGB1Lgqz5t8V7+B2IXaBt+vC8P/qXHR
vwEsx0/M
                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC
1qMIhA7HYFVAsOqMnUq4tKKCpYBQBAkzBAhYDZeQYMaAkBDydXeTlxIT4AXi
PJ26M8v//Y/3z36/3f129/cwjJ1078Rf3XbbbVPC6Z97xzyVW1Q0ZvrQEDrJ
m148YWwX+pDWrHwRv8gv8hOW+vp6rHjtdTz04EN4YORIzJw+A8eOHQu2WR2S
y5cv47k5c2HU6aFKUsKo1UGtTMagu+7GkcOHg21ewLL9n9vgstlhIhxOiw0u
qw0OixXKnvF46fkXgm1ewDL/pXkwEwaHyQK31Y40txd2oxkmtRZjRz2ICxcu
BNvEgGT5kqVwGC3w2p2CI4WODsJh0Rnw2PiJuEy583OQisNHkOFJgVmrFxyM
h/2hV6rw5wUlwTavQ7JhbSkyPT4YlGqYKZ74+MSEh3Hy+Ilgm9Zh4Xx/7tnZ
eHraDKxesRLnqqqDbVKH5OzZKmxYvx7vvP0Odn22Cw3Ewz8nqfm2BksWL8Gd
BXfC7XTBznxL/PvIxIfxny+/DLZ5AcnWT7Zg+H33Q5WYBLPBKPXCYjTBbrZA
TbVwDNX177//PthmXlMqv/4ac2bPQarHCxPVbQfZ7SQ/uKj+eZinms+thOmT
zR8F29w2cuXKFfzt3XdRkD8AWo0WFvKB3WCC02yFmzDY6LOnmXNZdcS5o4aP
xKWLl4JteitZuGABjHoDTGS/jnHojbCSpjhc0oewP7hmWOgZxsaYUp1ulP79
vWCb3iJHjhxBZnoGDNR72CgPCvLzcf89v0Om1wcn9SJss8dih8tklXO7wQwX
YdEnJePxiY/8ZOr57GefhTpZBYvJjAdGjMSeXbuxinr0vr50WDV6+KwOUQ/h
8JrtcOgpxsw2OaY53Pj04y3XfX91dTXmzJ2LHTt2/mgYuO/O7tNX4qlXRiZK
31sr119f/hc4dZQjGgO8JhupFT7ySQrhcOnNcOgIg80Fs1KLyY8+fs3319TU
IOeOHHTp0gWDBg/60XAsWlhCeWEUHBPGjce56nO4XFePqZOLYExUIYUwuMnu
FJMdPrNDMNR+V4uSlxciw+6BTa1Hb28q/k0+bE/++tZbgoFVrVHjxInO72NO
njyJ3NtzoFNr0CejFz7Y+H7T9crjGD1yFGzUF6bbXXAamtbeS7FkTFKjsbFR
nntz5RuNTvYN5X//7H6YNWsWtm7dijNnzrT8jaqqKixaVILobjGCZe3atdLn
X7x4sdNwLJw3H1ayUZesxuTHCnGh5ju5vnf3HtyVXyC86yGecjeri3Bwnvtx
sGzb+mmDl3KnKf9NcLvdyMnJQVFREZYtWybKsun9TbBarRh631BMKS7GsGHD
8NVXX90yhmpap1/n5kOToER2r97Y9slWoOGK3Ptg3QakujwyNzHf+pXP7ZQz
P5S6urrzbpNtp5N4TK1WIykpCYmJiYiNjUVhYWHLcxs2bkB8fDy69eguvkmk
50pKSnDp0s3XoK9pLUYNG4EM4tZJ7Iva81QMaZ1prd9etUZmJK4TV+PgesL8
dYWLZltpbGhoqKOYqlq1alX98OHDkZ6RAfosN7ds2QKz2YwQRShCwxQI6xqO
LiEhgicrqy/27Nlz01h4D6SyshInjh9vuXaJ4vbpqdNoDre2j4Py+mBZ2akb
vJpx1hGubwUgrU2//v3FZkW4gjRMNDI6CjHdu8n17OzsVnl1q1J99ix+T/2G
8wcx5a/nfh6+0tDQnk/8wgnUQCqNZPmhckTHxEARFoYeFFPdu3dHD1KVKpli
i+KvZxx0ej1efe3VTsNxtPyw5DjHFeeDx+YQDNxTSb4QP/mohmxct77qBq9q
bFa8sXq1rHkMYeF6mkYcmErv430KjrMecbHiG5fLhUOHDnUKjsMHy5FFHMxr
z3Z7bfT3NDo5l9mcfME4nFQHG67vE5GTVC/S09IR2TUCsd26S0+QQvWUaypz
Rkx0NMLJT/4as2nTpk7B8dE/PoSPeg1Wtp2Pk6heZ2f2lvxIszrFBofWiPw+
/equ+mpje+/749znoCNOTLO7xRdeI/WYBqusBb+HfWMg3mcMoeSbPZ9/3ik4
li9eKj06Y+A87+VLQwX1Lju2/Qt90zNhUGkk1ljZXy/OnltzPSyznn4GhsTk
Zh844CZuNiVrZD08RgtSCZtJpW3yB/HXihUrOgXHTOIqjiPGwjkxMG8Ajh+v
lHsff7hZcBlUaunn+T7jmjh2fH39pbo2w2HF0aPwUMy7KQY95IcM8gnbHK4I
Q6pgoms2t3C5P66G3DPkljE0Uv2YMHos4dBKLuiVahQ+/AjnQcszH2zchN6p
6RJjvJ/FPb2Jji8+/0KbujJ6zGixzao1wJCkknxIjO0pOGzEI2bicDthTI5L
aMGRlZXV6u/djJz55hsMHFAgM5TP5YZWmYyZ06a3eY64Svxhp76dY0VL8T9h
3Lg2z2X3yxbbmJP8dvqVeTgqIgoKhQIhFE8hzTUxmbj4VvuVfXv3Ic2XKrOU
g3ohM81+S5csaffZlTSfcMw7qZ6YlRoUPvpom2dy8/KacShaYWCbuW+J7hqJ
mMhIwvI/nEajEd/Qet6KvLL8FZmnnHYHbGaLzOgfEn+1Jwf2lyHT5UWKwQKb
SocnHms7g+Tk5optXPeiIiIQTTaHESb2QVQk1XLSOOJi5l1FaKjg02i10off
rHyxbx+y+2bJjM44eI9n0MC7rvnOL8h3KVRbMqwuWMgfkwqfaPPMHXm5YpuP
uIn5NZ1iUUezcERkhNSNmMhoKHsmICEuDqqEJCjjExFKeHbtbn+WuZFwXgwZ
/FuZpXivTUvzSCbVro83b77mdw5T3e3l8cGlJY6mfC2aNLnNM/kFA8QfV9c+
5qsE6nmT4hMo5+Opputg1enhJj4zqpv4d/HixR3GwBQzg3KZ90h4r5Bzw+v2
YH3puut+71jFUeRk9hFfOChHniya0uo+96BpGekSQ8yxzLvpNIvxXMwzjY/8
k8LcS9ddpDynMa8xjnHtcMaN5M01a2SfxE7vNlMsOQnLyhUrb/g97vv7Z/SG
S2OEhWbE4j8Utbp/6tQpifXw8HCpD7w/z3byPOmm+pcisz7NZcR57CMX1V01
xRbjyM3P6xAG5ifeW7DyHqHDIT5ZOH9BQN89QbPv7eQPF/UnZrJt6pTiVvf3
79+PqJjopnnjKj6KCAtHmsUpvQn7x0wc4eddPz9zXgUqZ8+ewcjhIySvOZ4Y
Q3FRMerrAtuLOn3yFHL7ZMOhNgiO6VOfanV/52efSZ+hoJmJ1V8fGIeFcsJC
OcXzPve8EeFdic8iEUl8Jv4IEAfHLv9urNfqZB+dsYx5aLTs0QS8DjTzDOh3
O+y0npwjz8yY0er+9u3bm+YmwRHWqtbJdcqbZKVS9sGYy1j9eR6oP7iX7peV
LbykoV6J995Onz4dMAYWnu8LCIdNqaX8YBwzW93fu3evzHyhiqb5ryV2rsLC
9YPnAH8PydzF1+/+zd0B2cB7LtMoDtzUw42g2KqoqOgQBhb+zWDo4CFQdouF
OjYBL/9pXqv7lTQr836DxNYPcAiWkC6IoplEuKy5X7Q18xXvtQQqjIVnr9ra
2g5j8MvOHTtl725q8ZPye8PVwrE7oKCgpR9nu5uUPoc2nXclLtNTT6+m+se9
fGJsHMIIc2lp6U3b9GMI43Q6ncS/Gpm/dXodtDodTCYTbDabnDM3a3RaOSYp
k5BHnHvu3Llgm95Gzp8/j4MHD+LAgTLSAygrK5M9nvLycjn3K1/nnPq5/J+C
/3f5LzkVlgk=
                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 8->
                TagBox[GridBox[{
                   {"\<\"Date: 03/29/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 4}, {1, 5}, {1, 6}, {1, 7}, {1,
                     8}, {1, 9}, {1, 10}, {1, 11}, {1, 12}, {1, 15}, {1, 
                    16}, {1, 19}, {1, 21}, {1, 25}, {1, 34}, {3, 7}, {3, 8}, {
                    3, 9}, {3, 11}, {3, 21}, {4, 15}, {4, 22}, {5, 6}, {5, 
                    8}, {5, 9}, {5, 12}, {5, 17}, {5, 19}, {5, 34}, {6, 8}, {
                    6, 12}, {6, 15}, {6, 34}, {8, 9}, {8, 10}, {8, 11}, {8, 
                    12}, {8, 16}, {8, 26}, {8, 34}, {9, 10}, {9, 11}, {9, 12},
                     {9, 15}, {9, 16}, {9, 26}, {9, 34}, {10, 11}, {10, 17}, {
                    10, 34}, {11, 12}, {11, 15}, {11, 16}, {11, 27}, {11, 
                    34}, {12, 15}, {12, 16}, {12, 22}, {12, 24}, {12, 34}, {
                    13, 16}, {14, 16}, {15, 16}, {15, 34}, {16, 19}}}, {
                    EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo
i0EFjVTaQqkKGk38ZTRaLaZGo0KiiUsw0hgNLnEBl0QxFIS4nd7vvnnP9woU
aWZ4Nnlfcudt9818595zvnPunfDU7IUug06n+87KPhau+j5h3bpV+V+b2EVi
fk5GqpGdxLAWyRpukgYNGjRo0KBBQx9oaWmhlJQUCg0Lo9DQUCr/oVxtSv8J
ixcvJpQ9OoOedHodP6+srFSb1oDQ2NhIZrOZfKwWsjnsZPd1cDsSEhLo9evX
atP7YFy6dIn0ej1ZYAezAbZwO+Lj6dWrV2rTGxBEvzKaTbzhvLz8/xUjb968
oWfPntHKlSvJz9+fhg4dSqWlpWrT+iA0NTXRnj17uEYhDqqrq6m1tZXHw8uX
L9Wm1ye6urvo/v37tHnzZpo1axYFBQUJ+iRr48ePp5s3b6pNtVfcu3ePqqqq
aNq0aWQwGiXOiAFRm+QalZycTO/evVObtgKwYdzn4wTuTI+gqwaTkax2m8Rf
3swWHzKZTPT48WO1qSuQl5fHbXB84itp0NixYykgMIAsNqvCBtgm6m1+fr7a
1BXIyMjgvAwGA02aNInOnz9PDQ0NFBQ8QvIrecMcIY9ER0dT50cU69AiMR7W
r1/P79XU1vBrOXe5LRY2L3h+6tQpldkLQB6GnoKTXqen3bt309u3b7lWYcyt
DluP+bCiueM9KSlJbRM4mm/domDnSF73ORi3a9eu8VxnZJol1B/vY4I3N3+T
j5nHDvrl5ORQc3OzqnbUN9TzcYcdgZ8G8ntlZWUKn3pvg51r8pw5c2jMmDFc
02AL+g4bNoyioqLo8OHDquSWuro6IcYZp+HDh/N7cXFx/B5iQtReHEXOLQ8f
8vds7hjhPok63n0eGBhILpeL7t69O2h2YPzE3586dSpduXKFj62pF53SMz2b
+eVMqbZ9+vQpbdu2jdttNAm508z8zezjw8+hH4g1Odra2qijo8PjdqBWimd1
t8PhoNOnT/MGDhh7zIEYG4h33N+/f3+v3wPdKikpoVFOpzQuX0yZQvv27eO2
oMasqKigiIgIWrp0qcftAFDzvXjxgp9j3RoeHs7ixaCYC/gd1rEPHjz41+9C
7lmQtID27t1L7R1/UfKiZIqJiaH09HQq27pV8Fe7nf+Ot1FQWNAjd+AautQf
UKsUFRfTzl27KCY2lkwWwceGDBlCf5w8Sc5Ro/j1hg0bvG4Hxo6PG6tTBlKH
tDAfLWY2oD4TfQv5UtTqrNVZlO4SaofJkydLPuANIH8EBATw/PBPrYI/HDx4
UNEffn/kyBGeN6uqf6ERrJYBT3lsoZnYut450kk/V1Xy70GfuhMnvGZHQUGB
VDNa3boKG3CN3AEOjVevSv07Ozt5LkG/FStW0OpvVys0W4ox9h7qt8LiIqYr
Qv0QFz/dKzZAE/0D/KW5sNhsNPur2eTLbICviHEyc8YMxdpje/l2fh/558ef
fyI70z4r+tuVuo0+sdNjue/hHL91/fp1j9tRxtba4lgajAYKY7oFvoWFhVLc
Y15wnpmZKb13+/Zt5k/Bghbk5dLcefOE74FGyOp9zCvWLVgbh4SE8D7Z2dke
tQFr7cjISF6jiOMu15Tly5dLfm9xx/GFCxek50uWLBHiNzKCtpRuEeozxJTb
BqtM95IWJNHGjRtp9OjRtIvpmieBWBXHHH6FvZA7d+5Iz1sfPRJqKsbP4eaz
Zs0a6Tn26MR8vqNiB02YMIHnf7uv26fY/Ioahhr5yZMn1N3d7VEbgKjoKP67
kt98k9mjpjhw4ICgAb5Cn7S0NOkZ4h1re9xftmwZ36eQ111hYWF8vwh62NXV
5XH+AGoRvk/I5h9zAW1p+rOpR7/6+nphzty6uShlkeL5zl93uuPCQYcOHSIb
0wn4KuqR1lbv5m+MOeaZ83PPxfz583vte+7cOcn3cJw7b67iOfLaiJHBPHfX
1tbSQ1YXt7e3e5W/CPg1dBV7ICI/8O0Nly9f5nUwz9fMXyZOnMjXXHIc/e0o
Xbx4cTCoK5CVlSXlPRwTExP73HNGbYx9FPg89h/8/Py4v6uNtufPeQ1iZJrO
NVGv4/VdX4APwudE/cXxzJkzg0e4D2wq2ST5u96oJydbO/T3P0ZqWqoiRo7/
fnyQ2PYOrCOwhyjuT4ETdKU/uDJdUs7HEetJNXH27Nn3c8HWSCGfhfD96f6w
du1aRTyp/Z/ajRs3+H6AmGNzc3M/6L2TbC2EGkl879ixY15m2j8wJ6j3ioqK
BvT/HtbomS4X1dTUeJGdBg0aNGjQoEHDx4W/AU6fUkQ=
                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$4", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$7", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$21", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$25", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$7", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$21", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$22", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$10", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$27", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$22", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$13", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$14", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z
Mi9ZK1PLxvK6RiPHympWWZrTmGMJNk05TqCiIIIGJqDAx8cze+9zzscXIgLm
/PJd6+Wc73De9zzvfvd+9rNffWbu6Gm/uueee/J+S39GT/5jv7lzJ88f8xv6
kTZ/3tTMX9NNDHUXdX6Iu+1u+z+05uZmBKkHAgGcOF6ID/d/gG8Ki3Dtat2N
LwdbgBaltwSDCFKXOdT7ID+/g1hbaP5gcxCBxiZ89P4HGJiaBnO0Hqm9EzFj
UibWr3oRX3xyEBWlZfROIGwgYQw0Uw+gqakJTXRlrAHCHAg2y7x3ojU1NpKd
CDN9O29OLqJ7RMBmMMGuN8EcEQV7pB4Jbj/GZgzHsvxF2Pf2Ozj1/X9Qf7VW
xnBjuwaaA2gk3Iwy2BK8o3jZvk3XG5CdNRVuq126y2yD22iBU2eCW2+GLVIH
a7QBvbwx6JeYjKzHJ2PL5jdw/Kuv8dOVK8pcARUz+0QX8YpPqr7VUWO/lW81
NCJnejYsOgMsegOcJgu8hNlnssNjtMJlMAt+Nz1n21v1RtiNZiTE9ULek3Px
z6NHZZ5GXn8X8ZaUlKCwsFDG3qqxL3ALEN6Z06YLBo/NAY/FrmCk7iW8jNlr
sskanAYLHOQzDsJvovVFR/RENo2tYx8JtnTZvqtXr8bGjRs7N0Z9h+Ntlmpf
B9mQ7esxqRi5M14Vt5vwiq3NVlmbITIaGYMG4/zZUnVOdBpvdXU1Vq5ciaPq
/tyyBVvx5mTPgIW4wUk4XNTdJgWfR8XatvN6PGRvc5QOQwcN6RbeoqIirFu3
DnV17XBn29YS5g+3wmuwIoa6rw1etr2F8A5jvGe6hpdjbM+ePdi7d68yrIMx
mo91Fq9PxfszzCpeK3HHiIFdx1tbW4u1a9aguLhYfjM/dDium3j9hhvxDu8k
Xvke9dqfruKzjz9Bwe7dqK+rF27gHhpHlzp653JllXC95rfatZnwzpkxU3Lb
zfzXp3aP5rth/jvsJv4b4grBGeTELf3sDyWYOG4Cnpg5GxUVFQqUZiUv/lRz
BTu3bUfmxEmSbx8dNx7bNm9B9aXLoXVzrppB+cJIse622G7AG975uYu600JX
etcUrUPG4CE41wZveNfwtnBOpNudb24lzrRh+bOLcb2hIeQLDXS/Yf16eJwu
6HtGCr8aekbBa3Vg2cJFwpka3ulTssS+dwwv7yPlvw/ffR+D09IpX+rxxoZN
6jYr/z9y5AhS+iTDQHM6aH7OS6wPbDoj4n0x+JR8SPyX8sVs8gdeD/PvL45X
db+DnxygfN4Huvsj0D8pGd8eLwr5Dbddu3bBZDDCajLDZbMLVv6Gl3g+msZs
eGV9mP/Ogo3wyju/AN7WsFbuTxMPjBk+Ur4b6/Fh99YdYvcAa1nqzG+M126l
mCBNYFNzLX+D7cu5bNOrG1r9d+o0iR22Mec3t5qDOZ/56Nod+wZVXdxI9li2
eInkbo7nF1euIhsF5N2mgKJHGS/riMSERBiiouF1OMUfeL8Zl49+a/7Aemda
5hThM9FoNCdrBb/FIXj9ZnuX8bLGZG3M7bt/f4eUpD6Cd7jGJfxeIKho/RZF
mzGnvfzSy3CSL0Te10PiSU/xxtpwaf6zwh3iv00BTJs8BTbSXoKX9I7oyWgj
YlTMXcUrGlH1hZ3bd4hPGslua59/gRwQoXc1n6mj/FFTU4P62jrs2LoNWZMe
x5D+AzB+9Fi89vJ61P5YrfgC+xDhnU35whylF3+wkw/7bU7Bxzb2dcO+mi9w
X/3CKol5xrt4QT6qLlTgwvlyfP/Nt9i/fz+eW7ECj02ciDGjx2DF8udk34tP
ncLZ4tO4+mONWoe1rq+R9DrzA2tfiTeTgivW6pIaw2vqeryFa/C9BXtD9vU5
XBg6cDDS+6QgOb43nE4nTCYTTEYToohzbRbS3i43xo8agz9veh2XL1apSQKt
+oz8jOsLjsHnly7H5lc2IMkfByf5h4N8ojv8wFib1XrgQvkFZFM8cxxx/HAO
cNI+uuhe6i+KFyfFi521LN3biNOMEZFSG8yYnIV/HStUcqOQmVJzZk9R8DKf
f3XkKPrT+u2k1znnerph33Au42f8/3Wr1yA9ORVeu1M4k+3hVvcyvHspfnyU
05z0fXPPaKRTDfbWxtdx5XJ1KF/kTJ0u/JExYBBGPjgUDtbjNC+vn23RHbxs
32Y1B3O/XluPU9+dxCHKG+9R7fpM7lyxh0tqrVa8/CyEneLfQpi55pmbMwd/
3VOA7VveQkb6IMnFNjUHsi8znhiXR/B1h381H+b9k1pR21PGT/cL856GnXJB
W7w+i2LbBxxuWIkDmKusxMHsJy76rmgG6sx3OvIbtrNZp8dYyke5M3MQ7/FL
ndyleFO5QcvHnJOCxEPMufz7zKli0c024ta2/sBY+Xm8y4vMRx5DWu8k+W2V
WtgqeSLy3vvhd7rxYPpAPDRiFP60ZBk2v7oRkx5+VPSRxsFdzW98biT2JawS
K01KDO7bXYAYu0uwtYeX++C+acR9F+W8KYv0JduT+YV9Npf0A3PDS6vWSJ9F
/tw/ua/EK+eX29eTyrkMY+bzjqULFsKm7nVbvH6yjykiCsvzF0FrnEcOf3aI
+kGcKTlNmnQbJo5/GKmknzh+eS2aPuqu/4bj5dqC8z431usjh2SIT7bHD2xb
9uH33t6LSxWV+Ig469CBT3Gt/loI/+zsmdD3UDSynIcQv/uYdwiTw9B1frip
fakxZ/psjnZ9QcObEtcb86j+GDU4Q/iBny1fvDTEPXNn58Kk6TPhbwUP/2Zd
cdv2VXmtqb4Bi+bnSy7wqtzeFq+D/hdrdwtvWKg+ZD+3UW5IeCAOFZR7uD39
ZJ6i1QkDY3UIZotoUI63XwQvtdKSM3iQdIzEBNuEMIXzrWZf/p+T/DGG9pg5
j8+U4rx+nFPr2nm5T4h9JT+ouF2qjSXHheEVzKzpud6MVs5LOuMP3L48/AUS
Y+MFL+dj7XyR5+M6QmzFz9Xvs714j9k3E3yxOP3fH2SevJxc4TjOhW33p706
Q85LzK3nD2WnS0O6pF28aq44+sUR0TkOrr0MCg7RhKwn2DZqTWHkOtOuaHav
ijmJ1llWek7xB8qNpp460ZJiV3Xfb1YbaecPNhozcsAQlJd0jLdF1WplZ8/h
kbHjEEV8L7mYsMW6veJ/bFeu0eO8Pkya8AhWLnsOvfyxEvu874kPxKP8fJnM
kzsrB1btvE+Nt1DcmTvAG9k5vNyb+cyUrgc/PoDRGcNVf9JTDOhD+z522Ajs
3rELNZd+xCXKFWlUl2r5NyE2DqVnzir+MCeX1hYViref4W0nhjkePGH+UH4r
f2hz5FNGcfNMbp74Ln/DT1rBQhogOzMrdDZSU3UZj42bIHHloNhPiu+F8jLF
vgW795Ce1sFKupn/x/U/c4BcVRv/bA0qP7B9+Hyn7MyN+ld+avU8a0qyTdFX
x1F47GvRrH/b9z4efWic+KlgUvXwomcWSJ7gOoLzLD/ntSQnJqGqUtHv165d
w8L5C2AnHEb6n45szVe7ilt4w6xoIy2G+RpFdeGojGEoLz0fwtfemfUBqnEm
jHkI6SmpSCNtnZqQhAF0TYrrJTEl5+TUtfsXlq9ANdl3DdV7bBOu8fsQ3srK
ytCc12k9fMayds1aPEy5OaFXb1jJ1nLeoq7dqXKMFsvMvyMzhqKSfK2jxvX8
H373e4knHuNQNZhWg7GN+cyBaww77TGv48vDf8c7f9kDE43hfe+X2g811TXt
zs/a9eTJk9i6dSuenvcU0vqmim9wTW4iu/N4p9UGHdVcIwgvnzN21N7b9y7i
/TESI8zZJuIrI+V/PuuR+oh9UNUCXOfYKY8c+/IoSohvGXuPe+9Dfn5+h9/Q
Gu/txYqL+PzgISxdvBjDhw5DXEws9PTdiPt7YNmSpZ2a5xSvf8ubeGntWiwh
ffbUnCdEF7LOTk/pi5TeiaJpPZRDuI5uuH5dxv3j88N447XXUVVV1anvtG18
fn+i6AQ2bdiIgrcL5Oz5dlodacUL5eUo+aEYXx87hhOFhYS14bbmvNvutttp
/wM7Ipn7
                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa
WuNbVWLIgISig/F1qbmTTqs6D6qj1rzf/+179vHf6ya5SSvRt95eayf3TP/5
z3f28O39nzqpD/bL9PHy8vq7Rf3plzKl88SJKVP7+6mNO6dOykj1VT/ilfZS
ip1Xr16l8uiVK1fKdd1fSUU8Pf/y5cuMiy7YJ/sr+3luBoxEvv/+e/rkk0/o
t99+c+B06RL/LyoqorfffrtMY97sWhaMIO+//z6lpqZSdHQ0RUZGUtOmTWnu
3Ll0/vx5Pj516lSaMmVKmbG/mdWTZxHf+vjjj6lRo0akwhf5+/tTYGAg+fj4
8DZwgxw+fJiys7OdfLCyn7Gi7AgCHICH3W5ntVqtZLPZGCvsLygooG+//Zb6
9u1LkydPpp9//pnx/avHqdIwEhs6c+YMRUVFMR6Cja7AaNy4cZScnMy/oatW
reJr9Rhf2c97IzE6ffo0RUREMEa6HVWpUoXxQHwaM2YMWSwWCggIYB/csmWL
iRG0OL+7EVIZGJ07d47jM/CA3QhG2K5fvz5NmDCBateuzXEK+/r06cPX4PqL
Fy/SJZX3PMUDWP7+++/066+/sr+ePXvWSX/88Uf65ZdfeHzkVZzvKW6YD+ZS
Fv8vDSNdnn32WX5+2Iqfnx//7969O8do+CH24XiDBg0Ys3379pljQ7766iva
u3cv5ebm0rJly2j27Nk0adIkGjVqFA0ePJjuu+8+6tmzJ3Xs2JFat25NcXFx
nCPwDmCnothu3LgxtWjRgtq2bUudOnWiu+66i/r378/jjFbjTZs2jfPtypUr
mY8cPXqUsYX8GRjJ9ZDz6n3u37+ftm3bRu+88w7jERYWxnODb91zzz0UFBRk
5jj4436FDeYHHgDBu8bvmjVrsh96e3ubMcud4rh+jmyL4j5yvLSx5BzY/R13
3MHvR2zVU590hxF8A/Lmm29SQkIC2wtwwXs6efIkv/+7776batSowfPFcYlJ
r732Gl/7n4MHqVevXvwb7xLH9WcrSX19fc24B/xDQ0P5/tWqVaOQkBCqWrUq
BQcHs6/Ddj0ZUzhKeHg4ffjhhx7jUxxGkA8++IDfO3jiyJEjacSIEWzPMTEx
HI/wHLAJ/IcOHDjQvDcEsaRLly7MuXEd5odna968OWM3aNAgzoMzZsygefPm
0YoVK2j9+vXMH1555RW23YMK5+PHjzNvBTcDr8c9Tp06xTwMx1999VXavn07
bd68mV588UVasmQJPfnkk8xjMzMzmYd07tyZYmNjTY7y9NNP/yGMRFJSUni8
9LR0atiwIeOhq/DIxMREM3/pcRGCWJOWlsbYIL4cOXLE5OOeCuIy/BRxZtiw
YYztaoNTeCqYE2IRMITttWnTxpxjeTH6/PPP2Y+ARZaKOeHKxr2Urfr4+VLV
0BBqEteUMkeP4lh44cIFJ2z0/IXjkvs2btxonleWuX355ZfUsmVLql69Ots1
fGXs2LF8zFN+qgtwxnzeeOMNp3mXFaNNmzbxOPD1lq1a0ZjscdSnf18aMmI4
Jaen0cDBD9Dr+/aa1wInd/n366+/5jgCzoBcfcWD+egKvDEurv3hhx/MvI/7
CT5lzU979uzhZ0PeFZzLY0cTJ040aw7/wAC6rXYUxbVoTlHRdclWJYi8VIwM
iwinZS88z/MXQR2CmLJmzRre3rVrF4+zYMEC3oafST7w5JkEA1cRPlpWjITD
gq/AT4C5Jzjp9xXp0KED5wr4SZDi0QFWC3n7+lCAzcr+5uXjzdhZ1H74QVJS
EsdGxC3JI/Pnz2efwG/kQYjYRVmfqTjsyloHiq3v3LmT57VhwwYnjEoTwQh9
IeRw+Bnyl9WualZDfQL8qd/AAdSlZw9KyUjnGnfo0KGc06Dp6emML+4P3MD1
kA/vvfde034qs77VuSNyHfiLyGeffUYbcnIYNyj8ATHno48+ug4j5Fnke8Rr
V4xgPy/v3kWHjx2lv9WsQVZ1HPwFCr6C2AOOCd9CLgJPQEwCd0YO99THbpRK
rwayY8cOzrfgFJAePXpcx1ex3b59e66LZO4QPAuuBZfQMYK/WdT/k4rvbM7L
I2/lc+CO8EdRjAvuc+LECWoW34weffRRHhM+98QTT1Q6Rg4/vZZbYPOoFYBX
hMrdpl0YfQ34EnjrF1984YQRnk/HiK9RiuurKftCLs7Pz3fir7r6Gny2bkw9
+u7MdzzmoSOHaf3GDaX6e0VLnnoOX38/jrVe3l7sJ97Gc4gdIbajLwQRXwOH
Rc0lmIqCL6JuRV2KPIw4Ay6GWgUKm0RtiZwRUS2C6tSLpuyJEygzazSNGz+e
xj6YTSPHZNHIrCzH/4rWrGs6StlOluIz4DFWladjG91OXXt0p4SOiQ41ngc1
KepOEbEj2AmwACauGNWqVYtjm4iegyHgLUuXLGWu5+0HzunneD94Jx7UVBWq
qI2VDfmqPNSuQwLt3vM6P8NFbY3HlXcIRqjRG6v6GL4ovTSb4WuI5bAzPt/I
DxIDEet79+7Nduqn8LQHVyFLkJ35QqAW97FP365otRr3x3/5DV/DvB6e9g86
Z8RnqRdEdV+D9OvXz+SQZkxScQwxCrWmbkMQ1Jf16tXja3Ce3cDGzxJIvopH
MU4GVrDtysDGfDdqHpiPv8pBnIvUb2CFeWL+A1Q9iHpc52fuBDUq7EGPSXh2
1Pe7d+92sruzik+hFyb48Pl4Nyr+4d41FUe3GLwhwJhXZWEEPOD7IeFhVKPW
beSn/MxX2bzFsCn8x3OMV/FT7KAkbjlnzhzu2yC/C0aI9ahTdbub/fjjjv6t
HdjYWX2U7Q5VMT13SwHlKB6WW1BAAx4YRF5qf2BJvqeOWeyGD1itjK2uVuN/
oJqPxaZtG/ZQEkawafj/jJkzKX/bVtqUn0tr16+juObxPC+5HvaFHv2hQ4ec
bEF+u/of+hrSv4YyRoWF165R2rO3ozcUIDxTvafkjDTaur2ImiiOFKZyXMs2
rWmH4p6Dhw9je9LnLnMDVjalds1undaogBEwNDgZ/Fn2B2q+rGMVYPgVxkaN
sGz5C7TgX4soqm4dCousxrX5voMHKPZ2VUMpvodzbcGONYyFCxeWiJHYiI4R
5gP/e1nxLZELKq61ateOx5d3FRwaQluKClU+ddRuglucwqtA4Yt45C6O4/0h
1kudKL1N6bPCz6VnJcd8cK663hf5EzWkur9ulxL7ML/2KqfnbS3gehO5DPfD
GKPHjaWn5s8z58rnq9+PPPJIsRhJTIegr6VjhPgkMZvPU1ji3oIR4l5MwwaU
o+od9heb1fSF0PBw5pHR9WP4PNfnwL5U9U6WLl3KvKROnTr0zDPP0EMPPcS1
Dnp+ixcv5l4d8gPWH3DMX80pLTODFi5+jtq0b8f839VGvXy8aFjyCPqn4vq8
ZiH5TJ2bkJhIK1avYtwC7FaOmThHaoTS7Ah1lmCEd4f3iR63yEXF68EtxH9g
RyER4VT08g62Z44/xnuJiY1l/wuqeouZU3TFGAVGPxM91latWvFvcApgJL1O
2Da4qxwLVGMVGbadMTLTyR7ERjGPLooj5mw2+mIKD4sxrxRVhwNf2Lp5vto/
a9asEjGSbXBNwYhrEVW7YF7X7OgytUWdr8YXvxf7xXyAE3CrHV2X8rduoYzR
o657BhMjNUZeQT6Pi34C+t4Q8DHcP0/ViBCsA8OWIFinCVB8pKBwG2+jF6GP
L3PCO0E8QoyePmsm3RIWyjYObr3nwH6Ka9mC7y/25SlG6J01adLE7JHgP+z/
m2++cfK1trAjvAMjf2JesOHsCeNp647ttDEvl7bv2kmjx44x46InGMXHx5cZ
o1QXjCxGPpd8FaHi9CLlr4XK7jbl59Fmdb+OXe5kG7ZpnNdTjFBz3HrrrSZH
QuwEZnrP/tLVKw5fU8+n+w/7tNoXqnIa4lNoZAT3w91xbJ23oMYUf8L6IuS9
995jHxeMEJd0jBCPCg0+kpaepvEQgzPo3FHNCzVsjahaFB1bn98peIpVm5f4
4EzFEUrDCPwAMUhyLa5DfNIFtU1Cp46mr7njJLBx/C+Otwgfx/iCEewI/U3I
u+++y+9I1g5xTGLVW2+9xXmu0OAjaanOXMXq7n5GfjD5v+s7MzB67LHHeMzi
vueArF27lvOt9IZwnaxHiCD3x8OX/3B96fi/UfFNCPIp1qohWJ/T+6pYO8Ia
gmCEY1iTg8iax5+h06dPL9WOsF6uvxP8XrRokRNGiNng0kteeJ7z54o1q8us
K/+9hhVjnP70Ux4X3wlIHsM6CL7RkX7DgQMHTEwQM1evXs1rXRB8S7B8+XLe
B11VjvksV8+BMbAWWBxGIujhS10r645Sh8h5S59fRn3vv5+5B9aVhql4Wm5N
SaaBSUlcTw8ZMoRtAr8HDBjAvaokl2NYV8cxxHD9GLZFR5RjHsOhw4fzmFKP
uMMIfX+s/UpOAz7ou31qvGc5b85Tc5x85X9J0eNAT7Y4jLBOJzW81Pvo/Qr/
lvOOHj9OduMbLX/Ed+Rau93MuXruNXNMkI3Vse1Q2ba6fBv3R5VjdpDkT5tZ
33N8Drp+npxjDZ6N73vkec3Yoq1Boz+J8wQn/JbvQF19Et8RxTVrxt9zWARX
l1wh9YbU71Krmj08l+0/U/WxsR5oNfrzFpfcCuxQ7wWHVKVu3brRsWPH3MYj
EfSk9ToN3Ehfr3etWSD4NgLnyTt0nQOU6zSjXq1olTUMxA0r1ni0vG9yNMUl
O3ft6lRr6M8oPcVTirPpfSP4GbgkvmtxxUjWXUvDiHmuekewJ5uqvW6UzZSk
qPnQF5LvyWwufFZ4bCfFu12/33LFCGvQ4mfCi/ANnmvc0nvZEFn/docRxkga
MpiOnDhO+w8e4O+GKkORp8AbsJbm78Jr8f4wzzu7d3MboyFiU3rOF4zAF1zx
ce1hIsaVhNHkh6fQzSBYN46sHumEkcXo48COuvXsYZ5bHEbo5XL/wPj+E36m
r1MWhxN6Pqb9GX1BiUPYj/Usvk8x49z49VnH84G/YM0d/RGZn7+xBgCMEjt3
KhYj8RvggW/zEI+wRvnSSy+ZGLr7jkME30MAC3Ot3MdQg28sWvyc4z6V+E0E
5KeffuI6h+flc22e6FVgX0ZmZrEYyT4I1tjQk8D3RCWJfj3We5H7UOdB161b
x/ji+zqsp18w+gXuvieqKJF7o07GHDE/6Dql2M7JyTHXrf8v5ZP/AozBoMg=

                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY
gQQBDKaJCEhIKGpxYyhbBSoxKoYQCKmIUaYg1BYghsQetjH49Hzn3XN7/WSD
C4+HK/VIx3e+6/P9Z58/PiMnZbKfj4/PdAf/SRk/8+P8/PGzUgP44lezvpqU
4c8nPZg/ZMbNmpoaagwMqq6upqqqKjnHPVw/f/5czl+8ePHOZWwoQ1YQjhUV
FSYmEM7/F7CAnj17Rps2baLk5GTq1KkT9ejRgzIzM+n06dMmnnctZ10MmwGD
KisradLkycSmLuzr70d+/v5yHtMkhjZv2dJosQADfAA0f/58kTkgyEF2Z7Bw
UGiIsI+fL0VGR9Hx48dNu2tMNqb+cOPGDWrTpo3oQDHYgoPk6G+3UXBYqGCc
Nm2aaX+NEcf+/fvJx9eXHIbs9hCn4LCxbhx8jns+fn70M/YXjWEaxxoDK449
e/bIettZdoeBwWHoRBm21bFjR/EjUGPCoT5+4cIFiomJIRvbEOR3GLalmAIc
dsE5YsQI088bm10plnHjxoms4tssvzM8TDDg2j8wQJ5tMWIWfgsfedfyg93p
0uXL1PmDriKvH8sNfQSyf/j4uuJwZm62+IbGqje1K9Xn63wHcug6gq5du0ZH
jhyhY8eOybNr16/T2HFjKbZFLNntdgoJDaXEzp1o5XffSX7XmOsJu9L10Fqo
Lox1shEvQQ8ePKA5c+ZQdHS0mfcGDRpEN2/elOdlZWV06NAhwXf//n2P5z5r
/nkZaW6ry5YeP35Mw4YNE9m7d+9Oo0aNop49e8r1hAkT6v2ep+OTylheXk5n
z56VWKOM67t379arG9CiRYtE5jFjxtCUKVOob58+lJeXRwMGDKAmTZrId3UN
1A5fN1+oH+E77muvMR8yREVFUVxcnHCLFi2oefPmtHXr1lrvKoOAEe8mJSVR
RkaGy6c5v4WHh9OsWbPIZrPRiRMn5F2r3Fa/aChrHLTKbL3W51i3U6dOiQ7A
586do5MnT4qs7r9RWTZu3Cg4Zs6cSYGBgeRwOMSfY2Njafr06RQZGSl6fR25
3fnJkyfihw8fPhSGPSs/Yn746BE9Yn769Kn4uepc9afvyjeYNRaAkCPgG337
9hU9BAcHS/4rKCigrl27UufOneV/1udbSq/CANqxY4fYSOvWraV2a9u2rRzB
CQkJch+M+9Zn+q6+g3Xv37+/qR/gSkxMlFoP6+/g3BAQEECjvviCBg4cKDY2
cuTIWnp3x4CaRGOe4qnPD2EvGzZskNy5efNmsXfl7du307Zt2+Qcz3GOo5X1
GfqhnTt3it5AsPsItptpWb+nMORqxuEb4E9Lly+jrLxc+s2YNPqh9AdTPuQL
teG9e/fS8OHDqUOHDtS7d29avny5qbf6al+NR54i7U137tpJSZ8n09dFS6UO
Bw7U5LPnFVJi1y6UkNiBOrK+xqen05kzZ8zfY01DQkLMmOBv9FajR48WrC/z
c12Hffv2SYxHfO/Vq5esRZcuXaiwsFCevyoWYp3UDqCbT5M+o5lzZlPEe9Fk
49oP9d+kL6dSy/h4kQ32jJq2Xbt2Ejfgq7BFyB4UFCRxwel0SmzA++vXrzft
sK7/XWXUxvhWUVGR6LG4uFgY17CvhvRkGu8Qp8LCwly5bspkapXQlgJYF6id
PmUdfTJ4EMX+JI7mFs6lrKws8ZOJEydKPocupEbhIxg4gAnfQuxuyHq+LG83
JPaBoI8+nOukZ7UFiszJKcPl2p+vm8U2p8zsLPo8NYU+MfwdGKZOnSo6BH7I
DfkR3xSPNf9rnntbDEKcat++veQ42FLT95tRXsEMCuZ6HH2GD/eyKaNGUmZO
NqVxjod8iHlHjx6le/fuiZ0h1wADGLpRfZSUlDRYH2+KA4Q5jvQW3E+gJh/5
29HUu99Hch7I2CLZX+A3qGtbtmwp765du1Z+u27dOpHbl/texGn4usZo+I83
cCiW1atXu3yV+yOs/0f9f0nL/rBCfAR6gVzAVVFZQTnZ2XKNnAhdgnbv3k1D
hw4V3WCmtXDhQsnF3sKgOFCvoIZCrAUO+PrcBfPFx8VvoBOu4a9yP3Lx4kWp
23B/1apVpk7hA8ip2od4Q3Z3HFeuXJFew844YEtjM8ZTQscOlJ2fR/0+7k/R
TZvIvXtGr4GYBRyoC27dumXKraR5wVsYNO4eOHBA4g3mOtAHfLopx6mmzd+n
jEkTBQ/i2JAhQ+jOnTt09epVqZ2BJScnx5RZa/i3bU/WntNa58KeIVMg+0NE
dJTUIciFyOeY5yD+6ixBazLYFK5btWpl1iCQ3VN97atwuNf6t2/flvyMWIP8
8UH3D2nytC/JF7HKMgOVOSjHJT+OS+hxMWNcuXIllZaWvpV+8L+1qdzcXFlX
2JXkYLajHlznQAdWDDbmEOQUu0PeS01NNfWJOrfai3Meq85BqHmxxshd0Ed7
9u0ly4okPumc0IrFyXka+Rt1FLDk5+f/x7ervacPdxzoNSCPylXy5xJavHSp
nFsxqH0hLodwLexEPcy/wdx67feufPjci/ND91kKepHQ0FDJxVlcQ/FTM2fo
TB32hXweHhkhuR3zQ3OOyM/e437xH0bP7m3fAKlOsGeBPgh+WlZeRjFcXyFO
QQc6f0Z+37htC4VGhNfyG3nOmAdwTH5WzyzJm/ZFhoqKuRax6kLqFJl5unLE
im+/IT/uEQON/QI8xxH1fdGKYlPP3sRhnR3h/Pr169SG+w4fltNu7AuIb7At
7fn7PpEPa542bqzLp4x9D+D1M+r7yz9eNnXtzThs3TfT+GvGJ2Odf967F1VU
VZJmnSvl5dSa8SK/KBbZx+HfZnMN+S5wqF2h9pY8yH7hbvvf/+mP8k51DffA
Na73S/+yQeoXa56ET0VxjaZ7t297/8OdsNeE+hV1uzMspNb69v1FP3rEPUSN
4OD6CeuMc76TPHxYLftyGL6kOvFkD2jVr8wUMIPHnMJY17/+bRc143oPvota
18mx1Ik9Js6LOB48eND0W1eOeC4Mwp6hAznUYZf8iHyKvhCzCOw3eNrfrTVV
5bMqwVDFNcTS4uXSI6FOtxn2ERQcbPakSxYvroVBcOg82vgeahO8qz0tGNdr
1qzxOA7U0joXB53452n6ddJnkhes+5aCw6ix0tPTa9WT7muiz3bt2iV9vfu8
Z/DgwR6Pwfp/MW/7esliijB6uQAjN1v3K7X+w/xXfVVlscZqvY/3unXrJr5l
nTOgJ8Ns3NM4JMZwfS11kyXGyF4rxxnpM/hZyohUmYGoDb0s5ijNmzfPNaNg
ewS/Dduy7iOkpaW54gtyG8uP2Sf0gDoDe/y5M76ip5UV+Me19lZexqDDhw+L
XensSnFgvuVJ21K/wJ6G7uUHMQbkYFzHxf+UStaXuuyojnV4FQ7YFuYkqDWB
QWvn2bNne9SuNF9jztEWdYexb4l9gd+NT6cfy/7livdGTG1oLgbpGsGGEHP1
2/Hx8XT+/HmPxyy1rcuXLtGCBQtoRkGB1Lgqz5t8V7+B2IXaBt+vC8P/qXHR
vwEsx0/M
                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"], 9->
                TagBox[GridBox[{
                   {"\<\"Date: 03/30/2014\"\>"},
                   {
                    GraphicsBox[
                    NamespaceBox["NetworkGraphics",
                    DynamicModuleBox[{Typeset`graph = HoldComplete[
                    
                    Graph[{"larceny/theft", "fraud", "vandalism", 
                    "weapon laws", "burglary", "vehicle theft", "trespass", 
                    "non-criminal", "assault", "suspicious occ", 
                    "missing person", "other offenses", 
                    "sex offenses, forcible", "drunkenness", "drug/narcotic", 
                    "warrants", "forgery/counterfeiting", "arson", "robbery", 
                    "driving under the influence", "family offenses", 
                    "disorderly conduct", "embezzlement", "liquor laws", 
                    "prostitution", "kidnapping", "runaway", "loitering", 
                    "sex offenses, non forcible", "suicide", 
                    "stolen property", "bad checks", "extortion", 
                    "bribery"}, {
                    Null, {{1, 2}, {1, 3}, {1, 5}, {1, 6}, {1, 8}, {1, 9}, {1,
                     11}, {1, 12}, {1, 15}, {1, 16}, {1, 18}, {1, 19}, {1, 
                    20}, {1, 26}, {1, 34}, {3, 8}, {3, 9}, {3, 11}, {3, 12}, {
                    3, 15}, {4, 11}, {5, 8}, {5, 15}, {5, 34}, {6, 8}, {6, 
                    9}, {6, 15}, {6, 34}, {8, 9}, {8, 11}, {8, 12}, {8, 15}, {
                    8, 18}, {8, 26}, {8, 34}, {9, 11}, {9, 12}, {9, 16}, {9, 
                    19}, {9, 20}, {9, 34}, {10, 11}, {10, 12}, {10, 15}, {10, 
                    16}, {10, 26}, {11, 12}, {11, 16}, {12, 15}, {12, 16}, {
                    12, 19}, {12, 24}, {12, 34}, {13, 26}, {15, 16}, {16, 
                    17}, {17, 19}}}, {EdgeStyle -> {
                    GrayLevel[0]}, ImagePadding -> 10, ImageSize -> 640, 
                    VertexCoordinates -> CompressedData["
1:eJwtkTtIQlEYxy9BT7SpqaHIlihaQghJ+IYghLaGIMKh19ZjcTRuYGYuQqVL
pb0wFwnEQYLqAyntMVRDeoeEoDLKyrRosKXy+x+4HA73O//H77SMzgxMVCiK
Yvj7/vfzRCrc6Ezy156qzNvylLV7rL6mNHtru5Wr1Bs5M2O9i9odH+7UL5WM
OQpN+dtfPI/stlirv4NPVKpcnRx2P3O8cDN9arkn/XjA3hl85bSjraO0cEtb
RvNyX/KdG/TNiYjjmlr7B3P6TJ5XYkNd2UCMDDgb5MwBzBd05Xmugd6x6PEn
/KLix5vIMyd52I68UcnLl+jjkT68hr5F6cuqzW/quTgxK+X1wQn5T+DBD3Kf
fLjvEn06gv6u+JML/j+Sj8CDdZKfNOQHD6oSHgwetI7+4EEm8NnAfF54UB30
4uBbhN8++G8jj4r3AQ+K4f0y6AMeFEJf8KBZqxaOjJwdgAf9AjXQJm8=
                    
                    "], VertexLabels -> {
                    Placed["Name", Tooltip]}, VertexLabelStyle -> {
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]}, 
                    VertexShape -> {"drug/narcotic" -> Image[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "liquor laws" -> Image[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "arson" -> Image[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "kidnapping" -> Image[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "weapon laws" -> Image[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "family offenses" -> Image[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "assault" -> Image[CompressedData["

1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond
SKeaxixLbEKyOccOejpnDuqok2Oooeh4qTG8JNgoiho1oMAGfFrrpb0ThG1N
3/ZXa3jZ8H3f7Pf5nrXWs9Z6tfM8mQvuGjNmTNE99Cszr3RiYWFe+fR/0D8p
5cXz591Nf0TT0tHii5DJbty44V+jXQ+05LT+gYE7iqOvrw/b/l+PipJSFBV4
sP6Dj/DDyVPi3gBhGW5yvy9bV1cXXl66DFaDEdoIJTSKSBiUGsyemY0TJ04I
HMOxBANH7YZaqBQRMOslWCUjnGYr7HojwkNC4fF4BM6RfCOn9fb2Iic7B0rC
YZEMsBlMsBEWh2SCiXDFJyTgyJEjsu45knV0dODhSZNh1Olh1Or8fFh1Bug1
OiQmJqKhoUE829/fHzQczMeCZ+ZDE6mC3WSGRT/IidNghk6lQUpKCpqbm8Wz
wYiJm23b1m2IsjtgUGth1klwGAmPVhI4Kisr0dPTM2LOyG38nuvXrcP4B5Jh
JwxmrR6xdicqXixDS0uLeIbz+k5Z69mz+PzTDahZtx6Nexrw89UOcZ3jwueT
QL7p7OzErl27cPny5T+9N/PdsGcPtpKGHaO8uND6I7p/6Rxyn3HwYk4GftPX
4bp5/vx5lJaWIisrCxcvXvxTGI4fPYYlpJ0xTpfwR3JcAjLTnsDcWTmoWvEa
vjt2HDcGaC/Wsf4BeL3e3/emnz5vH/r7BnNo7dq1kCQJxcXFfzivfmw9h1Vv
VmF8YpLQTs5V1gwj5amF4pSv6ZRqLKQ8unypXWBhHDcbX+vt7hFY2s5fwKyZ
s0SO79ix47b7eylHv/z3ZjwyMRUmikXe30q6yVwwDr7GuSJilfDYzBa8+fob
4p37vUPjVPDT64W3pxcfrvkATqcT5eXlOH36dEAM7PtncucKvTaotNCRXvD7
i/1YQ2nZf/sUGKnWsLa5XVHYUrdZ+GGQCAg/iUVYDh04KHQwPT0dO3fuxLVr
10bF0H7xEqakTIImLAIuo0VgSIpPxIK8pzEh6UE4TBahX8wP/82LObEaCRPh
SZ2YQu9x1I+jj3hgPtg3e79uQHFhEVatXIlz584F5GLLF3XEgQZO+n6rRo+y
ohKcoprOvk+b9DDU4RF+LOIZ4S8DTFRvJOLETHhm5+SitmYDGvd/g7YLbQIP
Y8uelY01768R+cJxPKpRbBcu8kAiHHriYXnFMv+tpoMH4TLbxL4ui23QN8SX
kXS1uGAxPPmLoOeaQ3GiVWsEN+OSH0RmegYqysqR91QeIqk+LlzwbEAe2M6c
Oo0JpJMG+p4Ym1Nolc/27N4tYoFjhLmIIiwcI8zFPuL7ypUryJiWjvvuHQuN
Sg21UgVVpBLhoWFQRlBOabQCR25Ozm319ot//ov2oFwk7l9Z+tKQe9vqt9L1
yMHYoPh1+n1jxeFDh8Uz3x4/jsWexVg4/1lkPzkTWTOykEEx+diURxEfF4eE
uHgULSkMiGOA9KSspATK0HAkRsei5SYu2N57+12/fvDe/MkxHOdy4xLF9mjG
cXCFtPvkyeaA2unT2pazLZhA/lSE3I/XKlfc8ty8OXOgoz6Qex4b9RvsE/bR
xORx6OrsGvX7/6j5dHXTpk1Qq9VwR7lx5syZIc9wnch8/AmYqA+N0pvg0BEn
9Ml5NZ1igvsSuay6uhohISGoqqq65V7HTz8N6irhcEtmRNGyqnXQKZQopHiQ
01hXamtrcf369VvunaVYSY6NJxxagcOmJu00WCFFqPDq8kpZcQTE2NqKB2Lj
YCEOoo3Un2spbw0WqCimZ2Rk4noAfZbTWBseIk1nHDEmG6IJA2PhmFWTRry/
evUdweHt82Lao2kwRqrhIu1g39g1EtwWO/XMSsTFxOKor6YE2WZOnyHiNJb4
cBAGzhk78WGh/FWEhSMvL0/WvBnN5s2eCxP1AHEWBxzkE1/eumwOmIxGaDQa
1NTUBB3HMqpVEuWpL2/dFCMOmlv0VDe4tul0OiQlJYlaGkz7vPYzkaccFzGU
M5OTxuPp3Dk0TxpgpNrKnKhUKqovnqDOUDu2b4eW6wvNTC7iIjVpHJoaDyCH
6pme6rPLaqdZUw+J+Pnfl/8NGo6vaNbQU774erFomp24bh1qaqK+xAoT9Y2c
x1wng6lt26nu83mHrz/lfrX5xPfiXi5xog5V0FznQuT9YXh75aqgYLh69Soy
0qYKPkzU+3E/yj0R6yzHwrTH0oTPuJ9lvvbv3Ss7Bu5xSxYXIiIkFFEUAxby
iUTzyjtvrRIYDjcdgpty10o9gEQ40yY/gu4RatRftU/WVYt+x+cLiXq+l8uX
+mf6/2zeImZ/C8co5dPry1fIni/79+2D02IdnJlMg3VtWVnFkF67+qOPoQpT
+M+F9jfI65O2tjakpqSKszCOBzXtVUozxPB+v+C558UsYSau0qekoae7W1Yc
BQUFUFHPbSMM3DcvWVSA3p6h9YN9M5V6YMZhoJhZWlIqK4a6ujqhjQaajVTh
Cnief0Gc8wy3C6ThCe4YkSMJTjcOftMoKw7mIjQ0VMweBS/kj9ijsR1obKR6
a4SeuMicOm1ErH/F6uvrxbkAn3f1Bvju3V/thiI8HPeNHYuNGzfKisFn7e3t
t32G+7T8/HxxtsPnt3/b3xYs+xWA5H/D
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "runaway" -> 
                    Image[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], 
                    "driving under the influence" -> Image[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "drunkenness" -> Image[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "robbery" -> Image[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "bad checks" -> 
                    Image[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "missing person" -> 
                    Image[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "forgery/counterfeiting" -> 
                    Image[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "other offenses" -> Image[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "larceny/theft" -> Image[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "embezzlement" -> Image[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "fraud" -> 
                    Image[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "bribery" -> Image[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "vehicle theft" -> Image[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa
WuNbVWLIgISig/F1qbmTTqs6D6qj1rzf/+179vHf6ya5SSvRt95eayf3TP/5
z3f28O39nzqpD/bL9PHy8vq7Rf3plzKl88SJKVP7+6mNO6dOykj1VT/ilfZS
ip1Xr16l8uiVK1fKdd1fSUU8Pf/y5cuMiy7YJ/sr+3luBoxEvv/+e/rkk0/o
t99+c+B06RL/LyoqorfffrtMY97sWhaMIO+//z6lpqZSdHQ0RUZGUtOmTWnu
3Ll0/vx5Pj516lSaMmVKmbG/mdWTZxHf+vjjj6lRo0akwhf5+/tTYGAg+fj4
8DZwgxw+fJiys7OdfLCyn7Gi7AgCHICH3W5ntVqtZLPZGCvsLygooG+//Zb6
9u1LkydPpp9//pnx/avHqdIwEhs6c+YMRUVFMR6Cja7AaNy4cZScnMy/oatW
reJr9Rhf2c97IzE6ffo0RUREMEa6HVWpUoXxQHwaM2YMWSwWCggIYB/csmWL
iRG0OL+7EVIZGJ07d47jM/CA3QhG2K5fvz5NmDCBateuzXEK+/r06cPX4PqL
Fy/SJZX3PMUDWP7+++/066+/sr+ePXvWSX/88Uf65ZdfeHzkVZzvKW6YD+ZS
Fv8vDSNdnn32WX5+2Iqfnx//7969O8do+CH24XiDBg0Ys3379pljQ7766iva
u3cv5ebm0rJly2j27Nk0adIkGjVqFA0ePJjuu+8+6tmzJ3Xs2JFat25NcXFx
nCPwDmCnothu3LgxtWjRgtq2bUudOnWiu+66i/r378/jjFbjTZs2jfPtypUr
mY8cPXqUsYX8GRjJ9ZDz6n3u37+ftm3bRu+88w7jERYWxnODb91zzz0UFBRk
5jj4436FDeYHHgDBu8bvmjVrsh96e3ubMcud4rh+jmyL4j5yvLSx5BzY/R13
3MHvR2zVU590hxF8A/Lmm29SQkIC2wtwwXs6efIkv/+7776batSowfPFcYlJ
r732Gl/7n4MHqVevXvwb7xLH9WcrSX19fc24B/xDQ0P5/tWqVaOQkBCqWrUq
BQcHs6/Ddj0ZUzhKeHg4ffjhhx7jUxxGkA8++IDfO3jiyJEjacSIEWzPMTEx
HI/wHLAJ/IcOHDjQvDcEsaRLly7MuXEd5odna968OWM3aNAgzoMzZsygefPm
0YoVK2j9+vXMH1555RW23YMK5+PHjzNvBTcDr8c9Tp06xTwMx1999VXavn07
bd68mV588UVasmQJPfnkk8xjMzMzmYd07tyZYmNjTY7y9NNP/yGMRFJSUni8
9LR0atiwIeOhq/DIxMREM3/pcRGCWJOWlsbYIL4cOXLE5OOeCuIy/BRxZtiw
YYztaoNTeCqYE2IRMITttWnTxpxjeTH6/PPP2Y+ARZaKOeHKxr2Urfr4+VLV
0BBqEteUMkeP4lh44cIFJ2z0/IXjkvs2btxonleWuX355ZfUsmVLql69Ots1
fGXs2LF8zFN+qgtwxnzeeOMNp3mXFaNNmzbxOPD1lq1a0ZjscdSnf18aMmI4
Jaen0cDBD9Dr+/aa1wInd/n366+/5jgCzoBcfcWD+egKvDEurv3hhx/MvI/7
CT5lzU979uzhZ0PeFZzLY0cTJ040aw7/wAC6rXYUxbVoTlHRdclWJYi8VIwM
iwinZS88z/MXQR2CmLJmzRre3rVrF4+zYMEC3oafST7w5JkEA1cRPlpWjITD
gq/AT4C5Jzjp9xXp0KED5wr4SZDi0QFWC3n7+lCAzcr+5uXjzdhZ1H74QVJS
EsdGxC3JI/Pnz2efwG/kQYjYRVmfqTjsyloHiq3v3LmT57VhwwYnjEoTwQh9
IeRw+Bnyl9WualZDfQL8qd/AAdSlZw9KyUjnGnfo0KGc06Dp6emML+4P3MD1
kA/vvfde034qs77VuSNyHfiLyGeffUYbcnIYNyj8ATHno48+ug4j5Fnke8Rr
V4xgPy/v3kWHjx2lv9WsQVZ1HPwFCr6C2AOOCd9CLgJPQEwCd0YO99THbpRK
rwayY8cOzrfgFJAePXpcx1ex3b59e66LZO4QPAuuBZfQMYK/WdT/k4rvbM7L
I2/lc+CO8EdRjAvuc+LECWoW34weffRRHhM+98QTT1Q6Rg4/vZZbYPOoFYBX
hMrdpl0YfQ34EnjrF1984YQRnk/HiK9RiuurKftCLs7Pz3fir7r6Gny2bkw9
+u7MdzzmoSOHaf3GDaX6e0VLnnoOX38/jrVe3l7sJ97Gc4gdIbajLwQRXwOH
Rc0lmIqCL6JuRV2KPIw4Ay6GWgUKm0RtiZwRUS2C6tSLpuyJEygzazSNGz+e
xj6YTSPHZNHIrCzH/4rWrGs6StlOluIz4DFWladjG91OXXt0p4SOiQ41ngc1
KepOEbEj2AmwACauGNWqVYtjm4iegyHgLUuXLGWu5+0HzunneD94Jx7UVBWq
qI2VDfmqPNSuQwLt3vM6P8NFbY3HlXcIRqjRG6v6GL4ovTSb4WuI5bAzPt/I
DxIDEet79+7Nduqn8LQHVyFLkJ35QqAW97FP365otRr3x3/5DV/DvB6e9g86
Z8RnqRdEdV+D9OvXz+SQZkxScQwxCrWmbkMQ1Jf16tXja3Ce3cDGzxJIvopH
MU4GVrDtysDGfDdqHpiPv8pBnIvUb2CFeWL+A1Q9iHpc52fuBDUq7EGPSXh2
1Pe7d+92sruzik+hFyb48Pl4Nyr+4d41FUe3GLwhwJhXZWEEPOD7IeFhVKPW
beSn/MxX2bzFsCn8x3OMV/FT7KAkbjlnzhzu2yC/C0aI9ahTdbub/fjjjv6t
HdjYWX2U7Q5VMT13SwHlKB6WW1BAAx4YRF5qf2BJvqeOWeyGD1itjK2uVuN/
oJqPxaZtG/ZQEkawafj/jJkzKX/bVtqUn0tr16+juObxPC+5HvaFHv2hQ4ec
bEF+u/of+hrSv4YyRoWF165R2rO3ozcUIDxTvafkjDTaur2ImiiOFKZyXMs2
rWmH4p6Dhw9je9LnLnMDVjalds1undaogBEwNDgZ/Fn2B2q+rGMVYPgVxkaN
sGz5C7TgX4soqm4dCousxrX5voMHKPZ2VUMpvodzbcGONYyFCxeWiJHYiI4R
5gP/e1nxLZELKq61ateOx5d3FRwaQluKClU+ddRuglucwqtA4Yt45C6O4/0h
1kudKL1N6bPCz6VnJcd8cK663hf5EzWkur9ulxL7ML/2KqfnbS3gehO5DPfD
GKPHjaWn5s8z58rnq9+PPPJIsRhJTIegr6VjhPgkMZvPU1ji3oIR4l5MwwaU
o+od9heb1fSF0PBw5pHR9WP4PNfnwL5U9U6WLl3KvKROnTr0zDPP0EMPPcS1
Dnp+ixcv5l4d8gPWH3DMX80pLTODFi5+jtq0b8f839VGvXy8aFjyCPqn4vq8
ZiH5TJ2bkJhIK1avYtwC7FaOmThHaoTS7Ah1lmCEd4f3iR63yEXF68EtxH9g
RyER4VT08g62Z44/xnuJiY1l/wuqeouZU3TFGAVGPxM91latWvFvcApgJL1O
2Da4qxwLVGMVGbadMTLTyR7ERjGPLooj5mw2+mIKD4sxrxRVhwNf2Lp5vto/
a9asEjGSbXBNwYhrEVW7YF7X7OgytUWdr8YXvxf7xXyAE3CrHV2X8rduoYzR
o657BhMjNUZeQT6Pi34C+t4Q8DHcP0/ViBCsA8OWIFinCVB8pKBwG2+jF6GP
L3PCO0E8QoyePmsm3RIWyjYObr3nwH6Ka9mC7y/25SlG6J01adLE7JHgP+z/
m2++cfK1trAjvAMjf2JesOHsCeNp647ttDEvl7bv2kmjx44x46InGMXHx5cZ
o1QXjCxGPpd8FaHi9CLlr4XK7jbl59Fmdb+OXe5kG7ZpnNdTjFBz3HrrrSZH
QuwEZnrP/tLVKw5fU8+n+w/7tNoXqnIa4lNoZAT3w91xbJ23oMYUf8L6IuS9
995jHxeMEJd0jBCPCg0+kpaepvEQgzPo3FHNCzVsjahaFB1bn98peIpVm5f4
4EzFEUrDCPwAMUhyLa5DfNIFtU1Cp46mr7njJLBx/C+Otwgfx/iCEewI/U3I
u+++y+9I1g5xTGLVW2+9xXmu0OAjaanOXMXq7n5GfjD5v+s7MzB67LHHeMzi
vueArF27lvOt9IZwnaxHiCD3x8OX/3B96fi/UfFNCPIp1qohWJ/T+6pYO8Ia
gmCEY1iTg8iax5+h06dPL9WOsF6uvxP8XrRokRNGiNng0kteeJ7z54o1q8us
K/+9hhVjnP70Ux4X3wlIHsM6CL7RkX7DgQMHTEwQM1evXs1rXRB8S7B8+XLe
B11VjvksV8+BMbAWWBxGIujhS10r645Sh8h5S59fRn3vv5+5B9aVhql4Wm5N
SaaBSUlcTw8ZMoRtAr8HDBjAvaokl2NYV8cxxHD9GLZFR5RjHsOhw4fzmFKP
uMMIfX+s/UpOAz7ou31qvGc5b85Tc5x85X9J0eNAT7Y4jLBOJzW81Pvo/Qr/
lvOOHj9OduMbLX/Ed+Rau93MuXruNXNMkI3Vse1Q2ba6fBv3R5VjdpDkT5tZ
33N8Drp+npxjDZ6N73vkec3Yoq1Boz+J8wQn/JbvQF19Et8RxTVrxt9zWARX
l1wh9YbU71Krmj08l+0/U/WxsR5oNfrzFpfcCuxQ7wWHVKVu3brRsWPH3MYj
EfSk9ToN3Ehfr3etWSD4NgLnyTt0nQOU6zSjXq1olTUMxA0r1ni0vG9yNMUl
O3ft6lRr6M8oPcVTirPpfSP4GbgkvmtxxUjWXUvDiHmuekewJ5uqvW6UzZSk
qPnQF5LvyWwufFZ4bCfFu12/33LFCGvQ4mfCi/ANnmvc0nvZEFn/docRxkga
MpiOnDhO+w8e4O+GKkORp8AbsJbm78Jr8f4wzzu7d3MboyFiU3rOF4zAF1zx
ce1hIsaVhNHkh6fQzSBYN46sHumEkcXo48COuvXsYZ5bHEbo5XL/wPj+E36m
r1MWhxN6Pqb9GX1BiUPYj/Usvk8x49z49VnH84G/YM0d/RGZn7+xBgCMEjt3
KhYj8RvggW/zEI+wRvnSSy+ZGLr7jkME30MAC3Ot3MdQg28sWvyc4z6V+E0E
5KeffuI6h+flc22e6FVgX0ZmZrEYyT4I1tjQk8D3RCWJfj3We5H7UOdB161b
x/ji+zqsp18w+gXuvieqKJF7o07GHDE/6Dql2M7JyTHXrf8v5ZP/AozBoMg=

                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "suicide" -> Image[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "extortion" -> 
                    Image[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "stolen property" -> 
                    Image[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "warrants" -> 
                    Image[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "burglary" -> Image[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> 
                    True], "disorderly conduct" -> Image[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "non-criminal" -> Image[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "suspicious occ" -> Image[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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                    "], "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, forcible" -> Image[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], 
                    "sex offenses, non forcible" -> Image[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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                    "], "Byte", 
                    ColorSpace -> "RGB", Interleaving -> True], "loitering" -> 
                    Image[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True], "trespass" -> Image[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], "Byte", ColorSpace -> 
                    "RGB", Interleaving -> True], "prostitution" -> 
                    Image[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    "], 
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    "vandalism" -> Image[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2
5YZWUGOKaUmKuQM6OqaU4VI6Ls24EoqimOgPUVNA0Kf3/ew65TKTeC5O78zH
udxz7n3e7Xue97vG7JyM8S906dJl6sv0JyNrRmJublb+4Jfon6T8aeOyX6QX
4bQMtPhN/A/s3r17Yj1P/OdpjF9TU4Pa2trngn/lyhWkpaXB6XRiWUkJO9Sp
+JUVFTAZJXR75VXkvJvTqfVoaW7B8DeHIzQ4BFERkTh54mSnYbNVlFfAIpuh
1+pQsnRpp2K3tbVh3Ni3ENw9CGmpg3D79u1Oxf9hxw7Ikgl2qw379u597DM3
btzAzZs3A4I/edLbCAkKxvuz3nvk3oljxzBudCb6REUjvmdvfDL7I+GLUlZd
XS16vmd0DC41XPrXvdrfaxEf0wtSkAp2vQRZrYMxVIOPP5ytCHZ7Wzuys7Kg
VWuwpqzskfuLChdC2y0Y4RYHIm0uuE0WmLUG9IrsgfN1dR3G9e/rAwcOitgz
R49Ba2vrI89NmzqN4lXDZZDhM9tpOeAwmOC12vHb0aMdxmWOzZuRh/i4eESG
R6Dm9OnHPv/V4sXQBYfCR/G7JDN8NifsRhOiwyNxlbjyaYz32N27dx/g94yJ
ETyXOSbziZ+5evUqhqSlQ9s9BLJWD21IqMjX0iVLngqbrb29XSzOQWNjI/qn
pEBF3+d1e4hvSp74uQv1F/AZ9UHWqNEYm5mJjes3PDU2G8fux1+7di3cLhcS
4xNg0OlhNsmYP29eh773v9o/Z4t5hDVz5kw0NDRgBHE+9z/ndeKECSK3hQsK
8enCRZg7Zw6++KwIyxcvRemKb/A5vbe1opK0ovmZfLl165boB7YTx08gOqoH
JIMRGvJDRfoTEhQEdahK+GWmusshGkjBahiCQiGpNCiYNetBLylhO3fuhMfl
hkQ5YB5mHfJf3WYbIqxOuIxmhFnscBEHWImLZhd8oBg+22nag5s2bcLqVauw
ma5lq8vwWmISLDoDYhxewQEeyYIw4gEv+SSptVg0v1BRHx62USNGQk85j5Dt
cOuZg2xwUx4cetIq4iGbUUbuOzlYRvtnxfLlWLduHaqqqnDkyBGcOXPmmXSU
98rQjCGQVVp4tCb4JCvCaMX6ojB+ZCai3T7YDBLxkwqq7sEIJf3SarXQ6XTi
ajQaUVpa2mH8O3fuICM9XdTapTMhnLjXpjEgLTkFf5IOb1y7HhFuLxxmq+DD
cJ8PCQkJ6Nu3L4YNG4aCggKcOnWqw/gtLS1ITU2FhfEp517ZCitpT3JCEq43
XRfP1J09i6Oca5qXL9TXo6mpSeRcibmR8QcMGACz3gg39Z3HZIVNZ0RS71j8
QbwRaGsmjkkhjmZ8L2F7aN/xDBAf0xsNFy8GHJ/zyLVkfNZe1j/u+d40B50/
dy7g+FzL5ORkmEgfeM9zD3AvxvaIEXUPtF27dg39+vUT8Xv+rj/je20O7Nn9
c8DxWR8GUf8zvpO5j+ov5i/iw/TXB6Lx8uWA+zB9+nToSIe4/9kHL/F/GMWv
p5lszPCRtA+bAopfXl4OifSP+4/z7yGu4fzbJBl6lRqTJ0567NyolJ2lPvOS
Ljo598T9LuIgxnbIFrEM5EPBY84MShnPCemD0mCiHHjtToHJVzv5YDeZ4aR8
SBo9viwqDpgP8+fMFVrrovgtNPu+QZo0sG8KaZ9J5MJFPrBfWyorA4K/tXIL
rDSXMAbjjRg6DFs2lSOxT5zYGy6LDUbyj/Ok5EzkN57zE4jz/XFGuDw4/OtB
bCj7HmEOl6iDmXR4cHpGQPDZ0gcMvK8DVHvuhfWEzT5E+yIEPu+F/Ly8gGAf
OXxY6LyV6i20kM5e1VU/Yc+Pu+/3IuGzT6UrVyqOzfkcm5Ut+IbrLGl0yMud
htbbLdhGfeEw3d+H7Nsv+/crjr99+3aYaQ7mmLnHBg8chLqaM+Le+tVrRD8y
NvdB/fnzimLzbx08fxm0OthpDg+nc9rObdsf3P9uxbeQqR7Mj6kp/XHj+nVF
8VfRHK7R0PlDlsXZZMHceWhrvfOgx78uWQZJb6Dzmw65U6Yois3an5SUJGZY
nmWzs7OFHrP5Z7vi4mKo1Wq6r0FhobLngJKSEhE7z9JxcXE4fvy4eJ81medy
tqKiIoHPPu7atUtR/Pz8fHTt2hVRUVHYvHmzyDkv/28InIN9+/YhNjYWE+jM
2vyM59GH7dChQ8jNzUUlcTpjsQ5x3DwT85XPBvyaz8+B1F82xvfHzNj+/nva
Gf8vLb2dJQ==
                    "], "Byte", ColorSpace -> "RGB", 
                    Interleaving -> True]}, VertexSize -> {0.75}, VertexStyle -> {
                    GrayLevel[1]}}]], Typeset`boxes, Typeset`boxes$s2d = 
                    GraphicsGroupBox[{{
                    Directive[
                    Opacity[0.7], 
                    Hue[0.6, 0.7, 0.5]], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$2", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$3", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$5", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$6", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$20", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$1", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$3", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$4", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$5", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$8", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$6", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$9", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$18", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$8", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$20", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$9", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$11", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$10", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$12", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$11", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$15", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$24", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$12", Automatic, Center], 
                    DynamicLocation["VertexID$34", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$13", Automatic, Center], 
                    DynamicLocation["VertexID$26", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$15", Automatic, Center], 
                    DynamicLocation["VertexID$16", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$16", Automatic, Center], 
                    DynamicLocation["VertexID$17", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False], 
                    StyleBox[
                    LineBox[{
                    DynamicLocation["VertexID$17", Automatic, Center], 
                    DynamicLocation["VertexID$19", Automatic, Center]}], 
                    GrayLevel[0], StripOnInput -> False]}, {
                    Directive[
                    Hue[0.6, 0.2, 0.8], 
                    EdgeForm[
                    Directive[
                    GrayLevel[0], 
                    Opacity[0.7]]]], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.18374951781657095`, 
                    0.9829730996839019}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$1"], 
                    StyleBox["\"larceny/theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["larceny/theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$1"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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                    "], {{0, 50}, {62, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {62, 50}, 
                    PlotRange -> {{0, 62}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871535, 
                    0.9324722294043561}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$2"], 
                    StyleBox["\"fraud\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["fraud", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$2"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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                    "], {{0, 50}, {32, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {32, 50}, 
                    PlotRange -> {{0, 32}, {0, 50}}], 
                    TraditionalForm]], {-0.5264321628773564, 
                    0.8502171357296145}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$3"], 
                    StyleBox["\"vandalism\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vandalism", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$3"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
                    "], {{0, 43}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 43}, 
                    PlotRange -> {{0, 50}, {0, 43}}], 
                    TraditionalForm]], {-0.6736956436465577, 
                    0.7390089172206596}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$4"], 
                    StyleBox["\"weapon laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["weapon laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$4"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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                    "], {{0, 50}, {44, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {44, 50}, 
                    PlotRange -> {{0, 44}, {0, 50}}], 
                    TraditionalForm]], {-0.7980172272802399, 
                    0.6026346363792572}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$5"], 
                    StyleBox["\"burglary\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["burglary", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$5"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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                    "], {{0, 50}, {73, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {73, 50}, 
                    PlotRange -> {{0, 73}, {0, 50}}], 
                    TraditionalForm]], {-0.8951632913550626, 
                    0.4457383557765388}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$6"], 
                    StyleBox["\"vehicle theft\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["vehicle theft", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$6"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9618256431728193, 
                    0.27366299007208394`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$7"], 
                    StyleBox["\"trespass\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["trespass", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$7"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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                    "], {{0, 50}, {50, 
                    0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950346, 
                    0.09226835946330274}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$8"], 
                    StyleBox["\"non-criminal\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["non-criminal", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$8"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond
SKeaxixLbEKyOccOejpnDuqok2Oooeh4qTG8JNgoiho1oMAGfFrrpb0ThG1N
3/ZXa3jZ8H3f7Pf5nrXWs9Z6tfM8mQvuGjNmTNE99Cszr3RiYWFe+fR/0D8p
5cXz591Nf0TT0tHii5DJbty44V+jXQ+05LT+gYE7iqOvrw/b/l+PipJSFBV4
sP6Dj/DDyVPi3gBhGW5yvy9bV1cXXl66DFaDEdoIJTSKSBiUGsyemY0TJ04I
HMOxBANH7YZaqBQRMOslWCUjnGYr7HojwkNC4fF4BM6RfCOn9fb2Iic7B0rC
YZEMsBlMsBEWh2SCiXDFJyTgyJEjsu45knV0dODhSZNh1Olh1Or8fFh1Bug1
OiQmJqKhoUE829/fHzQczMeCZ+ZDE6mC3WSGRT/IidNghk6lQUpKCpqbm8Wz
wYiJm23b1m2IsjtgUGth1klwGAmPVhI4Kisr0dPTM2LOyG38nuvXrcP4B5Jh
JwxmrR6xdicqXixDS0uLeIbz+k5Z69mz+PzTDahZtx6Nexrw89UOcZ3jwueT
QL7p7OzErl27cPny5T+9N/PdsGcPtpKGHaO8uND6I7p/6Rxyn3HwYk4GftPX
4bp5/vx5lJaWIisrCxcvXvxTGI4fPYYlpJ0xTpfwR3JcAjLTnsDcWTmoWvEa
vjt2HDcGaC/Wsf4BeL3e3/emnz5vH/r7BnNo7dq1kCQJxcXFfzivfmw9h1Vv
VmF8YpLQTs5V1gwj5amF4pSv6ZRqLKQ8unypXWBhHDcbX+vt7hFY2s5fwKyZ
s0SO79ix47b7eylHv/z3ZjwyMRUmikXe30q6yVwwDr7GuSJilfDYzBa8+fob
4p37vUPjVPDT64W3pxcfrvkATqcT5eXlOH36dEAM7PtncucKvTaotNCRXvD7
i/1YQ2nZf/sUGKnWsLa5XVHYUrdZ+GGQCAg/iUVYDh04KHQwPT0dO3fuxLVr
10bF0H7xEqakTIImLAIuo0VgSIpPxIK8pzEh6UE4TBahX8wP/82LObEaCRPh
SZ2YQu9x1I+jj3hgPtg3e79uQHFhEVatXIlz584F5GLLF3XEgQZO+n6rRo+y
ohKcoprOvk+b9DDU4RF+LOIZ4S8DTFRvJOLETHhm5+SitmYDGvd/g7YLbQIP
Y8uelY01768R+cJxPKpRbBcu8kAiHHriYXnFMv+tpoMH4TLbxL4ui23QN8SX
kXS1uGAxPPmLoOeaQ3GiVWsEN+OSH0RmegYqysqR91QeIqk+LlzwbEAe2M6c
Oo0JpJMG+p4Ym1Nolc/27N4tYoFjhLmIIiwcI8zFPuL7ypUryJiWjvvuHQuN
Sg21UgVVpBLhoWFQRlBOabQCR25Ozm319ot//ov2oFwk7l9Z+tKQe9vqt9L1
yMHYoPh1+n1jxeFDh8Uz3x4/jsWexVg4/1lkPzkTWTOykEEx+diURxEfF4eE
uHgULSkMiGOA9KSspATK0HAkRsei5SYu2N57+12/fvDe/MkxHOdy4xLF9mjG
cXCFtPvkyeaA2unT2pazLZhA/lSE3I/XKlfc8ty8OXOgoz6Qex4b9RvsE/bR
xORx6OrsGvX7/6j5dHXTpk1Qq9VwR7lx5syZIc9wnch8/AmYqA+N0pvg0BEn
9Ml5NZ1igvsSuay6uhohISGoqqq65V7HTz8N6irhcEtmRNGyqnXQKZQopHiQ
01hXamtrcf369VvunaVYSY6NJxxagcOmJu00WCFFqPDq8kpZcQTE2NqKB2Lj
YCEOoo3Un2spbw0WqCimZ2Rk4noAfZbTWBseIk1nHDEmG6IJA2PhmFWTRry/
evUdweHt82Lao2kwRqrhIu1g39g1EtwWO/XMSsTFxOKor6YE2WZOnyHiNJb4
cBAGzhk78WGh/FWEhSMvL0/WvBnN5s2eCxP1AHEWBxzkE1/eumwOmIxGaDQa
1NTUBB3HMqpVEuWpL2/dFCMOmlv0VDe4tul0OiQlJYlaGkz7vPYzkaccFzGU
M5OTxuPp3Dk0TxpgpNrKnKhUKqovnqDOUDu2b4eW6wvNTC7iIjVpHJoaDyCH
6pme6rPLaqdZUw+J+Pnfl/8NGo6vaNbQU774erFomp24bh1qaqK+xAoT9Y2c
x1wng6lt26nu83mHrz/lfrX5xPfiXi5xog5V0FznQuT9YXh75aqgYLh69Soy
0qYKPkzU+3E/yj0R6yzHwrTH0oTPuJ9lvvbv3Ss7Bu5xSxYXIiIkFFEUAxby
iUTzyjtvrRIYDjcdgpty10o9gEQ40yY/gu4RatRftU/WVYt+x+cLiXq+l8uX
+mf6/2zeImZ/C8co5dPry1fIni/79+2D02IdnJlMg3VtWVnFkF67+qOPoQpT
+M+F9jfI65O2tjakpqSKszCOBzXtVUozxPB+v+C558UsYSau0qekoae7W1Yc
BQUFUFHPbSMM3DcvWVSA3p6h9YN9M5V6YMZhoJhZWlIqK4a6ujqhjQaajVTh
Cnief0Gc8wy3C6ThCe4YkSMJTjcOftMoKw7mIjQ0VMweBS/kj9ijsR1obKR6
a4SeuMicOm1ErH/F6uvrxbkAn3f1Bvju3V/thiI8HPeNHYuNGzfKisFn7e3t
t32G+7T8/HxxtsPnt3/b3xYs+xWA5H/D
                    "], {{0, 50}, {34, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {34, 50}, 
                    PlotRange -> {{0, 34}, {0, 50}}], 
                    TraditionalForm]], {-0.9957341762950345, \
-0.09226835946330117}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$9"], 
                    StyleBox["\"assault\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["assault", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> "VertexLabelID$9"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV
SKlLAtYKjT/sD4mSWKrGGE0Vmxqr+EcTl4D+UHGLxkQtaFHw6z135o0zwwyL
MDyavC+5zJs3d+77ztxzz/nOYcLqfE2e3M7OrkjJ/miyimO12qxNSxzYm7hN
63NX27OLWDZmskE3IUGCBAkSJEiQIEGChAFBZ2cn3r9/LzYNCWZ48eIFGi83
4tSpU7h7967YdPoM8qmdu3bC19cXzi4ucHRyhKuHO5akpeH+/fti0+sWxueh
UFsIKkHtFQ5wclZCyYaj0onfC1ar8eDhQxGZ9g7HTxyHncyO83dWuRiGi6uK
v5ItKzLSxabZI3Lz8jhXYxuU+kHXDo4KjPbxxvPnz8WmahUUb+Pi49l+yEzs
MB7kX67ubvj70iWx6XaLVI2my34YDwU7817Dh6H59m2bc+lNDqM5u/fsQUxc
DILUwUhJSUFDQwPKysu7tYP2alpQEN69e2dzOwS0tbXh6NGj2LhxI6bPmMH5
Bk9XQ81GZHQUMjMzWWzSYuWqVfxcE8cffqzANHWQwRbjs6FgZ0PG5tTV1Q2a
DdU11ZgSOIXzoSGTyyGz/zDs5DJ+n/wkYf48FBQWQKFQwP+TCfh+x3YEBQfz
uEXzZA72OrtcnFFVWTUo/J88eYLklGQdd8ZXyZ5NMUZOXIi7flBuIBuEvFBQ
UIDx48fza/8J/ijasB5rvlmLhYsSERsfh5zcHFy9enVQbHj27BnCI8INPkH8
6XrS5Emcz4rMdHy9aiXLy0sQERkB33F+fJ8ms30rKSmBSqXS+Zd+D6cFByEp
eTGSU1MQExuD4uJiXL9+3eZ2kL/rbFBBzvZi2Ijh2F+9H3t/2osUTSpCw+Zi
dugczmn58uXIz8/n+0D8ApitSmdnnDx5ElV7q/h7wR7yL8G33Jk+ycjIwMWL
F21iw6FDtfw5TsyPyJ/8xo3DjRs3cPbsWeY/TgadYfAx/Z6N8R0LlZsrf7+9
bIdhPdKI1b/UYGbILIM9Tkb6hF6TFifh9OnTPO8MBCi3BgYGcn6OjLPXMC9c
YnnqzZs3zB4/bpdJfma2ks6gV4FXYWGhxbXb/23HkbojiEuIN9jPNRf7Ll3T
veiYaPY7HkJHZ0e/7GhsbORrCmtv36H7XbXaIsN9q/mAfZ725dJe5ZyGc+eQ
kprKdaOwJ6SHeVxj7zeXbu6XHffu3cNYprFprcCpU/Hy5Us0NTfDw9ODxyRL
/Gk/aP4MlleePn3ap+dduXIFWVlZcGfr0xoO7Bn0OjcsrN915J07d1D/ez1a
Wlr4ezrDtLagU80HnRU/Pz/cunXro5/Z1NQEbZEW3j4+kLO4t2v37n7ZYI4H
LQ/gM8aHn2lLNpB/y+ztmUY/MSDPo9/u5s2bA7KWMQ4fPmxdI+n9aQPTKkMd
dN6s2eHAtMes2SH459UrsWn2iG3fbbNohxDP1qxdIzbFXuEPlvt4XLRSmzqx
eLlgwQIedyxhKPWu1jOdR9pEacG3hH1Rubri23Xr8NCob0A2DGZt0RM6Ojow
MSCA59vualSyh3J+dU0N2t+28++SLcIYCqBz0F0OEXyNcgnNC4+IMOi/oWID
oba2ltdv3ekSwRbB1/z9/U38bCjg8ePHGOU92mI+pFrKvEcl6C3SfEMN81lc
ksllJmfck+nhhHkJXK+T/hL2Q9BcxZtKxKbdBVVVVSa5RKhzLzON/NeFC7yn
ZrxfpF0joiLFpm0A1TakG2fPmdPFr8guisuEFenpJnZSfKM69/Xr16Lypzru
wIEDCA0NNfQazOMV3V+YmMjn76+uNrGDzgzNF6tf+OjRI5SVl2HipAB9TW09
TtHn2Tk5/Hv19fX8/CjNPv+N3R9MNLN6ifpsVGcLdaY1/rxvxeao1WpeexHo
/zPeZhqf5pRu2TIo/KlPlZ2dDQ8vT10PgfEQYk4XDaKvO8nvqV9o3CunfBf4
2VSTGp7mx8+fZ3MbWltbeUwx1MiWNJRRH2pueBgO/noQr6xo9bSlaZy7cW6Z
FRLCtY0tQf1VocfD87GLkWZy1mkmB6Y1SNOeYDVfTxqjsrLS5KzTb0O1/bVr
12xqx7Fjx7r0QRT6Wt/N3Q3LvlqG83+e7/V6lvQLrXXmzBkbWgEe2yOjoj70
+9gYOWok7y18TN+SehQjRo4w6a3QmhUVFTZgbwrq5RJvjUaDrVu39uv/wu1v
3+LTgIkmGp/OyxeLkwaQse1Bpyfx80WmZ53tR1R0lNjU+ox9P+/T99QUhrNW
uqVUbFp9RmtbK3LzcuHp5cVihTvPTRTf/6+gHinlWAkSJEj4WPwHdl1UPw==

                    "], {{0, 65}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 65}, 
                    PlotRange -> {{0, 50}, {0, 65}}], 
                    TraditionalForm]], {-0.9618256431728189, \
-0.273662990072082}, Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$10"], 
                    StyleBox["\"suspicious occ\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suspicious occ", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$10"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
                    "], {{0, 50}, {42, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {42, 50}, 
                    PlotRange -> {{0, 42}, {0, 50}}], 
                    TraditionalForm]], {-0.895163291355062, \
-0.44573835577653775`}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$11"], 
                    StyleBox["\"missing person\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["missing person", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$11"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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                    "], {{0, 56}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 56}, 
                    PlotRange -> {{0, 50}, {0, 56}}], 
                    TraditionalForm]], {-0.7980172272802392, \
-0.6026346363792555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$12"], 
                    StyleBox["\"other offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["other offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$12"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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                    "], {{0, 
                    50}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], 
                    TraditionalForm]], {-0.6736956436465569, \
-0.7390089172206586}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$13"], 
                    StyleBox["\"sex offenses, forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$13"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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                    
                    "], {{0, 85}, {87, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {87, 85}, 
                    PlotRange -> {{0, 87}, {0, 85}}], 
                    TraditionalForm]], {-0.5264321628773554, \
-0.8502171357296134}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$14"], 
                    StyleBox["\"drunkenness\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drunkenness", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$14"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

                    "], {{0, 50}, {45, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {45, 50}, 
                    PlotRange -> {{0, 45}, {0, 50}}], 
                    TraditionalForm]], {-0.3612416661871522, \
-0.9324722294043555}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$15"], 
                    StyleBox["\"drug/narcotic\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["drug/narcotic", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$15"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
                    "], {{0, 47}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 47}, 
                    PlotRange -> {{0, 50}, {0, 47}}], 
                    TraditionalForm]], {-0.18374951781656965`, \
-0.9829730996839017}, Automatic, {0.13840253919495257`, 
                    0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$16"], 
                    StyleBox["\"warrants\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["warrants", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$16"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m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                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    6.049014748177263*^-16, -1.}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$17"], 
                    StyleBox["\"forgery/counterfeiting\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["forgery/counterfeiting", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$17"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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                    "], {{0, 50}, {60, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {60, 50}, 
                    PlotRange -> {{0, 60}, {0, 50}}], TraditionalForm]], {
                    0.18374951781657084`, -0.9829730996839019}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$18"], 
                    StyleBox["\"arson\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["arson", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$18"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.36124166618715337`, -0.9324722294043563}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$19"], 
                    StyleBox["\"robbery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["robbery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$19"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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                    "], {{0, 
                    50}, {67, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {67, 50}, 
                    PlotRange -> {{0, 67}, {0, 50}}], TraditionalForm]], {
                    0.5264321628773566, -0.8502171357296147}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$20"], 
                    StyleBox["\"driving under the influence\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["driving under the influence", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$20"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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                    "], {{0, 50}, {71, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {71, 50}, 
                    PlotRange -> {{0, 71}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465575, -0.7390089172206594}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$21"], 
                    StyleBox["\"family offenses\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["family offenses", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$21"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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                    
                    "], {{0, 50}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.79801722728024, -0.6026346363792572}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$22"], 
                    StyleBox["\"disorderly conduct\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["disorderly conduct", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$22"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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                    "], {{0, 
                    60}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 60}, 
                    PlotRange -> {{0, 50}, {0, 60}}], TraditionalForm]], {
                    0.8951632913550625, -0.44573835577653886`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$23"], 
                    StyleBox["\"embezzlement\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["embezzlement", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$23"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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                    
                    "], {{0, 50}, {46, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {46, 50}, 
                    PlotRange -> {{0, 46}, {0, 50}}], TraditionalForm]], {
                    0.9618256431728193, -0.27366299007208317`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$24"], 
                    StyleBox["\"liquor laws\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["liquor laws", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$24"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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                    
                    "], {{0, 50}, {55, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {55, 50}, 
                    PlotRange -> {{0, 55}, {0, 50}}], TraditionalForm]], {
                    0.9957341762950346, -0.09226835946330286}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$25"], 
                    StyleBox["\"prostitution\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["prostitution", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$25"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY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                    "], {{0, 53}, {50, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.9957341762950345, 0.09226835946330149}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$26"], 
                    StyleBox["\"kidnapping\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["kidnapping", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$26"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa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                    "], {{0, 50}, {50, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.961825643172819, 0.2736629900720819}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$27"], 
                    StyleBox["\"runaway\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["runaway", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$27"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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                    "], {{0, 50}, {50, 0}}, {0, 255}, 
                    ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.8951632913550622, 0.44573835577653764`}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$28"], 
                    StyleBox["\"loitering\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["loitering", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$28"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa
RFEQolFB1EkbNWhBrSEqyKJjbU21LnHHFdzFuOP66zmX9whGhffQ5KUzOTOX
7/HxvXvPfn7nfCiGTew76lctWrSY8jv60TdheqfJkxOSon5Dv/wpaerIYb+m
D37WxTfxC/2odPXKFWwuLET6x59gafZi7N+3z9ksOUznzpzFgJg4uLZsBZ1C
BYWbJ3RKFT7NzsazZ8+czZ5d9OTJE4wYmgCFpxRmrR5etAwKNcmhhkIuR3Fx
sbNZtIsqT1UiuG0A1HIFjCoNvHUGeGl08DGY4ObmhuTkZGezaBf9c/dumPUG
mIl/tVQOC/FvVuugJ5mkEimGDx/ubBbtonPnziGI7KEhewgZhF+pYCSbeLh7
YOrUqc5m0W6aNnkKJG7u5FNGGNVamMgeKokMJpMJ5eXlzmbPbqquqkL8gEFQ
eEigpHjXSuTw0huRszzH2aw5TA/u38fWoiKkpc7C4sxFOHjgoLNZcpju3b2H
ypOncPTbb7Fv717s3/sN3bvrbLYcpo/S5sCHYsOiNcJfb4beU47ZySnOZssh
unvnDsI7d4XExRUmpQa+GiP0FB/t/QNwhOzz/0KHKA6CfP1FzTBSHfdW6WDR
GCBp7Yq8vDxns2c3FeSvF5iKa7i3Ri9ksKj1kLt5IPXPqc5mz27KmJcOmau7
wFR+FBv+OhN8yCZamRKjR47G02dPnc1ik1RbW4uxw0eKmtfW5I0gb19hD/Yt
L60B0VFR4pmfO104dx7t2wZCK1ci2OKPbh06wY/sYZKrBWaMeCcCDx48cDab
TdKhAwdgorhgTGXRmxAf0x/tffxFfOhItujoaDx+/PhH5eHp09f32/y166CR
KaCnXsOLYnxcwgiEdwwT8aEh7BsSEoLLly+/AW5fpELqPYcNG4a4uDgUFBS8
ljzJSTMFpmK/8iabDI6OxfiEkTDJVNBT3EulUiQkJODSpUtvUAIgNycHKoUS
Ek9PyGUysZYvW96sva5du4awjqHkPyrhW4zVe4V1xcoly9C5XQhhXm39WTH9
YnDh/IU3IsP169fxdnA7qGVy6NQaGLWEralnCA4IRGVlpcP7rcxdATnZgnG6
gWKal5l8a/K497A0MwsTRo+Fxegl+l0p9SFRfSJx9vSZ15bj+NFjCLT4iX7H
hzA1n6tXqaFVKlFRUeHQXjdIJ106doKa8q3oyakX5L1YJi3Fy6ihw7Dxy/VY
nJ6Bzh3IZmQXGcnSp1eEmKu8Dl27ehV/DAoW/szn+nv5iPj08/bB0SNHHNor
LycXcnfP72Ugn/I1eZGOlHWy0LV7aBgKvliHff/6N5KmJcKbel/u47mff11a
OG++yC/MA58lc/XA3DlzHJrN3Ll9Gz06dxEyCDxCV+ad5wp8tRjNdfmL7gf7
+CH3s6Xie5yj/0N4/k3NgVavWIm4vtGI6NETn2V/irsO9gmFGwoEnza9ixkJ
+amYk1iXiWTQK1UC/7I8i9IXOsznferLqi5cELJvK9qKVbl5mPthGmZ9kIJN
hRtxs6YGtQ9qm6WX22SL6IjI+prBuhd8W2shX7mv5Xssn4X7dc4B9Oyc1NmE
8e3T2RHy8/DwcPhbfCmO63QmI9zJtZVjkucyHdu9jcT3p+BM5WmH5Vj/Zb6I
WTPxyzyz3k3a72VouLgusj3Y3zgHS9q4IXHKVNy/d69JXcXExKB169aQengK
GWy53ct2Dl21Vpk6BLdHwfoNdstQW/tQ5E7+Puc6MRexyvFDGXgJf6OexJds
xvMT/g7nyoT4oY3W+LS0NLi6ukJNdhj/7jjkr1mLQTFxwsZ8trA1nS3O1+hE
frQYTVSTk+zCDtu3b4dcUlcvOBbYrzjOOTZeZg+uJX4Gs7AF+0Zbb4uoWS5v
tUL8kPiXnsEzVLVaDblcjqQZSbhntd3Ed8fX+6uYj5FOeD8tnc+ftZzXPSXo
2bMntm7b1qgc6enpUNPzSrKlluxs08erlq0/ZB9kWdmn1aQ7s8FI9b3fC/tX
VVUhNDQUHh4eSExMrMfJlwnTdAhqJ+zLcnBuN1tzJOuxe1gX4VsSqk8e5Idq
jUbMYnm/lxHnD+63szMWIbp3H8Er+6dKIhW2MahI7w1quzhXpRWxyTHKNXjS
exOws7yiXs8NKTU1FS1btkRKSgruUM9vo6+3fCX8Uvgq+wLnRuvifLO5oBCn
Tp7E+xMmQsl2kcrg4e6OAKpVa9asEXP0V9FD6o3KS0uRmpyCHl26Cr5ZN3pr
HjaRHbif4t6qW6cwzJv7MY4ebnzmsGTJEmRlZeHhw4fP3U+eMVPEOeuqof9y
DeT5Rs2NmvpnS0pKRPxZvLwhI/2yr0X3jRLycP+QtTADkydOwo7ikhfOZ/xX
UV6OirJylG4vRnnJDuyu2IkD+/bjyKHDuHHteqP8N0Y3a24iont4fZ6vs7um
Lr5JZ2OoF7313XcoLd6BXXSmjQ4fOoSszEXoTX1cm1YudO0t+tIAH1/wK72F
89OfO6e6qhrTKJcuX7qMcGMuThCGY9pVWobVOSuQR1i6gj43l0pILwZ1Xf0x
WXMUL84hXLsY48VGRol7PN9fMO95/q4SFltLtsghnM9y8Oy2nX8A1v7ti+ee
20n40t3VDUrySbZzQf4G0c/EvtMHkrdaw5NWv96RzcYimQsWEqb2rMMKVixn
y1c2TKTylMGH8q6cfGhAXP9X7mXjga8N+akhXDBo4CCoCX/oKK9yLTl+rM4e
qTOToeW8JqGeMDBYYG1HiethZERvwbOtltrylA0XMTbluQzjdwXFQ//YOIfO
4Jo8dvQYSEkHOo1W6GIk9Zi22cg/Nm8WedZMZ8ndPB2qtza6WH1R9EYmjbZO
Bmu+Enaw1kTOgzZf05I+B/QfYPf+zCvnKa4lepaB9BAa0gEnjh+vf+bSxYui
HzBQnpG6ulO++shhOThvjRo+Ah4ubYRNRL21ymLDIymUy6LJb/nvXD8GDRho
9/48k2bZjSSDguwQ0q49viFM2pA4Z0dSrtCRzRXu5Lf9YvGsGXMArguDY/vT
HoSzVHW2YB8bMSRB9AFMq7gvJRnYrwaTn9tDnJPYF9UUW6wb9s/ibdtf+uwn
ZAPu2XluwjXwYnW1w3IwsQ9PmTBJ+Jc/2Zht8ZfZH9b//fNVq4UPq6hfjx80
uMn9CgsKRA70otpqJt0YCctuWJf/yue3Fn0t5DBZa/ymvxfazTv3RLt27ULR
V0UoKylFZvoCkS8ZY9lw75rP/1p/jp/ZW8gxdMiQRvc9QDYMopjjesSzQoNU
iSWLshv9Dr/X4XcHjEu47/0gcbpdMty6dQvx8fHQEE4y6ev6mIa13Gitg4yj
y6k2cb8u8JWbu6jljVFmRgbcWreBnuyhoF54wUfzGsUtTJyjR9C+PC+R0RlD
yHftqSNXrlxBYGAgXFxcyOdl0JPutNYrz/N9tAax3Fu2QnLiDPGdqJ4R+MNv
f49ZqbMa3XvTxo31+Gs2PduUDDZaQBjZhXABv0fv3rXbS/HhD4nr6J49ezB/
/nyMGzMWA6Nj0KtLN4QEBCOAsHpb8iH2aX5Pwe8smLaRb3EOPd1Eb/jo0SOU
Ei7csmULHtspA9MxqosdOnYUWHz69OnNml0y9r1OGO3C+fM4cew4Duz/L4q3
bsPhgwd/0v9dOXv2LMrKykR9/oV+vvQ/oI9Lbg==
                    "], {{0, 50}, {
                    50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 50}, 
                    PlotRange -> {{0, 50}, {0, 50}}], TraditionalForm]], {
                    0.798017227280239, 0.6026346363792562}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$29"], 
                    StyleBox["\"sex offenses, non forcible\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["sex offenses, non forcible", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$29"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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                    "], {{0, 50}, {54, 0}}, {
                    0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {54, 50}, 
                    PlotRange -> {{0, 54}, {0, 50}}], TraditionalForm]], {
                    0.6736956436465571, 0.7390089172206585}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$30"], 
                    StyleBox["\"suicide\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["suicide", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$30"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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                    "], {{0, 60}, {74, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {74, 60}, 
                    PlotRange -> {{0, 74}, {0, 60}}], TraditionalForm]], {
                    0.5264321628773554, 0.8502171357296139}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$31"], 
                    StyleBox["\"stolen property\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["stolen property", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$31"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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                    "], {{0, 53}, {50, 0}}, {0, 255},
                     ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 53}, 
                    PlotRange -> {{0, 50}, {0, 53}}], TraditionalForm]], {
                    0.361241666187153, 0.9324722294043555}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$32"], 
                    StyleBox["\"bad checks\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bad checks", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$32"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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                    "], {{0, 50}, {35, 0}}, {0, 
                    255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {35, 50}, 
                    PlotRange -> {{0, 35}, {0, 50}}], TraditionalForm]], {
                    0.18374951781656998`, 0.9829730996839017}, Automatic, {
                    0.13840253919495257`, 0.13840253919495257`}], 
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$33"], 
                    StyleBox["\"extortion\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["extortion", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$33"], 
                    TagBox[
                    TagBox[
                    TooltipBox[
                    TagBox[
                    StyleBox[
                    InsetBox[
                    BoxData[
                    FormBox[
                    GraphicsBox[
                    TagBox[
                    RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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                    "], {{0, 
                    64}, {50, 0}}, {0, 255}, ColorFunction -> RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], BaseStyle -> "ImageGraphics", 
                    ImageSizeRaw -> {50, 64}, 
                    PlotRange -> {{0, 50}, {0, 64}}], 
                    TraditionalForm]], {-7.044813998280222*^-16, 1.}, 
                    Automatic, {0.13840253919495257`, 0.13840253919495257`}], 
                    
                    GrayLevel[1], StripOnInput -> False], "DynamicName", 
                    BoxID -> "VertexID$34"], 
                    StyleBox["\"bribery\"", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"], 
                    StripOnInput -> False], LabelStyle -> "TextStyling"], 
                    Annotation[#, 
                    Style["bribery", 
                    Directive[
                    GrayLevel[0], 15, FontFamily -> "Helvetica"]], 
                    "Tooltip"]& ], "DynamicName", BoxID -> 
                    "VertexLabelID$34"]}}], $CellContext`flag}, 
                    TagBox[
                    DynamicBox[GraphComputation`NetworkGraphicsBox[
                    3, Typeset`graph, Typeset`boxes, $CellContext`flag], {
                    CachedValue :> Typeset`boxes, SingleEvaluation -> True, 
                    SynchronousUpdating -> False, 
                    TrackedSymbols :> {$CellContext`flag}},
                    
                    ImageSizeCache->{{1.534948317558129, 
                    638.282525841221}, {-321.77852584122104`, 
                    317.33642151583035`}}],
                    MouseAppearanceTag["NetworkGraphics"]],
                    AllowKernelInitialization->False,
                    UnsavedVariables:>{$CellContext`flag}]],
                    
                    DefaultBaseStyle->{
                    "NetworkGraphics", FrontEnd`GraphicsHighlightColor -> 
                    Hue[0.8, 1., 0.6]},
                    FrameTicks->None,
                    ImagePadding->10,
                    ImageSize->640]}
                  },
                  DefaultBaseStyle->"Column",
                  GridBoxAlignment->{"Columns" -> {{Left}}},
                  
                  GridBoxItemSize->{
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                 "Column"]}, Dynamic[$CellContext`i30$$],
                Alignment->Automatic,
                ImageSize->All],
               Identity,
               Editable->True,
               Selectable->True],
              ImageMargins->10],
             Deployed->False,
             StripOnInput->False,
             ScriptLevel->0,
             GraphicsBoxOptions->{PreserveImageOptions->True},
             Graphics3DBoxOptions->{PreserveImageOptions->True}],
            Identity,
            Editable->False,
            Selectable->False],
           Alignment->{Left, Center},
           Background->GrayLevel[1],
           Frame->1,
           FrameStyle->GrayLevel[0, 0.2],
           ItemSize->Automatic,
           StripOnInput->False]}
        },
        AutoDelete->False,
        GridBoxAlignment->{
         "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Top}}, 
          "RowsIndexed" -> {}},
        GridBoxDividers->{
         "Columns" -> {{False}}, "ColumnsIndexed" -> {}, "Rows" -> {{False}}, 
          "RowsIndexed" -> {}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {
            Offset[0.7], {
             Offset[0.5599999999999999]}, 
            Offset[0.7]}, "ColumnsIndexed" -> {}, "Rows" -> {
            Offset[0.4], {
             Offset[0.8]}, 
            Offset[0.4]}, "RowsIndexed" -> {}}], If[
        CurrentValue["SelectionOver"], 
        Manipulate`Dump`ReadControllerState[
         Map[Manipulate`Dump`updateOneVar[#, 
           CurrentValue["PreviousFormatTime"], 
           CurrentValue["CurrentFormatTime"]]& , {
           
           Manipulate`Dump`controllerLink[{$CellContext`i30$$, \
$CellContext`i30$126609$$}, "X1", 
            If["DefaultAbsolute", True, "JB1"], False, {1, 9, 1}, 9, 1.]}], 
         CurrentValue[{
          "ControllerData", {
           "Gamepad", "Joystick", "Multi-Axis Controller"}}], {}]],
       ImageSizeCache->{673., {357.875, 363.625}}],
      DefaultBaseStyle->{},
      FrameMargins->{{5, 5}, {5, 5}}],
     BaselinePosition->Automatic,
     ImageMargins->0],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    SynchronousInitialization->True,
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "ListAnimate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{{3.608245552905201*^9, 3.608245590340119*^9}, {
   3.6082460674132977`*^9, 3.608246094537565*^9}, 3.608246186948132*^9, 
   3.608246288978195*^9, 3.6082463620466223`*^9, 3.608246439489798*^9, 
   3.608246481886829*^9, 3.60824652663566*^9, {3.6082466772470016`*^9, 
   3.608246703060926*^9}, 3.608246736532778*^9, {3.6082471418725433`*^9, 
   3.608247154440534*^9}, 3.6082472428447533`*^9, {3.608247390311503*^9, 
   3.608247403310029*^9}, 3.6082475068324003`*^9, {3.608247576753902*^9, 
   3.608247584680422*^9}, 3.608247833857395*^9, {3.608247882239766*^9, 
   3.608247909060948*^9}, {3.608247961668952*^9, 3.608247982861075*^9}, {
   3.608248019664672*^9, 3.608248035719604*^9}, 3.608248445099711*^9, {
   3.6082484992*^9, 3.608248517240992*^9}, 3.608248597322381*^9, 
   3.608248648739973*^9, 3.60824868015912*^9, 3.608249946419271*^9, 
   3.608250914117951*^9, 3.6082565234414597`*^9, 3.6082567149567842`*^9, 
   3.608256910299217*^9, 3.608289537306775*^9, 3.608305627864809*^9, 
   3.6083168814335747`*^9, 3.6083171498625727`*^9, 3.608323314165595*^9, 
   3.6083259290097857`*^9, 3.60838065114904*^9, 3.60840451335*^9, {
   3.608405592581514*^9, 3.608405603340172*^9}}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"topology", " ", "analysis"}], "*)"}], "\[IndentingNewLine]", 
  RowBox[{"(*", 
   RowBox[{"compute", " ", "degree", " ", "distribution"}], "*)"}], 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{
    RowBox[{"degrees", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"VertexDegree", "[", 
        RowBox[{"g", "[", "k", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"emdist", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"EmpiricalDistribution", "[", 
        RowBox[{
        "degrees", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"degreeDistribution", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"1", "-", 
          RowBox[{"CDF", "[", 
           RowBox[{
            RowBox[{
            "emdist", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
            ",", "x"}], "]"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"x", ",", 
         RowBox[{"DistributionDomain", "[", 
          RowBox[{
          "emdist", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
          "]"}]}], "}"}]}], "]"}]}], ";"}], "\[IndentingNewLine]", 
   "\[IndentingNewLine]", 
   RowBox[{"(*", 
    RowBox[{"compute", " ", "clustering"}], "*)"}], "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"degreeList", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"Union", "[", 
        RowBox[{
        "degrees", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}], 
        "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], ";"}], 
   "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"clusteringCoefficients", "=", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"LocalClusteringCoefficient", "[", 
        RowBox[{"g", "[", "k", "]"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{
    RowBox[{"clusteringDistribution", " ", "=", " ", 
     RowBox[{"Table", "[", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{"Mean", "[", 
          RowBox[{"Pick", "[", 
           RowBox[{
            RowBox[{
            "clusteringCoefficients", "\[LeftDoubleBracket]", "k", 
             "\[RightDoubleBracket]"}], ",", 
            RowBox[{
            "degrees", "\[LeftDoubleBracket]", "k", "\[RightDoubleBracket]"}],
             ",", "d"}], "]"}], "]"}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"k", ",", "1", ",", "T"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"d", ",", 
         RowBox[{
         "degreeList", "\[LeftDoubleBracket]", "k", 
          "\[RightDoubleBracket]"}]}], "}"}]}], "]"}]}], ";"}], "\n", 
   RowBox[{"Row", "[", 
    RowBox[{"{", "\[IndentingNewLine]", 
     RowBox[{
      RowBox[{"ListLogLogPlot", "[", 
       RowBox[{"degreeDistribution", ",", 
        RowBox[{"Joined", "\[Rule]", "True"}], " ", ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", " ", "350"}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<degree \!\(\*
StyleBox[\"k\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<P[K>k]\>\""}], "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Bold", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", " ", 
           RowBox[{"FontSize", "\[Rule]", " ", "15"}]}], "]"}]}], ",", " ", 
        RowBox[{"Frame", "\[Rule]", " ", "True"}]}], "]"}], ",", ",", ",", 
      ",", " ", ",", "\[IndentingNewLine]", 
      RowBox[{"ListLogLogPlot", "[", 
       RowBox[{"clusteringDistribution", ",", " ", 
        RowBox[{"Joined", "\[Rule]", " ", "True"}], ",", " ", 
        RowBox[{"ImageSize", "\[Rule]", " ", "350"}], ",", " ", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Bold", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}], ",", " ", 
           RowBox[{"FontSize", "\[Rule]", " ", "15"}]}], "]"}]}], ",", 
        RowBox[{"FrameLabel", "\[Rule]", 
         RowBox[{"{", 
          RowBox[{"\"\<degree \!\(\*
StyleBox[\"k\",
FontSlant->\"Italic\"]\)\>\"", ",", "\"\<Average local clustering \!\(\*
StyleBox[\"c\",
FontSlant->\"Italic\"]\)(\!\(\*
StyleBox[\"k\",
FontSlant->\"Italic\"]\))\>\""}], "}"}]}], ",", 
        RowBox[{"LabelStyle", "\[Rule]", 
         RowBox[{"Directive", "[", 
          RowBox[{"Bold", ",", 
           RowBox[{"FontFamily", "\[Rule]", "\"\<Helvetica\>\""}]}], "]"}]}], 
        ",", " ", 
        RowBox[{"Frame", "\[Rule]", " ", "True"}]}], "]"}]}], "}"}], "]"}], 
   "\[IndentingNewLine]"}]}]], "Input",
 CellChangeTimes->{{3.6083083609555817`*^9, 3.6083083675966587`*^9}, {
   3.6083084395813227`*^9, 3.6083086599429493`*^9}, {3.608308856686474*^9, 
   3.60830897256131*^9}, 3.608309135466454*^9, {3.608310274979065*^9, 
   3.608310275090004*^9}, {3.608310627916634*^9, 3.608310650191873*^9}, {
   3.608386134693565*^9, 3.6083861370110083`*^9}, {3.6083862756498203`*^9, 
   3.6083863075744658`*^9}, {3.608386355246806*^9, 3.608386355369405*^9}, {
   3.608387008840817*^9, 3.608387154239472*^9}, {3.6083871919461927`*^9, 
   3.6083872953407183`*^9}, {3.608413750669297*^9, 3.6084137791340313`*^9}, {
   3.608413811991806*^9, 3.6084138953181143`*^9}, {3.608414321414588*^9, 
   3.608414326984868*^9}}],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[{{0., -0.6359887667199967}, {
        0.6931471805599453, -0.9614111671546247}, {
        1.3862943611198906`, -1.0414538748281612`}, {
        1.6094379124341003`, -1.2237754316221157`}, {
        1.791759469228055, -1.329135947279942}, {
        1.9459101490553132`, -1.916922612182061}, {
        2.1972245773362196`, -2.4277482359480516`}, {
        2.5649493574615367`, -2.833213344056216}, {
        2.6390573296152584`, -3.5263605246161616`}}]}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{{0., -0.6931471805599453}, {
        0.6931471805599453, -0.8873031950009027}, {
        1.3862943611198906`, -1.128465251817791}, {
        1.6094379124341003`, -1.329135947279942}, {
        1.791759469228055, -1.580450375560848}, {
        1.9459101490553132`, -1.7346010553881064`}, {
        2.0794415416798357`, -2.1400661634962708`}, {
        2.302585092994046, -2.4277482359480516`}, {
        2.3978952727983707`, -3.5263605246161616`}}]}, {
       Hue[0.1421359549995791, 0.6, 0.6], 
       LineBox[{{0., -0.581921545449721}, {
        0.6931471805599453, -0.8873031950009027}, {
        1.0986122886681098`, -1.0414538748281612`}, {
        1.791759469228055, -1.329135947279942}, {
        2.0794415416798357`, -1.580450375560848}, {
        2.1972245773362196`, -1.916922612182061}, {
        2.302585092994046, -2.1400661634962708`}, {
        2.3978952727983707`, -3.5263605246161616`}}]}, {
       Hue[0.37820393249936934`, 0.6, 0.6], 
       LineBox[{{0., -0.6359887667199967}, {
        0.6931471805599453, -0.7537718023763802}, {
        1.0986122886681098`, -0.8873031950009027}, {
        1.3862943611198906`, -0.9614111671546247}, {
        1.6094379124341003`, -1.128465251817791}, {
        1.791759469228055, -1.4469189829363254`}, {
        1.9459101490553132`, -1.580450375560848}, {
        2.0794415416798357`, -1.916922612182061}, {
        2.1972245773362196`, -2.1400661634962708`}, {
        2.302585092994046, -2.4277482359480516`}, {
        2.4849066497880004`, -2.833213344056216}, {
        2.70805020110221, -3.5263605246161616`}}]}, {
       Hue[0.6142719099991583, 0.6, 0.6], 
       LineBox[{{0., -0.7537718023763802}, {
        1.0986122886681098`, -0.8873031950009027}, {
        1.3862943611198906`, -1.0414538748281612`}, {
        1.6094379124341003`, -1.4469189829363254`}, {
        1.9459101490553132`, -1.7346010553881064`}, {
        2.0794415416798357`, -2.1400661634962708`}, {
        2.1972245773362196`, -2.833213344056216}}]}, {
       Hue[0.8503398874989481, 0.6, 0.6], 
       LineBox[{{0., -0.7537718023763802}, {
        0.6931471805599453, -0.9614111671546247}, {
        1.6094379124341003`, -1.0414538748281612`}, {
        1.791759469228055, -1.4469189829363254`}, {
        1.9459101490553132`, -1.580450375560848}, {
        2.0794415416798357`, -1.916922612182061}, {
        2.1972245773362196`, -2.1400661634962708`}, {
        2.302585092994046, -2.4277482359480516`}, {
        2.3978952727983707`, -2.833213344056216}, {
        2.4849066497880004`, -3.5263605246161616`}}]}, {
       Hue[0.08640786499873876, 0.6, 0.6], 
       LineBox[{{0., -0.7537718023763802}, {
        0.6931471805599453, -0.8873031950009027}, {
        1.0986122886681098`, -0.9614111671546247}, {
        1.3862943611198906`, -1.0414538748281612`}, {
        1.6094379124341003`, -1.128465251817791}, {
        1.791759469228055, -1.4469189829363254`}, {
        2.0794415416798357`, -1.580450375560848}, {
        2.1972245773362196`, -2.1400661634962708`}, {
        2.302585092994046, -2.4277482359480516`}, {
        2.3978952727983707`, -2.833213344056216}, {
        2.4849066497880004`, -3.5263605246161616`}}]}, {
       Hue[0.3224758424985268, 0.6, 0.6], 
       LineBox[{{0., -0.7537718023763802}, {
        0.6931471805599453, -0.8183103235139513}, {
        1.0986122886681098`, -0.8873031950009027}, {
        1.3862943611198906`, -1.0414538748281612`}, {
        1.6094379124341003`, -1.128465251817791}, {
        1.791759469228055, -1.2237754316221157`}, {
        1.9459101490553132`, -1.7346010553881064`}, {
        2.0794415416798357`, -1.916922612182061}, {
        2.1972245773362196`, -2.1400661634962708`}, {
        2.302585092994046, -2.4277482359480516`}, {
        2.4849066497880004`, -2.833213344056216}}]}, {
       Hue[0.5585438199983166, 0.6, 0.6], 
       LineBox[{{0., -0.6359887667199967}, {
        0.6931471805599453, -0.8183103235139513}, {
        1.0986122886681098`, -0.9614111671546247}, {
        1.3862943611198906`, -1.128465251817791}, {
        1.6094379124341003`, -1.4469189829363254`}, {
        1.791759469228055, -1.580450375560848}, {
        2.0794415416798357`, -1.916922612182061}, {
        2.302585092994046, -2.4277482359480516`}, {
        2.4849066497880004`, -2.833213344056216}, {
        2.5649493574615367`, -3.5263605246161616`}}]}, {
       Hue[0.7946117974981064, 0.6, 0.6], 
       LineBox[{{0., -0.581921545449721}, {
        0.6931471805599453, -0.8183103235139513}, {
        1.0986122886681098`, -1.0414538748281612`}, {
        1.3862943611198906`, -1.2237754316221157`}, {
        1.6094379124341003`, -1.4469189829363254`}, {
        1.791759469228055, -1.580450375560848}, {
        1.9459101490553132`, -1.7346010553881064`}, {
        2.0794415416798357`, -2.4277482359480516`}, {
        2.302585092994046, -2.833213344056216}, {
        2.6390573296152584`, -3.5263605246161616`}}]}}, {}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesOrigin -> {0., -3.5263605246161616`}, 
    CoordinatesToolOptions :> {"DisplayFunction" -> ({
        Exp[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Exp[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}, Frame -> True, FrameLabel -> {{
       FormBox["\"P[K>k]\"", TraditionalForm], None}, {
       FormBox[
       "\"degree \\!\\(\\*\\nStyleBox[\\\"k\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\"", TraditionalForm], None}}, FrameTicks -> {{{{-4.605170185988092, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-3.912023005428146, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.02\"", 0.02, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-2.995732273553991, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-2.302585092994046, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.20\"", 0.2, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.00\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-3.506557897319982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.6592600369327783`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.2039728043259361`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.35667494393873245`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-4.605170185988092, 
         FormBox["\"\"", TraditionalForm]}, {-3.912023005428146, 
         FormBox["\"\"", TraditionalForm]}, {-2.995732273553991, 
         FormBox["\"\"", TraditionalForm]}, {-2.302585092994046, 
         FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
         FormBox["\"\"", TraditionalForm]}, {0., 
         FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm]}, {-3.506557897319982, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-3.2188758248682006`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.8134107167600364`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.6592600369327783`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.5257286443082556`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.4079456086518722`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.2039728043259361`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.35667494393873245`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}, {{{0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.302585092994046, 
         FormBox[
          TagBox[
           InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.912023005428146, 
         FormBox[
          TagBox[
           InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.995732273553991, 
         FormBox[
          TagBox[
           InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.0986122886681098`, 
         FormBox[
          TagBox[
           InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.4011973816621555`, 
         FormBox[
          TagBox[
           InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.4054651081081644, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.70805020110221, 
         FormBox[
          TagBox[
           InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.9459101490553132`, 
         FormBox[
          TagBox[
           InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {4.248495242049359, 
         FormBox[
          TagBox[
           InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.09531017980432493, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.3978952727983707`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.5649493574615367`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.6390573296152584`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.772588722239781, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.833213344056216, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.8903717578961645`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.9444389791664403`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
         FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
         FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm]}, {3.4011973816621555`, 
         FormBox["\"\"", TraditionalForm]}, {0.4054651081081644, 
         FormBox["\"\"", TraditionalForm]}, {2.70805020110221, 
         FormBox["\"\"", TraditionalForm]}, {1.9459101490553132`, 
         FormBox["\"\"", TraditionalForm]}, {4.248495242049359, 
         FormBox["\"\"", TraditionalForm]}, {0.09531017980432493, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.3978952727983707`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.5649493574615367`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.6390573296152584`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.772588722239781, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.833213344056216, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.8903717578961645`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.9444389791664403`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}}, GridLines -> {None, None}, ImageSize -> 350, 
    LabelStyle -> Directive[Bold, FontFamily -> "Helvetica", FontSize -> 15], 
    Method -> {}, 
    PlotRange -> {{0., 2.70805020110221}, {-3.5263605246161616`, 0}}, 
    PlotRangeClipping -> True, PlotRangePadding -> {
      Scaled[0.02], {
       Scaled[0.02], 
       Scaled[0.02]}}, Ticks -> {{{0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.0\"", 1., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.0\"", 5., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {3.912023005428146, 
        FormBox[
         TagBox[
          InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"2.0\"", 2., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.0986122886681098`, 
        FormBox[
         TagBox[
          InterpretationBox["\"3.0\"", 3., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {3.4011973816621555`, 
        FormBox[
         TagBox[
          InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.4054651081081644, 
        FormBox[
         TagBox[
          InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {2.70805020110221, 
        FormBox[
         TagBox[
          InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.9459101490553132`, 
        FormBox[
         TagBox[
          InterpretationBox["\"7.0\"", 7., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {4.248495242049359, 
        FormBox[
         TagBox[
          InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.09531017980432493, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.1823215567939548, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.26236426446749106`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.336472236621213, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.47000362924573563`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.5306282510621705, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.5877866649021191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6418538861723948, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.3978952727983707`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.4849066497880004`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.5649493574615367`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.6390573296152584`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.772588722239781, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.833213344056216, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.8903717578961645`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.9444389791664403`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{-4.605170185988092, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.01\"", 0.01, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-3.912023005428146, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.02\"", 0.02, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.20\"", 0.2, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"2.00\"", 2., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-3.506557897319982, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-3.2188758248682006`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.8134107167600364`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.6592600369327783`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.5257286443082556`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.4079456086518722`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.2039728043259361`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.35667494393873245`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.0986122886681098`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}],"","","","",GraphicsBox[{{{}, {}, {
       Hue[0.67, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, 0.}, {
        1.3862943611198906`, -0.4054651081081644}, {
        1.6094379124341003`, -0.3566749439387324}, {
        1.791759469228055, -0.5108256237659907}, {
        1.9459101490553132`, -0.3364722366212129}, {
        2.1972245773362196`, -0.6131044728864089}, {
        2.5649493574615367`, -0.8303483020734302}, {
        2.6390573296152584`, -1.1786549963416462`}, {
        2.70805020110221, -1.0986122886681098`}}]}, {
       Hue[0.9060679774997897, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, -0.4054651081081644}, {
        1.3862943611198906`, -0.6931471805599453}, {
        1.6094379124341003`, -0.43078291609245434`}, {
        1.791759469228055, -0.22314355131420976`}, {
        1.9459101490553132`, -0.6466271649250525}, {
        2.0794415416798357`, -0.6580558607486753}, {
        2.302585092994046, -0.7156200364120039}, {
        2.3978952727983707`, -0.7884573603642703}, {
        2.70805020110221, -1.1882244473577968`}}]}, {
       Hue[0.1421359549995791, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, -0.5108256237659907}, {
        1.0986122886681098`, -0.6931471805599453}, {
        1.791759469228055, -0.3726752852851735}, {
        2.0794415416798357`, -0.528844129268669}, {
        2.1972245773362196`, -0.5389965007326869}, {
        2.302585092994046, -0.5485659517488377}, {
        2.3978952727983707`, -0.6173091041684409}, {
        2.833213344056216, -1.2237754316221157`}}]}, {
       Hue[0.37820393249936934`, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, 0.}, {
        1.0986122886681098`, -0.1823215567939546}, {
        1.3862943611198906`, -0.1823215567939546}, {
        1.6094379124341003`, -0.3566749439387324}, {
        1.791759469228055, -0.25131442828090617`}, {
        1.9459101490553132`, -0.27193371548364176`}, {
        2.0794415416798357`, -0.47000362924573563`}, {
        2.1972245773362196`, -0.750305594399894}, {
        2.302585092994046, -0.5877866649021191}, {
        2.4849066497880004`, -0.9707789171582248}, {
        2.70805020110221, -0.990398704027877}, {
        2.833213344056216, -1.2237754316221157`}}]}, {
       Hue[0.6142719099991583, 0.6, 0.6], 
       LineBox[{{1.0986122886681098`, -0.4054651081081644}, {
        1.3862943611198906`, -0.8754687373538999}, {
        1.6094379124341003`, -0.5108256237659907}, {
        1.9459101490553132`, -0.6021754023542185}, {
        2.0794415416798357`, -0.4989911661189878}, {
        2.1972245773362196`, -0.780158557549575}, {
        2.5649493574615367`, -1.0068047394149868`}}]}, {
       Hue[0.8503398874989481, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, 0.}, {1.6094379124341003`, 0.}, {
        1.791759469228055, -0.28768207245178085`}, {
        1.9459101490553132`, -0.5596157879354227}, {
        2.0794415416798357`, -0.38776553100876343`}, {
        2.1972245773362196`, -0.44802472252696035`}, {
        2.302585092994046, -0.4393666597838457}, {
        2.3978952727983707`, -0.48097266061630956`}, {
        2.4849066497880004`, -0.7884573603642703}, {
        2.8903717578961645`, -1.5040773967762742`}}]}, {
       Hue[0.08640786499873876, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, -0.6931471805599453}, {
        1.0986122886681098`, -1.0986122886681098`}, {
        1.3862943611198906`, -1.0986122886681098`}, {
        1.6094379124341003`, -0.3566749439387324}, {
        1.791759469228055, -0.4744579795951159}, {
        2.0794415416798357`, -0.44183275227903923`}, {
        2.1972245773362196`, -0.36464311358790924`}, {
        2.302585092994046, -0.3726752852851735}, {
        2.3978952727983707`, -0.7114963192281419}, {
        2.4849066497880004`, -0.8938178760220965}, {
        2.5649493574615367`, -0.719122666963206}}]}, {
       Hue[0.3224758424985268, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, 0.}, {
        1.0986122886681098`, -1.0986122886681098`}, {
        1.3862943611198906`, -0.4054651081081644}, {1.6094379124341003`, 
        0.}, {1.791759469228055, -0.7621400520468967}, {
        1.9459101490553132`, -0.38776553100876343`}, {
        2.0794415416798357`, -0.5596157879354227}, {
        2.1972245773362196`, -0.6931471805599453}, {
        2.302585092994046, -0.7156200364120039}, {
        2.4849066497880004`, -0.6632942174102642}, {
        2.5649493574615367`, -0.7323678937132266}}]}, {
       Hue[0.5585438199983166, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, 0.}, {1.0986122886681098`, 0.}, {
        1.3862943611198906`, 0.}, {
        1.6094379124341003`, -0.7621400520468967}, {
        1.791759469228055, -0.6286086594223741}, {
        2.0794415416798357`, -0.6241543090729939}, {
        2.302585092994046, -0.8362480242006185}, {
        2.4849066497880004`, -0.9315582040049435}, {
        2.5649493574615367`, -0.9227216222044455}, {
        2.6390573296152584`, -1.143563676530376}}]}, {
       Hue[0.7946117974981064, 0.6, 0.6], 
       LineBox[{{0.6931471805599453, -0.28768207245178085`}, {
        1.0986122886681098`, -0.4054651081081644}, {
        1.3862943611198906`, -0.4054651081081644}, {
        1.6094379124341003`, -0.6931471805599453}, {
        1.791759469228055, -0.4054651081081644}, {
        1.9459101490553132`, -0.4795730802618863}, {
        2.0794415416798357`, -0.6241543090729939}, {
        2.302585092994046, -0.7621400520468967}, {
        2.6390573296152584`, -1.252762968495368}, {
        2.70805020110221, -1.2866645201710494`}}]}}, {}}, AspectRatio -> 
    NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> True, 
    AxesOrigin -> {0.6931471805599453, -1.5040773967762742`}, 
    CoordinatesToolOptions :> {"DisplayFunction" -> ({
        Exp[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Exp[
         Part[#, 1]], 
        Exp[
         Part[#, 2]]}& )}, Frame -> True, FrameLabel -> {{
       FormBox[
       "\"Average local clustering \
\\!\\(\\*\\nStyleBox[\\\"c\\\",\\nFontSlant->\\\"Italic\\\"]\\)(\\!\\(\\*\\\
nStyleBox[\\\"k\\\",\\nFontSlant->\\\"Italic\\\"]\\))\"", TraditionalForm], 
       None}, {
       FormBox[
       "\"degree \\!\\(\\*\\nStyleBox[\\\"k\\\",\\nFontSlant->\\\"Italic\\\"]\
\\)\"", TraditionalForm], None}}, FrameTicks -> {{{{-2.3025850929940455`, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"0.20\"", 0.2, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.00\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-1.203972804325936, 
         FormBox[
          TagBox[
           InterpretationBox[
           "\"0.30\"", 0.30000000000000004`, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.0986122886681098`, 
         FormBox[
          TagBox[
           InterpretationBox["\"3.00\"", 3., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-1.897119984885881, 
         FormBox[
          TagBox[
           InterpretationBox[
           "\"0.15\"", 0.15000000000000002`, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.4054651081081644, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.50\"", 1.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-0.3566749439387323, 
         FormBox[
          TagBox[
           InterpretationBox[
           "\"0.70\"", 0.7000000000000001, AutoDelete -> True], NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.9459101490553132`, 
         FormBox[
          TagBox[
           InterpretationBox["\"7.00\"", 7., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {-2.2072749131897207`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.120263536200091, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.040220828526554, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.9661128563728327`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.8170772772123447`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.7429693050586228`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6739764335716714`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.09531017980432493, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{-2.3025850929940455`, 
         FormBox["\"\"", TraditionalForm]}, {0., 
         FormBox["\"\"", TraditionalForm]}, {-0.6931471805599453, 
         FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm]}, {-1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm]}, {-1.203972804325936, 
         FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm]}, {-1.897119984885881, 
         FormBox["\"\"", TraditionalForm]}, {0.4054651081081644, 
         FormBox["\"\"", TraditionalForm]}, {-0.3566749439387323, 
         FormBox["\"\"", TraditionalForm]}, {1.9459101490553132`, 
         FormBox["\"\"", TraditionalForm]}, {-2.2072749131897207`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.120263536200091, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-2.040220828526554, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.9661128563728327`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.8170772772123447`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.7429693050586228`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-1.6739764335716714`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.916290731874155, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.5108256237659907, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.2231435513142097, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {-0.10536051565782628`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.09531017980432493, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}, {{{0., 
         FormBox[
          TagBox[
           InterpretationBox["\"1.0\"", 1., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.302585092994046, 
         FormBox[
          TagBox[
           InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.6094379124341003`, 
         FormBox[
          TagBox[
           InterpretationBox["\"5.0\"", 5., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.912023005428146, 
         FormBox[
          TagBox[
           InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.6931471805599453, 
         FormBox[
          TagBox[
           InterpretationBox["\"2.0\"", 2., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.995732273553991, 
         FormBox[
          TagBox[
           InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.0986122886681098`, 
         FormBox[
          TagBox[
           InterpretationBox["\"3.0\"", 3., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {3.4011973816621555`, 
         FormBox[
          TagBox[
           InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.4054651081081644, 
         FormBox[
          TagBox[
           InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {2.70805020110221, 
         FormBox[
          TagBox[
           InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {1.9459101490553132`, 
         FormBox[
          TagBox[
           InterpretationBox["\"7.0\"", 7., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {4.248495242049359, 
         FormBox[
          TagBox[
           InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
           NumberForm[#, {
             DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
          TraditionalForm]}, {0.09531017980432493, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.3978952727983707`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.5649493574615367`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.6390573296152584`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.772588722239781, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.833213344056216, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.8903717578961645`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.9444389791664403`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}, {{0., 
         FormBox["\"\"", TraditionalForm]}, {2.302585092994046, 
         FormBox["\"\"", TraditionalForm]}, {1.6094379124341003`, 
         FormBox["\"\"", TraditionalForm]}, {3.912023005428146, 
         FormBox["\"\"", TraditionalForm]}, {0.6931471805599453, 
         FormBox["\"\"", TraditionalForm]}, {2.995732273553991, 
         FormBox["\"\"", TraditionalForm]}, {1.0986122886681098`, 
         FormBox["\"\"", TraditionalForm]}, {3.4011973816621555`, 
         FormBox["\"\"", TraditionalForm]}, {0.4054651081081644, 
         FormBox["\"\"", TraditionalForm]}, {2.70805020110221, 
         FormBox["\"\"", TraditionalForm]}, {1.9459101490553132`, 
         FormBox["\"\"", TraditionalForm]}, {4.248495242049359, 
         FormBox["\"\"", TraditionalForm]}, {0.09531017980432493, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.1823215567939548, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.26236426446749106`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.336472236621213, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.47000362924573563`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5306282510621705, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.5877866649021191, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {0.6418538861723948, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.3862943611198906`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {1.791759469228055, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.0794415416798357`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.1972245773362196`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.3978952727983707`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.4849066497880004`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.5649493574615367`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.6390573296152584`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.772588722239781, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.833213344056216, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.8903717578961645`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {2.9444389791664403`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {3.6888794541139363`, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}, {4.0943445622221, 
         FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
          Thickness[0.001]}}}}}, GridLines -> {None, None}, ImageSize -> 350, 
    LabelStyle -> Directive[Bold, FontFamily -> "Helvetica", FontSize -> 15], 
    Method -> {}, 
    PlotRange -> {{0.6931471805599453, 
     2.8903717578961645`}, {-1.5040773967762742`, 0.}}, PlotRangeClipping -> 
    True, PlotRangePadding -> {
      Scaled[0.02], {
       Scaled[0.02], 
       Scaled[0.02]}}, Ticks -> {{{0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.0\"", 1., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {2.302585092994046, 
        FormBox[
         TagBox[
          InterpretationBox["\"10.0\"", 10., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.0\"", 5., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {3.912023005428146, 
        FormBox[
         TagBox[
          InterpretationBox["\"50.0\"", 50., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"2.0\"", 2., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {2.995732273553991, 
        FormBox[
         TagBox[
          InterpretationBox["\"20.0\"", 20., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.0986122886681098`, 
        FormBox[
         TagBox[
          InterpretationBox["\"3.0\"", 3., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {3.4011973816621555`, 
        FormBox[
         TagBox[
          InterpretationBox["\"30.0\"", 30., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.4054651081081644, 
        FormBox[
         TagBox[
          InterpretationBox["\"1.5\"", 1.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {2.70805020110221, 
        FormBox[
         TagBox[
          InterpretationBox["\"15.0\"", 15., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.9459101490553132`, 
        FormBox[
         TagBox[
          InterpretationBox["\"7.0\"", 7., AutoDelete -> True], NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {4.248495242049359, 
        FormBox[
         TagBox[
          InterpretationBox["\"70.0\"", 70., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 1}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.09531017980432493, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.1823215567939548, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.26236426446749106`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.336472236621213, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.47000362924573563`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.5306282510621705, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.5877866649021191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6418538861723948, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.0794415416798357`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.1972245773362196`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.3978952727983707`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.4849066497880004`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.5649493574615367`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.6390573296152584`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.772588722239781, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.833213344056216, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.8903717578961645`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {2.9444389791664403`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {3.6888794541139363`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {4.0943445622221, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}, {{-2.3025850929940455`, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0., 
        FormBox[
         TagBox[
          InterpretationBox["\"1.00\"", 1., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"5.00\"", 5., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-1.6094379124341003`, 
        FormBox[
         TagBox[
          InterpretationBox["\"0.20\"", 0.2, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.6931471805599453, 
        FormBox[
         TagBox[
          InterpretationBox["\"2.00\"", 2., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-1.203972804325936, 
        FormBox[
         TagBox[
          InterpretationBox[
          "\"0.30\"", 0.30000000000000004`, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.0986122886681098`, 
        FormBox[
         TagBox[
          InterpretationBox["\"3.00\"", 3., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-1.897119984885881, 
        FormBox[
         TagBox[
          InterpretationBox[
          "\"0.15\"", 0.15000000000000002`, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {0.4054651081081644, 
        FormBox[
         TagBox[
          InterpretationBox["\"1.50\"", 1.5, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-0.3566749439387323, 
        FormBox[
         TagBox[
          InterpretationBox[
          "\"0.70\"", 0.7000000000000001, AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {1.9459101490553132`, 
        FormBox[
         TagBox[
          InterpretationBox["\"7.00\"", 7., AutoDelete -> True], 
          NumberForm[#, {
            DirectedInfinity[1], 2}, NumberPadding -> {"", "0"}]& ], 
         TraditionalForm]}, {-2.2072749131897207`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.120263536200091, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-2.040220828526554, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.9661128563728327`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.8170772772123447`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.7429693050586228`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-1.6739764335716714`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.916290731874155, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.5108256237659907, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.2231435513142097, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {-0.10536051565782628`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.09531017980432493, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.1823215567939548, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.26236426446749106`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.336472236621213, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.47000362924573563`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.5306282510621705, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.5877866649021191, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {0.6418538861723948, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.3862943611198906`, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}, {1.791759469228055, 
        FormBox["\"\"", TraditionalForm], {0.00375, 0.}, {
         Thickness[0.001]}}}}]},
  "RowDefault"]], "Output",
 CellChangeTimes->{
  3.608310275620036*^9, 3.608310637254395*^9, 3.6083259299376574`*^9, {
   3.6083863038573227`*^9, 3.608386308432261*^9}, 3.6083863566008663`*^9, {
   3.6083870107896013`*^9, 3.608387024774002*^9}, {3.608387073434717*^9, 
   3.6083871555788813`*^9}, 3.608387194629753*^9, {3.6083872466189747`*^9, 
   3.608387296075301*^9}, 3.608405593315053*^9, {3.608413752421771*^9, 
   3.608413780075777*^9}, {3.608413813755261*^9, 3.608413896606339*^9}, 
   3.608414327873451*^9}]
}, Open  ]],

Cell[BoxData[
 RowBox[{"\[IndentingNewLine]", "\[IndentingNewLine]", "\[IndentingNewLine]", 
  "\[IndentingNewLine]"}]], "Input",
 CellChangeTimes->{{3.6083102854031277`*^9, 3.6083102858984823`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"(*", 
   RowBox[{"initiatilizatoin", " ", "cells"}], "*)"}], "\[IndentingNewLine]", 
  "\[IndentingNewLine]", 
  RowBox[{
   RowBox[{"icons", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"\"\<larceny/theft\>\"", "\[Rule]", " ", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWGlUlecR9rT90V/NSZTAvdx9+e6+gBUQMKKoEQ1gseVg4oZIFCVqNS64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          "], {{0, 50}, {
          50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<fraud\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWXlMlGcaZ+4LpGpn0FqvbXFXUEAOOVRAVDwQWxFqa0tZsNjSreCCggq1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          "], {{0, 50}, {62, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{62, 50},
        PlotRange->{{0, 62}, {0, 50}}]}], ",", 
      RowBox[{"\"\<vandalism\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJzVWGlQVWUYdqof/XOmlOXu99xz943LIriwNoNiioA6litgbjnFiI6CFjU2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          "], {{0, 50}, {32, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{32, 50},
        PlotRange->{{0, 32}, {0, 50}}]}], ",", 
      RowBox[{"\"\<weapon laws\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWFtPVFcUNm0f+jeoCgPOMHPm3GZGU7kIsdVWoSVFKKAwI0KaFG8ltkHt
Q1ttn5rWKKQJxRD1rda+gElFEVDAUBuspkYYLom1NdGEO8Lwda01jgh0DI7o
mGa+ZHHOPuTss7691vr22hNX/HH29leWLVu2+3X6k72tMnXXrm373nuNBmn7
9viKX6WbVWROMn6IGGKIIYYYYngBmJmZweTk5Av51tDQEMbHx5/L3Ldu3UJ2
djY6OztlHAgExKanp2fvZRx4NF6M8fqw3wMDA6ivr8fBgwexdu1a1NbWPhce
hw4dQlxcHFJTU+HzeVFSUiy23eeTsc/rhddbErx/CtuxoxSbNr0Lj8cNh8MO
i8WClStXorq6esk53L59GykpKdA0DarqhM2aiPgVcVAcNthtSUhMWCH3NqsF
yTR22G2LNKuY6nTA0FUyJ9xuF/FxoLS0FEeOHEFjY+OS8aipqYHNZoNpmsRF
hcetw1tSJNeMdSnYWphP/qxC7gdZyM56B7qmwGVqkZnLRVzctF4q4uPjJf4T
ExPPzGF4eBjr16+XeQ3DgKLYsXd3BeX0fWx4KwMnThzHH9euYrXHQE/PTfxY
+wOsqxIi5uEhDsH1CnJKT0/H6OhoRL5zTXsp38vKylBYWCjzsvE6ORUHWlua
0dZ2EZkZqbh/7y6++forlO3wYSYwhYIPt0iORcLB7dJlreQ7TqfUSWZmZsQ6
yfwPHz6M5cuXw2q1ytzMQ1EU5OS8j4nxMZSX+UhbqjAyMoz0tDdxvulXtF9u
gabaYRpqxDx0XYPdbkd5eTkaGhrQ0dEREYfHcfToUZkzxINjnZGxDgf2fyq1
kbclBzsrPpLa+GTvThQWbJG6jbg2yAxDR0KCBceOHXtm/0OYmppCUVGR6Eco
twxDE70yDSfpi0J5lgyD6tqezDqVRGuqSTxCNrvWweesSU80WjOub9aqpURd
XS1plZU46GSG8PC4jdl8Ji7MyUWmOZMlrzTNKcZayu+5XQZpq0I6RlrnYT3i
GjDnGT2j+V0uE4mJifTduiXlcfW3rgVr+7iFnvN6nzx5XOr/XFMTzp+/gPb2
dlRUVCApKQlpaWnSC/T396O31x/GeuH3+0VnRkZGlpTHmZ9/Ev0Jx4Nj4qT/
834SCEzPeZd1Py8vj/I9AVVVVUvq19OisnKP1EO4umR+CtX5L2dOL3j37Nmz
ohOscxybaMHv75X97b9iYRrBWKhUE7yPNDefw80/r+Fa9++4fv065VcbcnNz
JRb5+flR48D4/rtvKRYL92bWXL7qukNqnGtjjcekZyrxdonmsEZzz8exaG5u
jhqHO3f+kv1tfq8U0qg1q02JFceDTdccpME20iuFehhNeGRlZeH06YX59iIR
jIVFfJ4fC9NQZO15/+N9/cqVDrS2tqCj/TIuXWqTnOru7n5uZ6HF4v69e9jw
diZU2uPY3/l1zb2D6+Ge0NJyMaq+PgmstRwL03x4JnDpC3q55GQ7CgoK+MAb
bXfD4sD+z6TP4FhwDc/pf/Rg/869yqlTp6Ltalhwj7x580apXU0N6tHc+gj2
WdxX37hxI9ruhsXk5AQ2Um1oarA2gnU92/dxnvH5hvWUz54PHjyItsth8eUX
n8OS8Ab1baro6dz+VX/Uw/Me19XVFW13w+LuP3/D590qucXx4BoJmeSWxyM8
+KzIv9m8zBgbG5PflPr6+qgP7ZEexU/XPrry88HBwZeeQwwxxBBDDDH83/Ev
4RZoiA==
          "], {{0, 43}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 43},
        PlotRange->{{0, 50}, {0, 43}}]}], ",", 
      RowBox[{"\"\<burglary\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWGtUVmUWbs3Mj/k382PWqkTgu9+vECggiIi38K6pXVwmoqKilFiTYl5z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          "], {{0, 50}, {44, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{44, 50},
        PlotRange->{{0, 44}, {0, 50}}]}], ",", 
      RowBox[{"\"\<vehicle theft\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWgl0TecWzpw7RCqTeKWCiFBFxEwENVdbRYkaMyNI8ahaT1ml+lpVqrwa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          "], {{0, 50}, {73, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{73, 50},
        PlotRange->{{0, 73}, {0, 50}}]}], ",", 
      RowBox[{"\"\<trespass\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJzVWglYU1cWriIIiijIaggBQiDsi4CO+4KjHa1aWwdbP6sIVIo6UmvtoNYq
YlXcakWty6h1qa1LsdrOqNWiKOJSOy4Vpy6AWteqiKCoYP4558aXJhBCQGbm
m/N9ly+8vHfv+d89y3/OjdfIcYPebvzSSy+9Z01/BsV90H38+LjU15rQPz1S
JySOtKAPEc8HX9RUVKChRKPRoLKyUowKmvfp06cGg6/x4O+fPXvWYOuKtV8Q
B+v0+PFjXL16FRs2bMCYMWMQExMDpVIJe3t7WFhYiMGfvb290bNnT4wePRpr
1qxBYWGheJbn+F/h4PWvXLmCRYsWITw8HLS1BoN1t7S0hJWVlRj8ma9VvS80
NBQLFy4Uc/Gc/y0cbB8XL17EuHHjYG1trdOnadOmaNGiBdzc3NC1a1fEx8dj
8uTJSE9PF4M/JyQkiO/4Hr6Xn9F/nvfp/PnzePLkyX8Ux61btzB37lzxfnnt
xo0bo2XLloiIiMDMmTNx6tQps+c6c+YMZs2ahcjISDEHz8Vz8r7x9Zs3bwp/
e66liWE+DvbN48ePo127drr35+DggP79+yMvL89s3WuSY8eOYcCAAWJOaX7G
d/ToUbE28ITiwiOjw1wcbLNffvmlzoZsbGyEbeTm5r6w/lXlyJEj6Natm1hD
sjWOHeXlJaxJvXE8evQIS5Ys0b0jFxcXTJ06tcH1ryrTp08XPiSt+8kn81Fa
etcoltpw8D4sXrxYN5darcb27dvrrFNFZYWw9Z9+/BFHDh3GRfLjBw8e1Prc
7t274eHhoVt/4cJ59F6LyWfKzcbB/sX7qR8b2VbrIz+S/i/37AVZKyfIHZzh
K/fEzGlpuHfvXo3P8Po3btwQeahRo0Y6PdauXUX+UmaAxRQO1rlZs2a6fWBd
6iPso9OnfASXlvYIVKqgVnhDKfNAaEAQ9mfvN/pMWVkZdu7cabAXFhaNn/uL
FQ4dyjYLx+3btxEdHS2ec3Z2xo4dO+qFgeUmvdO34+Lh7uiCUF9/hPkGQO2l
hB+NPbt2V7v/2rVrwv+kGMxDLpdj5Mg40sVJ/N+2bTjdV6DDYgwHcx7OA1Ic
Z397ESkm2xk3egxkjEPljyBvFXzkCgSq/PDD3n0G93I+6dOnT7Vcn52dLb6f
NStN7AdfnzZtMuXjUoHFGI4LFy6I+Mo2ybG1IWTj+vW0Bz7waSMXvuHl5o5X
+/XHubP54nv2+c2bN4v3LulvZ2eH2NhYkXeFjhptfo+J6SF0s7KyRH7+SaP7
wXsxatQoMU+rVq1w+PBhs/R8TBzCFM8re/gQq5avwNhR7+Dd0WMxMeU95B7S
5h7miRMnTjTYA+aS8+bNM5jj2TN+7xrKLwd1uTI+Po5iakk1HNevXxd7wbbZ
r1+/WvV/QnE5e1825mXMw8oVK0Su/Oqrr/B1VhZ2fPONsJufTvyEosIio89z
7OjVq5cBhqioKJ0dVcWh0TwUn199tb/QkblRUdEvBjg4zmVmZoq5OE7VxjV4
73Io3qgVSrS0tIEjxSOHVvZoTe/KzdkF3u5yBJFfd4iMxsA+fbEicxnyz5zF
4/JyEW/XrVtnYEe8/yNGjBCx1vh6kk9XUCw9KDgmP7dgwRydLTAO1ov5DNte
SEhIrXtRSjY9Ki4Bra2bw9tFBk+XNpC3kcG5tSNcaXA8Unl6w5t8QuHoCpWb
HL27dEfatGnCdvX5u5+fn8i3pt+bFodGo/WHtm0jhK6hoSE6bsw42KakGMXx
ypQ8JHv/YsNGeLVxR7BKjTcH/RkfjH8fKeNSkJz0Doa8PhgRQSHwVXgh0McP
YRSnQihOObawq1Z7dOnSBTk5ObW+NwmHdk80yMj4WMf5uW6RcGzatEnHAX/+
+eca57ty+TKmTJqMYP9ARIdHYP3adbh967bBPbkHc9EuPBIeLm4IUQcggGIV
x10rSyuDWiMuLq5GOzKN4zHOnTuF5s2bi7nWUzxkv2AcXBPxNVdX1xrnKr5X
jLGUCywbW8CHbGYdYai+ngarVq6Ewk0GFe2HL93nQLWF/h7wnruSDzFXN1f0
cUh+IpO1EfNx7cV+wTh69+4t7I05c01y6cJFyOgdN7e2QWJ8ItnXo2r3XPv1
OhJHxsOttRPc6V4bvXqRRyMa7sRjFeRLk/6aSn5WWk8coDpfm0u43mf+wzh8
fHyE7yUmJtY419Url9G7e08MGRxL8d94bjl29BjCA4Nh16w5mlg0McCgVHgi
dtBgRIWFQ077ofL0wrrVa3XP8n4fpz3aSPx0/vwFOEExu0KX26ri0CApKUHo
zPlGwsFxrEmTJkhNTa0RR1lpGXZ9uws5Bw7hfnGJ0XtWrlgJqyaWBvo3pThv
Z90Mk96biKKCIsydnQGVhydc7FujW4fOyFy0GN98nYX3U8ajQ1Q7ODm0Fs8l
JSWhuPh+DTgqqd7/QNgo92EkHJxXGEdtfKriaSXu3i022gfYunUrwsMM+yZ2
ti3g4eSK9sHh+P4fWl74oOQBZs1IF1zFpZWDiHsezm5o1bS5uDag7ysYMiQW
Gzdu1NmuMRzp6dNFLuQ94d4H4+DP5uAwJqWlpaIfIpPJDHo+nEvU3j7wJB2T
E5Nw7+7v9UbJ/RJ8PGMm2ZoX5UwF+vSMwez0j7F39x6c/+U8SkoM99tcHObY
lTHJz88XfE6/1mlGsdtD5o4Ayh3hVGe4O7sKW6oqxffvY8uWbcRltuD06dMm
1zFlV8wFJLtSqVS1+nlVYTtq3769gR3ZU4z1llOdpA4U3Nxf6UNDhS/WbazT
+6kdh4Z4QXU/NyfuSsL5fMqUKQZ25OTkhH5/6gtP4uQhfgFiBPmqBaauHTrh
wA/Ga7/64+C4271a3JXyIPdDfu99VZezZ89i4MCBBnYUFhaGffv24XBuLtpH
REHm5IIApS+CiLNwXOoc/Qfs3fN9g+HQcizjeZA5t8RLuC4zJhw/uG+ob0fD
hg3DyZMnxffsaz/s3YvBAwfBifgv5/QAH18E+/mj/8t98beVq8zOe6ZwMC/J
z/8nbG21vIT7IRIvYZ7D19j/OfboSzlx7QkTJgjOIunPcYF7y9zPqSpXrlzF
h6lTiJMoIXdxhT9h4djKeS85KZlqzosviAOYM2cm6VqdJ/K+cG+B7SU4OFj3
PNsR+44+z+7UqRP2799f7fyCbbSwoFDk5cqKSmzfloWYzt0FR2SepfLyggfV
Jb1ielF9c6ReOCTeHhERLnQNCws14O28L1LfkHkk68l2FBQUZMgtKP4sXfqZ
0bXu3rmLyRNTMZR4y8kTWlvjXDBq5NtwpnznLVfA28tb9KRjh7whaoW64mC/
yMs7oKujFi7MMKijWNi22D84twcEBBjYEQ9r66bac5geMXhr+HAsW/aZ4Pjc
O2XZQzksmOKU3K0NoiMiMYvy2sOyh7hx/QbmzJyN9m2j4UZxRO4hhwfVggsW
LKD62rzzAS0ObV07YMArQkfm/lXrWu29z5CcnFyt1uE6ceuWrUgYMVLEVbum
NmTvckSGhOGPXbvjtVcG4q2hw9C9azco6X07UwyOpnr2253f6c5luLd2Lv8c
5s6ZC1/aU659Q6nW2rFzp9k4OGfk5eUIPsV6JSYmGO0zsPD5jNRXt7W1FTGN
r7HcvHETu777O94aMhSeru6ERYZAiq9K4hVsMz5KJRSeCvip1Vi9eo3RHgrj
eTflXchc3dDa3gH9iEtdunTJDCRPBA4pZ3A84lrKVB9u9uzZutjFZ31VhfFs
3rRZ8HNniq8han8Eke5eXp5QKBSY+tFHQt+a5Ny5f6EvxWEXR2dhZ/Pnzccj
I7VMVUlL+1BXy86YMVX04Uz1Re/cuYMOHTqI+7l3b6zHXkHxKHvvPrzx+hC4
OjjClmorW4oPw4ePIK5dbFIfjincK1IRX5HR/FFto3DmtPGcJcmOHVk6f23X
LopiRKHJvqgkJ06cED09qZ/BZ1HV9KEa9tbNW1SP5CBzcSY+XfRpjTm0qhQU
FAoew/WtK+X/oW8ORdFl430uPttRq/2ex9Jm9H+O2f12fmdSjufB8ddUf5H9
mfOlKU5Tdf6DBw+ic8dOaEO+4uzohGVLl1WLX4yB+1CSHuvXrxbnBnU9x9E/
i/L19UVWVpZZepojHAeWZi4RMc6OYsowinlXr/6q+577/GwL0vpLliyq8zmO
JPyOly9fbsBrJ02a1GBYOPeMHfMXWBPHCAkKxsXnnIXPDvjMQh9DWRnXYXU/
V5OE8z7XGlK/iONyx44dceDAgQbBcrnoMkYnj0Y61Yfbtm1Djx49dLGfe7Tc
My4vf2AUQ11wsLANsO/r103ML7if3RDntnuJJzPv4tgi1QTcs+b4ou2ZGMdQ
VxziPvJNjsnMJ6QzN+YHnC/ZF9PS0gRWc4X5PnNrPqthviRxUeZGGRkZ+O23
36rEjRf/HYC+cJ1RUFCAlJQUHR4pb/L/XItJv8vgep/x8eDP/LsMrjn5HrZT
6XcRkr1y3uX8zmvUVer7Oxlei7klnzcwBzPoG5Jt8F5JfRge/Jmv6deSPLg2
434789/66P+iOCRhLlPxvGfPPsn7xOd8HDMdHR0Fl+D3zp85dnM9w3X0559/
Tny1SDzbEL/F0jyv0f/fx78BrPedhw==
          "], {{0, 50}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<non-criminal\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWnlwTVkaT/Lykpe87Bi0xFbGVgZptOpRVDE9EsOYKZSilD+YorosE1sh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          "], {{0, 50}, {50, 0}}, {0, 
          255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<assault\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWGtQleUWdur86Ff2h4AN+/7t+43NPUhN0LLIBJRJATUszQrZyiUuWond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          "], {{0, 50}, {34, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{34, 50},
        PlotRange->{{0, 34}, {0, 50}}]}], ",", 
      RowBox[{"\"\<suspicious occ\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWWlMVFcUZgYGBobVFRQUW1GxwrigRPbNBVsERqxVoIosiTYVGFRQTLRV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          "], {{0, 65}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 65},
        PlotRange->{{0, 50}, {0, 65}}]}], ",", 
      RowBox[{"\"\<missing person\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztlvtPk1cYx822H/YvzM0L+NbeL2/7XlqgN6gBBYeAbGiYKIo4wAuIGLzM
idmi0Rid6OaFIca5yDbFhGwoA5lmKCCbwwEqbkRHIggIsoBCKd+dvgsVM7NF
eeElC5/ktG+bniefnnOe5zx+iWujV74yZcqU9a+Tl+hlG50ZGcuyY14jH4Kz
M5MSXyUPRjJUZHi/xCST/I/xeAbR1tqKpqbbaLp9G+3tD6RW8uF2D6Cmugo7
crZjUdw7CAl2QK9Vg2OMCAudg+TkJBQcz0dX10PJHOvqriMlJQlajQJKhQzB
wXYsT0zAhswMpKYkIyY6EjxnwmzKD05bAM5+fZrMGhpXx3NFZ8CxBqhVFNau
SUFFRRl6errR/+QJMfFg0OMmz49xp+kWPvs0F1GR4VD4T8PW7Cy0tt4fF8dT
X5yAQu4HaxCP8vLvhXP5Xzzu68WenR+BmvEmEha/i86O9jF1rKy8DJ1WDpfL
hl+u//RCc4eGhnA87yjUMj+kr04h/88zJo49f/YgNnYBaL0Kly5dfOk4e3Z+
DK2CQun578STG0FR0TeY5fcWcrZ/MKo4XQ87MT/MheUJ8SKZPUsqyW3vWnrz
fLQcPLAfSmombjY2iGD2lEePuhERFoKViUtEqSz1N+pgNumEMyAmtTXV0Mr9
cUaogaPHMziIiFAXVq1YJkq8YcpKL5CaMhXnS74VJZ4396Mi5mIJqVFiUl5W
Cmr6VFwoES9HoyLCkLhksWjxvNReq4FBLUdB/jFR4nV3d2GOw4rU5BWixBum
r68PkfNCERcTKezZ37x8RlWUl0GvpPD50cPiCI5g+9ZN4GmtKLVk44Z04ilD
Y329CGbPcrOxHnqVDJuzMkcV5+faa9ARx/Vr00Qy+yfZWRlQyWaSfHq5vHe7
3cI9pCZ9TGOD+Gs5TEvLH5gf7oKRVqDq6o8vNNc9MICcLZtBTZtK8jFvjAyf
cvduM0JDrdDpKOTm7kV//5N//X3/QD9a7t1DcsJSaPz9ceRg7pg7DtPe3ob4
+BhQ1BvYti0bDfV16OzsQG9vr1Ab+ki/2Xb/Ps58VYiM1WtgoWkEm804VVAw
bo7DeM/a6cKTiIxwIYDRI4g3wWbhSV20w2WzI5DlQat1oFU6GJUafLJ797g7
jqSD9OaXKy7iwy2bsCE9HWmrVmFd6mqkrXwfZtpM1tICVkMji6zrRGTIM4Tk
pUkwKPUINPKwGk2kT7ohtdZzKS0pgU6uREiQFQbZbBQcOSq10nPpaH9A+rc5
4A0GmLU6vBcbK5zriciBfXuhl1OwsxwCSN7HLXgb+eRef9onTAyO5x8Go1XB
wfBwciSn1BqwWg2abt2UWs1HS8s9hLgspG4Z4DRZYCeuDtYMk0qFnTtypNbz
0dbWCoeTQxBngsNkFjy9w6LXIzp8Hjo7OqRW9LFrVw50ChmcjMXn6eB5Uvvl
KD53Vmo9HzU1V2A26mEXaign7LuNZWFSK5Emcj8/Grx9ytJFcQjQGGEjnk7O
DCvDkntKD5c9EM2//ya1oo/Ck1/CSHlz3iwMr6eNY8l5oJB/7IjUej4a6n5F
uDUEFh0teNo5Dnaehdmkx+LYKKE3nSisW0H6Eg2pT6wFQTTprVgGgQwNC6lZ
P1wsk1rPR0lxMejZcjh5svccySmGEd6VM6bj0P59Uuv56Ol+hOi588Co1LAx
HAJpI3SzKIRZbaiqrJRa7xmOHTqEANKTWBkj6UkW4kReHprvTJx8H0ltdRWq
r14h9apfapVJJplkgvMXVq3EVw==
          "], {{0, 50}, {42, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{42, 50},
        PlotRange->{{0, 42}, {0, 50}}]}], ",", 
      RowBox[{"\"\<other offenses\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWglIFWsUNjUz27GyPaSyTSq1xcosbScs6kG0SppLC2joK7NokRLBFloo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          "], {{0, 56}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 56},
        PlotRange->{{0, 50}, {0, 56}}]}], ",", 
      RowBox[{"\"\<sex offenses, forcible\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWWd0VNcR5iT5kT85OSaCqLB9tU2rigoIUSR6MREiFGODImQgpsoUCRRM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          "], {{0, 50}, {50, 
          0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<drunkenness\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztXGtoVVcWjsncR8iDxJCEJMQyUoPBoiQoFlF0hBCR9ker01FKKYojEhGx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          "], {{0, 
          85}, {87, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{87, 85},
        PlotRange->{{0, 87}, {0, 85}}]}], ",", 
      RowBox[{"\"\<drug/narcotic\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztmEsobVEYx3HQMfDKoyjphpRSKMJAGJggdSQpEqJE3Tr3esZIkhIDGSBJ
SkpGUvIqIiN5ZIKSpLzyirz57vl/tVZn57jOvZO1T51fLXuv1R78zufb3/rW
/lH+01Tl5uLi8sto+WMqa8gwm8ua8t0tk8ym35XlBstNgmXEWgYWyYmT/+T1
9ZXe3t5Ua9jN5uYmZWZm0vT0tGoVu1hZWaGAgABydXXle72zuLhI3t7e5O/v
TwsLC6p1vmVubo58fHwIZTAjI0O1zrcMDw+Tu7s7+4prYWEhv4d64+Pjg/r6
+tgxMDCQvLy8yGAwSO/Kykp+Rk8gf+GWnJxMBwcH0t/NzY3fQdw3NDTws/f3
97S+vq7YmOjs7IxGRkbo7u5OrjU2NkpvMXp6eig/P59/x/LyskLjrzGbzeyN
PBHxRt7U1NRQWFgYra6uqla0SW1trfRFvZ6dneX17u5unu/s7Cg2/AxiaTQa
KSgoiJaWlnhN1JHm5mYKDQ2l3d1dlYoa9vf32TU+Pp62t7d5DfXj6elJ1pHq
6mqKiIigo6MjlaqS5+dnKigooPT0dHp/f+c1uCLOYg6KioooMTGRbm5uVKlq
QE+Xk5NDJpNJxlY4i34Pvy0rK4tyc3N1U8fhlJaWRqWlpTyHKwa8Rbxvb28p
KSmJiouLFZpqubi44P9/fX09z0VeI+a4gqurK4qNjZXP6AG8Z3jfOjo6eA5v
xBveLy8vvLa1tcV1sb29XaWqhrW1NfLz86PBwUGeC2+RI9jj4YzR29urUlXD
zMwM99cTExOa9ZaWFrnf4+rp6UmTk5OKLD8zPj7OfTb6K+RxVVWV9EQ/iAF3
X19fmp+fV60rGR0dpeDgYIqJiWFfDw8PdsXVuifEM8hzvYC8FvmAGIt+SsRZ
eEdHR9PJyYlqXUlXV5cmztauGOI+ISGBrq+vVetK6urqZLzF+cbWSElJ0Y03
anRJSYmmblgPxFrEG2djvfQmj4+PlJ2d/WWMkeviPi8vT7WuBP/31NRUm3G2
zvOKigrVqhrOz8+55xbvJQZiLM6V4eHhdHh4qFrzE+ip0C+JfcY6z1E/9PjN
BBwfH3NdFvmBPVHcI++npqZUK9oE31ZxXmhra6PT01NqbW3lXIE3zm16OZP9
DZwNIiMjZbzxe/SaJ9ZsbGxQVFSU9O7v71etZBeoG3FxcewcEhJCe3t7qpXs
4vLyks/H8O7s7FStYzc4k42NjXF/iDrjSGD/xPdYPfWr9oBcwfuIfdSRwP45
MDDgcN7wHRoa4lruSOD7Js6bDw8PqlX+Cew9ONc7GjhHOHFiL38Ai2Otvw==

          "], {{0, 50}, {45, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{45, 50},
        PlotRange->{{0, 45}, {0, 50}}]}], ",", 
      RowBox[{"\"\<warrants\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWUlMm1cQ9oqN00PasATSCxdadRE0DYEeQyjkAoU0VMQNeMG0JAdCHGjJ
LUkdUQL0nEpsNjJIIErSqoEUjkFEDZI5EUACxCLgQlnMvmT6ZrB/8ALkt01I
on+k8fzv/+fNm+9/8897bxylv37xB4lIJLqpZD8XdT+fMxp1t76VsUbiraI8
vZRdxDA+zRhvgkACCXQktLi4CA0NDWAymWBsbOyo3eFN4+Pj8GtZGcTGxgKm
EuTQk+Fw9do1sPXaYGtr66hd3JPQt56eHsi/ms98DiPfpTIZBB9TEQcpFHRP
EayE5JQUaGTzhPP1ppDdbofGxkZITk4GpVJJvgYpFZz/7qxUBYNILCL+PCYG
TPfuwcjIyJH5j2ObfjHBJ5996vBLDEr2rlXvHSNGf5H3w4Pzhbg/CDkBulw9
dHV1vZaYwzG6u7tBp9fT2BQ7chnnL/q/l997MfaRK4LIlixIDufOJ0JtbS0s
LCwE3H+0abZYIDHpPCiUigNjx1fG9yFm84r2oz/+CO7cvQv9/f1++z8wOEi2
0KZIIqYx8DsNtP/7xdzx94+DWq2Gzs5On2Luwe8PIFilcsSOlGzziRulg/3F
FOSYfxnDlXLhAiwvL/PCUVhYyOX+N4XlcjlMTEzwwtHc3AyX1Zch12AAjVYL
Go2GWMuuc5jEb13jInWg0+k4PWxrsa3TUh9k1M1x2sjJIZlryGX9ttvYByWy
RrvTD+3hvYKCgkP5/t82ampqonel0WponrwR7kWMRiNkZmZCSUkJtb1RVVUV
XMm+AtnZ2dDR0eFVp/vZM8jLywP192qoqKiAzc1NvzHMzMxASGgoF6MKtmYP
DQ156GEM7Y5l3Bu6U3t7u4tOdHQ0zM7OeuglfZ3koldTU+M3jsnJSQhjezxc
ozD/oOx78cJDLz0jg8bEHIPyBpsbd6qvr6dnmPswD6Fd93eytLQEcfFnQSKT
crbK7t/3G8fU9DSER5ykNdc5vre16VLmJRccRcXFHjq4h3fiQHsRkZEwPDzs
ooN5Nf6rBBBLJZytispKAYeDpgUcAg4Bh4DjEHAkMBySdwDHuzIfAo4A4Pgu
82AcVnccEa+Io8JvHFNTUxwOtIvn81fBcbOoyEPHarUeiAP3iWcT4mmfSLUu
pl9eXh4QHFjjkbAzOmLAWlVfX5+HXuo3ads+Bm/X4op/8pwPi8XC1RQlchk7
D4TA8JDnfJyJO8PhRVlaWuo3DrSL+2iRVEw1ky++PE1nEneq/K2Saln4HlFa
G6weOgMDAxAVFUV20L/UtFSvNZAf8/PpuZjpnQgJofpcIGh29j9oa2uDvx8/
9orBSf8+fw6tDx9Cb2/vnjpj7Jz46K8/4ck/T2DBbveqs7KyQmfFlpYWGGTY
/aX19XWYn5+nGi6eLTc2Nih+8Qw3NzfnIlFvbXWN9FZXV12eO6+RsT/ZYrYX
7YtebSE+HHvr5UuKB7y3trbmEwb0Kz0jnc60+D1GnIokjvzwFETylT70ofEc
Miw8jH0zcWCz2XjjuH3nNldzxdyCUuq4fl0sczIbF30xGAy8cRQUXufyqLMO
vV/9/LAZfUlLS+ONo9B4g8PhxBCIOievOu+u2ir6kpWVxRvH066nVM+g+rRE
QvkU11iUEqmUn/Sxj5jGlNKapWJYMH/5QqOjo/BHayvVj3ANq66upv8PsG22
mHdkLZNmM/1vUWeu25F1TNbVEdP17mdMYh/qu9sWSQsnsW6HYwfi/wOBBBLo
7ab/AUekR8k=
          "], {{0, 47}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 47},
        PlotRange->{{0, 50}, {0, 47}}]}], ",", 
      RowBox[{"\"\<forgery/counterfeiting\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWXlQVWUU562895D1AQkoqyAom1AIiRJGanuQNaPmgiNqaTWhReZfNU7m
XplhKmXN1AjSOFOUjehYM86IzDg5o6CJAbIjjAu5pKC/zvnuEg8fJS3cFs7M
4bvc7y7nd7+z/L7zwua/mLNQ7+LissxCf3JyCzLz83NXPGmkfyavWJ4330AH
SbLySQzJkAzJP1KuX/8ZixbnITUtFevWr8eZM2e0NmnA0tV1CdnZj4NTjaK+
/n54Zs4cfPvdd4TxutYm/q60tDRh6pQHhO1WNzehtmE2GF2N4pzRbEJ6ejrK
ysq0NrVfqa+vxb0TUoW9FjcrqY1wSGpR1GYV83en3IMrV69qbfJtUnXiBOJi
x8jrYHOuw9wEDl6TiMhRaGtv09psB6mrq0NkVKS0DmQr22u1ucl+5bgWNpoz
uZoRFDwCDY0NWpvuIKd/+AF2uw8MJpPqSxbCYOlnXcwWVxH3tXW1Wpt+m2zd
ulVaD/rmVjk2nOHgeVerBR5enqipqdHabKeycNECgcU2TMKi+JXiW+xTfMw4
2PdOnTqltclOpZ3iNjEpHgajUbLfNkxgYR9zlTEpWDhGqqqrtTa5X9m37xuy
n2PA4uBPvAasbL/OoBfrdpxy3GDIlStXBnxP0YfbYaT1EHEir4eLXidi28fX
juGBAYhPTMArrxbg4sWLf4PVjlJZeQShYaGY9cwsfP31V3d0T3d3NybfnwG9
Xi/5D+Vek9kVOTk52LVrl8jPFy5cwNVBqn+3bt3CvNx5KjcyuZqQkpKM9wvf
Q119Xb/3HTlSQdfyWlhEnBvNVCeCgvBTV9eg2N1XGhoa4OXtBbPVVc73VujI
NxhTQFAAcufPRUXFYdy82SPZT2u3ZOmzmJgxQfi+1U32J7o+f9kyTTCwrFq1
ypFf2H7lFQaTxPcMRh2ypmRhzbq1uGd8inTOZJDyk03KRz52O74/dkwTDJ2d
nYiLi4NefNd+eJKswu/kGO5b64yEI5B86uTJk5rgqKysVONCsU/J+c5Uqt/O
z+uMeiQkJuLatWuDjoPfWVJSggdoD6F8c73RoNrbH2dyphwr6RMnDjqGvnK4
ogIv5eeL/CvWSKeDxer8+ztTrnvexB8fefRR7C7djYuUc7WU8+fPY8eOHcjI
yIDNZnPwud9S9kfGIn0DF8TGxoocUlurLc+9ceMGDh06hIWLFwnerdh3p3HD
/sn32Kmuz6T6+sWXX2iKh6WxsREbNmxAWlqawKLsvfvmBWc5gnOyyNNmI/HK
cSgkzq9174G5yMGDBzFj1kz4D79L2Kej787+xBgUHM7wqD5Hufvo0aOa4ugt
p0+fFr2quPg4tV6KvUY/fmaT6+rY2LG4fPmy1ubfJrxGJbtL8OT06fDw9FBz
t7PY4bm1xAn+6XKK9u4rVr6G0THRDvVVWQvOFzX/ol4j853ikmJMe3Ca4GsK
ptlz52ht2h8W5j7LiAfHUT05phGP/C9KT0+P1iY4COe81W+9hYmTJom+a1JS
ksidscTfma+mpI7H+LRUMSbfnYyYsWOQSvUvOycb8QkJSExIlO6jOVaubdFj
YhAdHY3omBjBRzi3Zt4/GaWfl/5tOObN+3UPyxoYGIjnlizBxo0bsWbtGmG3
wkE416RPSsfmzZuJRx7G62+8jszJmWo9Y308+wkUffQhCgsLMf3pp2hv6e3w
/KKior8cQ0FBgXi2j483Nm3ahPLyfWhualbnlz6/VNQypU++6NnF4jz30HJz
czF79mwkjksU+16FFzJ/+mDbNvUZ3Dfcv38/lr7wvLTPpHy1Z8+evwwD117R
RyBetK3XexXZ+cnHak3mfYfZbEb4qAi8uXq1sKuqqkrwxvX0HOb2/BzGwjXP
3cMdx48fd3hed083ZsycIe/zA3Gi6s/3r74sKxN7CZ1ej9dWrlTPc69E6R+8
/e47Eg7uyco1mONkXHISwsLDkZWVhdaWVnHty6+8rO7pTRYzjCaT6D/0FY7F
SffdJ67l2Ovo6PjDGKqrqzEieKTYr7G/PPjwQ9iyZQtuEobe0nXpEqZMnSK+
r+gte3uhhPZDVdVVVINr0NbWhuqT1dj58U6Miook/moSzzMTn12+fPlt762t
/RELFixAZNRoEWeMZQLtFy/RewYq9fX1iBwdJWJW4aBKn3Lj25tw4MAB7N27
V2h5eTk+/exTjI2LFZzcTDZyzIaGhWH79u2Eo53yVbzK2ZXfNjIzM1FcXCz2
xzyy7i4tFfEv9cPMKk/k/x957LEB9eZaW1uRnJys9vf5myh9Vz4WeOScI/YU
tI9V3snz3LMVPJbmPDw9EUB5jecFRprnY1bhrzqdQ45S8plyPatBVp7Ly8u7
43rE/uTn5wt3d3eKQ094ki2e3p6i5+blxaOknLt87N7SSOrrZyf1hV0e/Yf7
wZ/4nS/lJf+7/AlPAEYGB2HkyBE0jkAw+WxwSDBCQkMQEiIrHYdHhFFchSE0
IpTyRaj4DSsqahQiwkMxl3jWQLh7e3s7zp49K5T7hqyNjfIojhtVbWJtYm1y
0JaWZtIWaWxupnVuEbHSW/k9vfUc67lzpNLY0XFOcMfOzg4xDsmQDMn/W34B
PbxqvA==
          "], {{0, 50}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<arson\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWmdQlOcWztx7f9w/mcnMnZuIsJTdZQu9iQg2RFHEXtAYDdJU7KJGRSyJ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          "], {{0, 50}, {60, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{60, 50},
        PlotRange->{{0, 60}, {0, 50}}]}], ",", 
      RowBox[{"\"\<robbery\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWWlQlecVdtr+yNQ/nenUheVe7r5fuMgoLrhgRKyCjVtdYgO4o8Ro0iAY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          "], {{0, 50}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<driving under the influence\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJzdWwdQVEsWFYaZIZjLgC6W/hK/ihFMGFlBVEyroq6YVkBA9C/fQBDXr2V2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          "], {{0, 50}, {67, 
          0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{67, 50},
        PlotRange->{{0, 67}, {0, 50}}]}], ",", 
      RowBox[{"\"\<family offenses\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWgdwVWUWTn8vL5USCEWqIL0oBIJRJAUQBEIQQYqQSGgCsklY2rCiFGcW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          "], {{0, 50}, {71, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{71, 50},
        PlotRange->{{0, 71}, {0, 50}}]}], ",", 
      RowBox[{"\"\<disorderly conduct\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWWlQlGcStnb3x/5dg9wzw9wXDJeAoiggh0Y8gKiIeECIxqiAiAgV2U00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          "], {{0, 50}, {
          50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<embezzlement\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWWlMVFcUnpXZqLJUEUcKaLQxMSqkGoiAgDbaGBVtgrjEhWVogg1qgYYo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          "], {{0, 60}, {50, 
          0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 60},
        PlotRange->{{0, 50}, {0, 60}}]}], ",", 
      RowBox[{"\"\<liquor laws\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztmOlTFEcYxq0kH/I3REshCMICy94nu8uxIqggCmIpmkSj0dJ4BAQUVDRq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          "], {{0, 
          50}, {46, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{46, 50},
        PlotRange->{{0, 46}, {0, 50}}]}], ",", 
      RowBox[{"\"\<prostitution\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWHtQVFUY32WXXZCnCCiCKIjNAGKMhaiF9vBBIVLyh2hQoaaQPAop1EoL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          "], {{0, 50}, {
          55, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{55, 50},
        PlotRange->{{0, 55}, {0, 50}}]}], ",", 
      RowBox[{"\"\<kidnapping\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWQdsVecV9nzv2c/bMRCMS80ww4wQSlmhJSWMktgBGwitKRgzg+tJMGIY
gQQBDKaJCEhIKGpxYyhbBSoxKoYQCKmIUaYg1BYghsQetjH49Hzn3XN7/WSD
C4+HK/VIx3e+6/P9Z58/PiMnZbKfj4/PdAf/SRk/8+P8/PGzUgP44lezvpqU
4c8nPZg/ZMbNmpoaagwMqq6upqqqKjnHPVw/f/5czl+8ePHOZWwoQ1YQjhUV
FSYmEM7/F7CAnj17Rps2baLk5GTq1KkT9ejRgzIzM+n06dMmnnctZ10MmwGD
KisradLkycSmLuzr70d+/v5yHtMkhjZv2dJosQADfAA0f/58kTkgyEF2Z7Bw
UGiIsI+fL0VGR9Hx48dNu2tMNqb+cOPGDWrTpo3oQDHYgoPk6G+3UXBYqGCc
Nm2aaX+NEcf+/fvJx9eXHIbs9hCn4LCxbhx8jns+fn70M/YXjWEaxxoDK449
e/bIettZdoeBwWHoRBm21bFjR/EjUGPCoT5+4cIFiomJIRvbEOR3GLalmAIc
dsE5YsQI088bm10plnHjxoms4tssvzM8TDDg2j8wQJ5tMWIWfgsfedfyg93p
0uXL1PmDriKvH8sNfQSyf/j4uuJwZm62+IbGqje1K9Xn63wHcug6gq5du0ZH
jhyhY8eOybNr16/T2HFjKbZFLNntdgoJDaXEzp1o5XffSX7XmOsJu9L10Fqo
Lox1shEvQQ8ePKA5c+ZQdHS0mfcGDRpEN2/elOdlZWV06NAhwXf//n2P5z5r
/nkZaW6ry5YeP35Mw4YNE9m7d+9Oo0aNop49e8r1hAkT6v2ep+OTylheXk5n
z56VWKOM67t379arG9CiRYtE5jFjxtCUKVOob58+lJeXRwMGDKAmTZrId3UN
1A5fN1+oH+E77muvMR8yREVFUVxcnHCLFi2oefPmtHXr1lrvKoOAEe8mJSVR
RkaGy6c5v4WHh9OsWbPIZrPRiRMn5F2r3Fa/aChrHLTKbL3W51i3U6dOiQ7A
586do5MnT4qs7r9RWTZu3Cg4Zs6cSYGBgeRwOMSfY2Njafr06RQZGSl6fR25
3fnJkyfihw8fPhSGPSs/Yn746BE9Yn769Kn4uepc9afvyjeYNRaAkCPgG337
9hU9BAcHS/4rKCigrl27UufOneV/1udbSq/CANqxY4fYSOvWraV2a9u2rRzB
CQkJch+M+9Zn+q6+g3Xv37+/qR/gSkxMlFoP6+/g3BAQEECjvviCBg4cKDY2
cuTIWnp3x4CaRGOe4qnPD2EvGzZskNy5efNmsXfl7du307Zt2+Qcz3GOo5X1
GfqhnTt3it5AsPsItptpWb+nMORqxuEb4E9Lly+jrLxc+s2YNPqh9AdTPuQL
teG9e/fS8OHDqUOHDtS7d29avny5qbf6al+NR54i7U137tpJSZ8n09dFS6UO
Bw7U5LPnFVJi1y6UkNiBOrK+xqen05kzZ8zfY01DQkLMmOBv9FajR48WrC/z
c12Hffv2SYxHfO/Vq5esRZcuXaiwsFCevyoWYp3UDqCbT5M+o5lzZlPEe9Fk
49oP9d+kL6dSy/h4kQ32jJq2Xbt2Ejfgq7BFyB4UFCRxwel0SmzA++vXrzft
sK7/XWXUxvhWUVGR6LG4uFgY17CvhvRkGu8Qp8LCwly5bspkapXQlgJYF6id
PmUdfTJ4EMX+JI7mFs6lrKws8ZOJEydKPocupEbhIxg4gAnfQuxuyHq+LG83
JPaBoI8+nOukZ7UFiszJKcPl2p+vm8U2p8zsLPo8NYU+MfwdGKZOnSo6BH7I
DfkR3xSPNf9rnntbDEKcat++veQ42FLT95tRXsEMCuZ6HH2GD/eyKaNGUmZO
NqVxjod8iHlHjx6le/fuiZ0h1wADGLpRfZSUlDRYH2+KA4Q5jvQW3E+gJh/5
29HUu99Hch7I2CLZX+A3qGtbtmwp765du1Z+u27dOpHbl/texGn4usZo+I83
cCiW1atXu3yV+yOs/0f9f0nL/rBCfAR6gVzAVVFZQTnZ2XKNnAhdgnbv3k1D
hw4V3WCmtXDhQsnF3sKgOFCvoIZCrAUO+PrcBfPFx8VvoBOu4a9yP3Lx4kWp
23B/1apVpk7hA8ip2od4Q3Z3HFeuXJFew844YEtjM8ZTQscOlJ2fR/0+7k/R
TZvIvXtGr4GYBRyoC27dumXKraR5wVsYNO4eOHBA4g3mOtAHfLopx6mmzd+n
jEkTBQ/i2JAhQ+jOnTt09epVqZ2BJScnx5RZa/i3bU/WntNa58KeIVMg+0NE
dJTUIciFyOeY5yD+6ixBazLYFK5btWpl1iCQ3VN97atwuNf6t2/flvyMWIP8
8UH3D2nytC/JF7HKMgOVOSjHJT+OS+hxMWNcuXIllZaWvpV+8L+1qdzcXFlX
2JXkYLajHlznQAdWDDbmEOQUu0PeS01NNfWJOrfai3Meq85BqHmxxshd0Ed7
9u0ly4okPumc0IrFyXka+Rt1FLDk5+f/x7ervacPdxzoNSCPylXy5xJavHSp
nFsxqH0hLodwLexEPcy/wdx67feufPjci/ND91kKepHQ0FDJxVlcQ/FTM2fo
TB32hXweHhkhuR3zQ3OOyM/e437xH0bP7m3fAKlOsGeBPgh+WlZeRjFcXyFO
QQc6f0Z+37htC4VGhNfyG3nOmAdwTH5WzyzJm/ZFhoqKuRax6kLqFJl5unLE
im+/IT/uEQON/QI8xxH1fdGKYlPP3sRhnR3h/Pr169SG+w4fltNu7AuIb7At
7fn7PpEPa542bqzLp4x9D+D1M+r7yz9eNnXtzThs3TfT+GvGJ2Odf967F1VU
VZJmnSvl5dSa8SK/KBbZx+HfZnMN+S5wqF2h9pY8yH7hbvvf/+mP8k51DffA
Na73S/+yQeoXa56ET0VxjaZ7t297/8OdsNeE+hV1uzMspNb69v1FP3rEPUSN
4OD6CeuMc76TPHxYLftyGL6kOvFkD2jVr8wUMIPHnMJY17/+bRc143oPvota
18mx1Ik9Js6LOB48eND0W1eOeC4Mwp6hAznUYZf8iHyKvhCzCOw3eNrfrTVV
5bMqwVDFNcTS4uXSI6FOtxn2ERQcbPakSxYvroVBcOg82vgeahO8qz0tGNdr
1qzxOA7U0joXB53452n6ddJnkhes+5aCw6ix0tPTa9WT7muiz3bt2iV9vfu8
Z/DgwR6Pwfp/MW/7esliijB6uQAjN1v3K7X+w/xXfVVlscZqvY/3unXrJr5l
nTOgJ8Ns3NM4JMZwfS11kyXGyF4rxxnpM/hZyohUmYGoDb0s5ijNmzfPNaNg
ewS/Dduy7iOkpaW54gtyG8uP2Sf0gDoDe/y5M76ip5UV+Me19lZexqDDhw+L
XensSnFgvuVJ21K/wJ6G7uUHMQbkYFzHxf+UStaXuuyojnV4FQ7YFuYkqDWB
QWvn2bNne9SuNF9jztEWdYexb4l9gd+NT6cfy/7livdGTG1oLgbpGsGGEHP1
2/Hx8XT+/HmPxyy1rcuXLtGCBQtoRkGB1Lgqz5t8V7+B2IXaBt+vC8P/qXHR
vwEsx0/M
          "], {{0, 53}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 53},
        PlotRange->{{0, 50}, {0, 53}}]}], ",", 
      RowBox[{"\"\<runaway\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWWlQVecZdtr+6N8kEuDu2zn3nnvPXYCqCBivoKkkQSy0DKYRt5CIUqGa
RnEZDXXSxopoFjEumDZpJbFgQUWcqp0qaatxQZPaqXZqANEgFU1YFfTp+34Y
p5mABQ0cnfGZOXCXj3Pe53u35/2wzsxJeeFbw4YNW/Bd+pEyY+G4+fNn5KV+
h97E572UOfPb9CLy1sUf4iEe4iEEbty4obUJuNHdjfN19bjafEVrU+4albt2
I+WpJIxQ/QiOisGaVavR0tKitVkDQtn2UjhMFhiHhyJK8cKhM8KmN2Laj6ei
o71Da/P6hcaLjYiOiILTaodfVuAy28TlcTihDwkVHB8EVO7cDdlkhUdywmOT
EHC64ZNccDtk4ZP583K1NrFf2F2xk+w1wetUEKmoUG0yvOQLl80Bh9GMvJde
1trEfqH58mXEjoyG4fEwRBAPjqmAywPZbIUpNBzlZX/Q2sR+44OS9yFb7LCE
6eGkGFPtMozEK2dONq5du6a1eQPCzvIKZKQ/i6QJE5H0ZCIKXluN1tY2rc1C
N/XVY8eO4+jRo6itrUVdXR3q6+vRcOECLl68iKamJrS1teHmTa0t7RtsX05W
tshfmeqpU3bCbrdD9Xjg8/owMjIKY2NikZ76I8yelYmVy1egsmIXOjvunxjq
6urGy7kLIBvM8FLtcVsdcNqp9tjscMkyrEYT1VQJil2inOjpFbLeDJ/DhR8m
TkLhrwpw5p9ntKaBn6/Ih0S5qpAfuC9HuFRE+gJQ3VSDyH6byQwnceL+wFy4
xjIHv536B+U616j4+Hg0NFzQjENZaanoyyr1MbvBhCkpaag5VoMTx2tQfaga
B/YfQFVlFVIn/QAWnQGq7IKHuVB9ChAXH3FhH5nNZmRlZVGtuj7kHPbuqYLq
UiDbyI5wHTKnz8Lly829rl22eKno1dzDFep3Hoo9H8Ug+0TsAflLkiQUbyke
Ug4fVn8In0eFRM836fWY/fyLuNJ8tde1zaTJJyZMgJV4cGx5iYtKekQxkaay
OKiPU8w5XZC4LlAsHjp0aEg4tLe3I/mZSTCQD8wGI5YuWYbWlr7rfhX7jTQI
x4/QhqSnAqQPI+iKdPb0cfark3LJQjXh6e8n9unXb5ZHG8YHxyHkkUeRm/NT
Ua/6wk1qFksWLYaddBPrdPYHa1wf5fqX+aFQrrsoZ1TyiULf26kuZM+e0+c9
m5ubcelS0z3zaG1txca3irD+zfX4+yen77j2iy9aMGZ0rKhTrAM5P5gH+4Nr
NNffVSt/gQ1vbYApTEfa0S3WsO+2bioWvm+he1TsKMfagjWY82IWYqJHIz8/
H3v37r1nLtevd+FS4yV0dHTecd3Bg9Wil/gUN7xcq8hG3y0ebsqP4MgYfH71
c7F2XUGh0LtO4sC5zz5KmvgUEim3eB/M4XoYw8JF7OXkzCPtcOyeefQXv3z1
NVgoh9ySLDh8GVdeynMp3IjFCxZ+df3KV2EOJb8wD8olrtGS0SJqnZV4eOlv
UyenoKioCI20j0MB9tWkp5NEvMtWG/ykzUW9otxwU07IBgve2fT1Ovv6mnWi
F/HloMtKvfUJmt/nZ+fi4J/+POR6uHJXpfAB57fKeUE8PLJTvHYSj4Bbxdkz
/+r1bwvXrMWoEdGYnjEDv333vSHb+96wrmAtDDRvc85Gqj7x2+9yC/s51p+h
+so53BdYw2utjTs7O5E2OVX0BsncM4tzbHNccQ9hXbyB6t39Dt7LsdGxwmbe
f7Y/QDOsk/QIv+eras+9183BBve/wtWF4hzHR72c6yZf7BfuIz7Klb9U/01r
M/uFrq4urKK661c8Ijc8t3S7yHn67MlgAg7/9cHgwjiwbz+CMXFCJ7IvWLvz
mQ/r3oDHizfWvU59+8E4Q2w4fwG52Tm346undnnEnMh6edbM52mWPz9k9tTW
1qG8vKLfs9ueXXvw/u9Kbr/f9t42REd8T+S9i3LeQbUswueHLjwccXFjcPjw
kcEy/TZOn/4HPSsOOp0OMTExWLZsOQ4f6fu5tZ/WYfyYscLmn8yeS+9rxefn
/v0pZk6dcXsesZNveIYyGo2QaJ6vqhrcOrZ9eymGPzYcfr8fJpMJoY9Tj6Pn
pqWloaxsx9fOnvJ+tlDMiQ6zRdgcHTlC9HhGJ2mWEvLTiECUmN8dDofgYrFY
EBsbi7Nne+/z3wSamv6DKWnpCCUuJr0BbspXnn2sZIeNbE0IxmP9G+vx0ZGP
8JtfvwuFNQjnM2lE/t5LNWr/H/d95Z6nak5h6rPPwULzueKi+9G+sL8XLcob
NB6M9rZ2bN1cjMRxE3rONM099ZRnVT7vYW0acHsh095KfNZDc56N5nd+vf2D
3/d6T54B5mXPg1GnJ+6kc4l/ZCASH3/8yaByYfDMsGXjZiSMCcJGmlTUUNpv
0fO4T9BsxzGnKAqsNiuWLFl6x/vxHDshYTys5DebxQoTaf1pGdNFDxoKXLly
Fe9s3ooo1S/mOaGjyAcOux1er4qQkBCkp0/pl9beR31Gov2QaO7icy8H+bGs
dMfgk/gf1NfVYWPRRsTRnGAIDYOR8sdgMCA5efKAZulXVuQLn3hofrRQ3iWS
Jm7T4Oz6s88aUUjzacZzGcjMfEH0m4GA4ys5KVnsA8emQWdA8Zatg2PsIKOm
5iTleYQ4HzbTLD56VDT13QatzborlGwrEfnOecLxtWL5K/fF//sHiu7ubszN
mgMdn48QDy/pyZMnT2lt1l2B60PwiSAee+RRcXb59tubtDbprnHi+AnqI9PI
N3Nx7lxtr2tuaj3EP8T/xX8Bd1txeg==
          "], {{0, 50}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<loitering\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWglw1fURdkryEnIBCTle3n3fLy8XRwLGJMSihWJFORyq3F5xoCEihzIC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          "], {{0, 50}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<sex offenses, non forcible\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWnlQldcVd9rOtJ3pP05E2d6+L8ADZNEUxeKKBkUQcEXcjUaNC4qBosGa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          "], {{0, 50}, {50, 0}}, {0,
           255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 50},
        PlotRange->{{0, 50}, {0, 50}}]}], ",", 
      RowBox[{"\"\<suicide\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztlwtQVOcVx50+rASsVlFx2V32dfdx9/1mYVHAkBAnGkUNYpNMcQw+ghXf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          "], {{0, 50}, {54, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{54, 50},
        PlotRange->{{0, 54}, {0, 50}}]}], ",", 
      RowBox[{"\"\<stolen property\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWwdUVFcaZugirgK2VWOS3WQlWTXRXXV1RYU9WRUkdI0KKqjYa9Q9Jm4S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          "], {{0, 60}, {74, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{74, 60},
        PlotRange->{{0, 74}, {0, 60}}]}], ",", 
      RowBox[{"\"\<bad checks\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztmedPlWcYxk3bD/0LGtuaYEWUddh7KWBkCChUERSRVdRqBRkCdQTHB0fc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          "], {{0, 53}, {50, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 53},
        PlotRange->{{0, 50}, {0, 53}}]}], ",", 
      RowBox[{"\"\<extortion\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztmHtQlFUUwHeXfa8bj1WEAmEFmZFEBCXxEe8CxDR5DQohoAipgGMggihK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          "], {{0, 50}, {35, 0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{35, 50},
        PlotRange->{{0, 35}, {0, 50}}]}], ",", 
      RowBox[{"\"\<bribery\>\"", "\[Rule]", 
       GraphicsBox[
        TagBox[RasterBox[CompressedData["
1:eJztWgdQVVcapr9HU6QKmAQsiAVsiCW6syKxZWfVrEGxQGwkCIKCa1bXbDS2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          "], {{0, 64}, {50, 
          0}}, {0, 255},
          ColorFunction->RGBColor],
         BoxForm`ImageTag["Byte", ColorSpace -> "RGB", Interleaving -> True],
         Selectable->False],
        BaseStyle->"ImageGraphics",
        ImageSize->Automatic,
        ImageSizeRaw->{50, 64},
        PlotRange->{{0, 50}, {0, 64}}]}]}], "}"}]}], ";"}]}]], "Input",
 InitializationCell->True,
 CellChangeTimes->{{3.6082894811821947`*^9, 3.6082894877890167`*^9}, 
   3.608310290576894*^9}]
},
WindowSize->{1934, 1396},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
FrontEndVersion->"9.0 for Mac OS X x86 (32-bit, 64-bit Kernel) (January 25, \
2013)",
StyleDefinitions->"Default.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[579, 22, 12007, 294, 454, "Input"],
Cell[12589, 318, 6700, 114, 248, "Output"]
}, Open  ]],
Cell[19304, 435, 5437, 104, 182, "Input"],
Cell[24744, 541, 6950, 143, 267, "Input"],
Cell[CellGroupData[{
Cell[31719, 688, 6395, 109, 97, "Input"],
Cell[38117, 799, 2710345, 47569, 751, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2748499, 48373, 5814, 145, 267, "Input"],
Cell[2754316, 48520, 65537, 1324, 257, "Output"]
}, Open  ]],
Cell[2819868, 49847, 199, 3, 97, "Input"],
Cell[2820070, 49852, 127211, 2243, 442, "Input",
 InitializationCell->True]
}
]
*)

(* End of internal cache information *)
